@@ -6,32 +6,19 @@
 start=$(date +%s)
 
 # Download all translations from transifex.com.
-cd ../share/translations
-RESOURCES=`find . -regextype sed -regex ".*/measurements_p[0-9]\{1,2\}\.ts"`
-cd ../../scripts
 
 # Empty means unstable branch
-MEASUREMENTS_BRANCH='' # For example _05x
 VALENTINA_BRANCH=''    # for example 05x
 
-NUMBER=( $RESOURCES )
-NUMBER=${#NUMBER[@]}
+LANGUAGES="uk,de_DE,cs,he_IL,fr_FR,it_IT,nl,id,es,fi,ro_RO,zh_CN,pt_BR,el_GR,pl_PL"
 
 # Certant languages like he_IL and zh_CN are not supported by math parser
-for ((i=0;i<NUMBER;i++)); do
-  tx pull -r valentina-project.measurements_p${i}${MEASUREMENTS_BRANCH}ts --mode=developer -f --skip -l "uk,de_DE,cs,he_IL,fr_FR,it_IT,nl,id,es,fi,en_US,en_CA,en_IN,ro_RO,zh_CN,pt_BR,el_GR,pl_PL" &
-  sleep 1
-done
-
-tx pull -r valentina-project.valentina_${VALENTINA_BRANCH}ts --mode=developer -f --skip &
-sleep 1
-tx pull -r valentina-project.measurements_p998${MEASUREMENTS_BRANCH}ts --mode=developer -f --skip -l "uk,de_DE,cs,he_IL,fr_FR,it_IT,nl,id,es,fi,en_US,en_CA,en_IN,ro_RO,zh_CN,pt_BR,el_GR,pl_PL" &
+tx pull -r valentina-project.valentina_${VALENTINA_BRANCH}ts --mode=default -f --skip -l "${LANGUAGES}" &
 
 wait
 
 # Update local strings
 lupdate -recursive ../share/translations/translations.pro
-lupdate -recursive ../share/translations/measurements.pro
 #clean stale QM files
 rm -f -v ../share/translations/*.qm
 # force to run qmake
