@@ -27,21 +27,24 @@
  *************************************************************************/
 #include "vpcarrousel.h"
 #include "ui_vpcarrousel.h"
-#include <QVBoxLayout>
+#include <QFontMetrics>
 #include <QMessageBox>
 #include <QScrollBar>
-#include <QFontMetrics>
+#include <QVBoxLayout>
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
-#include "../vmisc/backport/qoverload.h"
-#endif // QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
-#include "../layout/vpsheet.h"
 #include "../layout/vplayout.h"
+#include "../layout/vpsheet.h"
 
 #include <QLoggingCategory>
 #include <QMenu>
 #include <QPainter>
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
+#include "../vmisc/compatibility.h"
+#endif
+
+using namespace Qt::Literals::StringLiterals;
+
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_CLANG("-Wmissing-prototypes")
 QT_WARNING_DISABLE_INTEL(1418)
@@ -51,9 +54,9 @@ Q_LOGGING_CATEGORY(pCarrousel, "p.carrousel") // NOLINT
 QT_WARNING_POP
 
 //---------------------------------------------------------------------------------------------------------------------
-VPCarrousel::VPCarrousel(const VPLayoutPtr &layout, QWidget *parent) :
-    QWidget(parent),
-    ui(new Ui::VPCarrousel),
+VPCarrousel::VPCarrousel(const VPLayoutPtr &layout, QWidget *parent)
+  : QWidget(parent),
+    ui(std::make_unique<Ui::VPCarrousel>()),
     m_layout(layout)
 {
     SCASSERT(not layout.isNull())
@@ -71,6 +74,8 @@ VPCarrousel::VPCarrousel(const VPLayoutPtr &layout, QWidget *parent) :
     Refresh();
 }
 
+VPCarrousel::~VPCarrousel() = default;
+
 //---------------------------------------------------------------------------------------------------------------------
 void VPCarrousel::Refresh()
 {
@@ -85,8 +90,7 @@ void VPCarrousel::Refresh()
     // Do not rely on m_layout because we do not control it.
     m_pieceLists = QList<VPCarrouselSheet>();
 
-    VPLayoutPtr layout = m_layout.toStrongRef();
-    if (not layout.isNull())
+    if (VPLayoutPtr const layout = m_layout.toStrongRef(); not layout.isNull())
     {
         {
             VPCarrouselSheet carrouselSheet;
@@ -98,7 +102,7 @@ void VPCarrousel::Refresh()
             m_pieceLists.append(carrouselSheet);
         }
 
-        QList<VPSheetPtr> sheets = layout->GetSheets();
+        QList<VPSheetPtr> const sheets = layout->GetSheets();
         for (const auto &sheet : sheets)
         {
             if (not sheet.isNull())
@@ -116,7 +120,7 @@ void VPCarrousel::Refresh()
 
         ui->comboBoxPieceList->blockSignals(true);
 
-        for (const auto& sheet: qAsConst(m_pieceLists))
+        for (const auto &sheet : qAsConst(m_pieceLists))
         {
             ui->comboBoxPieceList->addItem(GetSheetName(sheet), sheet.sheetUuid);
         }
@@ -128,7 +132,7 @@ void VPCarrousel::Refresh()
     ui->comboBoxPieceList->setCurrentIndex(-1);
     ui->comboBoxPieceList->blockSignals(false);
 
-    int index = ui->comboBoxPieceList->findData(sheetUuid);
+    int const index = ui->comboBoxPieceList->findData(sheetUuid);
     ui->comboBoxPieceList->setCurrentIndex(index != -1 ? index : 0);
 
     RefreshOrientation();
@@ -139,7 +143,7 @@ void VPCarrousel::on_ActiveSheetChanged(const VPSheetPtr &sheet)
 {
     if (not sheet.isNull())
     {
-        int index = ui->comboBoxPieceList->findData(sheet->Uuid());
+        int const index = ui->comboBoxPieceList->findData(sheet->Uuid());
         if (index != -1)
         {
             ui->comboBoxPieceList->setCurrentIndex(index);
@@ -154,17 +158,17 @@ void VPCarrousel::on_ActiveSheetChanged(const VPSheetPtr &sheet)
 //---------------------------------------------------------------------------------------------------------------------
 void VPCarrousel::RefreshSheetNames()
 {
-    VPLayoutPtr layout = m_layout.toStrongRef();
+    VPLayoutPtr const layout = m_layout.toStrongRef();
     if (layout.isNull())
     {
         return;
     }
 
-    for (int i=0; i < m_pieceLists.size(); ++i)
+    for (int i = 0; i < m_pieceLists.size(); ++i)
     {
         if (not m_pieceLists.at(i).unplaced)
         {
-            VPSheetPtr sheet = layout->GetSheet(m_pieceLists.at(i).sheetUuid);
+            VPSheetPtr const sheet = layout->GetSheet(m_pieceLists.at(i).sheetUuid);
             if (not sheet.isNull())
             {
                 m_pieceLists[i].name = sheet->GetName();
@@ -194,7 +198,7 @@ void VPCarrousel::on_ActivePieceListChanged(int index)
 {
     qCDebug(pCarrousel, "index changed %i", index);
 
-    VPLayoutPtr layout = m_layout.toStrongRef();
+    VPLayoutPtr const layout = m_layout.toStrongRef();
     if (layout.isNull())
     {
         return;
@@ -206,13 +210,12 @@ void VPCarrousel::on_ActivePieceListChanged(int index)
 
         if (index > 0)
         {
-            QUuid sheetUuid = ui->comboBoxPieceList->currentData().toUuid();
-            VPSheetPtr sheet = layout->GetSheet(sheetUuid);
+            QUuid const sheetUuid = ui->comboBoxPieceList->currentData().toUuid();
+            VPSheetPtr const sheet = layout->GetSheet(sheetUuid);
 
             if (not sheet.isNull())
             {
-                VPSheetPtr activeSheet = layout->GetFocusedSheet();
-                if (not activeSheet.isNull())
+                if (VPSheetPtr const activeSheet = layout->GetFocusedSheet(); not activeSheet.isNull())
                 {
                     activeSheet->ClearSelection();
                 }
@@ -247,11 +250,17 @@ void VPCarrousel::SetOrientation(Qt::Orientation orientation)
     RefreshOrientation();
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void VPCarrousel::RefreshPieceMiniature()
+{
+    ui->listWidget->Refresh();
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void VPCarrousel::RefreshOrientation()
 {
     // then update the scrollarea min height / width and scrollbar behaviour
-    if(m_orientation == Qt::Horizontal)
+    if (m_orientation == Qt::Horizontal)
     {
         ui->comboBoxPieceList->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
 
@@ -302,5 +311,5 @@ auto VPCarrousel::GetSheetName(const VPCarrouselSheet &sheet) -> QString
         return QStringLiteral("--> %1 %2 <--").arg(tr("Pieces of"), sheet.name);
     }
 
-    return tr("Pieces of") + ' ' + sheet.name;
+    return tr("Pieces of") + ' '_L1 + sheet.name;
 }
