@@ -32,7 +32,9 @@
 #include <QMenu>
 #include <QPainter>
 
+#include "../layout/vplayout.h"
 #include "../layout/vppiece.h"
+#include "../vmisc/theme/vscenestylesheet.h"
 
 #include <QLoggingCategory>
 
@@ -44,18 +46,17 @@ Q_LOGGING_CATEGORY(pCarrouselPiece, "p.carrouselPiece") // NOLINT
 
 QT_WARNING_POP
 
-
 //---------------------------------------------------------------------------------------------------------------------
-VPCarrouselPiece::VPCarrouselPiece(const VPPiecePtr &piece, QListWidget* parent) :
-    QListWidgetItem(parent, Type),
+VPCarrouselPiece::VPCarrouselPiece(const VPPiecePtr &piece, QListWidget *parent)
+  : QListWidgetItem(parent, Type),
     m_piece(piece)
 {
     SCASSERT(m_piece != nullptr)
-    int width = 120 - 8;
-    QFontMetrics metrix = QFontMetrics(QFont());
-    QString clippedText = metrix.elidedText(piece->GetName(), Qt::ElideRight, width);
-    setIcon(CreatePieceIcon(QSize(120, 120)));
+    const int width = 120 - 8;
+    QString const clippedText = QFontMetrics(font()).elidedText(piece->GetName(), Qt::ElideRight, width);
+    RefreshPieceIcon();
     setText(clippedText);
+    setToolTip(piece->GetName());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -67,89 +68,89 @@ auto VPCarrouselPiece::GetPiece() const -> VPPiecePtr
 //---------------------------------------------------------------------------------------------------------------------
 void VPCarrouselPiece::RefreshSelection()
 {
-    VPPiecePtr piece = GetPiece();
+    VPPiecePtr const piece = GetPiece();
     if (not piece.isNull())
     {
         setSelected(piece->IsSelected());
     }
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void VPCarrouselPiece::RefreshPieceIcon()
+{
+    setIcon(CreatePieceIcon(QSize(120, 120)));
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 auto VPCarrouselPiece::CreatePieceIcon(const QSize &size, bool isDragIcon) const -> QIcon
 {
-    VPPiecePtr piece = GetPiece();
+    VPPiecePtr const piece = GetPiece();
     if (piece.isNull())
     {
         return {};
     }
 
-    QRectF boundingRect = piece->DetailBoundingRect();
-    qreal canvasSize = qMax(boundingRect.height(), boundingRect.width());
-    QRectF canvas = QRectF(0, 0, canvasSize, canvasSize);
+    QRectF const boundingRect = piece->DetailBoundingRect();
+    qreal const canvasSize = qMax(boundingRect.height(), boundingRect.width());
+    auto const canvas = QRectF(0, 0, canvasSize, canvasSize);
 
-    qreal dx = canvas.center().x() - boundingRect.center().x();
-    qreal dy = canvas.center().y() - boundingRect.center().y();
+    qreal const dx = canvas.center().x() - boundingRect.center().x();
+    qreal const dy = canvas.center().y() - boundingRect.center().y();
 
     QVector<QIcon::Mode> iconModes;
     iconModes.append(QIcon::Normal);
 
-    if(not isDragIcon)
+    if (not isDragIcon)
     {
         iconModes.append(QIcon::Selected);
     }
 
     QIcon icon;
 
-    for(auto iconMode : iconModes)
+    const VManualLayoutStyle &style = VSceneStylesheet::ManualLayoutStyle();
+
+    for (auto iconMode : iconModes)
     {
         QPixmap pixmap(size);
-
-        if(not isDragIcon)
-        {
-            pixmap.fill(QColor(Qt::white));
-        }
-        else
-        {
-            pixmap.fill(QColor(Qt::transparent));
-        }
+        pixmap.fill(not isDragIcon ? style.CarrouselPieceBackgroundColor() : QColor(Qt::transparent));
 
         QPainter painter;
         painter.begin(&pixmap);
         painter.setRenderHint(QPainter::Antialiasing);
         painter.setRenderHint(QPainter::SmoothPixmapTransform);
 
-        int spacing = 2;
+        int const spacing = 2;
 
         painter.translate(spacing, spacing);
 
-        qreal scaleFactorX = canvasSize * 100 / (size.width() - spacing*2) / 100;
-        qreal scaleFactorY = canvasSize * 100 / (size.height() - spacing*2) / 100;
-        painter.scale(1./scaleFactorX, 1./scaleFactorY);
-        painter.setPen(QPen(Qt::black, 0.8*qMax(scaleFactorX, scaleFactorY)));
+        qreal const scaleFactorX = canvasSize * 100 / (size.width() - spacing * 2) / 100;
+        qreal const scaleFactorY = canvasSize * 100 / (size.height() - spacing * 2) / 100;
+        painter.scale(1. / scaleFactorX, 1. / scaleFactorY);
+        painter.setPen(QPen(style.CarrouselPieceColor(), 0.8 * qMax(scaleFactorX, scaleFactorY)));
 
-        if(not isDragIcon)
+        if (not isDragIcon)
         {
             painter.translate(dx, dy);
         }
         else
         {
-            painter.translate(-boundingRect.topLeft().x()+spacing, -boundingRect.topLeft().y()+spacing);
+            painter.translate(-boundingRect.topLeft().x() + spacing, -boundingRect.topLeft().y() + spacing);
         }
 
-        if(iconMode == QIcon::Selected)
+        painter.setBrush(QBrush(iconMode == QIcon::Selected ? style.CarrouselPieceSelectedColor()
+                                                            : style.CarrouselPieceForegroundColor()));
+
+        bool togetherWithNotches = false;
+        if (VPLayoutPtr const pieceLayout = piece->Layout(); not pieceLayout.isNull())
         {
-            painter.setBrush(QBrush(QColor(255,160,160,60)));
-        }
-        else
-        {
-            painter.setBrush(QBrush(Qt::white));
+            togetherWithNotches = pieceLayout->LayoutSettings().IsBoundaryTogetherWithNotches();
         }
 
-        piece->DrawMiniature(painter);
+        piece->DrawMiniature(painter, togetherWithNotches);
 
         painter.end();
 
-        icon.addPixmap(pixmap,iconMode);
+        icon.addPixmap(pixmap, iconMode);
     }
 
     return icon;
