@@ -27,24 +27,21 @@
  *************************************************************************/
 #include "vpcarrouselpiecelist.h"
 
+#include <QApplication>
 #include <QDrag>
 #include <QDragMoveEvent>
-#include <QPainter>
-#include <QApplication>
+#include <QLoggingCategory>
 #include <QMenu>
+#include <QPainter>
 
+#include "../layout/vplayout.h"
+#include "../layout/vppiece.h"
+#include "../layout/vpsheet.h"
+#include "../undocommands/vpundomovepieceonsheet.h"
+#include "../vmisc/theme/vtheme.h"
 #include "vpcarrousel.h"
 #include "vpcarrouselpiece.h"
-#if QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
-#include "../vmisc/backport/qoverload.h"
-#endif // QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
 #include "vpmimedatapiece.h"
-#include "../layout/vpsheet.h"
-#include "../layout/vplayout.h"
-#include "../undocommands/vpundomovepieceonsheet.h"
-#include "../layout/vppiece.h"
-
-#include <QLoggingCategory>
 
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_CLANG("-Wmissing-prototypes")
@@ -55,14 +52,29 @@ Q_LOGGING_CATEGORY(pCarrouselPieceList, "p.carrouselPieceList") // NOLINT
 QT_WARNING_POP
 
 //---------------------------------------------------------------------------------------------------------------------
-VPCarrouselPieceList::VPCarrouselPieceList(QWidget* parent) :
-    QListWidget(parent)
+VPCarrouselPieceList::VPCarrouselPieceList(QWidget *parent)
+  : QListWidget(parent)
 {
-    setStyleSheet("QListWidget::item{border: 2px solid transparent; color: black;}  "
-                  "QListWidget::item:selected {border: 2px solid rgb(255,160,160);}");
+    InitStyleSheet();
     setContextMenuPolicy(Qt::DefaultContextMenu);
     setSelectionMode(QAbstractItemView::MultiSelection);
     setViewMode(QListView::IconMode);
+
+    // Because we cannot control icon color with stylesheet we must wait until scene style update. It happens after
+    // the palette change signal.
+    connect(VTheme::Instance(), &VTheme::ThemeSettingsChanged, this,
+            [this]()
+            {
+                for (int i = 0; i < count(); ++i)
+                {
+                    if (auto *pieceItem = dynamic_cast<VPCarrouselPiece *>(item(i)))
+                    {
+                        pieceItem->RefreshPieceIcon();
+                    }
+                }
+
+                InitStyleSheet();
+            });
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -76,20 +88,22 @@ void VPCarrouselPieceList::Refresh()
 {
     clear();
 
-    if(not m_pieceList.isEmpty())
+    if (m_pieceList.isEmpty())
     {
-        // create the corresponding carrousel pieces
-        for (const auto &piece : qAsConst(m_pieceList)) // NOLINT(clang-analyzer-cplusplus.NewDeleteLeaks)
-        {
-            if (not piece.isNull())
-            {
-                // update the label of the piece
-                auto* carrouselpiece = new VPCarrouselPiece(piece, this);
-                carrouselpiece->setSelected(piece->IsSelected());
-            }
-        }
-        sortItems();
+        return;
     }
+
+    // create the corresponding carrousel pieces
+    for (const auto &piece : qAsConst(m_pieceList)) // NOLINT(clang-analyzer-cplusplus.NewDeleteLeaks)
+    {
+        if (not piece.isNull())
+        {
+            // update the label of the piece
+            auto *carrouselpiece = new VPCarrouselPiece(piece, this);
+            carrouselpiece->setSelected(piece->IsSelected());
+        }
+    }
+    sortItems();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -111,8 +125,8 @@ void VPCarrouselPieceList::mousePressEvent(QMouseEvent *event)
     if (!(event->modifiers() & Qt::ControlModifier))
     {
         // clearSelection doesn't work properly here so we go through the elements.
-        const QList<QListWidgetItem*> items = selectedItems();
-        for(auto *item: items)
+        const QList<QListWidgetItem *> items = selectedItems();
+        for (auto *item : items)
         {
             item->setSelected(false);
         }
@@ -126,8 +140,8 @@ void VPCarrouselPieceList::mouseMoveEvent(QMouseEvent *event)
 {
     if (((event->buttons() & Qt::LeftButton) != 0U) &&
         ((event->pos() - m_dragStart).manhattanLength() >= QApplication::startDragDistance()) &&
-        (selectedItems().count() > 0) &&
-        (not m_pieceList.isEmpty() && ConstFirst(m_pieceList)->Sheet() == nullptr)) // only if it's from unplaced pieces
+        (!selectedItems().isEmpty()) &&
+        (!m_pieceList.isEmpty() && m_pieceList.constFirst()->Sheet() == nullptr)) // only if it's from unplaced pieces
     {
         startDrag(Qt::MoveAction);
     }
@@ -142,10 +156,10 @@ void VPCarrouselPieceList::startDrag(Qt::DropActions supportedActions)
 {
     Q_UNUSED(supportedActions)
 
-    QListWidgetItem* _item = currentItem();
-    if(_item->type() == VPCarrouselPiece::Type)
+    QListWidgetItem *_item = currentItem();
+    if (_item->type() == VPCarrouselPiece::Type)
     {
-        auto *pieceItem = dynamic_cast<VPCarrouselPiece *> (_item);
+        auto *pieceItem = dynamic_cast<VPCarrouselPiece *>(_item);
         SCASSERT(pieceItem != nullptr)
 
         if (m_carrousel == nullptr)
@@ -153,7 +167,7 @@ void VPCarrouselPieceList::startDrag(Qt::DropActions supportedActions)
             return;
         }
 
-        VPLayoutPtr layout = m_carrousel->Layout().toStrongRef();
+        VPLayoutPtr const layout = m_carrousel->Layout().toStrongRef();
         if (layout.isNull())
         {
             return;
@@ -162,19 +176,24 @@ void VPCarrouselPieceList::startDrag(Qt::DropActions supportedActions)
         // starts the dragging
         auto *drag = new QDrag(this);
         auto *mimeData = new VPMimeDataPiece(layout->Uuid());
-        VPPiecePtr piece = pieceItem->GetPiece();
+        VPPiecePtr const piece = pieceItem->GetPiece();
         mimeData->SetPiecePtr(piece);
 
-        QPixmap pixmap = pieceItem->CreatePieceIcon(QSize(120, 120), true).pixmap(QSize(120, 120));
+        QIcon const pieceIcon = pieceItem->CreatePieceIcon(QSize(120, 120), true);
+        QPixmap const pixmap;
+        if (!pieceIcon.isNull())
+        {
+            pieceIcon.pixmap(QSize(120, 120));
+        }
 
         drag->setDragCursor(VPMimeDataPiece::DragCursor(pixmap), Qt::MoveAction);
         drag->setMimeData(mimeData);
-        if(drag->exec() == Qt::MoveAction)
+        if (drag->exec() == Qt::MoveAction)
         {
             m_carrousel->Refresh();
             piece->SetSelected(false);
 
-            VPLayoutPtr pieceLayout = piece->Layout();
+            VPLayoutPtr const pieceLayout = piece->Layout();
             if (not pieceLayout.isNull())
             {
                 emit pieceLayout->PieceSelectionChanged(piece);
@@ -184,7 +203,7 @@ void VPCarrouselPieceList::startDrag(Qt::DropActions supportedActions)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VPCarrouselPieceList::dragMoveEvent(QDragMoveEvent* e)
+void VPCarrouselPieceList::dragMoveEvent(QDragMoveEvent *e)
 {
     qCDebug(pCarrouselPieceList, "drag move");
     e->acceptProposedAction();
@@ -193,17 +212,17 @@ void VPCarrouselPieceList::dragMoveEvent(QDragMoveEvent* e)
 //---------------------------------------------------------------------------------------------------------------------
 void VPCarrouselPieceList::contextMenuEvent(QContextMenuEvent *event)
 {
-    QListWidgetItem* _item = currentItem();
-    if(_item == nullptr || _item->type() != VPCarrouselPiece::Type)
+    QListWidgetItem *_item = currentItem();
+    if (_item == nullptr || _item->type() != VPCarrouselPiece::Type)
     {
         return;
     }
 
-    auto *pieceItem = dynamic_cast<VPCarrouselPiece *> (_item);
+    auto *pieceItem = dynamic_cast<VPCarrouselPiece *>(_item);
     SCASSERT(pieceItem != nullptr)
 
-    VPPiecePtr piece = pieceItem->GetPiece();
-    VPLayoutPtr layout = piece->Layout();
+    VPPiecePtr const piece = pieceItem->GetPiece();
+    VPLayoutPtr const layout = piece->Layout();
 
     if (piece.isNull() || layout.isNull())
     {
@@ -212,7 +231,7 @@ void VPCarrouselPieceList::contextMenuEvent(QContextMenuEvent *event)
 
     QMenu menu;
 
-    QVector<QAction*> moveToActions;
+    QVector<QAction *> moveToActions;
 
     if (not piece->Sheet().isNull())
     {
@@ -227,7 +246,7 @@ void VPCarrouselPieceList::contextMenuEvent(QContextMenuEvent *event)
             {
                 if (not sheet.isNull())
                 {
-                    QAction* moveToSheet = moveMenu->addAction(sheet->GetName());
+                    QAction *moveToSheet = moveMenu->addAction(sheet->GetName());
                     moveToSheet->setData(QVariant::fromValue(sheet));
                     moveToActions.append(moveToSheet);
                 }
@@ -244,13 +263,13 @@ void VPCarrouselPieceList::contextMenuEvent(QContextMenuEvent *event)
     QAction *removeAction = menu.addAction(tr("Remove from Sheet"));
     removeAction->setVisible(false);
 
-    if(not m_pieceList.isEmpty() && ConstFirst(m_pieceList)->Sheet() == nullptr)
+    if (not m_pieceList.isEmpty() && m_pieceList.constFirst()->Sheet() == nullptr)
     {
         moveAction->setVisible(true);
         deleteAction->setVisible(true);
     }
 
-    if(not m_pieceList.isEmpty() && ConstFirst(m_pieceList)->Sheet() != nullptr)
+    if (not m_pieceList.isEmpty() && m_pieceList.constFirst()->Sheet() != nullptr)
     {
         removeAction->setVisible(true);
     }
@@ -259,11 +278,11 @@ void VPCarrouselPieceList::contextMenuEvent(QContextMenuEvent *event)
 
     if (selectedAction == moveAction)
     {
-        VPSheetPtr sheet = layout->GetFocusedSheet();
+        VPSheetPtr const sheet = layout->GetFocusedSheet();
         if (not sheet.isNull())
         {
             piece->ClearTransformations();
-            QRectF rect = sheet->GetMarginsRect();
+            QRectF const rect = sheet->GetMarginsRect();
             piece->SetPosition(QPointF(rect.topLeft().x() + 1, rect.topLeft().y() + 1));
             piece->SetZValue(1.0);
             auto *command = new VPUndoMovePieceOnSheet(layout->GetFocusedSheet(), piece);
@@ -287,16 +306,31 @@ void VPCarrouselPieceList::contextMenuEvent(QContextMenuEvent *event)
     }
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void VPCarrouselPieceList::InitStyleSheet()
+{
+    if (VTheme::ColorSheme() == VColorSheme::Dark)
+    {
+        setStyleSheet("QListWidget::item{border: 2px solid transparent;}"
+                      "QListWidget::item:selected {border: 2px solid rgb(255,160,160);}");
+    }
+    else
+    {
+        setStyleSheet("QListWidget::item{border: 2px solid transparent; color: black;}  "
+                      "QListWidget::item:selected {border: 2px solid rgb(255,160,160);}");
+    }
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void VPCarrouselPieceList::on_SelectionChangedExternal()
 {
     blockSignals(true);
-    for(int i = 0; i < count(); ++i)
+    for (int i = 0; i < count(); ++i)
     {
-        QListWidgetItem* _item = item(i);
-        if(_item->type() == VPCarrouselPiece::Type)
+        QListWidgetItem *_item = item(i);
+        if (_item->type() == VPCarrouselPiece::Type)
         {
-            auto *itemPiece = dynamic_cast<VPCarrouselPiece *> (_item);
+            auto *itemPiece = dynamic_cast<VPCarrouselPiece *>(_item);
             SCASSERT(itemPiece != nullptr)
             itemPiece->RefreshSelection();
         }
