@@ -33,12 +33,14 @@
 
 #include "../layout/vppiece.h"
 
-const QString VPMimeDataPiece::mineFormatPiecePtr = QStringLiteral("application/vnd.puzzle.piece.ptr"); // NOLINT(cert-err58-cpp)
+const QString VPMimeDataPiece::mineFormatPiecePtr =
+    QStringLiteral("application/vnd.puzzle.piece.ptr"); // NOLINT(cert-err58-cpp)
 
 //---------------------------------------------------------------------------------------------------------------------
 VPMimeDataPiece::VPMimeDataPiece(const QUuid &layoutUuid)
-    :m_layoutUuid(layoutUuid)
-{}
+  : m_layoutUuid(layoutUuid)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
 auto VPMimeDataPiece::formats() const -> QStringList
@@ -61,14 +63,22 @@ void VPMimeDataPiece::SetPiecePtr(const VPPiecePtr &piece)
 //---------------------------------------------------------------------------------------------------------------------
 auto VPMimeDataPiece::DragCursor(const QPixmap &piecePixmap) -> QPixmap
 {
-    QPixmap dragCursor(piecePixmap.width()*2, piecePixmap.height()*2);
-    dragCursor.fill(Qt::transparent);
-    QPainter painter(&dragCursor);
-    painter.drawPixmap(dragCursor.width()/2, dragCursor.height()/2, piecePixmap);
-    QPixmap cursor(QStringLiteral("://cursor/collect.png"));
-    painter.drawPixmap(dragCursor.width()/2 - cursor.width()/2, dragCursor.height()/2 - cursor.height()/2, cursor);
-    painter.end();
-    return dragCursor;
+    QPixmap cursor(QStringLiteral("://puzzlecursor/collect.png"));
+
+    if (!piecePixmap.isNull())
+    {
+        QPixmap dragCursor(piecePixmap.width() * 2, piecePixmap.height() * 2);
+        dragCursor.fill(Qt::transparent);
+        QPainter painter(&dragCursor);
+        painter.drawPixmap(dragCursor.width() / 2, dragCursor.height() / 2, piecePixmap);
+
+        painter.drawPixmap(dragCursor.width() / 2 - cursor.width() / 2, dragCursor.height() / 2 - cursor.height() / 2,
+                           cursor);
+        painter.end();
+        return dragCursor;
+    }
+
+    return cursor;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
