@@ -26,16 +26,13 @@
  **
  *************************************************************************/
 #include "puzzlepreferenceslayoutpage.h"
+#include "../../vpapplication.h"
 #include "ui_puzzlepreferenceslayoutpage.h"
-#include "vpapplication.h"
-#if QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
-#include "../vmisc/backport/qoverload.h"
-#endif // QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
 
 //---------------------------------------------------------------------------------------------------------------------
-PuzzlePreferencesLayoutPage::PuzzlePreferencesLayoutPage(QWidget *parent) :
-    QWidget(parent),
-    ui(new Ui::PuzzlePreferencesLayoutPage)
+PuzzlePreferencesLayoutPage::PuzzlePreferencesLayoutPage(QWidget *parent)
+  : QWidget(parent),
+    ui(std::make_unique<Ui::PuzzlePreferencesLayoutPage>())
 {
     ui->setupUi(this);
 
@@ -49,47 +46,48 @@ PuzzlePreferencesLayoutPage::PuzzlePreferencesLayoutPage(QWidget *parent) :
 
     ReadSettings();
 
-    connect(ui->comboBoxLayoutUnit, QOverload<int>::of(&QComboBox::currentIndexChanged),
-            this, &PuzzlePreferencesLayoutPage::ConvertPaperSize);
+    connect(ui->comboBoxLayoutUnit, QOverload<int>::of(&QComboBox::currentIndexChanged), this,
+            &PuzzlePreferencesLayoutPage::ConvertPaperSize);
 
-    connect(ui->comboBoxSheetTemplates, QOverload<int>::of(&QComboBox::currentIndexChanged),
-            this, [this]
-    {
-        SheetSize(SheetTemplate()); m_settingsChanged = true;
-    });
-    connect(ui->comboBoxTileTemplates, QOverload<int>::of(&QComboBox::currentIndexChanged),
-            this, [this]
-    {
-        TileSize(TileTemplate());
-        m_settingsChanged = true;
-    });
+    connect(ui->comboBoxSheetTemplates, QOverload<int>::of(&QComboBox::currentIndexChanged), this,
+            [this]
+            {
+                SheetSize(SheetTemplate());
+                m_settingsChanged = true;
+            });
+    connect(ui->comboBoxTileTemplates, QOverload<int>::of(&QComboBox::currentIndexChanged), this,
+            [this]
+            {
+                TileSize(TileTemplate());
+                m_settingsChanged = true;
+            });
 
-    connect(ui->doubleSpinBoxSheetPaperWidth, QOverload<double>::of(&QDoubleSpinBox::valueChanged),
-            this, &PuzzlePreferencesLayoutPage::SheetPaperSizeChanged);
-    connect(ui->doubleSpinBoxSheetPaperHeight, QOverload<double>::of(&QDoubleSpinBox::valueChanged),
-            this, &PuzzlePreferencesLayoutPage::SheetPaperSizeChanged);
-    connect(ui->doubleSpinBoxTilePaperWidth, QOverload<double>::of(&QDoubleSpinBox::valueChanged),
-            this, &PuzzlePreferencesLayoutPage::TilePaperSizeChanged);
-    connect(ui->doubleSpinBoxTilePaperHeight, QOverload<double>::of(&QDoubleSpinBox::valueChanged),
-            this, &PuzzlePreferencesLayoutPage::TilePaperSizeChanged);
+    connect(ui->doubleSpinBoxSheetPaperWidth, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this,
+            &PuzzlePreferencesLayoutPage::SheetPaperSizeChanged);
+    connect(ui->doubleSpinBoxSheetPaperHeight, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this,
+            &PuzzlePreferencesLayoutPage::SheetPaperSizeChanged);
+    connect(ui->doubleSpinBoxTilePaperWidth, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this,
+            &PuzzlePreferencesLayoutPage::TilePaperSizeChanged);
+    connect(ui->doubleSpinBoxTilePaperHeight, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this,
+            &PuzzlePreferencesLayoutPage::TilePaperSizeChanged);
 
-    connect(ui->doubleSpinBoxSheetPaperWidth, QOverload<double>::of(&QDoubleSpinBox::valueChanged),
-            this, &PuzzlePreferencesLayoutPage::FindSheetTemplate);
-    connect(ui->doubleSpinBoxSheetPaperHeight, QOverload<double>::of(&QDoubleSpinBox::valueChanged),
-            this, &PuzzlePreferencesLayoutPage::FindSheetTemplate);
-    connect(ui->doubleSpinBoxTilePaperWidth, QOverload<double>::of(&QDoubleSpinBox::valueChanged),
-            this, &PuzzlePreferencesLayoutPage::FindTileTemplate);
-    connect(ui->doubleSpinBoxTilePaperHeight, QOverload<double>::of(&QDoubleSpinBox::valueChanged),
-            this, &PuzzlePreferencesLayoutPage::FindTileTemplate);
+    connect(ui->doubleSpinBoxSheetPaperWidth, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this,
+            &PuzzlePreferencesLayoutPage::FindSheetTemplate);
+    connect(ui->doubleSpinBoxSheetPaperHeight, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this,
+            &PuzzlePreferencesLayoutPage::FindSheetTemplate);
+    connect(ui->doubleSpinBoxTilePaperWidth, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this,
+            &PuzzlePreferencesLayoutPage::FindTileTemplate);
+    connect(ui->doubleSpinBoxTilePaperHeight, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this,
+            &PuzzlePreferencesLayoutPage::FindTileTemplate);
 
-    connect(ui->doubleSpinBoxSheetPaperWidth, QOverload<double>::of(&QDoubleSpinBox::valueChanged),
-            this, &PuzzlePreferencesLayoutPage::CorrectMaxMargins);
-    connect(ui->doubleSpinBoxSheetPaperHeight, QOverload<double>::of(&QDoubleSpinBox::valueChanged),
-            this, &PuzzlePreferencesLayoutPage::CorrectMaxMargins);
-    connect(ui->doubleSpinBoxTilePaperWidth, QOverload<double>::of(&QDoubleSpinBox::valueChanged),
-            this, &PuzzlePreferencesLayoutPage::CorrectMaxMargins);
-    connect(ui->doubleSpinBoxTilePaperHeight, QOverload<double>::of(&QDoubleSpinBox::valueChanged),
-            this, &PuzzlePreferencesLayoutPage::CorrectMaxMargins);
+    connect(ui->doubleSpinBoxSheetPaperWidth, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this,
+            &PuzzlePreferencesLayoutPage::CorrectMaxMargins);
+    connect(ui->doubleSpinBoxSheetPaperHeight, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this,
+            &PuzzlePreferencesLayoutPage::CorrectMaxMargins);
+    connect(ui->doubleSpinBoxTilePaperWidth, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this,
+            &PuzzlePreferencesLayoutPage::CorrectMaxMargins);
+    connect(ui->doubleSpinBoxTilePaperHeight, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this,
+            &PuzzlePreferencesLayoutPage::CorrectMaxMargins);
 
     connect(ui->checkBoxLayoutIgnoreFileds, &QCheckBox::stateChanged, this,
             &PuzzlePreferencesLayoutPage::LayoutSheetIgnoreMargins);
@@ -105,36 +103,37 @@ PuzzlePreferencesLayoutPage::PuzzlePreferencesLayoutPage(QWidget *parent) :
     connect(ui->toolButtonTileLandscapeOrientation, &QToolButton::toggled, this,
             &PuzzlePreferencesLayoutPage::SwapTileOrientation);
 
-    connect(ui->doubleSpinBoxSheetMarginLeft, QOverload<double>::of(&QDoubleSpinBox::valueChanged),
-            this, [this](){m_settingsChanged=true;});
-    connect(ui->doubleSpinBoxSheetMarginRight, QOverload<double>::of(&QDoubleSpinBox::valueChanged),
-            this, [this](){m_settingsChanged=true;});
-    connect(ui->doubleSpinBoxSheetMarginTop, QOverload<double>::of(&QDoubleSpinBox::valueChanged),
-            this, [this](){m_settingsChanged=true;});
-    connect(ui->doubleSpinBoxSheetMarginBottom, QOverload<double>::of(&QDoubleSpinBox::valueChanged),
-            this, [this](){m_settingsChanged=true;});
+    connect(ui->doubleSpinBoxSheetMarginLeft, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this,
+            [this]() { m_settingsChanged = true; });
+    connect(ui->doubleSpinBoxSheetMarginRight, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this,
+            [this]() { m_settingsChanged = true; });
+    connect(ui->doubleSpinBoxSheetMarginTop, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this,
+            [this]() { m_settingsChanged = true; });
+    connect(ui->doubleSpinBoxSheetMarginBottom, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this,
+            [this]() { m_settingsChanged = true; });
 
-    connect(ui->checkBoxTileShowTiles, &QCheckBox::stateChanged, this, [this](){m_settingsChanged=true;});
-    connect(ui->checkBoxTileShowWatermark, &QCheckBox::stateChanged, this, [this](){m_settingsChanged=true;});
-    connect(ui->checkBoxTileShowWatermark, &QCheckBox::stateChanged, this, [this](){m_settingsChanged=true;});
+    connect(ui->checkBoxTileShowTiles, &QCheckBox::stateChanged, this, [this]() { m_settingsChanged = true; });
+    connect(ui->checkBoxTileShowWatermark, &QCheckBox::stateChanged, this, [this]() { m_settingsChanged = true; });
+    connect(ui->checkBoxTileShowWatermark, &QCheckBox::stateChanged, this, [this]() { m_settingsChanged = true; });
 
-    connect(ui->doubleSpinBoxPiecesGap, QOverload<double>::of(&QDoubleSpinBox::valueChanged),
-            this, [this](){m_settingsChanged=true;});
+    connect(ui->doubleSpinBoxPiecesGap, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this,
+            [this]() { m_settingsChanged = true; });
     ui->doubleSpinBoxPiecesGap->setSuffix(UnitsToStr(m_oldLayoutUnit));
 
     ui->spinBoxLineWidth->setSuffix(UnitsToStr(Unit::Px));
 
-    connect(ui->checkBoxWarningPiecesSuperposition, &QCheckBox::stateChanged, this, [this](){m_settingsChanged=true;});
-    connect(ui->checkBoxStickyEdges, &QCheckBox::stateChanged, this, [this](){m_settingsChanged=true;});
-    connect(ui->checkBoxWarningPiecesOutOfBound, &QCheckBox::stateChanged, this, [this](){m_settingsChanged=true;});
-    connect(ui->checkBoxFollowGrainline, &QCheckBox::stateChanged, this, [this](){m_settingsChanged=true;});
+    connect(ui->checkBoxWarningPiecesSuperposition, &QCheckBox::stateChanged, this,
+            [this]() { m_settingsChanged = true; });
+    connect(ui->checkBoxStickyEdges, &QCheckBox::stateChanged, this, [this]() { m_settingsChanged = true; });
+    connect(ui->checkBoxWarningPiecesOutOfBound, &QCheckBox::stateChanged, this,
+            [this]() { m_settingsChanged = true; });
+    connect(ui->checkBoxFollowGrainline, &QCheckBox::stateChanged, this, [this]() { m_settingsChanged = true; });
+    connect(ui->checkBoxWarningPieceGapePosition, &QCheckBox::stateChanged, this,
+            [this]() { m_settingsChanged = true; });
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-PuzzlePreferencesLayoutPage::~PuzzlePreferencesLayoutPage()
-{
-    delete ui;
-}
+PuzzlePreferencesLayoutPage::~PuzzlePreferencesLayoutPage() = default;
 
 //---------------------------------------------------------------------------------------------------------------------
 auto PuzzlePreferencesLayoutPage::Apply() -> QStringList
@@ -145,9 +144,9 @@ auto PuzzlePreferencesLayoutPage::Apply() -> QStringList
     settings->SetLayoutUnit(LayoutUnit());
 
     settings->SetLayoutSheetPaperHeight(
-                UnitConvertor(ui->doubleSpinBoxSheetPaperHeight->value(), m_oldLayoutUnit, Unit::Px));
+        UnitConvertor(ui->doubleSpinBoxSheetPaperHeight->value(), m_oldLayoutUnit, Unit::Px));
     settings->SetLayoutSheetPaperWidth(
-                UnitConvertor(ui->doubleSpinBoxSheetPaperWidth->value(), m_oldLayoutUnit, Unit::Px));
+        UnitConvertor(ui->doubleSpinBoxSheetPaperWidth->value(), m_oldLayoutUnit, Unit::Px));
 
     settings->SetLayoutSheetIgnoreMargins(ui->checkBoxLayoutIgnoreFileds->isChecked());
     settings->SetLayoutSheetMargins(GetSheetMargins());
@@ -156,9 +155,9 @@ auto PuzzlePreferencesLayoutPage::Apply() -> QStringList
     settings->SetLayoutTileShowWatermark(ui->checkBoxTileShowWatermark->isChecked());
 
     settings->SetLayoutTilePaperHeight(
-                UnitConvertor(ui->doubleSpinBoxTilePaperHeight->value(), m_oldLayoutUnit, Unit::Px));
+        UnitConvertor(ui->doubleSpinBoxTilePaperHeight->value(), m_oldLayoutUnit, Unit::Px));
     settings->SetLayoutTilePaperWidth(
-                UnitConvertor(ui->doubleSpinBoxTilePaperWidth->value(), m_oldLayoutUnit, Unit::Px));
+        UnitConvertor(ui->doubleSpinBoxTilePaperWidth->value(), m_oldLayoutUnit, Unit::Px));
 
     settings->SetLayoutTileIgnoreMargins(ui->checkBoxTileIgnoreFileds->isChecked());
     settings->SetLayoutTileMargins(GetTileMargins());
@@ -169,6 +168,7 @@ auto PuzzlePreferencesLayoutPage::Apply() -> QStringList
     settings->SetLayoutStickyEdges(ui->checkBoxStickyEdges->isChecked());
     settings->SetLayoutWarningPiecesOutOfBound(ui->checkBoxWarningPiecesOutOfBound->isChecked());
     settings->SetLayoutFollowGrainline(ui->checkBoxFollowGrainline->isChecked());
+    settings->SetLayoutWarningPieceGapePosition(ui->checkBoxWarningPieceGapePosition->isChecked());
 
     settings->SetLayoutLineWidth(ui->spinBoxLineWidth->value());
 
@@ -243,7 +243,7 @@ void PuzzlePreferencesLayoutPage::ConvertPaperSize()
     const qreal newTileTopMargin = UnitConvertor(tileTopMargin, m_oldLayoutUnit, layoutUnit);
     const qreal newTileBottomMargin = UnitConvertor(tileBottomMargin, m_oldLayoutUnit, layoutUnit);
 
-    qreal newGap = UnitConvertor(ui->doubleSpinBoxPiecesGap->value(), m_oldLayoutUnit, layoutUnit);
+    qreal const newGap = UnitConvertor(ui->doubleSpinBoxPiecesGap->value(), m_oldLayoutUnit, layoutUnit);
 
     m_oldLayoutUnit = layoutUnit;
     CorrectPaperDecimals();
@@ -318,8 +318,8 @@ void PuzzlePreferencesLayoutPage::CorrectMaxMargins()
     const qreal sheetHeight = ui->doubleSpinBoxSheetPaperHeight->value();
 
     // 80%/2 of paper size for each field
-    const qreal sheetWidthMargin = (sheetWidth*80.0/100.0)/2.0;
-    const qreal sheetHeightMargin = (sheetHeight*80.0/100.0)/2.0;
+    const qreal sheetWidthMargin = (sheetWidth * 80.0 / 100.0) / 2.0;
+    const qreal sheetHeightMargin = (sheetHeight * 80.0 / 100.0) / 2.0;
 
     ui->doubleSpinBoxSheetMarginLeft->setMaximum(sheetWidthMargin);
     ui->doubleSpinBoxSheetMarginRight->setMaximum(sheetWidthMargin);
@@ -330,8 +330,8 @@ void PuzzlePreferencesLayoutPage::CorrectMaxMargins()
     const qreal tileHeight = ui->doubleSpinBoxTilePaperHeight->value();
 
     // 80%/2 of paper size for each field
-    const qreal tileWidthMargin = (tileWidth*80.0/100.0)/2.0;
-    const qreal tileHeightMargin = (tileHeight*80.0/100.0)/2.0;
+    const qreal tileWidthMargin = (tileWidth * 80.0 / 100.0) / 2.0;
+    const qreal tileHeightMargin = (tileHeight * 80.0 / 100.0) / 2.0;
 
     ui->doubleSpinBoxTileMarginLeft->setMaximum(tileWidthMargin);
     ui->doubleSpinBoxTileMarginRight->setMaximum(tileWidthMargin);
@@ -559,7 +559,7 @@ void PuzzlePreferencesLayoutPage::CorrectPaperDecimals()
 //---------------------------------------------------------------------------------------------------------------------
 void PuzzlePreferencesLayoutPage::SheetPaperSizeChanged()
 {
-    bool portrait = ui->doubleSpinBoxSheetPaperHeight->value() > ui->doubleSpinBoxSheetPaperWidth->value();
+    bool const portrait = ui->doubleSpinBoxSheetPaperHeight->value() > ui->doubleSpinBoxSheetPaperWidth->value();
 
     ui->toolButtonSheetPortraitOritation->blockSignals(true);
     ui->toolButtonSheetPortraitOritation->setChecked(portrait);
@@ -575,7 +575,7 @@ void PuzzlePreferencesLayoutPage::SheetPaperSizeChanged()
 //---------------------------------------------------------------------------------------------------------------------
 void PuzzlePreferencesLayoutPage::TilePaperSizeChanged()
 {
-    bool portrait = ui->doubleSpinBoxTilePaperHeight->value() > ui->doubleSpinBoxTilePaperWidth->value();
+    bool const portrait = ui->doubleSpinBoxTilePaperHeight->value() > ui->doubleSpinBoxTilePaperWidth->value();
 
     ui->toolButtonTilePortraitOrientation->blockSignals(true);
     ui->toolButtonTilePortraitOrientation->setChecked(portrait);
@@ -631,7 +631,7 @@ void PuzzlePreferencesLayoutPage::SetTileMargins(const QMarginsF &value)
 //---------------------------------------------------------------------------------------------------------------------
 void PuzzlePreferencesLayoutPage::SetPieceGap(qreal gap)
 {
-    qreal value = UnitConvertor(gap, Unit::Px, LayoutUnit());
+    qreal const value = UnitConvertor(gap, Unit::Px, LayoutUnit());
     ui->doubleSpinBoxPiecesGap->setValue(value);
     CorrectPaperDecimals();
 }
@@ -664,6 +664,7 @@ void PuzzlePreferencesLayoutPage::ReadSettings()
     ui->checkBoxStickyEdges->setChecked(settings->GetLayoutStickyEdges());
     ui->checkBoxWarningPiecesOutOfBound->setChecked(settings->GetLayoutWarningPiecesOutOfBound());
     ui->checkBoxFollowGrainline->setChecked(settings->GetLayoutFollowGrainline());
+    ui->checkBoxWarningPieceGapePosition->setChecked(settings->GetLayoutWarningPieceGapePosition());
 
     ui->doubleSpinBoxPiecesGap->setMaximum(UnitConvertor(VPSettings::GetMaxLayoutPieceGap(), Unit::Px, LayoutUnit()));
     SetPieceGap(settings->GetLayoutPieceGap());
@@ -683,21 +684,21 @@ void PuzzlePreferencesLayoutPage::ReadSettings()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void PuzzlePreferencesLayoutPage::FindTemplate(QComboBox *box, qreal width, qreal height)
+void PuzzlePreferencesLayoutPage::FindTemplate(QComboBox *box, qreal width, qreal height) const
 {
     SCASSERT(box != nullptr)
     const Unit paperUnit = LayoutUnit();
 
-    const int max = static_cast<int>(VAbstractLayoutDialog::PaperSizeTemplate::Custom);
-    for (int i=0; i < max; ++i)
+    const auto max = static_cast<int>(VAbstractLayoutDialog::PaperSizeTemplate::Custom);
+    for (int i = 0; i < max; ++i)
     {
-        const QSizeF tmplSize = VAbstractLayoutDialog::GetTemplateSize(
-                    static_cast<VAbstractLayoutDialog::PaperSizeTemplate>(i), paperUnit);
-        if (QSizeF(width, height) == tmplSize || QSizeF(height, width) == tmplSize)
+        const QSizeF tmplSize =
+            VAbstractLayoutDialog::GetTemplateSize(static_cast<VAbstractLayoutDialog::PaperSizeTemplate>(i), paperUnit);
+        if (VAbstractLayoutDialog::RoundTemplateSize(width, height, paperUnit) == tmplSize ||
+            VAbstractLayoutDialog::RoundTemplateSize(height, width, paperUnit) == tmplSize)
         {
             box->blockSignals(true);
-            const int index = box->findData(i);
-            if (index != -1)
+            if (const int index = box->findData(i); index != -1)
             {
                 box->setCurrentIndex(index);
             }
@@ -707,8 +708,7 @@ void PuzzlePreferencesLayoutPage::FindTemplate(QComboBox *box, qreal width, qrea
     }
 
     box->blockSignals(true);
-    const int index = box->findData(max);
-    if (index != -1)
+    if (const int index = box->findData(max); index != -1)
     {
         box->setCurrentIndex(index);
     }
