@@ -26,46 +26,42 @@
  **
  *************************************************************************/
 #include "puzzlepreferencespathpage.h"
-#include "ui_puzzlepreferencespathpage.h"
 #include "../../vpapplication.h"
+#include "ui_puzzlepreferencespathpage.h"
 
 //---------------------------------------------------------------------------------------------------------------------
-PuzzlePreferencesPathPage::PuzzlePreferencesPathPage(QWidget *parent) :
-    QWidget(parent),
-    ui(new Ui::PuzzlePreferencesPathPage)
+PuzzlePreferencesPathPage::PuzzlePreferencesPathPage(QWidget *parent)
+  : QWidget(parent),
+    ui(std::make_unique<Ui::PuzzlePreferencesPathPage>())
 {
     ui->setupUi(this);
 
     InitTable();
 
-    connect(ui->pathTable, &QTableWidget::itemSelectionChanged, this, [this]()
-    {
-        ui->defaultButton->setEnabled(not ui->pathTable->selectedItems().isEmpty());
-        ui->defaultButton->setDefault(false);
+    connect(ui->pathTable, &QTableWidget::itemSelectionChanged, this,
+            [this]()
+            {
+                ui->defaultButton->setEnabled(not ui->pathTable->selectedItems().isEmpty());
+                ui->defaultButton->setDefault(false);
 
-        ui->editButton->setEnabled(not ui->pathTable->selectedItems().isEmpty());
-        ui->editButton->setDefault(true);
-    });
+                ui->editButton->setEnabled(not ui->pathTable->selectedItems().isEmpty());
+                ui->editButton->setDefault(true);
+            });
 
     connect(ui->defaultButton, &QPushButton::clicked, this, &PuzzlePreferencesPathPage::DefaultPath);
     connect(ui->editButton, &QPushButton::clicked, this, &PuzzlePreferencesPathPage::EditPath);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-PuzzlePreferencesPathPage::~PuzzlePreferencesPathPage()
-{
-    delete ui;
-}
+PuzzlePreferencesPathPage::~PuzzlePreferencesPathPage() = default;
 
 //---------------------------------------------------------------------------------------------------------------------
-void PuzzlePreferencesPathPage::Apply()
+void PuzzlePreferencesPathPage::Apply() const
 {
     VPSettings *settings = VPApplication::VApp()->PuzzleSettings();
-    settings->SetPathIndividualMeasurements(ui->pathTable->item(0, 1)->text());
-    settings->SetPathMultisizeMeasurements(ui->pathTable->item(1, 1)->text());
-    settings->SetPathPattern(ui->pathTable->item(2, 1)->text());
-    settings->SetPathTemplate(ui->pathTable->item(3, 1)->text());
-    settings->SetPathManualLayouts(ui->pathTable->item(4, 1)->text());
+    settings->SetPathSVGFonts(ui->pathTable->item(0, 1)->text());
+    settings->SetPathFontCorrections(ui->pathTable->item(1, 1)->text());
+    settings->SetPathKnownMeasurements(ui->pathTable->item(1, 1)->text());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -82,7 +78,7 @@ void PuzzlePreferencesPathPage::changeEvent(QEvent *event)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void PuzzlePreferencesPathPage::DefaultPath()
+void PuzzlePreferencesPathPage::DefaultPath() const
 {
     const int row = ui->pathTable->currentRow();
     QTableWidgetItem *item = ui->pathTable->item(row, 1);
@@ -91,20 +87,14 @@ void PuzzlePreferencesPathPage::DefaultPath()
     QString path;
     switch (row)
     {
-        case 0: // individual measurements
-            path = VCommonSettings::GetDefPathIndividualMeasurements();
+        case 0: // svg fonts
+            path = VCommonSettings::GetDefPathSVGFonts();
             break;
-        case 1: // multisize measurements
-            path = VCommonSettings::GetDefPathMultisizeMeasurements();
+        case 1: // font corrections
+            path = VCommonSettings::GetDefPathFontCorrections();
             break;
-        case 2: // pattern path
-            path = VCommonSettings::GetDefPathPattern();
-            break;
-        case 3: // templates
-            path = VCommonSettings::GetDefPathTemplate();
-            break;
-        case 4: // layouts
-            path = VCommonSettings::GetDefPathManualLayouts();
+        case 2: // known measurements
+            path = VCommonSettings::GetDefPathKnownMeasurements();
             break;
         default:
             break;
@@ -124,29 +114,21 @@ void PuzzlePreferencesPathPage::EditPath()
     QString path;
     switch (row)
     {
-        case 0: // individual measurements
-            path = VPApplication::VApp()->PuzzleSettings()->GetPathIndividualMeasurements();
+        case 0: // svg fonts
+            path = VPApplication::VApp()->PuzzleSettings()->GetPathSVGFonts();
             break;
-        case 1: // multisize measurements
-            path = VPApplication::VApp()->PuzzleSettings()->GetPathMultisizeMeasurements();
-            path = VCommonSettings::PrepareMultisizeTables(path);
+        case 1: // font corrections
+            path = VPApplication::VApp()->PuzzleSettings()->GetPathFontCorrections();
             break;
-        case 2: // pattern path
-            path = VPApplication::VApp()->PuzzleSettings()->GetPathPattern();
-            break;
-        case 3: // templates
-            path = VPApplication::VApp()->PuzzleSettings()->GetPathTemplate();
-            break;
-        case 4: // layouts
-            path = VPApplication::VApp()->PuzzleSettings()->GetPathManualLayouts();
+        case 2: // known measurements
+            path = VPApplication::VApp()->PuzzleSettings()->GetDefPathKnownMeasurements();
             break;
         default:
             break;
     }
 
     bool usedNotExistedDir = false;
-    QDir directory(path);
-    if (not directory.exists())
+    if (QDir const directory(path); not directory.exists())
     {
         usedNotExistedDir = directory.mkpath(QChar('.'));
     }
@@ -173,46 +155,32 @@ void PuzzlePreferencesPathPage::EditPath()
 void PuzzlePreferencesPathPage::InitTable()
 {
     ui->pathTable->clearContents();
-    ui->pathTable->setRowCount(5);
+    ui->pathTable->setRowCount(3);
     ui->pathTable->setColumnCount(2);
 
     const VPSettings *settings = VPApplication::VApp()->PuzzleSettings();
 
     {
-        ui->pathTable->setItem(0, 0, new QTableWidgetItem(tr("My Individual Measurements")));
-        auto *item = new QTableWidgetItem(settings->GetPathIndividualMeasurements());
-        item->setToolTip(settings->GetPathIndividualMeasurements());
+        ui->pathTable->setItem(0, 0, new QTableWidgetItem(tr("My SVG Fonts")));
+        auto *item = new QTableWidgetItem(settings->GetPathSVGFonts());
+        item->setToolTip(settings->GetPathSVGFonts());
         ui->pathTable->setItem(0, 1, item);
     }
 
     {
-        ui->pathTable->setItem(1, 0, new QTableWidgetItem(tr("My Multisize Measurements")));
-        auto *item = new QTableWidgetItem(settings->GetPathMultisizeMeasurements());
-        item->setToolTip(settings->GetPathMultisizeMeasurements());
+        ui->pathTable->setItem(1, 0, new QTableWidgetItem(tr("My font corrections")));
+        auto *item = new QTableWidgetItem(settings->GetPathFontCorrections());
+        item->setToolTip(settings->GetPathFontCorrections());
         ui->pathTable->setItem(1, 1, item);
     }
 
     {
-        ui->pathTable->setItem(2, 0, new QTableWidgetItem(tr("My Patterns")));
-        auto *item = new QTableWidgetItem(settings->GetPathPattern());
-        item->setToolTip(settings->GetPathPattern());
+        ui->pathTable->setItem(2, 0, new QTableWidgetItem(tr("My known measurements")));
+        auto *item = new QTableWidgetItem(settings->GetPathKnownMeasurements());
+        item->setToolTip(settings->GetPathKnownMeasurements());
         ui->pathTable->setItem(2, 1, item);
     }
 
-    {
-        ui->pathTable->setItem(3, 0, new QTableWidgetItem(tr("My Templates")));
-        auto *item = new QTableWidgetItem(settings->GetPathTemplate());
-        item->setToolTip(settings->GetPathTemplate());
-        ui->pathTable->setItem(3, 1, item);
-    }
-
-    {
-        ui->pathTable->setItem(4, 0, new QTableWidgetItem(tr("My Layouts")));
-        auto *item = new QTableWidgetItem(settings->GetPathManualLayouts());
-        item->setToolTip(settings->GetPathManualLayouts());
-        ui->pathTable->setItem(4, 1, item);
-    }
-
     ui->pathTable->verticalHeader()->setDefaultSectionSize(20);
     ui->pathTable->resizeColumnsToContents();
     ui->pathTable->resizeRowsToContents();
