@@ -29,12 +29,11 @@
 #define PUZZLEPREFERENCESPATHPAGE_H
 
 #include <QWidget>
-
-#include "../vmisc/defglobal.h"
+#include <memory>
 
 namespace Ui
 {
-    class PuzzlePreferencesPathPage;
+class PuzzlePreferencesPathPage;
 }
 
 class PuzzlePreferencesPathPage : public QWidget
@@ -45,19 +44,19 @@ public:
     explicit PuzzlePreferencesPathPage(QWidget *parent = nullptr);
     ~PuzzlePreferencesPathPage() override;
 
-    void Apply();
+    void Apply() const;
 
 protected:
-    void changeEvent(QEvent* event) override;
+    void changeEvent(QEvent *event) override;
 
 private slots:
-    void DefaultPath();
+    void DefaultPath() const;
     void EditPath();
 
 private:
     // cppcheck-suppress unknownMacro
     Q_DISABLE_COPY_MOVE(PuzzlePreferencesPathPage) // NOLINT
-    Ui::PuzzlePreferencesPathPage *ui;
+    std::unique_ptr<Ui::PuzzlePreferencesPathPage> ui;
 
     void InitTable();
 };
