@@ -29,12 +29,11 @@
 #define DIALOGPUZZLEPREFERENCES_H
 
 #include <QDialog>
-
-#include "../vmisc/defglobal.h"
+#include <memory>
 
 namespace Ui
 {
-    class DialogPuzzlePreferences;
+class DialogPuzzlePreferences;
 }
 
 class PuzzlePreferencesConfigurationPage;
@@ -56,21 +55,21 @@ signals:
 protected:
     void showEvent(QShowEvent *event) override;
     void resizeEvent(QResizeEvent *event) override;
-    void changeEvent(QEvent* event) override;
+    void changeEvent(QEvent *event) override;
 
 private slots:
     void Apply();
     void Ok();
-    void PageChanged(QListWidgetItem *current, QListWidgetItem *previous);
+    void PageChanged(const QListWidgetItem *current, const QListWidgetItem *previous);
 
 private:
     // cppcheck-suppress unknownMacro
     Q_DISABLE_COPY_MOVE(DialogPuzzlePreferences) // NOLINT
-    Ui::DialogPuzzlePreferences *ui;
+    std::unique_ptr<Ui::DialogPuzzlePreferences> ui;
     bool m_isInitialized{false};
     PuzzlePreferencesConfigurationPage *m_configurationPage;
-    PuzzlePreferencesLayoutPage        *m_layoutPage;
-    PuzzlePreferencesPathPage          *m_pathPage;
+    PuzzlePreferencesLayoutPage *m_layoutPage;
+    PuzzlePreferencesPathPage *m_pathPage;
 };
 
 #endif // DIALOGPUZZLEPREFERENCES_H
