@@ -26,30 +26,42 @@
  **
  *************************************************************************/
 #include "dialogsavemanuallayout.h"
-#include "ui_dialogsavemanuallayout.h"
-#include "../vpapplication.h"
 #include "../ifc/exception/vexception.h"
 #include "../vlayout/vlayoutexporter.h"
-#if QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
-#include "../vmisc/backport/qoverload.h"
-#endif // QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
+#include "../vpapplication.h"
+#include "ui_dialogsavemanuallayout.h"
 
 #include <QMessageBox>
 #include <QShowEvent>
 #include <QtDebug>
 
-#ifndef Q_OS_WIN
-    Q_GLOBAL_STATIC_WITH_ARGS(const QString, baseFilenameRegExp, (QLatin1String("^[^\\/]+$"))) // NOLINT
-#else
-    Q_GLOBAL_STATIC_WITH_ARGS(const QString, baseFilenameRegExp, (QLatin1String("^[^\\:?\"*|\\/<>]+$"))) // NOLINT
+#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
+#include "../vmisc/compatibility.h"
 #endif
 
+using namespace Qt::Literals::StringLiterals;
+
+namespace
+{
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_CLANG("-Wunused-member-function")
+
+#ifndef Q_OS_WIN
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, baseFilenameRegExp, ("^[^\\/]+$"_L1)) // NOLINT
+#else
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, baseFilenameRegExp, ("^[^\\:?\"*|\\/<>]+$"_L1)) // NOLINT
+#endif
+
+QT_WARNING_POP
+} // namespace
+
 //---------------------------------------------------------------------------------------------------------------------
-DialogSaveManualLayout::DialogSaveManualLayout(int count, bool consoleExport, const QString &fileName, QWidget *parent)
-    : VAbstractLayoutDialog(parent),
-      ui(new Ui::DialogSaveManualLayout),
-      m_count(count),
-      m_consoleExport(consoleExport)
+DialogSaveManualLayout::DialogSaveManualLayout(vsizetype count, bool consoleExport, const QString &fileName,
+                                               QWidget *parent)
+  : VAbstractLayoutDialog(parent),
+    ui(std::make_unique<Ui::DialogSaveManualLayout>()),
+    m_count(count),
+    m_consoleExport(consoleExport)
 {
     ui->setupUi(this);
 
@@ -57,15 +69,22 @@ DialogSaveManualLayout::DialogSaveManualLayout(int count, bool consoleExport, co
     setWindowFlags(Qt::Window);
 #endif
 
-    VPApplication::VApp()->PuzzleSettings()->GetOsSeparator() ? setLocale(QLocale()) : setLocale(QLocale::c());
+    VPSettings *settings = VPApplication::VApp()->PuzzleSettings();
+    settings->GetOsSeparator() ? setLocale(QLocale()) : setLocale(QLocale::c());
+
+    if (settings->GetSingleLineFonts() || settings->GetSingleStrokeOutlineFont())
+    {
+        ui->checkBoxTextAsPaths->setChecked(true);
+        ui->checkBoxTextAsPaths->setDisabled(true);
+    }
 
     QPushButton *bOk = ui->buttonBox->button(QDialogButtonBox::Ok);
     SCASSERT(bOk != nullptr)
     bOk->setEnabled(false);
 
-    ui->lineEditFileName->setValidator( new QRegularExpressionValidator(QRegularExpression(*baseFilenameRegExp), this));
+    ui->lineEditFileName->setValidator(new QRegularExpressionValidator(QRegularExpression(*baseFilenameRegExp), this));
 
-    const QString mask = m_count > 1 ? fileName + '_' : fileName;
+    const QString mask = m_count > 1 ? fileName + '_'_L1 : fileName;
     if (not m_consoleExport)
     {
         ui->lineEditFileName->setText(mask);
@@ -82,60 +101,50 @@ DialogSaveManualLayout::DialogSaveManualLayout(int count, bool consoleExport, co
         }
     }
 
-    for (auto &v : InitFormats())
+    for (auto &[first, second] : InitFormats())
     {
-        ui->comboBoxFormat->addItem(v.first, QVariant(static_cast<int>(v.second)));
+        ui->comboBoxFormat->addItem(first, QVariant(static_cast<int>(second)));
     }
 #ifdef V_NO_ASSERT // Temporarily unavailable
     RemoveFormatFromList(LayoutExportFormats::OBJ);
 #endif
 
-//    RemoveFormatFromList(LayoutExportFormats::NC); // No support for now
+    //    RemoveFormatFromList(LayoutExportFormats::NC); // No support for now
+
+    InitDxfCompatibility();
 
     connect(bOk, &QPushButton::clicked, this, &DialogSaveManualLayout::Save);
     connect(ui->lineEditFileName, &QLineEdit::textChanged, this, &DialogSaveManualLayout::ShowExample);
-    connect(ui->comboBoxFormat, QOverload<int>::of(&QComboBox::currentIndexChanged),
-            this, &DialogSaveManualLayout::ShowExample);
+    connect(ui->comboBoxFormat, QOverload<int>::of(&QComboBox::currentIndexChanged), this,
+            &DialogSaveManualLayout::ShowExample);
 
-    connect(ui->pushButtonBrowse, &QPushButton::clicked, this, [this]()
-    {
-        const QString dirPath = VPApplication::VApp()->PuzzleSettings()->GetPathManualLayouts();
-        bool usedNotExistedDir = false;
-        QDir directory(dirPath);
-        if (not directory.exists())
-        {
-            usedNotExistedDir = directory.mkpath(QChar('.'));
-        }
+    connect(ui->pushButtonBrowse, &QPushButton::clicked, this,
+            [this]()
+            {
+                const QString dirPath = VPApplication::VApp()->PuzzleSettings()->GetPathManualLayouts();
 
-        const QString dir = QFileDialog::getExistingDirectory(
-            this, tr("Select folder"), dirPath,
-            VAbstractApplication::VApp()->NativeFileDialog(QFileDialog::ShowDirsOnly |
-                                                           QFileDialog::DontResolveSymlinks));
-        if (not dir.isEmpty())
-        {// If paths equal the signal will not be called, we will do this manually
-            dir == ui->lineEditPath->text() ? PathChanged(dir) : ui->lineEditPath->setText(dir);
-        }
+                const QString dir = QFileDialog::getExistingDirectory(
+                    this, tr("Select folder"), dirPath,
+                    VAbstractApplication::VApp()->NativeFileDialog(QFileDialog::ShowDirsOnly |
+                                                                   QFileDialog::DontResolveSymlinks));
+                if (not dir.isEmpty())
+                { // If paths equal the signal will not be called, we will do this manually
+                    dir == ui->lineEditPath->text() ? PathChanged(dir) : ui->lineEditPath->setText(dir);
 
-        if (usedNotExistedDir)
-        {
-            QDir directory(dirPath);
-            directory.rmpath(QChar('.'));
-        }
-    });
+                    VPApplication::VApp()->PuzzleSettings()->SetPathManualLayouts(dir);
+                }
+            });
     connect(ui->lineEditPath, &QLineEdit::textChanged, this, &DialogSaveManualLayout::PathChanged);
 
     ui->lineEditPath->setText(VPApplication::VApp()->PuzzleSettings()->GetPathManualLayouts());
 
     ReadSettings();
 
-    ShowExample();//Show example for current format.
+    ShowExample(); // Show example for current format.
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-DialogSaveManualLayout::~DialogSaveManualLayout()
-{
-    delete ui;
-}
+DialogSaveManualLayout::~DialogSaveManualLayout() = default;
 
 //---------------------------------------------------------------------------------------------------------------------
 auto DialogSaveManualLayout::Path() const -> QString
@@ -174,7 +183,7 @@ void DialogSaveManualLayout::SelectFormat(LayoutExportFormats format)
 //---------------------------------------------------------------------------------------------------------------------
 void DialogSaveManualLayout::SetBinaryDXFFormat(bool binary)
 {
-    switch(Format())
+    switch (Format())
     {
         case LayoutExportFormats::DXF_AC1006_Flat:
         case LayoutExportFormats::DXF_AC1009_Flat:
@@ -185,24 +194,8 @@ void DialogSaveManualLayout::SetBinaryDXFFormat(bool binary)
         case LayoutExportFormats::DXF_AC1021_Flat:
         case LayoutExportFormats::DXF_AC1024_Flat:
         case LayoutExportFormats::DXF_AC1027_Flat:
-        case LayoutExportFormats::DXF_AC1006_AAMA:
-        case LayoutExportFormats::DXF_AC1009_AAMA:
-        case LayoutExportFormats::DXF_AC1012_AAMA:
-        case LayoutExportFormats::DXF_AC1014_AAMA:
-        case LayoutExportFormats::DXF_AC1015_AAMA:
-        case LayoutExportFormats::DXF_AC1018_AAMA:
-        case LayoutExportFormats::DXF_AC1021_AAMA:
-        case LayoutExportFormats::DXF_AC1024_AAMA:
-        case LayoutExportFormats::DXF_AC1027_AAMA:
-        case LayoutExportFormats::DXF_AC1006_ASTM:
-        case LayoutExportFormats::DXF_AC1009_ASTM:
-        case LayoutExportFormats::DXF_AC1012_ASTM:
-        case LayoutExportFormats::DXF_AC1014_ASTM:
-        case LayoutExportFormats::DXF_AC1015_ASTM:
-        case LayoutExportFormats::DXF_AC1018_ASTM:
-        case LayoutExportFormats::DXF_AC1021_ASTM:
-        case LayoutExportFormats::DXF_AC1024_ASTM:
-        case LayoutExportFormats::DXF_AC1027_ASTM:
+        case LayoutExportFormats::DXF_AAMA:
+        case LayoutExportFormats::DXF_ASTM:
             ui->checkBoxBinaryDXF->setChecked(binary);
             break;
         default:
@@ -214,7 +207,7 @@ void DialogSaveManualLayout::SetBinaryDXFFormat(bool binary)
 //---------------------------------------------------------------------------------------------------------------------
 auto DialogSaveManualLayout::IsBinaryDXFFormat() const -> bool
 {
-    switch(Format())
+    switch (Format())
     {
         case LayoutExportFormats::DXF_AC1006_Flat:
         case LayoutExportFormats::DXF_AC1009_Flat:
@@ -225,30 +218,113 @@ auto DialogSaveManualLayout::IsBinaryDXFFormat() const -> bool
         case LayoutExportFormats::DXF_AC1021_Flat:
         case LayoutExportFormats::DXF_AC1024_Flat:
         case LayoutExportFormats::DXF_AC1027_Flat:
-        case LayoutExportFormats::DXF_AC1006_AAMA:
-        case LayoutExportFormats::DXF_AC1009_AAMA:
-        case LayoutExportFormats::DXF_AC1012_AAMA:
-        case LayoutExportFormats::DXF_AC1014_AAMA:
-        case LayoutExportFormats::DXF_AC1015_AAMA:
-        case LayoutExportFormats::DXF_AC1018_AAMA:
-        case LayoutExportFormats::DXF_AC1021_AAMA:
-        case LayoutExportFormats::DXF_AC1024_AAMA:
-        case LayoutExportFormats::DXF_AC1027_AAMA:
-        case LayoutExportFormats::DXF_AC1006_ASTM:
-        case LayoutExportFormats::DXF_AC1009_ASTM:
-        case LayoutExportFormats::DXF_AC1012_ASTM:
-        case LayoutExportFormats::DXF_AC1014_ASTM:
-        case LayoutExportFormats::DXF_AC1015_ASTM:
-        case LayoutExportFormats::DXF_AC1018_ASTM:
-        case LayoutExportFormats::DXF_AC1021_ASTM:
-        case LayoutExportFormats::DXF_AC1024_ASTM:
-        case LayoutExportFormats::DXF_AC1027_ASTM:
+        case LayoutExportFormats::DXF_AAMA:
+        case LayoutExportFormats::DXF_ASTM:
             return ui->checkBoxBinaryDXF->isChecked();
         default:
             return false;
     }
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+auto DialogSaveManualLayout::DxfCompatibility() const -> DXFApparelCompatibility
+{
+    switch (Format())
+    {
+        case LayoutExportFormats::DXF_AAMA:
+        case LayoutExportFormats::DXF_ASTM:
+            return static_cast<DXFApparelCompatibility>(ui->comboBoxDxfCompatibility->currentData().toInt());
+        default:
+            return DXFApparelCompatibility::STANDARD;
+    }
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void DialogSaveManualLayout::SetDxfCompatibility(DXFApparelCompatibility type)
+{
+    switch (Format())
+    {
+        case LayoutExportFormats::DXF_AAMA:
+        case LayoutExportFormats::DXF_ASTM:
+        {
+            if (static_cast<int>(type) < 0 || type >= DXFApparelCompatibility::COUNT)
+            {
+                break;
+            }
+
+            const int i = ui->comboBoxDxfCompatibility->findData(static_cast<int>(type));
+            if (i < 0)
+            {
+                break;
+            }
+            ui->comboBoxDxfCompatibility->setCurrentIndex(i);
+            break;
+        }
+        default:
+            break;
+    }
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void DialogSaveManualLayout::SetShowGrainline(bool show)
+{
+    switch (Format())
+    {
+        case LayoutExportFormats::SVG:
+        case LayoutExportFormats::PDF:
+        case LayoutExportFormats::PNG:
+        case LayoutExportFormats::PS:
+        case LayoutExportFormats::EPS:
+        case LayoutExportFormats::PDFTiled:
+        case LayoutExportFormats::TIF:
+        case LayoutExportFormats::DXF_AC1006_Flat:
+        case LayoutExportFormats::DXF_AC1009_Flat:
+        case LayoutExportFormats::DXF_AC1012_Flat:
+        case LayoutExportFormats::DXF_AC1014_Flat:
+        case LayoutExportFormats::DXF_AC1015_Flat:
+        case LayoutExportFormats::DXF_AC1018_Flat:
+        case LayoutExportFormats::DXF_AC1021_Flat:
+        case LayoutExportFormats::DXF_AC1024_Flat:
+        case LayoutExportFormats::DXF_AC1027_Flat:
+        case LayoutExportFormats::HPGL:
+        case LayoutExportFormats::HPGL2:
+            ui->checkBoxShowGrainline->setChecked(show);
+            break;
+        default:
+            ui->checkBoxShowGrainline->setChecked(true);
+            break;
+    }
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto DialogSaveManualLayout::IsShowGrainline() const -> bool
+{
+    switch (Format())
+    {
+        case LayoutExportFormats::SVG:
+        case LayoutExportFormats::PDF:
+        case LayoutExportFormats::PNG:
+        case LayoutExportFormats::PS:
+        case LayoutExportFormats::EPS:
+        case LayoutExportFormats::PDFTiled:
+        case LayoutExportFormats::TIF:
+        case LayoutExportFormats::DXF_AC1006_Flat:
+        case LayoutExportFormats::DXF_AC1009_Flat:
+        case LayoutExportFormats::DXF_AC1012_Flat:
+        case LayoutExportFormats::DXF_AC1014_Flat:
+        case LayoutExportFormats::DXF_AC1015_Flat:
+        case LayoutExportFormats::DXF_AC1018_Flat:
+        case LayoutExportFormats::DXF_AC1021_Flat:
+        case LayoutExportFormats::DXF_AC1024_Flat:
+        case LayoutExportFormats::DXF_AC1027_Flat:
+        case LayoutExportFormats::HPGL:
+        case LayoutExportFormats::HPGL2:
+            return ui->checkBoxShowGrainline->isChecked();
+        default:
+            return true;
+    }
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void DialogSaveManualLayout::SetDestinationPath(const QString &cmdDestinationPath)
 {
@@ -284,13 +360,21 @@ auto DialogSaveManualLayout::IsTextAsPaths() const -> bool
 //---------------------------------------------------------------------------------------------------------------------
 void DialogSaveManualLayout::SetTextAsPaths(bool textAsPaths)
 {
-    ui->checkBoxTextAsPaths->setChecked(textAsPaths);
+    VCommonSettings *settings = VAbstractApplication::VApp()->Settings();
+    if (settings->GetSingleLineFonts() || settings->GetSingleStrokeOutlineFont())
+    {
+        ui->checkBoxTextAsPaths->setChecked(true);
+    }
+    else
+    {
+        ui->checkBoxTextAsPaths->setChecked(textAsPaths);
+    }
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void DialogSaveManualLayout::SetExportUnified(bool value)
 {
-    switch(Format())
+    switch (Format())
     {
         case LayoutExportFormats::PDF:
         case LayoutExportFormats::PDFTiled:
@@ -307,7 +391,7 @@ void DialogSaveManualLayout::SetExportUnified(bool value)
 //---------------------------------------------------------------------------------------------------------------------
 auto DialogSaveManualLayout::IsExportUnified() const -> bool
 {
-    switch(Format())
+    switch (Format())
     {
         case LayoutExportFormats::PDF:
         case LayoutExportFormats::PDFTiled:
@@ -322,7 +406,7 @@ auto DialogSaveManualLayout::IsExportUnified() const -> bool
 //---------------------------------------------------------------------------------------------------------------------
 void DialogSaveManualLayout::SetTilesScheme(bool value)
 {
-    switch(Format())
+    switch (Format())
     {
         case LayoutExportFormats::PDFTiled:
             ui->checkBoxTilesScheme->setChecked(value);
@@ -336,7 +420,7 @@ void DialogSaveManualLayout::SetTilesScheme(bool value)
 //---------------------------------------------------------------------------------------------------------------------
 auto DialogSaveManualLayout::IsTilesScheme() const -> bool
 {
-    switch(Format())
+    switch (Format())
     {
         case LayoutExportFormats::PDFTiled:
             return ui->checkBoxTilesScheme->isChecked();
@@ -348,8 +432,8 @@ auto DialogSaveManualLayout::IsTilesScheme() const -> bool
 //---------------------------------------------------------------------------------------------------------------------
 void DialogSaveManualLayout::showEvent(QShowEvent *event)
 {
-    QDialog::showEvent( event );
-    if ( event->spontaneous() )
+    QDialog::showEvent(event);
+    if (event->spontaneous())
     {
         return;
     }
@@ -362,7 +446,7 @@ void DialogSaveManualLayout::showEvent(QShowEvent *event)
 
     setFixedHeight(size().height());
 
-    m_isInitialized = true;//first show windows are held
+    m_isInitialized = true; // first show windows are held
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -370,12 +454,12 @@ void DialogSaveManualLayout::Save()
 {
     WriteSettings();
 
-    for (int i=0; i < m_count; ++i)
+    for (int i = 0; i < m_count; ++i)
     {
         QString name;
         if (m_count > 1 && not IsExportUnified())
         {
-            name = Path() + '/' + FileName() + QString::number(i+1) + VLayoutExporter::ExportFormatSuffix(Format());
+            name = Path() + '/' + FileName() + QString::number(i + 1) + VLayoutExporter::ExportFormatSuffix(Format());
         }
         else
         {
@@ -384,10 +468,11 @@ void DialogSaveManualLayout::Save()
 
         if (QFile::exists(name))
         {
-            QMessageBox::StandardButton res = QMessageBox::question(this, tr("Name conflict"),
-                                  tr("Folder already contain file with name %1. Rewrite all conflict file names?")
-                                  .arg(name), QMessageBox::Yes|QMessageBox::No, QMessageBox::Yes);
-            if (res == QMessageBox::No)
+            if (QMessageBox::StandardButton const res = QMessageBox::question(
+                    this, tr("Name conflict"),
+                    tr("Folder already contain file with name %1. Rewrite all conflict file names?").arg(name),
+                    QMessageBox::Yes | QMessageBox::No, QMessageBox::Yes);
+                res == QMessageBox::No)
             {
                 reject();
                 return;
@@ -412,7 +497,7 @@ void DialogSaveManualLayout::PathChanged(const QString &text)
     if (not text.isEmpty() && dir.exists(text))
     {
         bOk->setEnabled(true);
-        palette.setColor(ui->lineEditPath->foregroundRole(), Qt::black);
+        palette.setColor(ui->lineEditPath->foregroundRole(), palette.color(QPalette::Text));
     }
     else
     {
@@ -431,7 +516,7 @@ void DialogSaveManualLayout::ShowExample()
     QString example;
     if (m_count > 1)
     {
-        example = tr("Example:") + FileName() + QLatin1Char('1') + VLayoutExporter::ExportFormatSuffix(currentFormat);
+        example = tr("Example:") + FileName() + '1'_L1 + VLayoutExporter::ExportFormatSuffix(currentFormat);
     }
     else
     {
@@ -439,13 +524,50 @@ void DialogSaveManualLayout::ShowExample()
     }
     ui->labelExample->setText(example);
 
-    ui->checkBoxBinaryDXF->setEnabled(false);
-    ui->checkBoxTextAsPaths->setEnabled(true);
-    ui->checkBoxExportUnified->setEnabled(false);
-    ui->checkBoxTilesScheme->setEnabled(false);
+    VCommonSettings *settings = VAbstractApplication::VApp()->Settings();
 
-    switch(currentFormat)
+    ui->labelOptionsNotAvailable->setVisible(false);
+    ui->checkBoxBinaryDXF->setVisible(false);
+    ui->checkBoxTextAsPaths->setVisible(false);
+    ui->checkBoxExportUnified->setVisible(false);
+    ui->checkBoxTilesScheme->setVisible(false);
+    ui->checkBoxShowGrainline->setVisible(false);
+    ui->labelDxfCompatibility->setVisible(false);
+    ui->comboBoxDxfCompatibility->setVisible(false);
+
+    const bool editableTextAsPaths = !settings->GetSingleLineFonts() && !settings->GetSingleStrokeOutlineFont();
+
+    switch (currentFormat)
     {
+        case LayoutExportFormats::DXF_AAMA:
+        case LayoutExportFormats::DXF_ASTM:
+            ui->checkBoxBinaryDXF->setVisible(true);
+            ui->labelDxfCompatibility->setVisible(true);
+            ui->comboBoxDxfCompatibility->setVisible(true);
+            break;
+        case LayoutExportFormats::PDFTiled:
+            ui->checkBoxTextAsPaths->setVisible(editableTextAsPaths);
+            ui->checkBoxTilesScheme->setVisible(true);
+            ui->checkBoxExportUnified->setVisible(m_count > 1);
+            ui->checkBoxShowGrainline->setVisible(true);
+            break;
+        case LayoutExportFormats::PDF:
+        case LayoutExportFormats::PS:
+        case LayoutExportFormats::EPS:
+            ui->checkBoxTextAsPaths->setVisible(editableTextAsPaths);
+            ui->checkBoxExportUnified->setVisible(m_count > 1);
+            ui->checkBoxShowGrainline->setVisible(true);
+            break;
+        case LayoutExportFormats::HPGL:
+        case LayoutExportFormats::HPGL2:
+            ui->checkBoxShowGrainline->setVisible(true);
+            break;
+        case LayoutExportFormats::SVG:
+        case LayoutExportFormats::PNG:
+        case LayoutExportFormats::TIF:
+            ui->checkBoxTextAsPaths->setVisible(editableTextAsPaths);
+            ui->checkBoxShowGrainline->setVisible(true);
+            break;
         case LayoutExportFormats::DXF_AC1006_Flat:
         case LayoutExportFormats::DXF_AC1009_Flat:
         case LayoutExportFormats::DXF_AC1012_Flat:
@@ -455,44 +577,12 @@ void DialogSaveManualLayout::ShowExample()
         case LayoutExportFormats::DXF_AC1021_Flat:
         case LayoutExportFormats::DXF_AC1024_Flat:
         case LayoutExportFormats::DXF_AC1027_Flat:
-        case LayoutExportFormats::DXF_AC1006_AAMA:
-        case LayoutExportFormats::DXF_AC1009_AAMA:
-        case LayoutExportFormats::DXF_AC1012_AAMA:
-        case LayoutExportFormats::DXF_AC1014_AAMA:
-        case LayoutExportFormats::DXF_AC1015_AAMA:
-        case LayoutExportFormats::DXF_AC1018_AAMA:
-        case LayoutExportFormats::DXF_AC1021_AAMA:
-        case LayoutExportFormats::DXF_AC1024_AAMA:
-        case LayoutExportFormats::DXF_AC1027_AAMA:
-        case LayoutExportFormats::DXF_AC1006_ASTM:
-        case LayoutExportFormats::DXF_AC1009_ASTM:
-        case LayoutExportFormats::DXF_AC1012_ASTM:
-        case LayoutExportFormats::DXF_AC1014_ASTM:
-        case LayoutExportFormats::DXF_AC1015_ASTM:
-        case LayoutExportFormats::DXF_AC1018_ASTM:
-        case LayoutExportFormats::DXF_AC1021_ASTM:
-        case LayoutExportFormats::DXF_AC1024_ASTM:
-        case LayoutExportFormats::DXF_AC1027_ASTM:
-            ui->checkBoxBinaryDXF->setEnabled(true);
+            ui->checkBoxBinaryDXF->setVisible(true);
+            ui->checkBoxTextAsPaths->setVisible(editableTextAsPaths);
+            ui->checkBoxShowGrainline->setVisible(true);
             break;
-        case LayoutExportFormats::RLD:
-            ui->checkBoxTextAsPaths->setEnabled(false);
-            break;
-        case LayoutExportFormats::PDFTiled:
-            ui->checkBoxTilesScheme->setEnabled(true);
-            ui->checkBoxExportUnified->setEnabled(true);
-            break;
-        case LayoutExportFormats::PDF:
-        case LayoutExportFormats::PS:
-        case LayoutExportFormats::EPS:
-            ui->checkBoxExportUnified->setEnabled(true);
-            break;
-        case LayoutExportFormats::SVG:
-        case LayoutExportFormats::PNG:
-        case LayoutExportFormats::OBJ:
-        case LayoutExportFormats::NC:
-        case LayoutExportFormats::TIF:
         default:
+            ui->labelOptionsNotAvailable->setVisible(true);
             break;
     }
 }
@@ -501,8 +591,7 @@ void DialogSaveManualLayout::ShowExample()
 auto DialogSaveManualLayout::SupportPSTest() -> bool
 {
     static bool havePdf = false;
-    static bool tested  = false;
-    if (!tested)
+    if (static bool tested = false; !tested)
     {
         havePdf = VLayoutExporter::SupportPDFConversion();
         tested = true;
@@ -511,14 +600,12 @@ auto DialogSaveManualLayout::SupportPSTest() -> bool
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-auto DialogSaveManualLayout::InitFormats() -> QVector<std::pair<QString, LayoutExportFormats> >
+auto DialogSaveManualLayout::InitFormats() -> QVector<std::pair<QString, LayoutExportFormats>>
 {
     QVector<std::pair<QString, LayoutExportFormats>> list;
 
     auto InitFormat = [&list](LayoutExportFormats format)
-    {
-        list.append(std::make_pair(VLayoutExporter::ExportFormatDescription(format), format));
-    };
+    { list.append(std::make_pair(VLayoutExporter::ExportFormatDescription(format), format)); };
 
     InitFormat(LayoutExportFormats::SVG);
     InitFormat(LayoutExportFormats::PDF);
@@ -538,28 +625,14 @@ auto DialogSaveManualLayout::InitFormats() -> QVector<std::pair<QString, LayoutE
     InitFormat(LayoutExportFormats::DXF_AC1021_Flat);
     InitFormat(LayoutExportFormats::DXF_AC1024_Flat);
     InitFormat(LayoutExportFormats::DXF_AC1027_Flat);
-    InitFormat(LayoutExportFormats::DXF_AC1006_AAMA);
-    InitFormat(LayoutExportFormats::DXF_AC1009_AAMA);
-    InitFormat(LayoutExportFormats::DXF_AC1012_AAMA);
-    InitFormat(LayoutExportFormats::DXF_AC1014_AAMA);
-    InitFormat(LayoutExportFormats::DXF_AC1015_AAMA);
-    InitFormat(LayoutExportFormats::DXF_AC1018_AAMA);
-    InitFormat(LayoutExportFormats::DXF_AC1021_AAMA);
-    InitFormat(LayoutExportFormats::DXF_AC1024_AAMA);
-    InitFormat(LayoutExportFormats::DXF_AC1027_AAMA);
-    InitFormat(LayoutExportFormats::DXF_AC1006_ASTM);
-    InitFormat(LayoutExportFormats::DXF_AC1009_ASTM);
-    InitFormat(LayoutExportFormats::DXF_AC1012_ASTM);
-    InitFormat(LayoutExportFormats::DXF_AC1014_ASTM);
-    InitFormat(LayoutExportFormats::DXF_AC1015_ASTM);
-    InitFormat(LayoutExportFormats::DXF_AC1018_ASTM);
-    InitFormat(LayoutExportFormats::DXF_AC1021_ASTM);
-    InitFormat(LayoutExportFormats::DXF_AC1024_ASTM);
-    InitFormat(LayoutExportFormats::DXF_AC1027_ASTM);
+    InitFormat(LayoutExportFormats::DXF_AAMA);
+    InitFormat(LayoutExportFormats::DXF_ASTM);
     InitFormat(LayoutExportFormats::PDFTiled);
-//    InitFormat(LayoutExportFormats::NC);
+    //    InitFormat(LayoutExportFormats::NC);
     InitFormat(LayoutExportFormats::RLD);
     InitFormat(LayoutExportFormats::TIF);
+    InitFormat(LayoutExportFormats::HPGL);
+    InitFormat(LayoutExportFormats::HPGL2);
 
     return list;
 }
@@ -578,7 +651,17 @@ void DialogSaveManualLayout::RemoveFormatFromList(LayoutExportFormats format)
 void DialogSaveManualLayout::ReadSettings()
 {
     VPSettings *settings = VPApplication::VApp()->PuzzleSettings();
-    SelectFormat(static_cast<LayoutExportFormats>(settings->GetLayoutExportFormat()));
+    try
+    {
+        SelectFormat(static_cast<LayoutExportFormats>(settings->GetLayoutExportFormat()));
+    }
+    catch (VException &e)
+    {
+        qDebug() << qUtf8Printable(e.ErrorMessage());
+    }
+    SetShowGrainline(settings->GetShowGrainline());
+
+    SetDxfCompatibility(static_cast<DXFApparelCompatibility>(settings->GetDxfCompatibility()));
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -591,4 +674,20 @@ void DialogSaveManualLayout::WriteSettings() const
 
     VPSettings *settings = VPApplication::VApp()->PuzzleSettings();
     settings->SetLayoutExportFormat(static_cast<qint8>(Format()));
+    settings->SetShowGrainline(IsShowGrainline());
+
+    settings->SetDxfCompatibility(static_cast<qint8>(DxfCompatibility()));
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void DialogSaveManualLayout::InitDxfCompatibility()
+{
+    ui->comboBoxDxfCompatibility->addItem(tr("By standard"),
+                                          QVariant(static_cast<int>(DXFApparelCompatibility::STANDARD)));
+    ui->comboBoxDxfCompatibility->addItem("Richpeace CAD V8"_L1,
+                                          QVariant(static_cast<int>(DXFApparelCompatibility::RPCADV08)));
+    ui->comboBoxDxfCompatibility->addItem("Richpeace CAD V9"_L1,
+                                          QVariant(static_cast<int>(DXFApparelCompatibility::RPCADV09)));
+    ui->comboBoxDxfCompatibility->addItem("Richpeace CAD V10"_L1,
+                                          QVariant(static_cast<int>(DXFApparelCompatibility::RPCADV10)));
 }
