@@ -28,8 +28,12 @@
 #ifndef DIALOGSAVEMANUALLAYOUT_H
 #define DIALOGSAVEMANUALLAYOUT_H
 
+#include <memory>
+
+#include "../vdxf/dxfdef.h"
 #include "../vlayout/dialogs/vabstractlayoutdialog.h"
 #include "../vlayout/vlayoutdef.h"
+#include "../vmisc/defglobal.h"
 
 namespace Ui
 {
@@ -41,7 +45,7 @@ class DialogSaveManualLayout : public VAbstractLayoutDialog
     Q_OBJECT // NOLINT
 
 public:
-    explicit DialogSaveManualLayout(int count, bool consoleExport, const QString &fileName = QString(),
+    explicit DialogSaveManualLayout(vsizetype count, bool consoleExport, const QString &fileName = QString(),
                                     QWidget *parent = nullptr);
     ~DialogSaveManualLayout() override;
 
@@ -54,7 +58,13 @@ public:
     void SetBinaryDXFFormat(bool binary);
     auto IsBinaryDXFFormat() const -> bool;
 
-    void SetDestinationPath(const QString& cmdDestinationPath);
+    auto DxfCompatibility() const -> DXFApparelCompatibility;
+    void SetDxfCompatibility(DXFApparelCompatibility type);
+
+    void SetShowGrainline(bool show);
+    auto IsShowGrainline() const -> bool;
+
+    void SetDestinationPath(const QString &cmdDestinationPath);
 
     auto IsTextAsPaths() const -> bool;
     void SetTextAsPaths(bool textAsPaths);
@@ -76,19 +86,21 @@ private slots:
 private:
     // cppcheck-suppress unknownMacro
     Q_DISABLE_COPY_MOVE(DialogSaveManualLayout) // NOLINT
-    Ui::DialogSaveManualLayout *ui;
-    int  m_count;
+    std::unique_ptr<Ui::DialogSaveManualLayout> ui;
+    vsizetype m_count;
     bool m_isInitialized{false};
     bool m_scaleConnected{true};
     bool m_consoleExport;
 
     static auto SupportPSTest() -> bool;
-    static auto InitFormats() -> QVector<std::pair<QString, LayoutExportFormats> >;
+    static auto InitFormats() -> QVector<std::pair<QString, LayoutExportFormats>>;
 
     void RemoveFormatFromList(LayoutExportFormats format);
 
     void ReadSettings();
     void WriteSettings() const;
+
+    void InitDxfCompatibility();
 };
 
 #endif // DIALOGSAVEMANUALLAYOUT_H
