@@ -27,10 +27,10 @@
  *************************************************************************/
 
 #include "vpdialogabout.h"
-#include "ui_vpdialogabout.h"
-#include "../vmisc/projectversion.h"
-#include "../vmisc/def.h"
 #include "../fervor/fvupdater.h"
+#include "../vmisc/def.h"
+#include "../vmisc/projectversion.h"
+#include "ui_vpdialogabout.h"
 
 #include <QDate>
 #include <QDesktopServices>
@@ -39,31 +39,44 @@
 #include <QUrl>
 #include <QtDebug>
 
+#if !defined(BUILD_REVISION) && defined(QBS_BUILD)
+#include <vcsRepoState.h>
+#define BUILD_REVISION VCS_REPO_STATE_REVISION
+#endif
+
+#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
+#include "../vmisc/compatibility.h"
+#endif
+
+using namespace Qt::Literals::StringLiterals;
+
 //---------------------------------------------------------------------------------------------------------------------
 VPDialogAbout::VPDialogAbout(QWidget *parent)
-    :QDialog(parent),
-      ui(new Ui::VPDialogAbout),
-      m_isInitialized(false)
+  : QDialog(parent),
+    ui(std::make_unique<Ui::VPDialogAbout>()),
+    m_isInitialized(false)
 {
     ui->setupUi(this);
 
-    //mApp->Settings()->GetOsSeparator() ? setLocale(QLocale()) : setLocale(QLocale::c());
+    // mApp->Settings()->GetOsSeparator() ? setLocale(QLocale()) : setLocale(QLocale::c());
 
     RetranslateUi();
-    connect(ui->pushButton_Web_Site, &QPushButton::clicked, this, []()
-    {
-        if ( not QDesktopServices::openUrl(QUrl(QStringLiteral(VER_COMPANYDOMAIN_STR))))
-        {
-            qWarning() << tr("Cannot open your default browser");
-        }
-    });
+    connect(ui->pushButton_Web_Site, &QPushButton::clicked, this,
+            []()
+            {
+                if (not QDesktopServices::openUrl(QUrl(QStringLiteral(VER_COMPANYDOMAIN_STR))))
+                {
+                    qWarning() << tr("Cannot open your default browser");
+                }
+            });
     connect(ui->buttonBox, &QDialogButtonBox::accepted, this, &VPDialogAbout::close);
-    connect(ui->pushButtonCheckUpdate, &QPushButton::clicked, []()
-    {
-        // Set feed URL before doing anything else
-        FvUpdater::sharedUpdater()->SetFeedURL(FvUpdater::CurrentFeedURL());
-        FvUpdater::sharedUpdater()->CheckForUpdatesNotSilent();
-    });
+    connect(ui->pushButtonCheckUpdate, &QPushButton::clicked,
+            []()
+            {
+                // Set feed URL before doing anything else
+                FvUpdater::sharedUpdater()->SetFeedURL(FvUpdater::CurrentFeedURL());
+                FvUpdater::sharedUpdater()->CheckForUpdatesNotSilent();
+            });
 
     // By default on Windows font point size 8 points we need 11 like on Linux.
     FontPointSize(ui->label_Legal_Stuff, 11);
@@ -72,10 +85,7 @@ VPDialogAbout::VPDialogAbout(QWidget *parent)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VPDialogAbout::~VPDialogAbout()
-{
-    delete ui;
-}
+VPDialogAbout::~VPDialogAbout() = default;
 
 //---------------------------------------------------------------------------------------------------------------------
 void VPDialogAbout::changeEvent(QEvent *event)
@@ -94,8 +104,8 @@ void VPDialogAbout::changeEvent(QEvent *event)
 //---------------------------------------------------------------------------------------------------------------------
 void VPDialogAbout::showEvent(QShowEvent *event)
 {
-    QDialog::showEvent( event );
-    if ( event->spontaneous() )
+    QDialog::showEvent(event);
+    if (event->spontaneous())
     {
         return;
     }
@@ -109,7 +119,7 @@ void VPDialogAbout::showEvent(QShowEvent *event)
     setMaximumSize(size());
     setMinimumSize(size());
 
-    m_isInitialized = true;//first show windows are held
+    m_isInitialized = true; // first show windows are held
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -118,18 +128,18 @@ void VPDialogAbout::FontPointSize(QWidget *w, int pointSize)
     SCASSERT(w != nullptr)
 
     QFont font = w->font();
-    font.setPointSize(pointSize);
+    font.setPointSize(qMax(pointSize, 1));
     w->setFont(font);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void VPDialogAbout::RetranslateUi()
 {
-    ui->label_Puzzle_Version->setText(QStringLiteral("Puzzle %1").arg(APP_VERSION_STR));
+    ui->label_Puzzle_Version->setText(QStringLiteral("Puzzle %1").arg(AppVersionStr()));
     ui->labelBuildRevision->setText(tr("Build revision: %1").arg(QStringLiteral(BUILD_REVISION)));
     ui->label_QT_Version->setText(buildCompatibilityString());
 
-    const QDate date = QLocale::c().toDate(QStringLiteral(__DATE__).simplified(), QStringLiteral("MMM d yyyy"));
+    const QDate date = QLocale::c().toDate(QStringLiteral(__DATE__).simplified(), "MMM d yyyy"_L1);
     ui->label_Puzzle_Built->setText(tr("Built on %1 at %2").arg(date.toString(), QStringLiteral(__TIME__)));
 
     ui->label_Legal_Stuff->setText(QApplication::translate("InternalStrings",
