@@ -30,12 +30,11 @@
 #define VPDIALOGABOUT_H
 
 #include <QDialog>
-
-#include "../vmisc/defglobal.h"
+#include <memory>
 
 namespace Ui
 {
-    class VPDialogAbout;
+class VPDialogAbout;
 }
 
 class VPDialogAbout : public QDialog
@@ -47,13 +46,13 @@ public:
     ~VPDialogAbout() override;
 
 protected:
-    void changeEvent(QEvent* event) override;
+    void changeEvent(QEvent *event) override;
     void showEvent(QShowEvent *event) override;
 
 private:
     // cppcheck-suppress unknownMacro
     Q_DISABLE_COPY_MOVE(VPDialogAbout) // NOLINT
-    Ui::VPDialogAbout *ui;
+    std::unique_ptr<Ui::VPDialogAbout> ui;
     bool m_isInitialized;
 
     static void FontPointSize(QWidget *w, int pointSize);
