@@ -27,17 +27,23 @@
  *************************************************************************/
 
 #include "vplayout.h"
-#include "vppiece.h"
-#include "vpsheet.h"
-#include "../vpapplication.h"
-#include "../vptilefactory.h"
+#include "../ifc/exception/vexception.h"
 #include "../ifc/xml/vwatermarkconverter.h"
 #include "../vformat/vwatermark.h"
-#include "../ifc/exception/vexception.h"
+#include "../vpapplication.h"
+#include "../vptilefactory.h"
+#include "vppiece.h"
+#include "vpsheet.h"
 
 #include <QLoggingCategory>
-#include <QUndoStack>
 #include <QPixmapCache>
+#include <QUndoStack>
+
+#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
+#include "../vmisc/compatibility.h"
+#endif
+
+using namespace Qt::Literals::StringLiterals;
 
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_CLANG("-Wmissing-prototypes")
@@ -48,12 +54,15 @@ Q_LOGGING_CATEGORY(pLayout, "p.layout") // NOLINT
 QT_WARNING_POP
 
 //---------------------------------------------------------------------------------------------------------------------
-VPLayout::VPLayout(QUndoStack *undoStack) :
-    m_undoStack(undoStack)
+VPLayout::VPLayout(QUndoStack *undoStack)
+  : m_undoStack(undoStack)
 {
-    SCASSERT(m_undoStack != nullptr)
+    SCASSERT(m_undoStack != nullptr);
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+VPLayout::~VPLayout() = default;
+
 //---------------------------------------------------------------------------------------------------------------------
 auto VPLayout::CreateLayout(QUndoStack *undoStack) -> VPLayoutPtr
 {
@@ -63,8 +72,8 @@ auto VPLayout::CreateLayout(QUndoStack *undoStack) -> VPLayoutPtr
     layout->AddTrashSheet(VPSheetPtr(new VPSheet(layout)));
 
     // create a standard sheet
-    VPSheetPtr sheet(new VPSheet(layout));
-    sheet->SetName(tr("Sheet %1").arg(layout->GetAllSheets().size()+1));
+    VPSheetPtr const sheet(new VPSheet(layout));
+    sheet->SetName(tr("Sheet %1").arg(layout->GetAllSheets().size() + 1));
     layout->AddSheet(sheet);
     layout->SetFocusedSheet(sheet);
 
@@ -74,13 +83,14 @@ auto VPLayout::CreateLayout(QUndoStack *undoStack) -> VPLayoutPtr
 
     layout->LayoutSettings().SetShowTiles(settings->GetLayoutTileShowTiles());
     layout->LayoutSettings().SetShowWatermark(settings->GetLayoutTileShowWatermark());
-    layout->LayoutSettings().SetTilesSize(QSizeF(settings->GetLayoutTilePaperWidth(),
-                                                 settings->GetLayoutTilePaperHeight()));
+    layout->LayoutSettings().SetTilesSize(
+        QSizeF(settings->GetLayoutTilePaperWidth(), settings->GetLayoutTilePaperHeight()));
     layout->LayoutSettings().SetIgnoreTilesMargins(settings->GetLayoutTileIgnoreMargins());
     layout->LayoutSettings().SetTilesMargins(settings->GetLayoutTileMargins());
 
     layout->LayoutSettings().SetWarningSuperpositionOfPieces(settings->GetLayoutWarningPiecesSuperposition());
     layout->LayoutSettings().SetWarningPiecesOutOfBound(settings->GetLayoutWarningPiecesOutOfBound());
+    layout->LayoutSettings().SetWarningPieceGapePosition(settings->GetLayoutWarningPieceGapePosition());
     layout->LayoutSettings().SetFollowGrainline(settings->GetLayoutFollowGrainline());
     layout->LayoutSettings().SetStickyEdges(settings->GetLayoutStickyEdges());
     layout->LayoutSettings().SetPiecesGap(settings->GetLayoutPieceGap());
@@ -88,7 +98,7 @@ auto VPLayout::CreateLayout(QUndoStack *undoStack) -> VPLayoutPtr
     // --------------------------------------------------------
 
     // init the tile factory
-    auto *tileFactory = new VPTileFactory(layout, settings);
+    auto tileFactory = QSharedPointer<VPTileFactory>(new VPTileFactory(layout, settings));
     tileFactory->RefreshTileInfos();
     tileFactory->RefreshWatermarkData();
     layout->SetTileFactory(tileFactory);
@@ -106,19 +116,29 @@ void VPLayout::AddPiece(const VPLayoutPtr &layout, const VPPiecePtr &piece)
 //---------------------------------------------------------------------------------------------------------------------
 void VPLayout::AddPiece(const VPPiecePtr &piece)
 {
-    if (not piece.isNull())
+    if (piece.isNull())
     {
-        if (not m_pieces.contains(piece->GetUniqueID()))
+        return;
+    }
+
+    VPPiece::CleanPosition(piece);
+
+    const QString uniqueId = piece->GetUniqueID();
+    if (not m_pieces.contains(uniqueId))
+    {
+        m_pieces.insert(uniqueId, piece);
+    }
+    else
+    {
+        VPPiecePtr const oldPiece = m_pieces.value(uniqueId);
+        if (not oldPiece.isNull())
         {
-            m_pieces.insert(piece->GetUniqueID(), piece);
+            oldPiece->Update(piece);
+            emit PieceTransformationChanged(oldPiece);
         }
         else
         {
-            VPPiecePtr oldPiece = m_pieces.value(piece->GetUniqueID());
-            if (not oldPiece.isNull())
-            {
-                oldPiece->Update(piece);
-            }
+            m_pieces.insert(uniqueId, piece);
         }
     }
 }
@@ -130,14 +150,15 @@ auto VPLayout::Uuid() const -> const QUuid &
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-auto VPLayout::TileFactory() const -> VPTileFactory *
+auto VPLayout::TileFactory() const -> QSharedPointer<VPTileFactory>
 {
     return m_tileFactory;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VPLayout::SetTileFactory(VPTileFactory *newTileFactory)
+void VPLayout::SetTileFactory(const QSharedPointer<VPTileFactory> &newTileFactory)
 {
+    m_tileFactory.clear();
     m_tileFactory = newTileFactory;
 }
 
@@ -145,7 +166,7 @@ void VPLayout::SetTileFactory(VPTileFactory *newTileFactory)
 void VPLayout::RefreshScenePieces() const
 {
     const QList<VPSheetPtr> sheets = GetSheets();
-    for (const auto& sheet : sheets)
+    for (const auto &sheet : sheets)
     {
         if (not sheet.isNull())
         {
@@ -172,7 +193,7 @@ auto VPLayout::WatermarkData() const -> VWatermarkData
             data.invalidFile = true;
             data.opacity = 20;
             data.showImage = true;
-            data.path = QStringLiteral("fake.png");
+            data.path = "fake.png"_L1;
             data.showText = false;
             return data;
         }
@@ -190,23 +211,24 @@ auto VPLayout::IsSheetsUniform() const -> bool
         return true;
     }
 
-    const VPSheetPtr &sheet = ConstFirst(sheets);
+    const VPSheetPtr &sheet = sheets.constFirst();
     if (sheet.isNull())
     {
         return false;
     }
 
-    QSizeF sheetSize = sheet->GetSheetSize().toSize();
+    QSizeF const sheetSize = sheet->GetSheetSize().toSize();
 
-    return std::all_of(sheets.begin(), sheets.end(), [sheetSize](const VPSheetPtr &sheet)
-    {
-        if (sheet.isNull())
-        {
-            return false;
-        }
-        QSize size = sheet->GetSheetSize().toSize();
-        return size == sheetSize || size.transposed() == sheetSize;
-    });
+    return std::all_of(sheets.begin(), sheets.end(),
+                       [sheetSize](const VPSheetPtr &sheet)
+                       {
+                           if (sheet.isNull())
+                           {
+                               return false;
+                           }
+                           QSize const size = sheet->GetSheetSize().toSize();
+                           return size == sheetSize || size.transposed() == sheetSize;
+                       });
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -221,7 +243,7 @@ auto VPLayout::GetPlacedPieces() const -> QList<VPPiecePtr>
     QList<VPPiecePtr> pieces;
     pieces.reserve(m_pieces.size());
 
-    for (const auto& piece : m_pieces)
+    for (const auto &piece : m_pieces)
     {
         if (not piece->isNull() && piece->Sheet() != VPSheetPtr() && piece->Sheet() != m_trashSheet)
         {
@@ -254,7 +276,7 @@ auto VPLayout::AddSheet(const VPSheetPtr &sheet) -> VPSheetPtr
     if (not sheet.isNull() && GetSheet(sheet->Uuid()).isNull())
     {
         m_sheets.append(sheet);
-        connect(this, &VPLayout::PieceTransformationChanged, sheet.data(), &VPSheet::CheckPiecePositionValidity);
+        connect(this, &VPLayout::PieceTransformationChanged, sheet.data(), &VPSheet::CheckPiecesPositionValidity);
     }
     return sheet;
 }
@@ -284,10 +306,9 @@ auto VPLayout::GetSheets() const -> QList<VPSheetPtr>
 //---------------------------------------------------------------------------------------------------------------------
 auto VPLayout::GetSheet(const QUuid &uuid) -> VPSheetPtr
 {
-    auto sheet = std::find_if(m_sheets.begin(), m_sheets.end(),
-                              [uuid](const VPSheetPtr &sheet) { return sheet->Uuid() == uuid; });
-
-    if (sheet != m_sheets.end())
+    if (auto sheet = std::find_if(m_sheets.begin(), m_sheets.end(),
+                                  [uuid](const VPSheetPtr &sheet) { return sheet->Uuid() == uuid; });
+        sheet != m_sheets.end())
     {
         return *sheet;
     }
@@ -304,9 +325,11 @@ void VPLayout::SetFocusedSheet(const VPSheetPtr &focusedSheet)
     }
     else
     {
-        m_focusedSheet = focusedSheet.isNull() ? ConstFirst(m_sheets) : focusedSheet;
+        m_focusedSheet = focusedSheet.isNull() ? m_sheets.constFirst() : focusedSheet;
     }
 
+    m_focusedSheet->CheckPiecesPositionValidity();
+
     emit ActiveSheetChanged(m_focusedSheet);
 }
 
@@ -322,6 +345,12 @@ auto VPLayout::GetTrashSheet() -> VPSheetPtr
     return m_trashSheet;
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+auto VPLayout::LayoutSettings() const -> const VPLayoutSettings &
+{
+    return m_layoutSettings;
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 auto VPLayout::LayoutSettings() -> VPLayoutSettings &
 {
@@ -334,7 +363,7 @@ auto VPLayout::PiecesForSheet(const VPSheetPtr &sheet) const -> QList<VPPiecePtr
     QList<VPPiecePtr> list;
     list.reserve(m_pieces.size());
 
-    for (const auto& piece : m_pieces)
+    for (const auto &piece : m_pieces)
     {
         if (not piece.isNull() && piece->Sheet() == sheet)
         {
@@ -351,11 +380,11 @@ auto VPLayout::PiecesForSheet(const QUuid &uuid) const -> QList<VPPiecePtr>
     QList<VPPiecePtr> list;
     list.reserve(m_pieces.size());
 
-    for (const auto& piece : m_pieces)
+    for (const auto &piece : m_pieces)
     {
         if (not piece.isNull())
         {
-            VPSheetPtr sheet = piece->Sheet();
+            VPSheetPtr const sheet = piece->Sheet();
             if (not sheet.isNull() && sheet->Uuid() == uuid)
             {
                 list.append(piece);
@@ -400,8 +429,7 @@ void VPLayout::CheckPiecesPositionValidity() const
     {
         if (not sheet.isNull())
         {
-            sheet->ValidateSuperpositionOfPieces();
-            sheet->ValidatePiecesOutOfBound();
+            sheet->CheckPiecesPositionValidity();
         }
     }
 }
