@@ -32,8 +32,8 @@
 #include <QMap>
 #include <QUuid>
 
-#include "vplayoutsettings.h"
 #include "layoutdef.h"
+#include "vplayoutsettings.h"
 
 class VPPiece;
 class VPSheet;
@@ -44,8 +44,9 @@ struct VWatermarkData;
 class VPLayout : public QObject
 {
     Q_OBJECT // NOLINT
+
 public:
-    ~VPLayout() override = default;
+    ~VPLayout() override;
 
     static auto CreateLayout(QUndoStack *undoStack) -> VPLayoutPtr;
     static void AddPiece(const VPLayoutPtr &layout, const VPPiecePtr &piece);
@@ -77,6 +78,7 @@ public:
     void AddTrashSheet(const VPSheetPtr &sheet);
     auto GetTrashSheet() -> VPSheetPtr;
 
+    auto LayoutSettings() const -> const VPLayoutSettings &;
     auto LayoutSettings() -> VPLayoutSettings &;
 
     auto PiecesForSheet(const VPSheetPtr &sheet) const -> QList<VPPiecePtr>;
@@ -90,8 +92,8 @@ public:
 
     void CheckPiecesPositionValidity() const;
 
-    auto TileFactory() const -> VPTileFactory *;
-    void SetTileFactory(VPTileFactory *newTileFactory);
+    auto TileFactory() const -> QSharedPointer<VPTileFactory>;
+    void SetTileFactory(const QSharedPointer<VPTileFactory> &newTileFactory);
 
     void RefreshScenePieces() const;
 
@@ -105,6 +107,7 @@ signals:
     void PieceSheetChanged(const VPPiecePtr &piece);
     void ActiveSheetChanged(const VPSheetPtr &focusedSheet);
     void PieceTransformationChanged(const VPPiecePtr &piece);
+    void BoundaryTogetherWithNotchesChanged(const VPPiecePtr &piece);
     void PieceZValueChanged(const VPPiecePtr &piece);
     void TransformationOriginChanged();
     void SheetListChanged();
@@ -132,7 +135,7 @@ private:
 
     QUndoStack *m_undoStack;
 
-    VPTileFactory *m_tileFactory{nullptr};
+    QSharedPointer<VPTileFactory> m_tileFactory{nullptr};
 
     QUuid m_uuid{QUuid::createUuid()};
 };
