@@ -27,22 +27,222 @@
  *************************************************************************/
 #include "vpsheet.h"
 
-#include "vplayout.h"
-#include "vppiece.h"
+#include "../scene/vpgraphicspiece.h"
+#include "../scene/vpgraphicspiececontrols.h"
+#include "../scene/vpgraphicssheet.h"
+#include "../scene/vpgraphicstilegrid.h"
 #include "../vpapplication.h"
 #include "../vwidgets/vmaingraphicsscene.h"
-#include "../scene/vpgraphicssheet.h"
-#include "../scene/vpgraphicspiece.h"
-#include "../scene/vpgraphicstilegrid.h"
-#include "../scene/vpgraphicspiececontrols.h"
-#include "../scene/vpgraphicstilegrid.h"
+#include "theme/vscenestylesheet.h"
+#include "theme/vstylesheetstyle.h"
+#include "vplayout.h"
+#include "vppiece.h"
+
+#include <QtConcurrent>
+
+namespace
+{
+struct VSheetPiece
+{
+    QString m_id{};
+    bool m_showFullPiece{false};
+    QLineF m_seamMirrorLine{};
+    QLineF m_seamAllowanceMirrorLine{};
+    QVector<QPointF> m_externalContourPoints{};
+};
+
+struct VPiecesValidationData
+{
+    bool m_warnPiecesOutOfBound{false};
+    bool m_warnSuperpositionOfPieces{false};
+    bool m_warnPieceGapePosition{false};
+    bool m_cutOnFold{false};
+    QRectF m_sheetRect{};
+    qreal m_pieceGap{0};
+    QVector<VSheetPiece> m_pieces{};
+};
+
+//---------------------------------------------------------------------------------------------------------------------
+void ValidatePiecesOutOfBound(const VPiecesValidationData &data, QHash<QString, VPiecePositionValidity> &validations)
+{
+
+    for (const auto &piece : data.m_pieces)
+    {
+        VPiecePositionValidity validation = validations.value(piece.m_id);
+
+        if (data.m_cutOnFold && not piece.m_showFullPiece && !piece.m_seamMirrorLine.isNull())
+        {
+            QLineF const foldLine = data.m_sheetRect.width() >= data.m_sheetRect.height()
+                                        ? QLineF(data.m_sheetRect.topLeft(), data.m_sheetRect.topRight())
+                                        : QLineF(data.m_sheetRect.topRight(), data.m_sheetRect.bottomRight());
+
+            validation.m_outOfBound =
+                not VGObject::IsLineSegmentOnLineSegment(foldLine, piece.m_seamAllowanceMirrorLine, MmToPixel(0.5));
+        }
+        else
+        {
+            QRectF const pieceRect = VLayoutPiece::BoundingRect(piece.m_externalContourPoints);
+            validation.m_outOfBound = not data.m_sheetRect.contains(pieceRect);
+        }
+
+        validations.insert(piece.m_id, validation);
+    }
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void ValidateSuperpositionOfPieces(const VPiecesValidationData &data,
+                                   QHash<QString, VPiecePositionValidity> &validations)
+{
+    QSet<QString> invalidPieces;
+    invalidPieces.reserve(data.m_pieces.size());
+
+    for (const auto &piece : data.m_pieces)
+    {
+        if (invalidPieces.contains(piece.m_id))
+        {
+            continue;
+        }
+
+        bool hasSuperposition = false;
+        VSheetPiece invalidPiece;
+
+        for (const auto &p : data.m_pieces)
+        {
+            if (piece.m_id == p.m_id)
+            {
+                continue;
+            }
+
+            if (VPPiece::PathsSuperposition(piece.m_externalContourPoints, p.m_externalContourPoints))
+            {
+                hasSuperposition = true;
+                invalidPiece = p;
+                break;
+            }
+        }
+
+        auto UpdateValidity = [&validations, hasSuperposition, &invalidPieces](const QString &id)
+        {
+            VPiecePositionValidity validation = validations.value(id);
+            validation.m_superposition = hasSuperposition;
+            validations.insert(id, validation);
+            if (hasSuperposition)
+            {
+                invalidPieces.insert(id);
+            }
+        };
+
+        UpdateValidity(piece.m_id);
+
+        if (!invalidPiece.m_id.isEmpty())
+        {
+            UpdateValidity(invalidPiece.m_id);
+        }
+    }
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void ValidatePiecesGapePosition(const VPiecesValidationData &data, QHash<QString, VPiecePositionValidity> &validations)
+{
+    if (data.m_pieceGap <= 0)
+    {
+        return;
+    }
+
+    QSet<QString> invalidPieces;
+    invalidPieces.reserve(data.m_pieces.size());
+
+    for (const auto &piece : data.m_pieces)
+    {
+        if (invalidPieces.contains(piece.m_id))
+        {
+            continue;
+        }
+
+        QRectF const path1Rect = VLayoutPiece::BoundingRect(piece.m_externalContourPoints)
+                                     .adjusted(-data.m_pieceGap, -data.m_pieceGap, data.m_pieceGap, data.m_pieceGap);
+        QVector<QPointF> const path1 = VPPiece::PrepareStickyPath(piece.m_externalContourPoints);
+        bool hasInvalidPieceGapPosition = false;
+        VSheetPiece invalidPiece;
+
+        for (const auto &p : data.m_pieces)
+        {
+            if (piece.m_id == p.m_id)
+            {
+                continue;
+            }
+
+            QRectF const path2Rect =
+                VLayoutPiece::BoundingRect(p.m_externalContourPoints)
+                    .adjusted(-data.m_pieceGap, -data.m_pieceGap, data.m_pieceGap, data.m_pieceGap);
+
+            if (!path1Rect.intersects(path2Rect) && !path1Rect.contains(path2Rect) && !path2Rect.contains(path1Rect))
+            {
+                continue;
+            }
+
+            QVector<QPointF> const path2 = VPPiece::PrepareStickyPath(p.m_externalContourPoints);
+
+            QLineF const distance = VPPiece::ClosestDistance(path1, path2);
+
+            if (distance.length() < data.m_pieceGap - accuracyPointOnLine)
+            {
+                hasInvalidPieceGapPosition = true;
+                invalidPiece = p;
+                break;
+            }
+        }
+
+        auto UpdateValidity = [&validations, hasInvalidPieceGapPosition, &invalidPieces](const QString &id)
+        {
+            VPiecePositionValidity validation = validations.value(id);
+            validation.m_gap = hasInvalidPieceGapPosition;
+            validations.insert(id, validation);
+            if (hasInvalidPieceGapPosition)
+            {
+                invalidPieces.insert(id);
+            }
+        };
+
+        UpdateValidity(piece.m_id);
+
+        if (!invalidPiece.m_id.isEmpty())
+        {
+            UpdateValidity(invalidPiece.m_id);
+        }
+    }
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto ValidatePiecesPositions(const VPiecesValidationData &data) -> QHash<QString, VPiecePositionValidity>
+{
+    QHash<QString, VPiecePositionValidity> validations;
+
+    if (data.m_warnPiecesOutOfBound)
+    {
+        ValidatePiecesOutOfBound(data, validations);
+    }
+
+    if (data.m_warnSuperpositionOfPieces)
+    {
+        ValidateSuperpositionOfPieces(data, validations);
+    }
+
+    if (data.m_warnPieceGapePosition)
+    {
+        ValidatePiecesGapePosition(data, validations);
+    }
+
+    return validations;
+}
+} // namespace
 
 // VPSheetSceneData
 //---------------------------------------------------------------------------------------------------------------------
 VPSheetSceneData::VPSheetSceneData(const VPLayoutPtr &layout, const QUuid &sheetUuid)
-    : m_layout(layout),
-      m_scene(new VMainGraphicsScene()),
-      m_sheetUuid(sheetUuid)
+  : m_layout(layout),
+    m_scene(QSharedPointer<VMainGraphicsScene>::create()),
+    m_sheetUuid(sheetUuid)
 {
     SCASSERT(not layout.isNull())
 
@@ -60,20 +260,17 @@ VPSheetSceneData::VPSheetSceneData(const VPLayoutPtr &layout, const QUuid &sheet
     m_rotationOrigin->setVisible(false);
     m_scene->addItem(m_rotationOrigin);
 
-    QObject::connect(m_rotationControls, &VPGraphicsPieceControls::ShowOrigin,
-                     m_rotationOrigin, &VPGraphicsTransformationOrigin::on_ShowOrigin);
-    QObject::connect(m_rotationControls, &VPGraphicsPieceControls::TransformationOriginChanged,
-                     m_rotationOrigin, &VPGraphicsTransformationOrigin::SetTransformationOrigin);
+    QObject::connect(m_rotationControls, &VPGraphicsPieceControls::ShowOrigin, m_rotationOrigin,
+                     &VPGraphicsTransformationOrigin::on_ShowOrigin);
+    QObject::connect(m_rotationControls, &VPGraphicsPieceControls::TransformationOriginChanged, m_rotationOrigin,
+                     &VPGraphicsTransformationOrigin::SetTransformationOrigin);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VPSheetSceneData::~VPSheetSceneData()
-{
-    delete m_scene;
-}
+VPSheetSceneData::~VPSheetSceneData() = default;
 
 //---------------------------------------------------------------------------------------------------------------------
-auto VPSheetSceneData::Scene() const -> VMainGraphicsScene *
+auto VPSheetSceneData::Scene() const -> QSharedPointer<VMainGraphicsScene>
 {
     return m_scene;
 }
@@ -94,42 +291,55 @@ void VPSheetSceneData::RefreshPieces()
     qDeleteAll(m_graphicsPieces);
     m_graphicsPieces.clear();
 
-    VPLayoutPtr layout = m_layout.toStrongRef();
-    if(layout.isNull())
+    VPLayoutPtr const layout = m_layout.toStrongRef();
+    if (layout.isNull())
     {
         return;
     }
 
-    VPSheetPtr sheet = layout->GetSheet(m_sheetUuid);
-    if (not sheet.isNull())
+    VPSheetPtr const sheet = layout->GetSheet(m_sheetUuid);
+    if (sheet.isNull())
     {
-        QList<VPPiecePtr> pieces = sheet->GetPieces();
-        m_graphicsPieces.reserve(pieces.size());
+        return;
+    }
 
-        for (const auto &piece : pieces)
+    QList<VPPiecePtr> const pieces = sheet->GetPieces();
+    m_graphicsPieces.reserve(pieces.size());
+
+    for (const auto &piece : pieces)
+    {
+        if (piece.isNull())
         {
-            if (not piece.isNull())
-            {
-                auto *graphicsPiece = new VPGraphicsPiece(piece);
-                m_graphicsPieces.append(graphicsPiece);
-                m_scene->addItem(graphicsPiece);
-                ConnectPiece(graphicsPiece);
-            }
+            continue;
         }
+
+        auto *graphicsPiece = new VPGraphicsPiece(piece);
+        m_graphicsPieces.append(graphicsPiece);
+        m_scene->addItem(graphicsPiece);
+
+        // Restore selection state
+        if (piece->IsSelected())
+        {
+            graphicsPiece->setSelected(piece->IsSelected());
+        }
+
+        ConnectPiece(graphicsPiece);
     }
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void VPSheetSceneData::PrepareForExport()
 {
+    VStylesheetStyle::SetExportColorScheme(ExportColorScheme::BackAndWhite);
+    VSceneStylesheet::ResetStyles();
+
     m_graphicsSheet->SetShowBorder(false);
     m_graphicsSheet->SetShowMargin(false);
 
     m_rotationControls->setVisible(false);
     m_rotationOrigin->setVisible(false);
 
-    VPLayoutPtr layout = m_layout.toStrongRef();
-    if (not layout.isNull())
+    if (VPLayoutPtr const layout = m_layout.toStrongRef(); not layout.isNull())
     {
         m_showGridTmp = layout->LayoutSettings().GetShowGrid();
         layout->LayoutSettings().SetShowGrid(false);
@@ -137,10 +347,10 @@ void VPSheetSceneData::PrepareForExport()
         m_showTilesTmp = layout->LayoutSettings().GetShowTiles();
         layout->LayoutSettings().SetShowTiles(false);
 
-        VPSheetPtr sheet = layout->GetSheet(m_sheetUuid);
+        VPSheetPtr const sheet = layout->GetSheet(m_sheetUuid);
         m_slectedPiecesTmp = sheet->GetSelectedPieces();
 
-        for (const auto& piece : qAsConst(m_slectedPiecesTmp))
+        for (const auto &piece : qAsConst(m_slectedPiecesTmp))
         {
             if (not piece.isNull())
             {
@@ -153,6 +363,9 @@ void VPSheetSceneData::PrepareForExport()
 
         m_pieceSuperpositionTmp = layout->LayoutSettings().GetWarningSuperpositionOfPieces();
         layout->LayoutSettings().SetWarningSuperpositionOfPieces(false);
+
+        m_pieceGapePositionTmp = layout->LayoutSettings().GetWarningPieceGapePosition();
+        layout->LayoutSettings().SetWarningPieceGapePosition(false);
     }
 
     RefreshLayout();
@@ -162,18 +375,20 @@ void VPSheetSceneData::PrepareForExport()
 //---------------------------------------------------------------------------------------------------------------------
 void VPSheetSceneData::CleanAfterExport()
 {
+    VStylesheetStyle::SetExportColorScheme(ExportColorScheme::Default);
+    VSceneStylesheet::ResetStyles();
+
     m_graphicsSheet->SetShowBorder(true);
     m_graphicsSheet->SetShowMargin(true);
 
     m_rotationControls->setVisible(true);
 
-    VPLayoutPtr layout = m_layout.toStrongRef();
-    if (not layout.isNull())
+    if (VPLayoutPtr const layout = m_layout.toStrongRef(); not layout.isNull())
     {
         layout->LayoutSettings().SetShowGrid(m_showGridTmp);
         layout->LayoutSettings().SetShowTiles(m_showTilesTmp);
 
-        for (const auto& piece : qAsConst(m_slectedPiecesTmp))
+        for (const auto &piece : qAsConst(m_slectedPiecesTmp))
         {
             if (not piece.isNull())
             {
@@ -184,6 +399,7 @@ void VPSheetSceneData::CleanAfterExport()
 
         layout->LayoutSettings().SetWarningPiecesOutOfBound(m_outOfBoundTmp);
         layout->LayoutSettings().SetWarningSuperpositionOfPieces(m_pieceSuperpositionTmp);
+        layout->LayoutSettings().SetWarningPieceGapePosition(m_pieceGapePositionTmp);
     }
 
     RefreshLayout();
@@ -202,7 +418,7 @@ auto VPSheetSceneData::GraphicsPiecesAsItems() const -> QList<QGraphicsItem *>
     QList<QGraphicsItem *> items;
     items.reserve(m_graphicsPieces.size());
 
-    for(auto *item : m_graphicsPieces)
+    for (auto *item : m_graphicsPieces)
     {
         items.append(item);
     }
@@ -219,11 +435,10 @@ auto VPSheetSceneData::RotationControls() const -> VPGraphicsPieceControls *
 //---------------------------------------------------------------------------------------------------------------------
 auto VPSheetSceneData::ScenePiece(const VPPiecePtr &piece) const -> VPGraphicsPiece *
 {
-    auto _graphicsPiece =
+    if (auto _graphicsPiece =
             std::find_if(m_graphicsPieces.begin(), m_graphicsPieces.end(),
                          [piece](VPGraphicsPiece *graphicPiece) { return graphicPiece->GetPiece() == piece; });
-
-    if (_graphicsPiece != m_graphicsPieces.end())
+        _graphicsPiece != m_graphicsPieces.end())
     {
         return *_graphicsPiece;
     }
@@ -259,8 +474,7 @@ void VPSheetSceneData::SetTextAsPaths(bool textAsPaths) const
 //---------------------------------------------------------------------------------------------------------------------
 void VPSheetSceneData::PrepareTilesScheme()
 {
-    VPLayoutPtr layout = m_layout.toStrongRef();
-    if (not layout.isNull())
+    if (VPLayoutPtr const layout = m_layout.toStrongRef(); not layout.isNull())
     {
         m_showTilesSchemeTmp = layout->LayoutSettings().GetShowTiles();
         layout->LayoutSettings().SetShowTiles(true);
@@ -275,8 +489,7 @@ void VPSheetSceneData::PrepareTilesScheme()
 //---------------------------------------------------------------------------------------------------------------------
 void VPSheetSceneData::ClearTilesScheme()
 {
-    VPLayoutPtr layout = m_layout.toStrongRef();
-    if (not layout.isNull())
+    if (VPLayoutPtr const layout = m_layout.toStrongRef(); not layout.isNull())
     {
         layout->LayoutSettings().SetShowTiles(m_showTilesSchemeTmp);
         layout->LayoutSettings().SetShowWatermark(m_showTilesWatermarkSchemeTmp);
@@ -295,38 +508,38 @@ void VPSheetSceneData::RefreshSheetSize()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VPSheetSceneData::ConnectPiece(VPGraphicsPiece *piece)
+void VPSheetSceneData::ConnectPiece(VPGraphicsPiece *piece) const
 {
     SCASSERT(piece != nullptr)
 
-    VPLayoutPtr layout = m_layout.toStrongRef();
+    VPLayoutPtr const layout = m_layout.toStrongRef();
     if (layout.isNull())
     {
         return;
     }
 
-    QObject::connect(layout.data(), &VPLayout::PieceTransformationChanged, piece,
+    QObject::connect(layout.data(), &VPLayout::PieceTransformationChanged, piece, &VPGraphicsPiece::on_RefreshPiece);
+    QObject::connect(layout.data(), &VPLayout::PieceZValueChanged, piece, &VPGraphicsPiece::PieceZValueChanged);
+    QObject::connect(layout.data(), &VPLayout::PieceSelectionChanged, m_rotationControls,
+                     &VPGraphicsPieceControls::on_UpdateControls, Qt::UniqueConnection);
+    QObject::connect(layout.data(), &VPLayout::PiecePositionValidityChanged, piece, &VPGraphicsPiece::on_RefreshPiece);
+    QObject::connect(piece, &VPGraphicsPiece::PieceTransformationChanged, m_rotationControls,
+                     &VPGraphicsPieceControls::on_UpdateControls);
+    QObject::connect(piece, &VPGraphicsPiece::HideTransformationHandles, m_rotationControls,
+                     &VPGraphicsPieceControls::on_HideHandles);
+    QObject::connect(piece, &VPGraphicsPiece::HideTransformationHandles, m_rotationOrigin,
+                     &VPGraphicsTransformationOrigin::on_HideHandles);
+    QObject::connect(layout.data(), &VPLayout::BoundaryTogetherWithNotchesChanged, piece,
                      &VPGraphicsPiece::on_RefreshPiece);
-    QObject::connect(layout.data(), &VPLayout::PieceZValueChanged, piece,
-                     &VPGraphicsPiece::PieceZValueChanged);
-    QObject::connect(layout.data(), &VPLayout::PieceSelectionChanged,
-                     m_rotationControls, &VPGraphicsPieceControls::on_UpdateControls);
-    QObject::connect(layout.data(), &VPLayout::PiecePositionValidityChanged,
-                     piece, &VPGraphicsPiece::on_RefreshPiece);
-    QObject::connect(piece, &VPGraphicsPiece::PieceTransformationChanged,
-                     m_rotationControls, &VPGraphicsPieceControls::on_UpdateControls);
-    QObject::connect(piece, &VPGraphicsPiece::HideTransformationHandles,
-                     m_rotationControls, &VPGraphicsPieceControls::on_HideHandles);
-    QObject::connect(piece, &VPGraphicsPiece::HideTransformationHandles,
-                     m_rotationOrigin, &VPGraphicsTransformationOrigin::on_HideHandles);
 }
 
 // VPSheet
 //---------------------------------------------------------------------------------------------------------------------
 VPSheet::VPSheet(const VPLayoutPtr &layout, QObject *parent)
-    : QObject(parent),
-      m_layout(layout),
-      m_sceneData(new VPSheetSceneData(layout, Uuid()))
+  : QObject(parent),
+    m_layout(layout),
+    m_sceneData(QSharedPointer<VPSheetSceneData>::create(layout, Uuid())),
+    m_validityWatcher(new QFutureWatcher<QHash<QString, VPiecePositionValidity>>(this))
 {
     SCASSERT(not layout.isNull())
 
@@ -334,6 +547,21 @@ VPSheet::VPSheet(const VPLayoutPtr &layout, QObject *parent)
     SetIgnoreMargins(settings->GetLayoutSheetIgnoreMargins());
     SetSheetMargins(settings->GetLayoutSheetMargins());
     SetSheetSize(QSizeF(settings->GetLayoutSheetPaperWidth(), settings->GetLayoutSheetPaperHeight()));
+
+    connect(qApp, &QCoreApplication::aboutToQuit, m_validityWatcher,
+            [this]()
+            {
+                m_validityWatcher->cancel();
+                m_validityWatcher->waitForFinished();
+            });
+    connect(m_validityWatcher, &QFutureWatcher<QHash<QString, VPiecePositionValidity>>::finished, this,
+            &VPSheet::UpdatePiecesValidity);
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+VPSheet::~VPSheet()
+{
+    m_validityWatcher->cancel();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -345,8 +573,7 @@ auto VPSheet::GetLayout() const -> VPLayoutPtr
 //---------------------------------------------------------------------------------------------------------------------
 auto VPSheet::GetPieces() const -> QList<VPPiecePtr>
 {
-    VPLayoutPtr layout = GetLayout();
-    if (not layout.isNull())
+    if (VPLayoutPtr const layout = GetLayout(); not layout.isNull())
     {
         return layout->PiecesForSheet(m_uuid);
     }
@@ -357,15 +584,14 @@ auto VPSheet::GetPieces() const -> QList<VPPiecePtr>
 //---------------------------------------------------------------------------------------------------------------------
 auto VPSheet::GetSelectedPieces() const -> QList<VPPiecePtr>
 {
-    VPLayoutPtr layout = GetLayout();
-    if (not layout.isNull())
+    if (VPLayoutPtr const layout = GetLayout(); not layout.isNull())
     {
-        QList<VPPiecePtr> list = layout->PiecesForSheet(m_uuid);
+        QList<VPPiecePtr> const list = layout->PiecesForSheet(m_uuid);
 
         QList<VPPiecePtr> selected;
         selected.reserve(list.size());
 
-        for (const auto& piece : list)
+        for (const auto &piece : list)
         {
             if (not piece.isNull() && piece->IsSelected())
             {
@@ -382,12 +608,12 @@ auto VPSheet::GetSelectedPieces() const -> QList<VPPiecePtr>
 //---------------------------------------------------------------------------------------------------------------------
 auto VPSheet::GetAsLayoutPieces() const -> QVector<VLayoutPiece>
 {
-    QList<VPPiecePtr> pieces = GetPieces();
+    QList<VPPiecePtr> const pieces = GetPieces();
 
     QVector<VLayoutPiece> details;
     details.reserve(pieces.size());
 
-    for (const auto& piece : pieces)
+    for (const auto &piece : pieces)
     {
         if (not piece.isNull())
         {
@@ -494,88 +720,6 @@ void VPSheet::SetTrashSheet(bool newTrashSheet)
     m_trashSheet = newTrashSheet;
 }
 
-//---------------------------------------------------------------------------------------------------------------------
-void VPSheet::ValidateSuperpositionOfPieces() const
-{
-    QList<VPPiecePtr> pieces = GetPieces();
-
-    for (const auto &piece : pieces)
-    {
-        if (piece.isNull())
-        {
-            continue;
-        }
-
-        const bool oldSuperpositionOfPieces = piece->HasSuperpositionWithPieces();
-        QVector<QPointF> path1 = piece->GetMappedExternalContourPoints();
-        bool hasSuperposition = false;
-
-        for (const auto &p : pieces)
-        {
-            if (p.isNull() || piece == p)
-            {
-                continue;
-            }
-
-            QVector<QPointF> path2 = p->GetMappedExternalContourPoints();
-
-            bool superposition = VPPiece::PathsSuperposition(path1, path2);
-            if (superposition)
-            {
-                hasSuperposition = superposition;
-                break;
-            }
-        }
-
-        piece->SetHasSuperpositionWithPieces(hasSuperposition);
-
-        if (oldSuperpositionOfPieces != piece->HasSuperpositionWithPieces())
-        {
-            VPLayoutPtr layout = GetLayout();
-            if (not layout.isNull())
-            {
-                emit layout->PiecePositionValidityChanged(piece);
-            }
-        }
-    }
-}
-
-//---------------------------------------------------------------------------------------------------------------------
-void VPSheet::ValidatePieceOutOfBound(const VPPiecePtr &piece) const
-{
-    if (piece.isNull())
-    {
-        return;
-    }
-
-    const bool oldOutOfBound = piece->OutOfBound();
-
-    QRectF pieceRect = piece->MappedDetailBoundingRect();
-    QRectF sheetRect = GetMarginsRect();
-
-    piece->SetOutOfBound(not sheetRect.contains(pieceRect));
-
-    if (oldOutOfBound != piece->OutOfBound())
-    {
-        VPLayoutPtr layout = GetLayout();
-        if (not layout.isNull())
-        {
-            emit layout->PiecePositionValidityChanged(piece);
-        }
-    }
-
-}
-
-//---------------------------------------------------------------------------------------------------------------------
-void VPSheet::ValidatePiecesOutOfBound() const
-{
-    QList<VPPiecePtr> pieces = GetPieces();
-    for (const auto &piece : pieces)
-    {
-        ValidatePieceOutOfBound(piece);
-    }
-}
-
 //---------------------------------------------------------------------------------------------------------------------
 auto VPSheet::GetSheetRect() const -> QRectF
 {
@@ -587,8 +731,8 @@ auto VPSheet::GetMarginsRect() const -> QRectF
 {
     if (not m_ignoreMargins)
     {
-        QRectF rect = QRectF(QPointF(m_margins.left(), m_margins.top()),
-                             QPointF(m_size.width() - m_margins.right(), m_size.height() - m_margins.bottom()));
+        auto rect = QRectF(QPointF(m_margins.left(), m_margins.top()),
+                           QPointF(m_size.width() - m_margins.right(), m_size.height() - m_margins.bottom()));
         return rect;
     }
 
@@ -598,13 +742,13 @@ auto VPSheet::GetMarginsRect() const -> QRectF
 //---------------------------------------------------------------------------------------------------------------------
 void VPSheet::RemoveUnusedLength()
 {
-    VPLayoutPtr layout = GetLayout();
+    VPLayoutPtr const layout = GetLayout();
     if (layout.isNull())
     {
         return;
     }
 
-    QList<VPPiecePtr> pieces = GetPieces();
+    QList<VPPiecePtr> const pieces = GetPieces();
     if (pieces.isEmpty())
     {
         return;
@@ -612,7 +756,7 @@ void VPSheet::RemoveUnusedLength()
 
     QRectF piecesBoundingRect;
 
-    for (const auto& piece : pieces)
+    for (const auto &piece : pieces)
     {
         if (not piece.isNull())
         {
@@ -623,8 +767,8 @@ void VPSheet::RemoveUnusedLength()
     }
 
     const qreal extra = 2;
-    QRectF sheetRect = GetSheetRect();
-    GrainlineType type = GrainlineOrientation();
+    QRectF const sheetRect = GetSheetRect();
+    GrainlineType const type = GrainlineOrientation();
 
     if (type == GrainlineType::Vertical)
     {
@@ -655,33 +799,101 @@ void VPSheet::RemoveUnusedLength()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VPSheet::CheckPiecePositionValidity(const VPPiecePtr &piece) const
+void VPSheet::CheckPiecesPositionValidity() const
 {
-    VPLayoutPtr layout = GetLayout();
+    if (m_validityWatcher->isFinished())
+    {
+        VPLayoutPtr const layout = GetLayout();
+        if (layout.isNull())
+        {
+            return;
+        }
+
+        VPiecesValidationData data;
+        data.m_warnPiecesOutOfBound = layout->LayoutSettings().GetWarningPiecesOutOfBound();
+        data.m_warnSuperpositionOfPieces = layout->LayoutSettings().GetWarningSuperpositionOfPieces();
+        data.m_warnPieceGapePosition = layout->LayoutSettings().GetWarningPieceGapePosition();
+        data.m_cutOnFold = layout->LayoutSettings().IsCutOnFold();
+        data.m_sheetRect = GetMarginsRect();
+        data.m_pieceGap = layout->LayoutSettings().GetPiecesGap();
+
+        QList<VPPiecePtr> const pieces = GetPieces();
+        QVector<VSheetPiece> sheetPieces;
+        sheetPieces.reserve(pieces.size());
+
+        for (const auto &piece : pieces)
+        {
+            VSheetPiece data;
+            data.m_showFullPiece = piece->IsShowFullPiece();
+            data.m_id = piece->GetUniqueID();
+            data.m_seamMirrorLine = piece->GetMappedSeamMirrorLine();
+            data.m_seamAllowanceMirrorLine = piece->GetMappedSeamAllowanceMirrorLine();
+
+            QVector<QPointF> points;
+            CastTo(piece->GetMappedExternalContourPoints(), points);
+            data.m_externalContourPoints = points;
+
+            sheetPieces.append(data);
+        }
+
+        data.m_pieces = sheetPieces;
+
+        m_validationStale = false;
+        m_validityWatcher->setFuture(QtConcurrent::run([data]() { return ValidatePiecesPositions(data); }));
+    }
+    else
+    {
+        m_validationStale = true;
+    }
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VPSheet::UpdatePiecesValidity()
+{
+    if (m_validityWatcher->isCanceled())
+    {
+        return;
+    }
+
+    QHash<QString, VPiecePositionValidity> const newValidations = m_validityWatcher->future().result();
+
+    QList<VPPiecePtr> const pieces = GetPieces();
+    QHash<QString, VPPiecePtr> sortedPieces;
+    sortedPieces.reserve(pieces.size());
+
+    for (const auto &piece : pieces)
+    {
+        sortedPieces.insert(piece->GetUniqueID(), piece);
+    }
+
+    VPLayoutPtr const layout = GetLayout();
     if (layout.isNull())
     {
         return;
     }
 
-    QList<VPPiecePtr> pieces = GetPieces();
-    if (piece.isNull() || not pieces.contains(piece))
+    for (auto i = newValidations.cbegin(), end = newValidations.cend(); i != end; ++i)
     {
-        return;
+        if (sortedPieces.contains(i.key()))
+        {
+            VPPiecePtr const piece = sortedPieces.value(i.key());
+            piece->SetOutOfBound(i.value().m_outOfBound);
+            piece->SetHasSuperpositionWithPieces(i.value().m_superposition);
+            piece->SetHasInvalidPieceGapPosition(i.value().m_gap);
+
+            emit layout->PiecePositionValidityChanged(piece);
+        }
     }
 
-    if (layout->LayoutSettings().GetWarningPiecesOutOfBound())
+    if (m_validationStale)
     {
-        ValidatePieceOutOfBound(piece);
-    }
-
-    if (layout->LayoutSettings().GetWarningSuperpositionOfPieces())
-    {
-        ValidateSuperpositionOfPieces();
+        m_validationStale = false;
+        CheckPiecesPositionValidity();
     }
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-auto VPSheet::SceneData() const -> VPSheetSceneData *
+auto VPSheet::SceneData() const -> QSharedPointer<VPSheetSceneData>
 {
     return m_sceneData;
 }
@@ -689,8 +901,8 @@ auto VPSheet::SceneData() const -> VPSheetSceneData *
 //---------------------------------------------------------------------------------------------------------------------
 void VPSheet::ClearSelection() const
 {
-    QList<VPPiecePtr> selectedPieces = GetSelectedPieces();
-    for (const auto& piece : selectedPieces)
+    QList<VPPiecePtr> const selectedPieces = GetSelectedPieces();
+    for (const auto &piece : selectedPieces)
     {
         if (piece->IsSelected())
         {
@@ -700,7 +912,7 @@ void VPSheet::ClearSelection() const
 
     if (not selectedPieces.isEmpty())
     {
-        VPLayoutPtr layout = GetLayout();
+        VPLayoutPtr const layout = GetLayout();
         if (not layout.isNull())
         {
             emit layout->PieceSelectionChanged(VPPiecePtr());
@@ -717,8 +929,7 @@ auto VPSheet::GetSheetOrientation() const -> QPageLayout::Orientation
 //---------------------------------------------------------------------------------------------------------------------
 auto VPSheet::SheetUnits() const -> Unit
 {
-    VPLayoutPtr layout = GetLayout();
-    if (not layout.isNull())
+    if (VPLayoutPtr const layout = GetLayout(); not layout.isNull())
     {
         return layout->LayoutSettings().GetUnit();
     }
@@ -741,7 +952,7 @@ void VPSheet::SetSheetSize(qreal width, qreal height)
 //---------------------------------------------------------------------------------------------------------------------
 void VPSheet::SetSheetSizeConverted(qreal width, qreal height)
 {
-    Unit unit = SheetUnits();
+    Unit const unit = SheetUnits();
     m_size.setWidth(UnitConvertor(width, unit, Unit::Px));
     m_size.setHeight(UnitConvertor(height, unit, Unit::Px));
 
@@ -765,9 +976,8 @@ void VPSheet::SetSheetSize(const QSizeF &size)
 //---------------------------------------------------------------------------------------------------------------------
 void VPSheet::SetSheetSizeConverted(const QSizeF &size)
 {
-    Unit unit = SheetUnits();
-    m_size = QSizeF(UnitConvertor(size.width(), unit, Unit::Px),
-                    UnitConvertor(size.height(), unit, Unit::Px));
+    Unit const unit = SheetUnits();
+    m_size = QSizeF(UnitConvertor(size.width(), unit, Unit::Px), UnitConvertor(size.height(), unit, Unit::Px));
 
     if (m_sceneData != nullptr)
     {
@@ -784,11 +994,9 @@ auto VPSheet::GetSheetSize() const -> QSizeF
 //---------------------------------------------------------------------------------------------------------------------
 auto VPSheet::GetSheetSizeConverted() const -> QSizeF
 {
-    Unit unit = SheetUnits();
-    QSizeF convertedSize = QSizeF(
-                UnitConvertor(m_size.width(), Unit::Px, unit),
-                UnitConvertor(m_size.height(), Unit::Px, unit)
-                );
+    Unit const unit = SheetUnits();
+    auto convertedSize =
+        QSizeF(UnitConvertor(m_size.width(), Unit::Px, unit), UnitConvertor(m_size.height(), Unit::Px, unit));
 
     return convertedSize;
 }
@@ -804,7 +1012,7 @@ void VPSheet::SetSheetMargins(qreal left, qreal top, qreal right, qreal bottom)
 //---------------------------------------------------------------------------------------------------------------------
 void VPSheet::SetSheetMarginsConverted(qreal left, qreal top, qreal right, qreal bottom)
 {
-    Unit unit = SheetUnits();
+    Unit const unit = SheetUnits();
     m_margins.setLeft(UnitConvertor(left, unit, Unit::Px));
     m_margins.setTop(UnitConvertor(top, unit, Unit::Px));
     m_margins.setRight(UnitConvertor(right, unit, Unit::Px));
@@ -820,7 +1028,7 @@ void VPSheet::SetSheetMargins(const QMarginsF &margins)
 //---------------------------------------------------------------------------------------------------------------------
 void VPSheet::SetSheetMarginsConverted(const QMarginsF &margins)
 {
-    Unit unit = SheetUnits();
+    Unit const unit = SheetUnits();
     m_margins = UnitConvertor(margins, unit, Unit::Px);
 }
 
@@ -833,7 +1041,7 @@ auto VPSheet::GetSheetMargins() const -> QMarginsF
 //---------------------------------------------------------------------------------------------------------------------
 auto VPSheet::GetSheetMarginsConverted() const -> QMarginsF
 {
-    Unit unit = SheetUnits();
+    Unit const unit = SheetUnits();
     return UnitConvertor(m_margins, Unit::Px, unit);
 }
 
