@@ -28,18 +28,17 @@
 #ifndef VPSHEET_H
 #define VPSHEET_H
 
-#include <QSizeF>
-#include <QMarginsF>
-#include <QList>
 #include <QComboBox>
+#include <QFutureWatcher>
+#include <QList>
+#include <QMarginsF>
+#include <QPageLayout>
+#include <QSizeF>
 #include <QUuid>
 
-#include "def.h"
 #include "layoutdef.h"
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 13, 0)
-#include "../vmisc/defglobal.h"
-#endif // QT_VERSION < QT_VERSION_CHECK(5, 13, 0)
+#include "../vmisc/def.h"
 
 class VPLayout;
 class VPPiece;
@@ -50,6 +49,14 @@ class VPGraphicsPiece;
 class VPGraphicsTileGrid;
 class VPGraphicsSheet;
 class VLayoutPiece;
+class QGraphicsItem;
+
+struct VPiecePositionValidity
+{
+    bool m_outOfBound{false};
+    bool m_superposition{false};
+    bool m_gap{false};
+};
 
 class VPSheetSceneData
 {
@@ -57,7 +64,7 @@ public:
     explicit VPSheetSceneData(const VPLayoutPtr &layout, const QUuid &sheetUuid);
     ~VPSheetSceneData();
 
-    auto Scene() const -> VMainGraphicsScene *;
+    auto Scene() const -> QSharedPointer<VMainGraphicsScene>;
 
     /**
      * @brief RefreshLayout Refreshes the rectangles for the layout border and the margin
@@ -99,7 +106,7 @@ private:
 
     VPLayoutWeakPtr m_layout{};
 
-    VMainGraphicsScene *m_scene;
+    QSharedPointer<VMainGraphicsScene> m_scene{nullptr};
 
     VPGraphicsSheet *m_graphicsSheet{nullptr};
 
@@ -108,7 +115,7 @@ private:
     VPGraphicsPieceControls *m_rotationControls{nullptr};
     VPGraphicsTransformationOrigin *m_rotationOrigin{nullptr};
 
-    QList<VPGraphicsPiece*> m_graphicsPieces{};
+    QList<VPGraphicsPiece *> m_graphicsPieces{};
 
     /**
      * variable to hold temporarly hte value of the show tiles
@@ -129,17 +136,19 @@ private:
 
     bool m_outOfBoundTmp{false};
     bool m_pieceSuperpositionTmp{false};
+    bool m_pieceGapePositionTmp{false};
 
-    void ConnectPiece(VPGraphicsPiece *piece);
+    void ConnectPiece(VPGraphicsPiece *piece) const;
 };
 
 class VPSheet : public QObject
 {
     Q_OBJECT // NOLINT
+
 public:
     explicit VPSheet(const VPLayoutPtr &layout, QObject *parent = nullptr);
 
-    ~VPSheet() override = default;
+    ~VPSheet() override;
 
     /**
      * @brief GetLayout Returns the Layout of the sheet
@@ -182,10 +191,6 @@ public:
     auto TrashSheet() const -> bool;
     void SetTrashSheet(bool newTrashSheet);
 
-    void ValidateSuperpositionOfPieces() const;
-    void ValidatePieceOutOfBound(const VPPiecePtr &piece) const;
-    void ValidatePiecesOutOfBound() const;
-
     auto GetSheetRect() const -> QRectF;
     auto GetMarginsRect() const -> QRectF;
 
@@ -273,14 +278,17 @@ public:
     auto IgnoreMargins() const -> bool;
     void SetIgnoreMargins(bool newIgnoreMargins);
 
-    auto SceneData() const -> VPSheetSceneData *;
+    auto SceneData() const -> QSharedPointer<VPSheetSceneData>;
 
     void ClearSelection() const;
 
     auto GetSheetOrientation() const -> QPageLayout::Orientation;
 
 public slots:
-    void CheckPiecePositionValidity(const VPPiecePtr &piece) const;
+    void CheckPiecesPositionValidity() const;
+
+private slots:
+    void UpdatePiecesValidity();
 
 private:
     Q_DISABLE_COPY_MOVE(VPSheet) // NOLINT
@@ -311,10 +319,12 @@ private:
 
     GrainlineType m_grainlineType{GrainlineType::NotFixed};
 
-    VPSheetSceneData *m_sceneData{nullptr};
+    QSharedPointer<VPSheetSceneData> m_sceneData{nullptr};
+
+    QFutureWatcher<QHash<QString, VPiecePositionValidity>> *m_validityWatcher;
+    mutable bool m_validationStale{false};
 
     auto SheetUnits() const -> Unit;
-
 };
 
 Q_DECLARE_METATYPE(VPSheetPtr) // NOLINT
