@@ -28,6 +28,8 @@
 #ifndef SCENEDEF_H
 #define SCENEDEF_H
 
+#include <QtGlobal>
+
 enum class PGraphicsItem : int
 {
     Piece = 1,
@@ -35,4 +37,7 @@ enum class PGraphicsItem : int
     TransformationOrigin = 3
 };
 
+constexpr qreal foldTextMargin = 5;
+constexpr int foldFontSize = 34;
+
 #endif // SCENEDEF_H
