@@ -29,21 +29,19 @@
 #ifndef VPGRAPHICSPIECE_H
 #define VPGRAPHICSPIECE_H
 
-#include <QGraphicsItem>
 #include <QCursor>
+#include <QGraphicsItem>
 
-#include "scenedef.h"
 #include "../layout/layoutdef.h"
-
-#if QT_VERSION < QT_VERSION_CHECK(5, 13, 0)
-#include "../vmisc/defglobal.h"
-#endif // QT_VERSION < QT_VERSION_CHECK(5, 13, 0)
+#include "scenedef.h"
 
 class VTextManager;
+class VGraphicsFillItem;
 
 class VPGraphicsPiece : public QGraphicsObject
 {
     Q_OBJECT // NOLINT
+
 public:
     explicit VPGraphicsPiece(const VPPiecePtr &piece, QGraphicsItem *parent = nullptr);
     ~VPGraphicsPiece() override = default;
@@ -52,10 +50,13 @@ public:
      * @brief GetPiece Returns the piece that corresponds to the graphics piece
      * @return the piece
      */
-    auto GetPiece() -> VPPiecePtr;
+    auto GetPiece() const -> VPPiecePtr;
 
-    auto type() const -> int override {return Type;}
-    enum { Type = UserType + static_cast<int>(PGraphicsItem::Piece)};
+    auto type() const -> int override { return Type; }
+    enum
+    {
+        Type = UserType + static_cast<int>(PGraphicsItem::Piece)
+    };
 
     void SetStickyPoints(const QVector<QPointF> &newStickyPoint);
 
@@ -74,7 +75,7 @@ protected:
     auto shape() const -> QPainterPath override;
     void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget) override;
 
-    void mousePressEvent(QGraphicsSceneMouseEvent * event) override;
+    void mousePressEvent(QGraphicsSceneMouseEvent *event) override;
     void mouseMoveEvent(QGraphicsSceneMouseEvent *event) override;
     void mouseReleaseEvent(QGraphicsSceneMouseEvent *event) override;
 
@@ -92,7 +93,6 @@ private:
 
     QPainterPath m_cuttingLine{};
     QPainterPath m_seamLine{};
-    QPainterPath m_grainline{};
     QPainterPath m_internalPaths{};
     QPainterPath m_passmarks{};
     QPainterPath m_placeLabels{};
@@ -105,6 +105,9 @@ private:
     QVector<QPointF> m_stickyPoints{};
     QPainterPath m_stickyPath{};
 
+    QPainterPath m_foldLineMarkPath{};
+    QPainterPath m_foldLineLabelPath{};
+
     bool m_hasStickyPosition{false};
     qreal m_stickyTranslateX{0};
     qreal m_stickyTranslateY{0};
@@ -113,19 +116,25 @@ private:
 
     bool m_hoverMode{false};
 
+    VGraphicsFillItem *m_grainlineItem{nullptr};
     QVector<QGraphicsPathItem *> m_labelPathItems{};
     QVector<QGraphicsSimpleTextItem *> m_labelTextItems{};
+    QGraphicsSimpleTextItem *m_foldLineLabelText{nullptr};
 
     void InitLabels();
+    void InitPieceLabelSVGFont(const QVector<QPointF> &labelShape, const VTextManager &tm);
+    void InitPieceLabelOutlineFont(const QVector<QPointF> &labelShape, const VTextManager &tm);
     void InitPieceLabel(const QVector<QPointF> &labelShape, const VTextManager &tm);
-    void PaintPiece(QPainter *painter=nullptr);
+    void InitGrainlineItem();
+    void PaintPiece(QPainter *painter = nullptr);
     void PaintSeamLine(QPainter *painter, const VPPiecePtr &piece);
     void PaintCuttingLine(QPainter *painter, const VPPiecePtr &piece);
-    void PaintGrainline(QPainter *painter, const VPPiecePtr &piece);
     void PaintInternalPaths(QPainter *painter, const VPPiecePtr &piece);
     void PaintPassmarks(QPainter *painter, const VPPiecePtr &piece);
     void PaintPlaceLabels(QPainter *painter, const VPPiecePtr &piece);
     void PaintStickyPath(QPainter *painter);
+    void PaintMirrorLine(QPainter *painter, const VPPiecePtr &piece) const;
+    void PaintFoldLine(QPainter *painter, const VPPiecePtr &piece);
 
     void GroupMove(const QPointF &pos);
 
