@@ -28,24 +28,24 @@
 #include "vpgraphicspiececontrols.h"
 
 #include <QCursor>
+#include <QFileInfo>
 #include <QGraphicsScene>
 #include <QGraphicsSceneMouseEvent>
+#include <QGraphicsView>
+#include <QGuiApplication>
 #include <QIcon>
 #include <QPainter>
-#include <QtDebug>
-#include <QGuiApplication>
 #include <QScreen>
+#include <QtDebug>
 
-#include "../vmisc/compatibility.h"
-#include "../vwidgets/global.h"
 #include "../layout/vplayout.h"
 #include "../layout/vppiece.h"
 #include "../layout/vpsheet.h"
-#include "../undocommands/vpundopiecerotate.h"
 #include "../undocommands/vpundooriginmove.h"
-#include "qgraphicsscene.h"
-#include "qgraphicsview.h"
-#include "qnamespace.h"
+#include "../undocommands/vpundopiecerotate.h"
+#include "../vmisc/theme/vscenestylesheet.h"
+#include "../vmisc/theme/vtheme.h"
+#include "../vwidgets/global.h"
 
 namespace
 {
@@ -54,14 +54,11 @@ constexpr qreal penWidth = 2;
 const qreal centerRadius1 = 5;
 const qreal centerRadius2 = 10;
 
-Q_GLOBAL_STATIC_WITH_ARGS(const QColor, defaultColor, (Qt::black)) // NOLINT
-Q_GLOBAL_STATIC_WITH_ARGS(const QColor, hoverColor, (Qt::green)) // NOLINT
-
+//---------------------------------------------------------------------------------------------------------------------
 auto TransformationOrigin(const VPLayoutPtr &layout, const QRectF &boundingRect) -> VPTransformationOrigon
 {
     SCASSERT(layout != nullptr)
-    VPSheetPtr sheet = layout->GetFocusedSheet();
-    if (not sheet.isNull())
+    if (VPSheetPtr const sheet = layout->GetFocusedSheet(); not sheet.isNull())
     {
         return sheet->TransformationOrigin();
     }
@@ -78,17 +75,16 @@ auto TransformationOrigin(const VPLayoutPtr &layout, const QRectF &boundingRect)
 
     return origin;
 }
-}  // namespace
+} // namespace
 
 //---------------------------------------------------------------------------------------------------------------------
 VPGraphicsTransformationOrigin::VPGraphicsTransformationOrigin(const VPLayoutPtr &layout, QGraphicsItem *parent)
-    : QGraphicsObject(parent),
-      m_layout(layout),
-      m_color(*defaultColor)
+  : QGraphicsObject(parent),
+    m_layout(layout)
 {
     SCASSERT(m_layout != nullptr)
     setCursor(Qt::OpenHandCursor);
-    setZValue(1);
+    setZValue(1000);
     setAcceptHoverEvents(true);
 
     connect(layout.data(), &VPLayout::TransformationOriginChanged, this,
@@ -113,12 +109,17 @@ void VPGraphicsTransformationOrigin::on_HideHandles(bool hide)
 void VPGraphicsTransformationOrigin::on_ShowOrigin(bool show)
 {
     setVisible(show);
+
+    if (not show)
+    {
+        m_hoverMode = false;
+    }
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 auto VPGraphicsTransformationOrigin::boundingRect() const -> QRectF
 {
-    constexpr qreal halfPenWidth = penWidth/2.;
+    constexpr qreal halfPenWidth = penWidth / 2.;
     return Center2().boundingRect().adjusted(-halfPenWidth, -halfPenWidth, halfPenWidth, halfPenWidth);
 }
 
@@ -136,14 +137,14 @@ void VPGraphicsTransformationOrigin::paint(QPainter *painter, const QStyleOption
 
     const qreal scale = SceneScale(scene());
 
-    QPen pen(m_color, penWidth/scale, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin);
+    QPen const pen(CurrentColor(), penWidth / scale, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin);
 
     painter->setPen(pen);
 
     if (m_originVisible)
     {
         painter->save();
-        painter->setBrush(QBrush(m_color));
+        painter->setBrush(QBrush(CurrentColor()));
         painter->drawPath(Center1());
         painter->restore();
 
@@ -158,14 +159,14 @@ void VPGraphicsTransformationOrigin::paint(QPainter *painter, const QStyleOption
 void VPGraphicsTransformationOrigin::mousePressEvent(QGraphicsSceneMouseEvent *event)
 {
     // change the cursor when clicking the left button
-    if((event->button() == Qt::LeftButton))
+    if ((event->button() == Qt::LeftButton))
     {
         setCursor(Qt::ClosedHandCursor);
         event->accept();
     }
     else
     {
-        //perform the default behaviour
+        // perform the default behaviour
         QGraphicsObject::mousePressEvent(event);
     }
 }
@@ -173,11 +174,9 @@ void VPGraphicsTransformationOrigin::mousePressEvent(QGraphicsSceneMouseEvent *e
 //---------------------------------------------------------------------------------------------------------------------
 void VPGraphicsTransformationOrigin::mouseMoveEvent(QGraphicsSceneMouseEvent *event)
 {
-    VPLayoutPtr layout = m_layout.toStrongRef();
-    if (not layout.isNull())
+    if (VPLayoutPtr const layout = m_layout.toStrongRef(); not layout.isNull())
     {
-        VPSheetPtr sheet = layout->GetFocusedSheet();
-        if (not sheet.isNull())
+        if (VPSheetPtr const sheet = layout->GetFocusedSheet(); not sheet.isNull())
         {
             VPTransformationOrigon origin = sheet->TransformationOrigin();
             origin.origin = event->scenePos();
@@ -196,7 +195,7 @@ void VPGraphicsTransformationOrigin::mouseMoveEvent(QGraphicsSceneMouseEvent *ev
 //---------------------------------------------------------------------------------------------------------------------
 void VPGraphicsTransformationOrigin::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
 {
-    //perform the default behaviour
+    // perform the default behaviour
     QGraphicsItem::mouseReleaseEvent(event);
 
     // change the cursor when clicking left button
@@ -210,14 +209,14 @@ void VPGraphicsTransformationOrigin::mouseReleaseEvent(QGraphicsSceneMouseEvent
 //---------------------------------------------------------------------------------------------------------------------
 void VPGraphicsTransformationOrigin::hoverEnterEvent(QGraphicsSceneHoverEvent *event)
 {
-    m_color = *hoverColor;
+    m_hoverMode = true;
     QGraphicsObject::hoverEnterEvent(event);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void VPGraphicsTransformationOrigin::hoverLeaveEvent(QGraphicsSceneHoverEvent *event)
 {
-    m_color = *defaultColor;
+    m_hoverMode = false;
     QGraphicsObject::hoverEnterEvent(event);
 }
 
@@ -227,9 +226,10 @@ auto VPGraphicsTransformationOrigin::RotationCenter(QPainter *painter) const ->
     QPainterPath path;
 
     const qreal scale = SceneScale(scene());
-    qreal radius = centerRadius1/scale;
-    VPTransformationOrigon transformationOrigin = TransformationOrigin(m_layout, QRectF());
-    QRectF rect(transformationOrigin.origin.x()-radius, transformationOrigin.origin.y()-radius, radius*2., radius*2.);
+    qreal radius = centerRadius1 / scale;
+    VPTransformationOrigon const transformationOrigin = TransformationOrigin(m_layout, QRectF());
+    QRectF rect(transformationOrigin.origin.x() - radius, transformationOrigin.origin.y() - radius, radius * 2.,
+                radius * 2.);
 
     QPainterPath center1;
     center1.addEllipse(rect);
@@ -237,14 +237,15 @@ auto VPGraphicsTransformationOrigin::RotationCenter(QPainter *painter) const ->
     if (painter != nullptr)
     {
         painter->save();
-        painter->setBrush(QBrush(m_color));
+        painter->setBrush(QBrush(CurrentColor()));
         painter->drawPath(Center1());
         painter->restore();
     }
     path.addPath(center1);
 
-    radius = centerRadius2/scale;
-    rect = QRectF(transformationOrigin.origin.x()-radius, transformationOrigin.origin.y()-radius, radius*2., radius*2.);
+    radius = centerRadius2 / scale;
+    rect = QRectF(transformationOrigin.origin.x() - radius, transformationOrigin.origin.y() - radius, radius * 2.,
+                  radius * 2.);
 
     QPainterPath center2;
     center2.addEllipse(rect);
@@ -265,9 +266,10 @@ auto VPGraphicsTransformationOrigin::RotationCenter(QPainter *painter) const ->
 auto VPGraphicsTransformationOrigin::Center1() const -> QPainterPath
 {
     const qreal scale = SceneScale(scene());
-    qreal radius = centerRadius1/scale;
-    VPTransformationOrigon transformationOrigin = TransformationOrigin(m_layout, QRectF());
-    QRectF rect(transformationOrigin.origin.x()-radius, transformationOrigin.origin.y()-radius, radius*2., radius*2.);
+    qreal const radius = centerRadius1 / scale;
+    VPTransformationOrigon const transformationOrigin = TransformationOrigin(m_layout, QRectF());
+    QRectF const rect(transformationOrigin.origin.x() - radius, transformationOrigin.origin.y() - radius, radius * 2.,
+                      radius * 2.);
 
     QPainterPath center1;
     center1.addEllipse(rect);
@@ -279,10 +281,10 @@ auto VPGraphicsTransformationOrigin::Center1() const -> QPainterPath
 auto VPGraphicsTransformationOrigin::Center2() const -> QPainterPath
 {
     const qreal scale = SceneScale(scene());
-    qreal radius = centerRadius2/scale;
-    VPTransformationOrigon transformationOrigin = TransformationOrigin(m_layout, QRectF());
-    QRectF rect = QRectF(transformationOrigin.origin.x()-radius, transformationOrigin.origin.y()-radius, radius*2.,
-                         radius*2.);
+    qreal const radius = centerRadius2 / scale;
+    VPTransformationOrigon const transformationOrigin = TransformationOrigin(m_layout, QRectF());
+    auto const rect = QRectF(transformationOrigin.origin.x() - radius, transformationOrigin.origin.y() - radius,
+                             radius * 2., radius * 2.);
 
     QPainterPath center2;
     center2.addEllipse(rect);
@@ -290,11 +292,18 @@ auto VPGraphicsTransformationOrigin::Center2() const -> QPainterPath
     return center2;
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+auto VPGraphicsTransformationOrigin::CurrentColor() const -> QColor
+{
+    return m_hoverMode ? VSceneStylesheet::ManualLayoutStyle().PieceHandleHoverColor()
+                       : VSceneStylesheet::ManualLayoutStyle().PieceHandleColor();
+}
+
 // VPGraphicsPieceControls
 //---------------------------------------------------------------------------------------------------------------------
 VPGraphicsPieceControls::VPGraphicsPieceControls(const VPLayoutPtr &layout, QGraphicsItem *parent)
-    : QGraphicsObject(parent),
-      m_layout(layout)
+  : QGraphicsObject(parent),
+    m_layout(layout)
 {
     SCASSERT(m_layout != nullptr)
     setCursor(QCursor(Qt::OpenHandCursor));
@@ -319,10 +328,10 @@ void VPGraphicsPieceControls::on_UpdateControls()
 
     if (not m_pieceRect.isNull())
     {
-        VPLayoutPtr layout = m_layout.toStrongRef();
+        VPLayoutPtr const layout = m_layout.toStrongRef();
         if (not layout.isNull())
         {
-            VPSheetPtr sheet = layout->GetFocusedSheet();
+            VPSheetPtr const sheet = layout->GetFocusedSheet();
             if (not sheet.isNull())
             {
                 VPTransformationOrigon origin = sheet->TransformationOrigin();
@@ -354,7 +363,7 @@ auto VPGraphicsPieceControls::boundingRect() const -> QRectF
 
     auto HandlerBoundingRect = [this, &boundingRect](VPHandleCorner corner, VPHandleCornerType type, QPointF pos)
     {
-        QPixmap handler = HandlerPixmap(m_handleCorner == corner, type);
+        QPixmap const handler = HandlerPixmap(m_handleCorner == corner, type);
         boundingRect = boundingRect.united(QRectF(pos, handler.size() / handler.devicePixelRatio()));
     };
 
@@ -381,30 +390,25 @@ void VPGraphicsPieceControls::paint(QPainter *painter, const QStyleOptionGraphic
     if (m_controlsVisible)
     {
         painter->drawPixmap(TopLeftHandlerPosition(),
-                            HandlerPixmap(m_handleCorner == VPHandleCorner::TopLeft,
-                                          VPHandleCornerType::TopLeft));
+                            HandlerPixmap(m_handleCorner == VPHandleCorner::TopLeft, VPHandleCornerType::TopLeft));
 
         painter->drawPixmap(TopRightHandlerPosition(),
-                            HandlerPixmap(m_handleCorner == VPHandleCorner::TopRight,
-                                          VPHandleCornerType::TopRight));
+                            HandlerPixmap(m_handleCorner == VPHandleCorner::TopRight, VPHandleCornerType::TopRight));
 
-        painter->drawPixmap(BottomRightHandlerPosition(),
-                            HandlerPixmap(m_handleCorner == VPHandleCorner::BottomRight,
-                                          VPHandleCornerType::BottomRight));
+        painter->drawPixmap(BottomRightHandlerPosition(), HandlerPixmap(m_handleCorner == VPHandleCorner::BottomRight,
+                                                                        VPHandleCornerType::BottomRight));
 
-        painter->drawPixmap(BottomLeftHandlerPosition(),
-                            HandlerPixmap(m_handleCorner == VPHandleCorner::BottomLeft,
-                                          VPHandleCornerType::BottomLeft));
+        painter->drawPixmap(BottomLeftHandlerPosition(), HandlerPixmap(m_handleCorner == VPHandleCorner::BottomLeft,
+                                                                       VPHandleCornerType::BottomLeft));
     }
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void VPGraphicsPieceControls::mousePressEvent(QGraphicsSceneMouseEvent *event)
 {
-    if(event->button() == Qt::LeftButton && event->type() != QEvent::GraphicsSceneMouseDoubleClick)
+    if (event->button() == Qt::LeftButton && event->type() != QEvent::GraphicsSceneMouseDoubleClick)
     {
         m_rotationStartPoint = event->scenePos();
-        m_rotationSum = 0;
         m_controlsVisible = false;
         m_handleCorner = SelectedHandleCorner(event->pos());
         m_ignorePieceTransformation = true;
@@ -417,8 +421,7 @@ void VPGraphicsPieceControls::mousePressEvent(QGraphicsSceneMouseEvent *event)
         }
         else
         {
-            QGraphicsView *view = ItemView();
-            if (view != nullptr)
+            if (QGraphicsView *view = ItemView(); view != nullptr)
             {
                 setCursor(view->viewport()->cursor()); // clazy:exclude=clazy-qt6-deprecated-api-fixes
             }
@@ -434,14 +437,14 @@ void VPGraphicsPieceControls::mousePressEvent(QGraphicsSceneMouseEvent *event)
 //---------------------------------------------------------------------------------------------------------------------
 void VPGraphicsPieceControls::mouseMoveEvent(QGraphicsSceneMouseEvent *event)
 {
-    PrepareTransformationOrigin(event->modifiers() & Qt::ShiftModifier);
+    PrepareTransformationOrigin(event->modifiers() & Qt::ShiftModifier); // NOLINT(readability-implicit-bool-conversion)
 
-    QPointF rotationNewPoint = event->scenePos();
+    QPointF const rotationNewPoint = event->scenePos();
 
     // get the angle from the center to the initial click point
-    VPTransformationOrigon rotationOrigin = TransformationOrigin(m_layout, m_pieceRect);
-    QLineF initPosition(rotationOrigin.origin, m_rotationStartPoint);
-    QLineF initRotationPosition(rotationOrigin.origin, rotationNewPoint);
+    VPTransformationOrigon const rotationOrigin = TransformationOrigin(m_layout, m_pieceRect);
+    QLineF const initPosition(rotationOrigin.origin, m_rotationStartPoint);
+    QLineF const initRotationPosition(rotationOrigin.origin, rotationNewPoint);
 
     qreal rotateOn = initPosition.angleTo(initRotationPosition);
 
@@ -452,24 +455,18 @@ void VPGraphicsPieceControls::mouseMoveEvent(QGraphicsSceneMouseEvent *event)
 
     if (not qFuzzyIsNull(rotateOn))
     {
-        QList<VPPiecePtr> pieces = SelectedPieces();
-
-        VPLayoutPtr layout = m_layout.toStrongRef();
-        if (not layout.isNull())
+        if (VPLayoutPtr const layout = m_layout.toStrongRef(); not layout.isNull())
         {
-            CorrectRotationSum(layout, rotationOrigin, rotateOn);
+            QList<VPPiecePtr> const pieces = SelectedPieces();
 
             if (pieces.size() == 1)
             {
-                auto *command = new VPUndoPieceRotate(ConstFirst(pieces), rotationOrigin, rotateOn, m_rotationSum,
-                                                      allowChangeMerge);
-                layout->UndoStack()->push(command);
+                layout->UndoStack()->push(
+                    new VPUndoPieceRotate(pieces.constFirst(), rotationOrigin, rotateOn, allowChangeMerge));
             }
             else if (pieces.size() > 1)
             {
-                auto *command = new VPUndoPiecesRotate(pieces, rotationOrigin, rotateOn, m_rotationSum,
-                                                       allowChangeMerge);
-                layout->UndoStack()->push(command);
+                layout->UndoStack()->push(new VPUndoPiecesRotate(pieces, rotationOrigin, rotateOn, allowChangeMerge));
             }
         }
     }
@@ -477,7 +474,7 @@ void VPGraphicsPieceControls::mouseMoveEvent(QGraphicsSceneMouseEvent *event)
     if (m_originSaved && m_savedOrigin.custom)
     {
         QLineF line(rotationOrigin.origin, m_savedOrigin.origin);
-        line.setAngle(line.angle()+rotateOn);
+        line.setAngle(line.angle() + rotateOn);
         m_savedOrigin.origin = line.p2();
     }
 
@@ -489,8 +486,21 @@ void VPGraphicsPieceControls::mouseMoveEvent(QGraphicsSceneMouseEvent *event)
 //---------------------------------------------------------------------------------------------------------------------
 void VPGraphicsPieceControls::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
 {
-    if(event->button() == Qt::LeftButton)
+    if (event->button() == Qt::LeftButton)
     {
+        VPLayoutPtr const layout = m_layout.toStrongRef();
+
+        if (not layout.isNull() && layout->LayoutSettings().GetFollowGrainline())
+        {
+            VPTransformationOrigon const rotationOrigin = TransformationOrigin(m_layout, m_pieceRect);
+            QList<VPPiecePtr> const pieces = SelectedPieces();
+            for (const auto &piece : qAsConst(pieces))
+            {
+                piece->RotateToGrainline(rotationOrigin);
+                emit layout->PieceTransformationChanged(piece);
+            }
+        }
+
         m_controlsVisible = true;
         m_ignorePieceTransformation = false;
 
@@ -500,31 +510,25 @@ void VPGraphicsPieceControls::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
         }
         else
         {
-            QGraphicsView *view = ItemView();
-            if (view != nullptr)
+            if (QGraphicsView *view = ItemView(); view != nullptr)
             {
                 setCursor(view->viewport()->cursor()); // clazy:exclude=clazy-qt6-deprecated-api-fixes
             }
         }
 
-        if (m_originSaved)
+        if (m_originSaved && not layout.isNull())
         {
-            VPLayoutPtr layout = m_layout.toStrongRef();
-            if (not layout.isNull())
+            if (VPSheetPtr const sheet = layout->GetFocusedSheet(); not sheet.isNull())
             {
-                VPSheetPtr sheet = layout->GetFocusedSheet();
-                if (not sheet.isNull())
+                if (not m_savedOrigin.custom)
                 {
-                    if (not m_savedOrigin.custom)
-                    {
-                        m_pieceRect = PiecesBoundingRect(m_selectedPieces);
-                        m_savedOrigin.origin = m_pieceRect.center();
-                    }
-                    sheet->SetTransformationOrigin(m_savedOrigin);
-                    emit TransformationOriginChanged();
+                    m_pieceRect = PiecesBoundingRect(m_selectedPieces);
+                    m_savedOrigin.origin = m_pieceRect.center();
                 }
-                m_originSaved = false;
+                sheet->SetTransformationOrigin(m_savedOrigin);
+                emit TransformationOriginChanged();
             }
+            m_originSaved = false;
         }
 
         on_UpdateControls();
@@ -561,45 +565,39 @@ void VPGraphicsPieceControls::InitPixmaps()
     m_handleHoverPixmaps.clear();
     m_handlePaths.clear();
 
-    auto InitPixmap = [this](VPHandleCornerType type, const QString &fileName)
+    auto InitPixmap = [this](VPHandleCornerType type, const QString &imageName)
     {
-        const QFileInfo fileInfo(fileName);
-        const QString imageName = fileInfo.baseName();
+        const auto resource = QStringLiteral("icon");
 
-        const QString fileNameHover = QStringLiteral("%1/%2-hover.%3")
-                .arg(fileInfo.absolutePath(), imageName, fileInfo.suffix());
+        const auto fileName = QStringLiteral("32x32/%1.png").arg(imageName);
+        QPixmap const handlePixmap = VTheme::GetPixmapResource(resource, fileName);
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 5, 0)
-        if (QGuiApplication::primaryScreen()->devicePixelRatio() >= 2 )
+        if (QGuiApplication::primaryScreen()->devicePixelRatio() >= 2)
         {
-            const QString fileName2x = QStringLiteral("%1/%2@2x.%3")
-                    .arg(fileInfo.absolutePath(), imageName, fileInfo.suffix());
+            const auto fileName2x = QStringLiteral("32x32/%1@2x.png").arg(imageName);
+            const auto fileName2xHover = QStringLiteral("32x32/%1-hover@2x.png").arg(imageName);
 
-            const QString fileName2xHover = QStringLiteral("%1/%2-hover@2x.%3")
-                    .arg(fileInfo.absolutePath(), imageName, fileInfo.suffix());
-
-            m_handlePixmaps.insert(type, QPixmap(fileName2x));
-            m_handleHoverPixmaps.insert(type, QPixmap(fileName2xHover));
+            m_handlePixmaps.insert(type, VTheme::GetPixmapResource(resource, fileName2x));
+            m_handleHoverPixmaps.insert(type, VTheme::GetPixmapResource(resource, fileName2xHover));
         }
         else
         {
-            m_handlePixmaps.insert(type, QPixmap(fileName));
-            m_handleHoverPixmaps.insert(type, QPixmap(fileNameHover));
+            const auto fileNameHover = QStringLiteral("32x32/%1-hover.png").arg(imageName);
+
+            m_handlePixmaps.insert(type, handlePixmap);
+            m_handleHoverPixmaps.insert(type, VTheme::GetPixmapResource(resource, fileNameHover));
         }
-#else
-        m_handlePixmaps.insert(type, QPixmap(fileName));
-        m_handleHoverPixmaps.insert(type, QPixmap(fileNameHover));
-#endif
-        QPainterPath p = PixmapToPainterPath(m_handlePixmaps.value(type));
+
+        QPainterPath p = PixmapToPainterPath(handlePixmap);
         p.setFillRule(Qt::WindingFill);
         p.closeSubpath();
         m_handlePaths.insert(type, p);
     };
 
-    InitPixmap(VPHandleCornerType::TopLeft, QStringLiteral("://icon/32x32/rotate-top-left.png"));
-    InitPixmap(VPHandleCornerType::TopRight, QStringLiteral("://icon/32x32/rotate-top-right.png"));
-    InitPixmap(VPHandleCornerType::BottomRight, QStringLiteral("://icon/32x32/rotate-bottom-right.png"));
-    InitPixmap(VPHandleCornerType::BottomLeft, QStringLiteral("://icon/32x32/rotate-bottom-left.png"));
+    InitPixmap(VPHandleCornerType::TopLeft, QStringLiteral("rotate-top-left"));
+    InitPixmap(VPHandleCornerType::TopRight, QStringLiteral("rotate-top-right"));
+    InitPixmap(VPHandleCornerType::BottomRight, QStringLiteral("rotate-bottom-right"));
+    InitPixmap(VPHandleCornerType::BottomLeft, QStringLiteral("rotate-bottom-left"));
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -611,28 +609,27 @@ auto VPGraphicsPieceControls::TopLeftHandlerPosition() const -> QPointF
 //---------------------------------------------------------------------------------------------------------------------
 auto VPGraphicsPieceControls::TopRightHandlerPosition() const -> QPointF
 {
-    QRectF rect = ControllersRect();
-    QPixmap handler = m_handlePixmaps.value(VPHandleCornerType::TopRight);
-    QSize size = handler.size() / handler.devicePixelRatio();
+    QRectF const rect = ControllersRect();
+    QPixmap const handler = m_handlePixmaps.value(VPHandleCornerType::TopRight);
+    QSize const size = handler.size() / handler.devicePixelRatio();
     return {rect.topLeft().x() + (rect.width() - size.width()), rect.topLeft().y()};
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 auto VPGraphicsPieceControls::BottomRightHandlerPosition() const -> QPointF
 {
-    QRectF rect = ControllersRect();
-    QPixmap handler = m_handlePixmaps.value(VPHandleCornerType::BottomRight);
-    QSize size = handler.size() / handler.devicePixelRatio();
-    return {rect.topLeft().x() + (rect.width() - size.width()),
-                rect.topLeft().y() + (rect.height() - size.height())};
+    QRectF const rect = ControllersRect();
+    QPixmap const handler = m_handlePixmaps.value(VPHandleCornerType::BottomRight);
+    QSize const size = handler.size() / handler.devicePixelRatio();
+    return {rect.topLeft().x() + (rect.width() - size.width()), rect.topLeft().y() + (rect.height() - size.height())};
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 auto VPGraphicsPieceControls::BottomLeftHandlerPosition() const -> QPointF
 {
-    QRectF rect = ControllersRect();
-    QPixmap handler = m_handlePixmaps.value(VPHandleCornerType::BottomLeft);
-    QSize size = handler.size() / handler.devicePixelRatio();
+    QRectF const rect = ControllersRect();
+    QPixmap const handler = m_handlePixmaps.value(VPHandleCornerType::BottomLeft);
+    QSize const size = handler.size() / handler.devicePixelRatio();
     return {rect.topLeft().x(), rect.topLeft().y() + (rect.height() - size.height())};
 }
 
@@ -696,26 +693,26 @@ auto VPGraphicsPieceControls::Handles() const -> QPainterPath
 auto VPGraphicsPieceControls::ControllersRect() const -> QRectF
 {
     const qreal scale = SceneScale(scene());
-    QPixmap handler = m_handlePixmaps.value(VPHandleCornerType::TopLeft);
+    QPixmap const handler = m_handlePixmaps.value(VPHandleCornerType::TopLeft);
     QRectF pieceRect = m_pieceRect;
 
-    pieceRect = QRectF(pieceRect.topLeft()*scale, QSizeF(pieceRect.width()*scale, pieceRect.height()*scale));
+    pieceRect = QRectF(pieceRect.topLeft() * scale, QSizeF(pieceRect.width() * scale, pieceRect.height() * scale));
     QRectF rect = pieceRect;
 
     if (pieceRect.width() < handler.width())
     {
-        qreal diff = handler.width() - pieceRect.width();
+        qreal const diff = handler.width() - pieceRect.width();
         rect.adjust(0, 0, diff, 0);
     }
 
     if (pieceRect.height() < handler.height())
     {
-        qreal diff = handler.height() - pieceRect.height();
+        qreal const diff = handler.height() - pieceRect.height();
         rect.adjust(0, 0, 0, diff);
     }
 
     const qreal gap = 2;
-    rect.adjust(- (handler.width() + gap), - (handler.height() + gap), handler.width() + gap, handler.height() + gap);
+    rect.adjust(-(handler.width() + gap), -(handler.height() + gap), handler.width() + gap, handler.height() + gap);
 
     return rect;
 }
@@ -725,11 +722,9 @@ auto VPGraphicsPieceControls::SelectedPieces() const -> QList<VPPiecePtr>
 {
     QList<VPPiecePtr> pieces;
 
-    VPLayoutPtr layout = m_layout.toStrongRef();
-    if (not layout.isNull())
+    if (VPLayoutPtr const layout = m_layout.toStrongRef(); not layout.isNull())
     {
-        VPSheetPtr sheet = layout->GetFocusedSheet();
-        if (not sheet.isNull())
+        if (VPSheetPtr const sheet = layout->GetFocusedSheet(); not sheet.isNull())
         {
             pieces = sheet->GetSelectedPieces();
         }
@@ -742,7 +737,7 @@ auto VPGraphicsPieceControls::SelectedPieces() const -> QList<VPPiecePtr>
 auto VPGraphicsPieceControls::PiecesBoundingRect(const QList<VPPiecePtr> &selectedPieces) -> QRectF
 {
     QRectF rect;
-    for (const auto& item : selectedPieces)
+    for (const auto &item : selectedPieces)
     {
         if (not item.isNull())
         {
@@ -756,11 +751,9 @@ auto VPGraphicsPieceControls::PiecesBoundingRect(const QList<VPPiecePtr> &select
 //---------------------------------------------------------------------------------------------------------------------
 auto VPGraphicsPieceControls::ItemView() -> QGraphicsView *
 {
-    QGraphicsScene *scene = this->scene();
-    if (scene != nullptr)
+    if (QGraphicsScene *scene = this->scene(); scene != nullptr)
     {
-        QList<QGraphicsView *> views = scene->views();
-        if (not views.isEmpty())
+        if (QList<QGraphicsView *> const views = scene->views(); not views.isEmpty())
         {
             return views.at(0);
         }
@@ -780,8 +773,7 @@ void VPGraphicsPieceControls::UpdateCursor(VPHandleCorner corner)
     }
     else
     {
-        QGraphicsView *view = ItemView();
-        if (view != nullptr)
+        if (QGraphicsView *view = ItemView(); view != nullptr)
         {
             setCursor(view->viewport()->cursor()); // clazy:exclude=clazy-qt6-deprecated-api-fixes
         }
@@ -791,20 +783,20 @@ void VPGraphicsPieceControls::UpdateCursor(VPHandleCorner corner)
 //---------------------------------------------------------------------------------------------------------------------
 void VPGraphicsPieceControls::PrepareTransformationOrigin(bool shiftPressed)
 {
-    if(shiftPressed && m_handleCorner != VPHandleCorner::Invalid)
+    if (shiftPressed && m_handleCorner != VPHandleCorner::Invalid)
     {
         if (m_originSaved)
         {
             return;
         }
 
-        VPLayoutPtr layout = m_layout.toStrongRef();
+        VPLayoutPtr const layout = m_layout.toStrongRef();
         if (layout.isNull())
         {
             return;
         }
 
-        VPSheetPtr sheet = layout->GetFocusedSheet();
+        VPSheetPtr const sheet = layout->GetFocusedSheet();
         if (sheet.isNull())
         {
             return;
@@ -846,13 +838,13 @@ void VPGraphicsPieceControls::PrepareTransformationOrigin(bool shiftPressed)
             return;
         }
 
-        VPLayoutPtr layout = m_layout.toStrongRef();
+        VPLayoutPtr const layout = m_layout.toStrongRef();
         if (layout.isNull())
         {
             return;
         }
 
-        VPSheetPtr sheet = layout->GetFocusedSheet();
+        VPSheetPtr const sheet = layout->GetFocusedSheet();
         if (sheet.isNull())
         {
             return;
@@ -869,37 +861,10 @@ void VPGraphicsPieceControls::PrepareTransformationOrigin(bool shiftPressed)
     }
 }
 
-//---------------------------------------------------------------------------------------------------------------------
-void VPGraphicsPieceControls::CorrectRotationSum(const VPLayoutPtr &layout,
-                                                 const VPTransformationOrigon &rotationOrigin, qreal rotateOn)
-{
-    if (layout.isNull())
-    {
-        return;
-    }
-
-    if (layout->LayoutSettings().GetFollowGrainline() && not rotationOrigin.custom)
-    {
-        if (m_rotationSum > 90 || m_rotationSum < -90)
-        {
-            m_rotationSum = rotateOn;
-        }
-        else
-        {
-            m_rotationSum += rotateOn;
-        }
-    }
-    else
-    {
-        m_rotationSum = rotateOn;
-    }
-}
-
 //---------------------------------------------------------------------------------------------------------------------
 auto VPGraphicsPieceControls::SelectedHandleCorner(const QPointF &pos) const -> VPHandleCorner
 {
-    QMap<VPHandleCorner, QPainterPath> corners
-    {
+    QMap<VPHandleCorner, QPainterPath> const corners{
         {VPHandleCorner::TopLeft, TopLeftControl()},
         {VPHandleCorner::TopRight, TopRightControl()},
         {VPHandleCorner::BottomRight, BottomRightControl()},
@@ -907,12 +872,10 @@ auto VPGraphicsPieceControls::SelectedHandleCorner(const QPointF &pos) const ->
     };
 
     QPainterPath circle;
-    circle.addEllipse(pos.x()-4, pos.y()-4, 8, 8);
+    circle.addEllipse(pos.x() - 4, pos.y() - 4, 8, 8);
 
     auto CheckCorner = [circle](const QPainterPath &handler)
-    {
-        return handler.intersects(circle) || handler.contains(circle);
-    };
+    { return handler.intersects(circle) || handler.contains(circle); };
 
     auto i = corners.constBegin();
     while (i != corners.constEnd())
