@@ -29,24 +29,25 @@
 #include "vpmaingraphicsview.h"
 
 #include <QDragEnterEvent>
-#include <QMimeData>
 #include <QKeyEvent>
 #include <QMenu>
+#include <QMimeData>
 #include <QUndoStack>
 
 #include "../carousel/vpmimedatapiece.h"
 #include "../layout/vplayout.h"
-#include "../layout/vpsheet.h"
 #include "../layout/vppiece.h"
+#include "../layout/vpsheet.h"
+#include "../vmisc/theme/themeDef.h"
 #include "../vwidgets/vmaingraphicsscene.h"
 #include "undocommands/vpundopiecezvaluemove.h"
 #include "vpgraphicspiece.h"
 #include "vpgraphicspiececontrols.h"
 
+#include "../undocommands/vpundomovepieceonsheet.h"
+#include "../undocommands/vpundooriginmove.h"
 #include "../undocommands/vpundopiecemove.h"
 #include "../undocommands/vpundopiecerotate.h"
-#include "../undocommands/vpundooriginmove.h"
-#include "../undocommands/vpundomovepieceonsheet.h"
 #include "../undocommands/vpundoremovesheet.h"
 
 #include <QLoggingCategory>
@@ -62,18 +63,28 @@ QT_WARNING_POP
 namespace
 {
 QT_WARNING_PUSH
+#if !defined(Q_OS_MACOS) && defined(Q_CC_CLANG)
 QT_WARNING_DISABLE_CLANG("-Wenum-enum-conversion")
+#endif
 
-Q_GLOBAL_STATIC_WITH_ARGS(const QKeySequence, restoreOriginShortcut, // NOLINT
+QT_WARNING_DISABLE_CLANG("-Wunused-member-function")
+
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+// NOLINTNEXTLINE
+Q_GLOBAL_STATIC_WITH_ARGS(const QKeySequence, restoreOriginShortcut,
+                          (QKeySequence(Qt::ControlModifier | Qt::Key_Asterisk)))
+#else
+// NOLINTNEXTLINE
+Q_GLOBAL_STATIC_WITH_ARGS(const QKeySequence, restoreOriginShortcut,
                           (QKeySequence(Qt::ControlModifier + Qt::Key_Asterisk)))
+#endif
 
 QT_WARNING_POP
-}
-
+} // namespace
 
 //---------------------------------------------------------------------------------------------------------------------
-VPMainGraphicsView::VPMainGraphicsView(const VPLayoutPtr &layout, QWidget *parent) :
-    VMainGraphicsView(parent),
+VPMainGraphicsView::VPMainGraphicsView(const VPLayoutPtr &layout, QWidget *parent)
+  : VMainGraphicsView(parent),
     m_layout(layout)
 {
     SCASSERT(not layout.isNull())
@@ -93,12 +104,12 @@ VPMainGraphicsView::VPMainGraphicsView(const VPLayoutPtr &layout, QWidget *paren
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VPMainGraphicsView::RefreshLayout()
+void VPMainGraphicsView::RefreshLayout() const
 {
-    VPLayoutPtr layout = m_layout.toStrongRef();
+    VPLayoutPtr const layout = m_layout.toStrongRef();
     if (not layout.isNull())
     {
-        VPSheetPtr sheet = layout->GetFocusedSheet();
+        VPSheetPtr const sheet = layout->GetFocusedSheet();
         if (not sheet.isNull())
         {
             sheet->SceneData()->RefreshLayout();
@@ -107,12 +118,12 @@ void VPMainGraphicsView::RefreshLayout()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VPMainGraphicsView::RefreshPieces()
+void VPMainGraphicsView::RefreshPieces() const
 {
-    VPLayoutPtr layout = m_layout.toStrongRef();
+    VPLayoutPtr const layout = m_layout.toStrongRef();
     if (not layout.isNull())
     {
-        VPSheetPtr sheet = layout->GetFocusedSheet();
+        VPSheetPtr const sheet = layout->GetFocusedSheet();
         if (not sheet.isNull())
         {
             sheet->SceneData()->RefreshPieces();
@@ -125,15 +136,15 @@ void VPMainGraphicsView::dragEnterEvent(QDragEnterEvent *event)
 {
     const QMimeData *mime = event->mimeData();
 
-    if(mime->hasFormat(VPMimeDataPiece::mineFormatPiecePtr))
+    if (mime->hasFormat(VPMimeDataPiece::mineFormatPiecePtr))
     {
-        VPLayoutPtr layout = m_layout.toStrongRef();
+        VPLayoutPtr const layout = m_layout.toStrongRef();
         if (layout.isNull())
         {
             return;
         }
 
-        const auto *mimePiece = qobject_cast<const VPMimeDataPiece *> (mime);
+        const auto *mimePiece = qobject_cast<const VPMimeDataPiece *>(mime);
         if (mimePiece != nullptr && mimePiece->LayoutUuid() == layout->Uuid())
         {
             qCDebug(pMainGraphicsView(), "drag enter");
@@ -147,15 +158,15 @@ void VPMainGraphicsView::dragMoveEvent(QDragMoveEvent *event)
 {
     const QMimeData *mime = event->mimeData();
 
-    if(mime->hasFormat(VPMimeDataPiece::mineFormatPiecePtr))
+    if (mime->hasFormat(VPMimeDataPiece::mineFormatPiecePtr))
     {
-        VPLayoutPtr layout = m_layout.toStrongRef();
+        VPLayoutPtr const layout = m_layout.toStrongRef();
         if (layout.isNull())
         {
             return;
         }
 
-        const auto *mimePiece = qobject_cast<const VPMimeDataPiece *> (mime);
+        const auto *mimePiece = qobject_cast<const VPMimeDataPiece *>(mime);
         if (mimePiece != nullptr && mimePiece->LayoutUuid() == layout->Uuid())
         {
             event->acceptProposedAction();
@@ -176,29 +187,29 @@ void VPMainGraphicsView::dropEvent(QDropEvent *event)
 
     qCDebug(pMainGraphicsView(), "drop enter , %s", qUtf8Printable(mime->objectName()));
 
-    if(mime->hasFormat(VPMimeDataPiece::mineFormatPiecePtr))
+    if (mime->hasFormat(VPMimeDataPiece::mineFormatPiecePtr))
     {
-        VPLayoutPtr layout = m_layout.toStrongRef();
+        VPLayoutPtr const layout = m_layout.toStrongRef();
         if (layout.isNull())
         {
             return;
         }
 
-        const auto *mimePiece = qobject_cast<const VPMimeDataPiece *> (mime);
+        const auto *mimePiece = qobject_cast<const VPMimeDataPiece *>(mime);
 
         if (mimePiece == nullptr || mimePiece->LayoutUuid() != layout->Uuid())
         {
             return;
         }
 
-        VPPiecePtr piece = mimePiece->GetPiecePtr();
-        if(not piece.isNull())
+        VPPiecePtr const piece = mimePiece->GetPiecePtr();
+        if (not piece.isNull())
         {
             qCDebug(pMainGraphicsView(), "element dropped, %s", qUtf8Printable(piece->GetName()));
             event->acceptProposedAction();
 
             piece->ClearTransformations();
-            piece->SetPosition(mapToScene(event->pos()));
+            piece->SetPosition(mapToScene(DropEventPos(event)));
             piece->SetZValue(1.0);
 
             auto *command = new VPUndoMovePieceOnSheet(layout->GetFocusedSheet(), piece);
@@ -214,7 +225,7 @@ void VPMainGraphicsView::keyPressEvent(QKeyEvent *event)
     const bool controlModifier = (event->modifiers() & Qt::ControlModifier) != 0U;
     const bool altModifier = (event->modifiers() & Qt::AltModifier) != 0U;
 
-    switch(event->key())
+    switch (event->key())
     {
         case Qt::Key_Backspace:
         case Qt::Key_Delete:
@@ -233,11 +244,11 @@ void VPMainGraphicsView::keyPressEvent(QKeyEvent *event)
             shiftModifier ? TranslatePiecesOn(0, 10) : TranslatePiecesOn(0, 1);
             break;
         case Qt::Key_BracketLeft:
-            if(controlModifier)
+            if (controlModifier)
             {
                 RotatePiecesByAngle(90);
             }
-            else if(altModifier)
+            else if (altModifier)
             {
                 RotatePiecesByAngle(1);
             }
@@ -247,11 +258,11 @@ void VPMainGraphicsView::keyPressEvent(QKeyEvent *event)
             }
             break;
         case Qt::Key_BracketRight:
-            if(controlModifier)
+            if (controlModifier)
             {
                 RotatePiecesByAngle(-90);
             }
-            else if(altModifier)
+            else if (altModifier)
             {
                 RotatePiecesByAngle(-1);
             }
@@ -280,7 +291,7 @@ void VPMainGraphicsView::keyPressEvent(QKeyEvent *event)
 //---------------------------------------------------------------------------------------------------------------------
 void VPMainGraphicsView::keyReleaseEvent(QKeyEvent *event)
 {
-    switch(event->key())
+    switch (event->key())
     {
         case Qt::Key_Left:
         case Qt::Key_Right:
@@ -294,25 +305,19 @@ void VPMainGraphicsView::keyReleaseEvent(QKeyEvent *event)
             break;
     }
 
-    if (event->key() == Qt::Key_BracketLeft || event->key() == Qt::Key_BracketRight)
+    if ((event->key() == Qt::Key_BracketLeft || event->key() == Qt::Key_BracketRight) && not event->isAutoRepeat())
     {
-        if (not event->isAutoRepeat())
+        VPLayoutPtr const layout = m_layout.toStrongRef();
+        if (layout.isNull())
         {
-            VPLayoutPtr layout = m_layout.toStrongRef();
-            if (layout.isNull())
-            {
-                return;
-            }
+            return;
+        }
 
-            VPSheetPtr sheet = layout->GetFocusedSheet();
-            if (not sheet.isNull())
-            {
-                sheet->SceneData()->RotationControls()->SetIgnorePieceTransformation(false);
-                sheet->SceneData()->RotationControls()->on_UpdateControls();
-                sheet->SceneData()->RotationControls()->on_HideHandles(false);
-            }
-
-            m_rotationSum = 0;
+        if (VPSheetPtr const sheet = layout->GetFocusedSheet(); not sheet.isNull())
+        {
+            sheet->SceneData()->RotationControls()->SetIgnorePieceTransformation(false);
+            sheet->SceneData()->RotationControls()->on_UpdateControls();
+            sheet->SceneData()->RotationControls()->on_HideHandles(false);
         }
     }
     VMainGraphicsView::keyReleaseEvent(event);
@@ -321,20 +326,19 @@ void VPMainGraphicsView::keyReleaseEvent(QKeyEvent *event)
 //---------------------------------------------------------------------------------------------------------------------
 void VPMainGraphicsView::contextMenuEvent(QContextMenuEvent *event)
 {
-    QGraphicsItem *item = itemAt(event->pos());
-    if (item != nullptr && item->type() == VPGraphicsPiece::Type)
+    if (QGraphicsItem *item = itemAt(event->pos()); item != nullptr && item->type() == VPGraphicsPiece::Type)
     {
         VMainGraphicsView::contextMenuEvent(event);
         return;
     }
 
-    VPLayoutPtr layout = m_layout.toStrongRef();
+    VPLayoutPtr const layout = m_layout.toStrongRef();
     if (layout.isNull())
     {
         return;
     }
 
-    VPSheetPtr sheet = layout->GetFocusedSheet();
+    VPSheetPtr const sheet = layout->GetFocusedSheet();
 
     QMenu menu;
 
@@ -342,7 +346,7 @@ void VPMainGraphicsView::contextMenuEvent(QContextMenuEvent *event)
     restoreOriginAction->setShortcut(*restoreOriginShortcut);
     restoreOriginAction->setEnabled(not sheet.isNull() && sheet->TransformationOrigin().custom);
 
-    QAction *removeSheetAction = menu.addAction(QIcon::fromTheme(QStringLiteral("edit-delete")), tr("Remove sheet"));
+    QAction *removeSheetAction = menu.addAction(FromTheme(VThemeIcon::EditDelete), tr("Remove sheet"));
     removeSheetAction->setEnabled(not sheet.isNull() && layout->GetSheets().size() > 1);
 
     QAction *selectedAction = menu.exec(event->globalPos());
@@ -354,19 +358,18 @@ void VPMainGraphicsView::contextMenuEvent(QContextMenuEvent *event)
     {
         RestoreOrigin();
     }
-
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void VPMainGraphicsView::RestoreOrigin() const
 {
-    VPLayoutPtr layout = m_layout.toStrongRef();
+    VPLayoutPtr const layout = m_layout.toStrongRef();
     if (layout.isNull())
     {
         return;
     }
 
-    VPSheetPtr sheet = layout->GetFocusedSheet();
+    VPSheetPtr const sheet = layout->GetFocusedSheet();
     if (not sheet.isNull())
     {
         VPTransformationOrigon origin = sheet->TransformationOrigin();
@@ -375,8 +378,8 @@ void VPMainGraphicsView::RestoreOrigin() const
             origin.custom = false;
 
             QRectF boundingRect;
-            QList<VPPiecePtr> selectedPieces = sheet->GetSelectedPieces();
-            for (const auto& piece : selectedPieces)
+            QList<VPPiecePtr> const selectedPieces = sheet->GetSelectedPieces();
+            for (const auto &piece : selectedPieces)
             {
                 if (piece->IsSelected())
                 {
@@ -400,13 +403,13 @@ void VPMainGraphicsView::on_SceneMouseMove(const QPointF &scenePos)
 //---------------------------------------------------------------------------------------------------------------------
 void VPMainGraphicsView::RotatePiecesByAngle(qreal angle)
 {
-    VPLayoutPtr layout = m_layout.toStrongRef();
+    VPLayoutPtr const layout = m_layout.toStrongRef();
     if (layout.isNull())
     {
         return;
     }
 
-    VPSheetPtr sheet = layout->GetFocusedSheet();
+    VPSheetPtr const sheet = layout->GetFocusedSheet();
     if (sheet.isNull())
     {
         return;
@@ -415,15 +418,14 @@ void VPMainGraphicsView::RotatePiecesByAngle(qreal angle)
     sheet->SceneData()->RotationControls()->on_HideHandles(true);
     sheet->SceneData()->RotationControls()->SetIgnorePieceTransformation(true);
 
-    VPTransformationOrigon origin = sheet->TransformationOrigin();
+    VPTransformationOrigon const origin = sheet->TransformationOrigin();
 
     auto PreparePieces = [this]()
     {
         QList<VPPiecePtr> pieces;
-        VPLayoutPtr layout = m_layout.toStrongRef();
-        if (not layout.isNull())
+        if (VPLayoutPtr const layout = m_layout.toStrongRef(); not layout.isNull())
         {
-            VPSheetPtr sheet = layout->GetFocusedSheet();
+            VPSheetPtr const sheet = layout->GetFocusedSheet();
             if (not sheet.isNull())
             {
                 pieces = sheet->GetSelectedPieces();
@@ -433,33 +435,34 @@ void VPMainGraphicsView::RotatePiecesByAngle(qreal angle)
         return pieces;
     };
 
-    if (layout->LayoutSettings().GetFollowGrainline() && not origin.custom)
-    {
-        if (m_rotationSum > 90 || m_rotationSum < -90)
-        {
-            m_rotationSum = angle;
-        }
-        else
-        {
-            m_rotationSum += angle;
-        }
-    }
-    else
-    {
-        m_rotationSum = angle;
-    }
-
-    QList<VPPiecePtr> pieces = PreparePieces();
+    QList<VPPiecePtr> const pieces = PreparePieces();
 
     if (pieces.size() == 1)
     {
-        auto *command = new VPUndoPieceRotate(ConstFirst(pieces), origin, angle, m_rotationSum, m_allowChangeMerge);
-        layout->UndoStack()->push(command);
+        layout->UndoStack()->push(new VPUndoPieceRotate(pieces.constFirst(), origin, angle, m_allowChangeMerge));
     }
     else if (pieces.size() > 1)
     {
-        auto *command = new VPUndoPiecesRotate(pieces, origin, angle, m_rotationSum, m_allowChangeMerge);
-        layout->UndoStack()->push(command);
+        layout->UndoStack()->push(new VPUndoPiecesRotate(pieces, origin, angle, m_allowChangeMerge));
+    }
+
+    QTime const dieTime = QTime::currentTime().addMSecs(150);
+    while (QTime::currentTime() < dieTime)
+    {
+        QCoreApplication::processEvents(QEventLoop::AllEvents, 50);
+    }
+
+    for (const auto &piece : qAsConst(pieces))
+    {
+        if (not piece.isNull())
+        {
+            if (layout->LayoutSettings().GetFollowGrainline() || piece->IsFollowGrainline())
+            {
+                piece->RotateToGrainline(origin);
+            }
+
+            emit layout->PieceTransformationChanged(piece);
+        }
     }
 
     m_allowChangeMerge = true;
@@ -468,13 +471,13 @@ void VPMainGraphicsView::RotatePiecesByAngle(qreal angle)
 //---------------------------------------------------------------------------------------------------------------------
 void VPMainGraphicsView::TranslatePiecesOn(qreal dx, qreal dy)
 {
-    VPLayoutPtr layout = m_layout.toStrongRef();
+    VPLayoutPtr const layout = m_layout.toStrongRef();
     if (layout.isNull())
     {
         return;
     }
 
-    VPSheetPtr sheet = layout->GetFocusedSheet();
+    VPSheetPtr const sheet = layout->GetFocusedSheet();
     if (sheet.isNull())
     {
         return;
@@ -487,8 +490,7 @@ void VPMainGraphicsView::TranslatePiecesOn(qreal dx, qreal dy)
         return;
     }
 
-    VPPiecePtr piece = ConstFirst(graphicsPieces)->GetPiece();
-    if (piece.isNull())
+    if (VPPiecePtr const piece = graphicsPieces.constFirst()->GetPiece(); piece.isNull())
     {
         return;
     }
@@ -496,11 +498,9 @@ void VPMainGraphicsView::TranslatePiecesOn(qreal dx, qreal dy)
     auto PreparePieces = [this]()
     {
         QList<VPPiecePtr> pieces;
-        VPLayoutPtr layout = m_layout.toStrongRef();
-        if (not layout.isNull())
+        if (VPLayoutPtr const layout = m_layout.toStrongRef(); not layout.isNull())
         {
-            VPSheetPtr sheet = layout->GetFocusedSheet();
-            if (not sheet.isNull())
+            if (VPSheetPtr const sheet = layout->GetFocusedSheet(); not sheet.isNull())
             {
                 pieces = sheet->GetSelectedPieces();
             }
@@ -509,19 +509,18 @@ void VPMainGraphicsView::TranslatePiecesOn(qreal dx, qreal dy)
         return pieces;
     };
 
-    QList<VPPiecePtr> pieces = PreparePieces();
-    if (pieces.size() == 1)
+    if (QList<VPPiecePtr> const pieces = PreparePieces(); pieces.size() == 1)
     {
-        const VPPiecePtr &p = ConstFirst(pieces);
+        const VPPiecePtr &p = pieces.constFirst();
         auto *command = new VPUndoPieceMove(p, dx, dy, m_allowChangeMerge);
         layout->UndoStack()->push(command);
 
-        if (layout->LayoutSettings().GetStickyEdges())
+        if (layout->LayoutSettings().IsStickyEdges())
         {
             QVector<QPointF> path;
             if (not p.isNull() && p->StickyPosition(m_stickyTranslateX, m_stickyTranslateY))
             {
-                path = p->GetMappedExternalContourPoints();
+                CastTo(p->GetMappedExternalContourPoints(), path);
                 QTransform m;
                 m.translate(m_stickyTranslateX, m_stickyTranslateY);
                 path = m.map(path);
@@ -532,8 +531,7 @@ void VPMainGraphicsView::TranslatePiecesOn(qreal dx, qreal dy)
                 m_hasStickyPosition = false;
             }
 
-            VPGraphicsPiece *gPiece = sheet->SceneData()->ScenePiece(p);
-            if (gPiece != nullptr)
+            if (VPGraphicsPiece *gPiece = sheet->SceneData()->ScenePiece(p); gPiece != nullptr)
             {
                 gPiece->SetStickyPoints(path);
             }
@@ -553,30 +551,30 @@ void VPMainGraphicsView::SwitchScene(const VPSheetPtr &sheet)
 {
     if (not sheet.isNull())
     {
-       VMainGraphicsScene *scene = sheet->SceneData()->Scene();
-       setScene(scene);
-       connect(scene, &VMainGraphicsScene::mouseMove, this, &VPMainGraphicsView::on_SceneMouseMove,
-               Qt::UniqueConnection);
+        QSharedPointer<VMainGraphicsScene> const scene = sheet->SceneData()->Scene();
+        setScene(scene.data());
+        connect(scene.data(), &VMainGraphicsScene::mouseMove, this, &VPMainGraphicsView::on_SceneMouseMove,
+                Qt::UniqueConnection);
     }
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VPMainGraphicsView::ClearSelection()
+void VPMainGraphicsView::ClearSelection() const
 {
-    VPLayoutPtr layout = m_layout.toStrongRef();
+    VPLayoutPtr const layout = m_layout.toStrongRef();
     if (layout.isNull())
     {
         return;
     }
 
-    VPSheetPtr sheet = layout->GetFocusedSheet();
+    VPSheetPtr const sheet = layout->GetFocusedSheet();
     if (sheet.isNull())
     {
         return;
     }
 
-    QList<VPPiecePtr> pieces = sheet->GetSelectedPieces();
-    for (const auto& piece : pieces)
+    QList<VPPiecePtr> const pieces = sheet->GetSelectedPieces();
+    for (const auto &piece : pieces)
     {
         piece->SetSelected(false);
         emit layout->PieceSelectionChanged(piece);
@@ -584,27 +582,27 @@ void VPMainGraphicsView::ClearSelection()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VPMainGraphicsView::ZValueMove(int move)
+void VPMainGraphicsView::ZValueMove(int move) const
 {
-    VPLayoutPtr layout = m_layout.toStrongRef();
+    VPLayoutPtr const layout = m_layout.toStrongRef();
     if (layout.isNull())
     {
         return;
     }
 
-    VPSheetPtr sheet = layout->GetFocusedSheet();
+    VPSheetPtr const sheet = layout->GetFocusedSheet();
     if (sheet.isNull())
     {
         return;
     }
 
-    QList<VPPiecePtr> selectedPieces = sheet->GetSelectedPieces();
+    QList<VPPiecePtr> const selectedPieces = sheet->GetSelectedPieces();
     if (selectedPieces.isEmpty())
     {
         return;
     }
 
-    QList<VPPiecePtr> allPieces = sheet->GetPieces();
+    QList<VPPiecePtr> const allPieces = sheet->GetPieces();
     if (allPieces.isEmpty() || (allPieces.size() == selectedPieces.size()))
     {
         return;
@@ -614,7 +612,7 @@ void VPMainGraphicsView::ZValueMove(int move)
 
     if (selectedPieces.size() == 1)
     {
-        layout->UndoStack()->push(new VPUndoPieceZValueMove(ConstFirst(selectedPieces), zMove));
+        layout->UndoStack()->push(new VPUndoPieceZValueMove(selectedPieces.constFirst(), zMove));
     }
     else if (selectedPieces.size() > 1)
     {
@@ -625,37 +623,50 @@ void VPMainGraphicsView::ZValueMove(int move)
 //---------------------------------------------------------------------------------------------------------------------
 void VPMainGraphicsView::RemovePiece() const
 {
-    VPLayoutPtr layout = m_layout.toStrongRef();
+    VPLayoutPtr const layout = m_layout.toStrongRef();
     if (layout.isNull())
     {
         return;
     }
 
-    VPSheetPtr sheet = layout->GetFocusedSheet();
+    VPSheetPtr const sheet = layout->GetFocusedSheet();
     if (sheet.isNull())
     {
-        return ;
+        return;
     }
 
     const QList<VPGraphicsPiece *> &graphicsPieces = sheet->SceneData()->GraphicsPieces();
-    for(auto *graphicsPiece : graphicsPieces)
-    {
-        VPPiecePtr piece = graphicsPiece->GetPiece();
 
-        if(not piece.isNull() && piece->IsSelected())
+    QVector<VPUndoMovePieceOnSheet *> commands;
+    commands.reserve(graphicsPieces.size());
+
+    for (auto *graphicsPiece : graphicsPieces)
+    {
+        VPPiecePtr const piece = graphicsPiece->GetPiece();
+
+        if (not piece.isNull() && piece->IsSelected())
         {
             piece->SetSelected(false);
+            emit layout->PieceSelectionChanged(piece);
 
-            VPLayoutPtr layout = m_layout.toStrongRef();
-            if (not layout.isNull())
-            {
-                emit layout->PieceSelectionChanged(piece);
-
-                auto *command = new VPUndoMovePieceOnSheet(VPSheetPtr(), piece);
-                layout->UndoStack()->push(command);
-            }
+            commands.append(new VPUndoMovePieceOnSheet(VPSheetPtr(), piece));
         }
     }
+
+    if (commands.size() > 1)
+    {
+        layout->UndoStack()->beginMacro(tr("Remove pieces"));
+    }
+
+    for (auto *command : commands)
+    {
+        layout->UndoStack()->push(command);
+    }
+
+    if (commands.size() > 1)
+    {
+        layout->UndoStack()->endMacro();
+    }
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -663,49 +674,42 @@ void VPMainGraphicsView::MovePiece(QKeyEvent *event)
 {
     if (not event->isAutoRepeat())
     {
-        VPLayoutPtr layout = m_layout.toStrongRef();
+        VPLayoutPtr const layout = m_layout.toStrongRef();
         if (layout.isNull())
         {
             return;
         }
 
-        VPSheetPtr sheet = layout->GetFocusedSheet();
+        VPSheetPtr const sheet = layout->GetFocusedSheet();
         if (sheet.isNull())
         {
             return;
         }
 
-        const QList<VPGraphicsPiece *> &graphicsPieces = sheet->SceneData()->GraphicsPieces();
-        if (m_hasStickyPosition && not graphicsPieces.isEmpty())
+        if (const QList<VPGraphicsPiece *> &graphicsPieces = sheet->SceneData()->GraphicsPieces();
+            m_hasStickyPosition && not graphicsPieces.isEmpty() && layout->LayoutSettings().IsStickyEdges())
         {
-            if (layout->LayoutSettings().GetStickyEdges())
+            auto PreparePieces = [layout]()
             {
-                auto PreparePieces = [layout]()
+                QList<VPPiecePtr> pieces;
+                if (VPSheetPtr const sheet = layout->GetFocusedSheet(); not sheet.isNull())
                 {
-                    QList<VPPiecePtr> pieces;
-                    VPSheetPtr sheet = layout->GetFocusedSheet();
-                    if (not sheet.isNull())
-                    {
-                        pieces = sheet->GetSelectedPieces();
-                    }
+                    pieces = sheet->GetSelectedPieces();
+                }
 
-                    return pieces;
-                };
+                return pieces;
+            };
 
-                QList<VPPiecePtr> pieces = PreparePieces();
-                if (pieces.size() == 1)
+            if (QList<VPPiecePtr> const pieces = PreparePieces(); pieces.size() == 1)
+            {
+                const VPPiecePtr &p = pieces.constFirst();
+
+                auto *command = new VPUndoPieceMove(p, m_stickyTranslateX, m_stickyTranslateY, m_allowChangeMerge);
+                layout->UndoStack()->push(command);
+
+                if (VPGraphicsPiece *gPiece = sheet->SceneData()->ScenePiece(p); gPiece != nullptr)
                 {
-                    const VPPiecePtr &p = ConstFirst(pieces);
-
-                    auto *command = new VPUndoPieceMove(p, m_stickyTranslateX, m_stickyTranslateY,
-                                                        m_allowChangeMerge);
-                    layout->UndoStack()->push(command);
-
-                    VPGraphicsPiece * gPiece = sheet->SceneData()->ScenePiece(p);
-                    if (gPiece != nullptr)
-                    {
-                        gPiece->SetStickyPoints(QVector<QPointF>());
-                    }
+                    gPiece->SetStickyPoints(QVector<QPointF>());
                 }
             }
         }
@@ -718,13 +722,13 @@ void VPMainGraphicsView::MovePiece(QKeyEvent *event)
 //---------------------------------------------------------------------------------------------------------------------
 void VPMainGraphicsView::on_PieceSheetChanged(const VPPiecePtr &piece)
 {
-    VPLayoutPtr layout = m_layout.toStrongRef();
+    VPLayoutPtr const layout = m_layout.toStrongRef();
     if (layout.isNull())
     {
         return;
     }
 
-    VPSheetPtr sheet = layout->GetFocusedSheet();
+    VPSheetPtr const sheet = layout->GetFocusedSheet();
     if (sheet.isNull())
     {
         return;
@@ -733,7 +737,7 @@ void VPMainGraphicsView::on_PieceSheetChanged(const VPPiecePtr &piece)
     VPGraphicsPiece *graphicsPiece = sheet->SceneData()->ScenePiece(piece);
 
     if (piece != nullptr && (piece->Sheet().isNull() || piece->Sheet() == layout->GetTrashSheet() ||
-            piece->Sheet() != layout->GetFocusedSheet())) // remove
+                             piece->Sheet() != layout->GetFocusedSheet())) // remove
     {
         if (graphicsPiece != nullptr)
         {
@@ -744,7 +748,7 @@ void VPMainGraphicsView::on_PieceSheetChanged(const VPPiecePtr &piece)
     }
     else // add
     {
-        if(graphicsPiece == nullptr)
+        if (graphicsPiece == nullptr)
         {
             graphicsPiece = new VPGraphicsPiece(piece);
             sheet->SceneData()->AddPiece(graphicsPiece);
