@@ -26,8 +26,8 @@
  **
  *************************************************************************/
 #include "vpundopiecerotate.h"
-#include "../layout/vppiece.h"
 #include "../layout/vplayout.h"
+#include "../layout/vppiece.h"
 
 namespace
 {
@@ -37,23 +37,21 @@ auto RoundAngle(qreal angle) -> qreal
     l.setAngle(angle);
     return l.angle();
 }
-}
+} // namespace
 
 //---------------------------------------------------------------------------------------------------------------------
 VPUndoPieceRotate::VPUndoPieceRotate(const VPPiecePtr &piece, const VPTransformationOrigon &origin, qreal angle,
-                                     qreal angleSum, bool allowMerge, QUndoCommand *parent)
-    : VPUndoCommand(allowMerge, parent),
-      m_piece(piece),
-      m_origin(origin),
-      m_angle(angle),
-      m_angleSum(angleSum)
+                                     bool allowMerge, QUndoCommand *parent)
+  : VPUndoCommand(allowMerge, parent),
+    m_piece(piece),
+    m_origin(origin),
+    m_angle(angle)
 {
     SCASSERT(not piece.isNull())
 
     m_oldTransform = piece->GetMatrix();
 
-    VPLayoutPtr layout = piece->Layout();
-    if (not layout.isNull())
+    if (VPLayoutPtr const layout = piece->Layout(); not layout.isNull())
     {
         m_followGrainline = layout->LayoutSettings().GetFollowGrainline();
     }
@@ -64,13 +62,13 @@ VPUndoPieceRotate::VPUndoPieceRotate(const VPPiecePtr &piece, const VPTransforma
 //---------------------------------------------------------------------------------------------------------------------
 void VPUndoPieceRotate::undo()
 {
-    VPPiecePtr piece = Piece();
+    VPPiecePtr const piece = Piece();
     if (piece.isNull())
     {
         return;
     }
 
-    VPLayoutPtr layout = piece->Layout();
+    VPLayoutPtr const layout = piece->Layout();
     if (layout.isNull())
     {
         return;
@@ -82,19 +80,23 @@ void VPUndoPieceRotate::undo()
     }
 
     piece->SetMatrix(m_oldTransform);
+    if (m_followGrainline || piece->IsFollowGrainline())
+    {
+        piece->RotateToGrainline(m_origin);
+    }
     emit layout->PieceTransformationChanged(piece);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void VPUndoPieceRotate::redo()
 {
-    VPPiecePtr piece = Piece();
+    VPPiecePtr const piece = Piece();
     if (piece.isNull())
     {
         return;
     }
 
-    VPLayoutPtr layout = piece->Layout();
+    VPLayoutPtr const layout = piece->Layout();
     if (layout.isNull())
     {
         return;
@@ -105,23 +107,9 @@ void VPUndoPieceRotate::redo()
         layout->SetFocusedSheet(piece->Sheet());
     }
 
-    if (m_firstCall)
-    {
-        if (m_followGrainline && piece->IsGrainlineEnabled())
-        {
-            piece->Rotate(m_origin.origin, m_angleSum);
-        }
-        else
-        {
-            piece->Rotate(m_origin.origin, m_angle);
-        }
-    }
-    else
-    {
-        piece->Rotate(m_origin.origin, m_angle);
-    }
+    piece->Rotate(m_origin.origin, m_angle);
 
-    if (m_followGrainline)
+    if (!m_firstCall && (m_followGrainline || piece->IsFollowGrainline()))
     {
         piece->RotateToGrainline(m_origin);
     }
@@ -147,10 +135,10 @@ auto VPUndoPieceRotate::mergeWith(const QUndoCommand *command) -> bool
     const auto *moveCommand = dynamic_cast<const VPUndoPieceRotate *>(command);
     SCASSERT(moveCommand != nullptr)
 
-    VPPiecePtr piece = Piece();
-    if (not moveCommand->AllowMerge() || (moveCommand->Piece().isNull() || piece.isNull()) ||
-            moveCommand->Piece() != piece || moveCommand->Origin() != m_origin ||
-            moveCommand->FollowGrainline() != m_followGrainline)
+    if (VPPiecePtr const piece = Piece(); not moveCommand->AllowMerge() ||
+                                          (moveCommand->Piece().isNull() || piece.isNull()) ||
+                                          moveCommand->Piece() != piece || moveCommand->Origin() != m_origin ||
+                                          moveCommand->FollowGrainline() != m_followGrainline)
     {
         return false;
     }
@@ -169,15 +157,14 @@ auto VPUndoPieceRotate::id() const -> int
 // rotate pieces
 //---------------------------------------------------------------------------------------------------------------------
 VPUndoPiecesRotate::VPUndoPiecesRotate(const QList<VPPiecePtr> &pieces, const VPTransformationOrigon &origin,
-                                       qreal angle, qreal angleSum, bool allowMerge, QUndoCommand *parent)
-    : VPUndoCommand(allowMerge, parent),
-      m_origin(origin),
-      m_angle(angle),
-      m_angleSum(angleSum)
+                                       qreal angle, bool allowMerge, QUndoCommand *parent)
+  : VPUndoCommand(allowMerge, parent),
+    m_origin(origin),
+    m_angle(angle)
 {
     setText(QObject::tr("rotate pieces"));
 
-    for (const auto& piece : pieces)
+    for (const auto &piece : pieces)
     {
         if (not piece.isNull())
         {
@@ -186,7 +173,7 @@ VPUndoPiecesRotate::VPUndoPiecesRotate(const QList<VPPiecePtr> &pieces, const VP
         }
     }
 
-    VPLayoutPtr layout = Layout();
+    VPLayoutPtr const layout = Layout();
     if (not layout.isNull())
     {
         m_followGrainline = layout->LayoutSettings().GetFollowGrainline();
@@ -201,28 +188,28 @@ void VPUndoPiecesRotate::undo()
         return;
     }
 
-    VPLayoutPtr layout = Layout();
+    VPLayoutPtr const layout = Layout();
     if (layout.isNull())
     {
         return;
     }
 
-    VPSheetPtr sheet = Sheet();
-    if (layout->GetFocusedSheet() != sheet)
+    if (VPSheetPtr const sheet = Sheet(); layout->GetFocusedSheet() != sheet)
     {
         layout->SetFocusedSheet(sheet);
     }
 
-    for (const auto& piece : qAsConst(m_pieces))
+    for (const auto &piece : qAsConst(m_pieces))
     {
-        VPPiecePtr p = piece.toStrongRef();
-        if (not p.isNull())
+        VPPiecePtr const p = piece.toStrongRef();
+        if (not p.isNull() && m_oldTransforms.contains(p->GetUniqueID()))
         {
-            if (m_oldTransforms.contains(p->GetUniqueID()))
+            p->SetMatrix(m_oldTransforms.value(p->GetUniqueID()));
+            if (m_followGrainline || p->IsFollowGrainline())
             {
-                p->SetMatrix(m_oldTransforms.value(p->GetUniqueID()));
-                emit layout->PieceTransformationChanged(p);
+                p->RotateToGrainline(m_origin);
             }
+            emit layout->PieceTransformationChanged(p);
         }
     }
 }
@@ -235,40 +222,25 @@ void VPUndoPiecesRotate::redo()
         return;
     }
 
-    VPLayoutPtr layout = Layout();
+    VPLayoutPtr const layout = Layout();
     if (layout.isNull())
     {
         return;
     }
 
-    VPSheetPtr sheet = Sheet();
-    if (layout->GetFocusedSheet() != sheet)
+    if (VPSheetPtr const sheet = Sheet(); layout->GetFocusedSheet() != sheet)
     {
         layout->SetFocusedSheet(sheet);
     }
 
-    for (const auto& piece : qAsConst(m_pieces))
+    for (const auto &piece : qAsConst(m_pieces))
     {
-        VPPiecePtr p = piece.toStrongRef();
+        VPPiecePtr const p = piece.toStrongRef();
         if (not p.isNull())
         {
-            if (m_firstCall)
-            {
-                if (m_followGrainline && p->IsGrainlineEnabled())
-                {
-                    p->Rotate(m_origin.origin, m_angleSum);
-                }
-                else
-                {
-                    p->Rotate(m_origin.origin, m_angle);
-                }
-            }
-            else
-            {
-                p->Rotate(m_origin.origin, m_angle);
-            }
+            p->Rotate(m_origin.origin, m_angle);
 
-            if (m_followGrainline)
+            if (!m_firstCall && (m_followGrainline || p->IsFollowGrainline()))
             {
                 p->RotateToGrainline(m_origin);
             }
@@ -297,7 +269,7 @@ auto VPUndoPiecesRotate::mergeWith(const QUndoCommand *command) -> bool
     SCASSERT(moveCommand != nullptr)
 
     if (not moveCommand->AllowMerge() || moveCommand->PieceIds() != PieceIds() || moveCommand->Origin() != m_origin ||
-            moveCommand->FollowGrainline() != m_followGrainline)
+        moveCommand->FollowGrainline() != m_followGrainline)
     {
         return false;
     }
@@ -317,9 +289,9 @@ auto VPUndoPiecesRotate::id() const -> int
 auto VPUndoPiecesRotate::PieceIds() const -> QSet<QString>
 {
     QSet<QString> ids;
-    for (const auto& piece : m_pieces)
+    for (const auto &piece : m_pieces)
     {
-        VPPiecePtr p = piece.toStrongRef();
+        VPPiecePtr const p = piece.toStrongRef();
         if (not p.isNull())
         {
             ids.insert(p->GetUniqueID());
@@ -332,9 +304,9 @@ auto VPUndoPiecesRotate::PieceIds() const -> QSet<QString>
 //---------------------------------------------------------------------------------------------------------------------
 auto VPUndoPiecesRotate::Layout() const -> VPLayoutPtr
 {
-    for (const auto& piece : m_pieces)
+    for (const auto &piece : m_pieces)
     {
-        VPPiecePtr p = piece.toStrongRef();
+        VPPiecePtr const p = piece.toStrongRef();
         if (not p.isNull())
         {
             return p->Layout();
@@ -347,9 +319,9 @@ auto VPUndoPiecesRotate::Layout() const -> VPLayoutPtr
 //---------------------------------------------------------------------------------------------------------------------
 auto VPUndoPiecesRotate::Sheet() const -> VPSheetPtr
 {
-    for (const auto& piece : m_pieces)
+    for (const auto &piece : m_pieces)
     {
-        VPPiecePtr p = piece.toStrongRef();
+        VPPiecePtr const p = piece.toStrongRef();
         if (not p.isNull())
         {
             return p->Sheet();
