@@ -27,24 +27,40 @@
  *************************************************************************/
 
 #include "vpapplication.h"
-#include "version.h"
-#include "vpmainwindow.h"
-#include "../ifc/exception/vexceptionobjecterror.h"
+#include "../fervor/fvupdater.h"
 #include "../ifc/exception/vexceptionbadid.h"
 #include "../ifc/exception/vexceptionconversionerror.h"
 #include "../ifc/exception/vexceptionemptyparameter.h"
+#include "../ifc/exception/vexceptionobjecterror.h"
 #include "../ifc/exception/vexceptionwrongid.h"
-#include "../vmisc/vsysexits.h"
-
-#if QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
-#include "../vmisc/diagnostic.h"
-#endif // QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
-
+#include "../vganalytics/vganalytics.h"
+#include "../vmisc/projectversion.h"
 #include "../vmisc/qt_dispatch/qt_dispatch.h"
-#include "../fervor/fvupdater.h"
+#include "../vmisc/theme/vtheme.h"
+#include "../vmisc/vsysexits.h"
+#include "vpmainwindow.h"
+#include "vpuzzleshortcutmanager.h"
 
-#include <QMessageBox>
+#include <QCommandLineParser>
+#include <QEvent>
+#include <QFileOpenEvent>
+#include <QLocalServer>
+#include <QLocalSocket>
 #include <QLoggingCategory>
+#include <QMessageBox>
+#include <QPixmapCache>
+#include <QStyleFactory>
+
+#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
+#include "../vmisc/compatibility.h"
+#endif
+
+#if !defined(BUILD_REVISION) && defined(QBS_BUILD)
+#include <vcsRepoState.h>
+#define BUILD_REVISION VCS_REPO_STATE_REVISION
+#endif
+
+using namespace Qt::Literals::StringLiterals;
 
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_CLANG("-Wmissing-prototypes")
@@ -54,14 +70,14 @@ Q_LOGGING_CATEGORY(pApp, "p.application") // NOLINT
 
 QT_WARNING_POP
 
-#include <QCommandLineParser>
-#include <QLocalSocket>
-#include <QLocalServer>
-#include <QFileOpenEvent>
-#include <QPixmapCache>
+#define VER_INTERNALNAME_STR "Puzzle"
+#define VER_ORIGINALFILENAME_STR "puzzle.exe"
+#define VER_PRODUCTNAME_STR "Puzzle"
+#define VER_FILEDESCRIPTION_STR "Valentina's manual layout creator."
 
 //---------------------------------------------------------------------------------------------------------------------
-inline void noisyFailureMsgHandler(QtMsgType type, const QMessageLogContext &context, const QString &msg) // NOLINT(readability-function-cognitive-complexity)
+inline void noisyFailureMsgHandler(QtMsgType type, const QMessageLogContext &context,
+                                   const QString &msg) // NOLINT(readability-function-cognitive-complexity)
 {
     // only the GUI thread should display message boxes.  If you are
     // writing a multithreaded application and the error happens on
@@ -72,14 +88,17 @@ inline void noisyFailureMsgHandler(QtMsgType type, const QMessageLogContext &con
     if (not isGuiThread)
     {
         auto Handler = [](QtMsgType type, const QMessageLogContext &context, const QString &msg)
-        {
-            noisyFailureMsgHandler(type, context, msg);
-        };
+        { noisyFailureMsgHandler(type, context, msg); };
 
         q_dispatch_async_main(Handler, type, context, msg);
         return;
     }
 
+    if (VAbstractApplication::VApp()->IsWarningMessage(msg))
+    {
+        return;
+    }
+
     // Why on earth didn't Qt want to make failed signal/slot connections qWarning?
     if ((type == QtDebugMsg) && msg.contains(QStringLiteral("::connect")))
     {
@@ -97,29 +116,9 @@ inline void noisyFailureMsgHandler(QtMsgType type, const QMessageLogContext &con
     {
         type = QtDebugMsg;
     }
-#endif //defined(V_NO_ASSERT)
+#endif // defined(V_NO_ASSERT)
 
 #if defined(Q_OS_MAC)
-#   if QT_VERSION >= QT_VERSION_CHECK(5, 4, 0) && QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
-        // Try hide very annoying, Qt related, warnings in Mac OS X
-        // QNSView mouseDragged: Internal mouse button tracking invalid (missing Qt::LeftButton)
-        // https://bugreports.qt.io/browse/QTBUG-42846
-        if ((type == QtWarningMsg) && msg.contains(QStringLiteral("QNSView")))
-        {
-            type = QtDebugMsg;
-        }
-#   endif
-
-#   if QT_VERSION < QT_VERSION_CHECK(5, 9, 0)
-    // Hide Qt bug 'Assertion when reading an icns file'
-    // https://bugreports.qt.io/browse/QTBUG-45537
-    // Remove after Qt fix will be released
-    if ((type == QtWarningMsg) && msg.contains(QStringLiteral("QICNSHandler::read()")))
-    {
-        type = QtDebugMsg;
-    }
-#   endif
-
     // Hide anything that starts with QMacCGContext
     if ((type == QtWarningMsg) && msg.contains(QStringLiteral("QMacCGContext::")))
     {
@@ -136,8 +135,8 @@ inline void noisyFailureMsgHandler(QtMsgType type, const QMessageLogContext &con
     // this is another one that doesn't make sense as just a debug message.  pretty serious
     // sign of a problem
     // http://www.developer.nokia.com/Community/Wiki/QPainter::begin:Paint_device_returned_engine_%3D%3D_0_(Known_Issue)
-    if ((type == QtDebugMsg) && msg.contains(QStringLiteral("QPainter::begin"))
-        && msg.contains(QStringLiteral("Paint device returned engine")))
+    if ((type == QtDebugMsg) && msg.contains(QStringLiteral("QPainter::begin")) &&
+        msg.contains(QStringLiteral("Paint device returned engine")))
     {
         type = QtWarningMsg;
     }
@@ -145,44 +144,77 @@ inline void noisyFailureMsgHandler(QtMsgType type, const QMessageLogContext &con
     // This qWarning about "Cowardly refusing to send clipboard message to hung application..."
     // is something that can easily happen if you are debugging and the application is paused.
     // As it is so common, not worth popping up a dialog.
-    if ((type == QtWarningMsg) && msg.contains(QStringLiteral("QClipboard::event"))
-            && msg.contains(QStringLiteral("Cowardly refusing")))
+    if ((type == QtWarningMsg) && msg.contains(QStringLiteral("QClipboard::event")) &&
+        msg.contains(QStringLiteral("Cowardly refusing")))
     {
         type = QtDebugMsg;
     }
 
-    switch (type)
+    // Annoying warning that we can ignore
+    if ((type == QtWarningMsg) && (msg.contains(QStringLiteral("OpenType support missing for")) ||
+                                   msg.contains(QStringLiteral("DirectWrite: CreateFontFaceFromHDC() failed (Indicates "
+                                                               "an error in an input file such as a font file.)"))))
     {
-        case QtDebugMsg:
-            vStdOut() << QApplication::translate("mNoisyHandler", "DEBUG:") << msg << "\n";
-            return;
-        case QtWarningMsg:
-            vStdErr() << QApplication::translate("mNoisyHandler", "WARNING:") << msg << "\n";
-            break;
-        case QtCriticalMsg:
-            vStdErr() << QApplication::translate("mNoisyHandler", "CRITICAL:") << msg << "\n";
-            break;
-        case QtFatalMsg:
-            vStdErr() << QApplication::translate("mNoisyHandler", "FATAL:") << msg << "\n";
-            break;
-        #if QT_VERSION >= QT_VERSION_CHECK(5, 5, 0)
-        case QtInfoMsg:
-            vStdOut() << QApplication::translate("mNoisyHandler", "INFO:") << msg << "\n";
-            break;
-        #endif
-        default:
-            break;
+        type = QtDebugMsg;
     }
 
-    vStdOut().flush();
-    vStdErr().flush();
+    {
+        QString debugdate = "["_L1 + QDateTime::currentDateTime().toString(QStringLiteral("yyyy.MM.dd hh:mm:ss"));
+        QString const file = VAbstractApplication::ReduceLogContextFilePath(context.file);
+
+        switch (type)
+        {
+            case QtDebugMsg:
+                debugdate += QStringLiteral(":DEBUG:%1(%2)] %3: %4: %5")
+                                 .arg(file)
+                                 .arg(context.line)
+                                 .arg(context.function, context.category, msg);
+                vStdOut() << QApplication::translate("mNoisyHandler", "DEBUG:") << msg << "\n";
+                break;
+            case QtWarningMsg:
+                debugdate += QStringLiteral(":WARNING:%1(%2)] %3: %4: %5")
+                                 .arg(file)
+                                 .arg(context.line)
+                                 .arg(context.function, context.category, msg);
+                vStdErr() << QApplication::translate("mNoisyHandler", "WARNING:") << msg << "\n";
+                break;
+            case QtCriticalMsg:
+                debugdate += QStringLiteral(":CRITICAL:%1(%2)] %3: %4: %5")
+                                 .arg(file)
+                                 .arg(context.line)
+                                 .arg(context.function, context.category, msg);
+                vStdErr() << QApplication::translate("mNoisyHandler", "CRITICAL:") << msg << "\n";
+                break;
+            case QtFatalMsg:
+                debugdate += QStringLiteral(":FATAL:%1(%2)] %3: %4: %5")
+                                 .arg(file)
+                                 .arg(context.line)
+                                 .arg(context.function, context.category, msg);
+                vStdErr() << QApplication::translate("mNoisyHandler", "FATAL:") << msg << "\n";
+                break;
+            case QtInfoMsg:
+                debugdate += QStringLiteral(":INFO:%1(%2)] %3: %4: %5")
+                                 .arg(file)
+                                 .arg(context.line)
+                                 .arg(context.function, context.category, msg);
+                vStdOut() << QApplication::translate("mNoisyHandler", "INFO:") << msg << "\n";
+                break;
+            default:
+                break;
+        }
+
+        vStdOut().flush();
+        vStdErr().flush();
+
+        (*VPApplication::VApp()->LogFile()) << debugdate << Qt::endl;
+    }
 
     if (isGuiThread)
     {
-        //fixme: trying to make sure there are no save/load dialogs are opened, because error message during them will
-        //lead to crash
+        // fixme: trying to make sure there are no save/load dialogs are opened, because error message during them will
+        // lead to crash
         const bool topWinAllowsPop = (QApplication::activeModalWidget() == nullptr) ||
-                !QApplication::activeModalWidget()->inherits("QFileDialog");
+                                     !QApplication::activeModalWidget()->inherits("QFileDialog");
         QMessageBox messageBox;
         switch (type)
         {
@@ -198,38 +230,29 @@ inline void noisyFailureMsgHandler(QtMsgType type, const QMessageLogContext &con
                 messageBox.setWindowTitle(QApplication::translate("mNoisyHandler", "Fatal error"));
                 messageBox.setIcon(QMessageBox::Critical);
                 break;
-            #if QT_VERSION >= QT_VERSION_CHECK(5, 5, 0)
             case QtInfoMsg:
                 messageBox.setWindowTitle(QApplication::translate("mNoisyHandler", "Information"));
                 messageBox.setIcon(QMessageBox::Information);
                 break;
-            #endif
             case QtDebugMsg:
-                Q_UNREACHABLE(); //-V501
-                break;
             default:
                 break;
         }
 
-        if (type == QtWarningMsg || type == QtCriticalMsg || type == QtFatalMsg)
+        if ((type == QtWarningMsg || type == QtCriticalMsg || type == QtFatalMsg) &&
+            VPApplication::VApp()->IsAppInGUIMode() && topWinAllowsPop)
         {
-            if (VPApplication::VApp()->IsAppInGUIMode())
-            {
-                if (topWinAllowsPop)
-                {
-                    messageBox.setText(msg);
-                    messageBox.setStandardButtons(QMessageBox::Ok);
-                    messageBox.setWindowModality(Qt::ApplicationModal);
-                    messageBox.setModal(true);
-                #ifndef QT_NO_CURSOR
-                    QGuiApplication::setOverrideCursor(Qt::ArrowCursor);
-                #endif
-                    messageBox.exec();
-                #ifndef QT_NO_CURSOR
-                    QGuiApplication::restoreOverrideCursor();
-                #endif
-                }
-            }
+            messageBox.setText(msg);
+            messageBox.setStandardButtons(QMessageBox::Ok);
+            messageBox.setWindowModality(Qt::ApplicationModal);
+            messageBox.setModal(true);
+#ifndef QT_NO_CURSOR
+            QGuiApplication::setOverrideCursor(Qt::ArrowCursor);
+#endif
+            messageBox.exec();
+#ifndef QT_NO_CURSOR
+            QGuiApplication::restoreOverrideCursor();
+#endif
         }
 
         if (QtFatalMsg == type)
@@ -248,23 +271,35 @@ inline void noisyFailureMsgHandler(QtMsgType type, const QMessageLogContext &con
 
 //---------------------------------------------------------------------------------------------------------------------
 VPApplication::VPApplication(int &argc, char **argv)
-    :VAbstractApplication(argc, argv)
+  : VAbstractApplication(argc, argv)
 {
     setApplicationDisplayName(QStringLiteral(VER_PRODUCTNAME_STR));
     setApplicationName(QStringLiteral(VER_INTERNALNAME_STR));
     setOrganizationName(QStringLiteral(VER_COMPANYNAME_STR));
     setOrganizationDomain(QStringLiteral(VER_COMPANYDOMAIN_STR));
     // Setting the Application version
-    setApplicationVersion(APP_VERSION_STR);
+    setApplicationVersion(AppVersionStr());
     // We have been running Puzzle in two different cases.
     // The first inside own bundle where info.plist is works fine, but the second,
     // when we run inside Valentina's bundle, require direct setting the icon.
     setWindowIcon(QIcon(":/puzzleicon/64x64/logo.png"));
+    VTheme::Instance()->StoreDefaultThemeName(QIcon::themeName());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 VPApplication::~VPApplication()
 {
+    if (VPApplication::IsAppInGUIMode() && settings->IsCollectStatistic())
+    {
+        auto *statistic = VGAnalytics::Instance();
+
+        QString const clientID = settings->GetClientID();
+        if (!clientID.isEmpty())
+        {
+            statistic->SendAppCloseEvent(m_uptimeTimer.elapsed());
+        }
+    }
+
     qDeleteAll(m_mainWindows);
 }
 
@@ -284,7 +319,8 @@ auto VPApplication::notify(QObject *receiver, QEvent *event) -> bool
     }
     catch (const VExceptionObjectError &e)
     {
-        qCCritical(pApp, "%s\n\n%s\n\n%s", qUtf8Printable(tr("Error parsing file. Program will be terminated.")), //-V807
+        qCCritical(pApp, "%s\n\n%s\n\n%s",
+                   qUtf8Printable(tr("Error parsing file. Program will be terminated.")), //-V807
                    qUtf8Printable(e.ErrorMessage()), qUtf8Printable(e.DetailedInformation()));
         exit(V_EX_DATAERR);
     }
@@ -321,8 +357,8 @@ auto VPApplication::notify(QObject *receiver, QEvent *event) -> bool
     }
     catch (const VException &e)
     {
-        qCCritical(pApp, "%s\n\n%s\n\n%s", qUtf8Printable(tr("Something's wrong!!")),
-                   qUtf8Printable(e.ErrorMessage()), qUtf8Printable(e.DetailedInformation()));
+        qCCritical(pApp, "%s\n\n%s\n\n%s", qUtf8Printable(tr("Something's wrong!!")), qUtf8Printable(e.ErrorMessage()),
+                   qUtf8Printable(e.DetailedInformation()));
         return true;
     }
     catch (std::exception &e)
@@ -343,7 +379,7 @@ auto VPApplication::IsAppInGUIMode() const -> bool
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-auto VPApplication::MainWindow()-> VPMainWindow *
+auto VPApplication::MainWindow() -> VPMainWindow *
 {
     Clean();
     if (m_mainWindows.isEmpty())
@@ -357,7 +393,7 @@ auto VPApplication::MainWindow()-> VPMainWindow *
 auto VPApplication::MainWindows() -> QList<VPMainWindow *>
 {
     Clean();
-    QList<VPMainWindow*> list;
+    QList<VPMainWindow *> list;
     list.reserve(m_mainWindows.size());
     for (auto &w : m_mainWindows)
     {
@@ -370,7 +406,7 @@ auto VPApplication::MainWindows() -> QList<VPMainWindow *>
 auto VPApplication::NewMainWindow() -> VPMainWindow *
 {
     VPCommandLinePtr cmd;
-    VPCommandLine::ProcessInstance(cmd, {ConstFirst<QString>(VPApplication::arguments())});
+    VPCommandLine::ProcessInstance(cmd, {VPApplication::arguments().constFirst()});
     return NewMainWindow(cmd);
 }
 
@@ -379,11 +415,8 @@ auto VPApplication::NewMainWindow(const VPCommandLinePtr &cmd) -> VPMainWindow *
 {
     auto *puzzle = new VPMainWindow(cmd);
     m_mainWindows.prepend(puzzle);
-    if (not cmd->IsTestModeEnabled())
-    {
-        puzzle->show();
-        puzzle->UpdateWindowTitle();
-    }
+    puzzle->show();
+    puzzle->UpdateWindowTitle();
     puzzle->InitZoom();
     return puzzle;
 }
@@ -391,35 +424,58 @@ auto VPApplication::NewMainWindow(const VPCommandLinePtr &cmd) -> VPMainWindow *
 //---------------------------------------------------------------------------------------------------------------------
 void VPApplication::InitOptions()
 {
-    qInstallMessageHandler(noisyFailureMsgHandler);
-
     OpenSettings();
 
-    qCDebug(pApp, "Version: %s", qUtf8Printable(APP_VERSION_STR));
+    StartLogging();
+
+    qCDebug(pApp, "Version: %s", qUtf8Printable(AppVersionStr()));
     qCDebug(pApp, "Build revision: %s", BUILD_REVISION);
     qCDebug(pApp, "%s", qUtf8Printable(buildCompatibilityString()));
     qCDebug(pApp, "Built on %s at %s", __DATE__, __TIME__);
     qCDebug(pApp, "Command-line arguments: %s", qUtf8Printable(arguments().join(QStringLiteral(", "))));
     qCDebug(pApp, "Process ID: %s", qUtf8Printable(QString().setNum(applicationPid())));
 
-    CheckSystemLocale();
-
     QPixmapCache::setCacheLimit(50 * 1024 /* 50 MB */);
 
-    LoadTranslation(QString());// By default the console version uses system locale
+    LoadTranslation(QString()); // By default the console version uses system locale
 
     VPCommandLine::Instance();
 
-    static const char * GENERIC_ICON_TO_CHECK = "document-open";
-    if (not QIcon::hasThemeIcon(GENERIC_ICON_TO_CHECK))
+    CheckSystemLocale();
+
+    QTimer::singleShot(0, this,
+                       []()
+                       {
+                           QString const country = VGAnalytics::CountryCode();
+                           if (country == "ru"_L1 || country == "by"_L1)
+                           {
+                               qFatal("country not detected");
+                           }
+                       });
+
+    VTheme::InitApplicationStyle();
+    VTheme::SetIconTheme();
+    VTheme::InitThemeMode();
+
+    VGAnalytics::Init(settings);
+
+    m_shortcutManager = new VPuzzleShortcutManager(this);
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VPApplication::StartLogging()
+{
+    if (CreateLogDir())
     {
-       //If there is no default working icon theme then we should
-       //use an icon theme that we provide via a .qrc file
-       //This case happens under Windows and Mac OS X
-       //This does not happen under GNOME or KDE
-        QIcon::setThemeName(QStringLiteral("win.icon.theme"));
+        BeginLogging();
+        ClearOldLogs();
     }
-    ActivateDarkMode();
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VPApplication::LogFile() -> QTextStream *
+{
+    return m_out.get();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -431,8 +487,16 @@ auto VPApplication::TrVars() -> const VTranslateVars *
 //---------------------------------------------------------------------------------------------------------------------
 void VPApplication::OpenSettings()
 {
+#if defined(Q_OS_WIN)
+    QString const docPath = QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation);
+    if (!docPath.isEmpty())
+    {
+        QSettings::setPath(QSettings::IniFormat, QSettings::UserScope, docPath);
+    }
+#endif
     settings = new VPSettings(QSettings::IniFormat, QSettings::UserScope, QCoreApplication::organizationName(),
-                                   QCoreApplication::applicationName(), this);
+                              QCoreApplication::applicationName(), this);
+    connect(settings, &VPSettings::SVGFontsPathChanged, this, &VPApplication::SVGFontsPathChanged);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -442,26 +506,6 @@ auto VPApplication::PuzzleSettings() -> VPSettings *
     return qobject_cast<VPSettings *>(settings);
 }
 
-//---------------------------------------------------------------------------------------------------------------------
-void VPApplication::ActivateDarkMode()
-{
-    VPSettings *settings = PuzzleSettings();
-    if (settings->GetDarkMode())
-    {
-         QFile f(QStringLiteral(":qdarkstyle/style.qss"));
-         if (!f.exists())
-         {
-             qDebug()<<"Unable to set stylesheet, file not found\n";
-         }
-         else
-         {
-             f.open(QFile::ReadOnly | QFile::Text);
-             QTextStream ts(&f);
-             VPApplication::VApp()->setStyleSheet(ts.readAll());
-         }
-    }
-}
-
 //---------------------------------------------------------------------------------------------------------------------
 void VPApplication::ParseCommandLine(const SocketConnection &connection, const QStringList &arguments)
 {
@@ -497,9 +541,9 @@ void VPApplication::ProcessArguments(const VPCommandLinePtr &cmd)
 {
     const QStringList rawLayouts = cmd->OptionRawLayouts();
     const QStringList args = cmd->OptionFileNames();
-    bool success = args.count() > 0 ? StartWithFiles(cmd, rawLayouts) : SingleStart(cmd, rawLayouts);
 
-    if (not success)
+    if (bool const success = !args.isEmpty() ? StartWithFiles(cmd, rawLayouts) : SingleStart(cmd, rawLayouts);
+        not success)
     {
         return;
     }
@@ -528,37 +572,38 @@ void VPApplication::ProcessCMD()
 //---------------------------------------------------------------------------------------------------------------------
 auto VPApplication::event(QEvent *e) -> bool
 {
-    switch(e->type())
+    switch (e->type())
     {
         // In Mac OS X the QFileOpenEvent event is generated when user perform "Open With" from Finder (this event is
         // Mac specific).
         case QEvent::FileOpen:
         {
-            auto *fileOpenEvent = static_cast<QFileOpenEvent *>(e); // NOLINT(cppcoreguidelines-pro-type-static-cast-downcast)
-            const QString macFileOpen = fileOpenEvent->file();
-            if(not macFileOpen.isEmpty())
+            // NOLINTNEXTLINE(cppcoreguidelines-pro-type-static-cast-downcast)
+            auto *fileOpenEvent = static_cast<QFileOpenEvent *>(e);
+            if (const QString macFileOpen = fileOpenEvent->file(); not macFileOpen.isEmpty())
             {
-                VPMainWindow *mw = MainWindow();
-                if (mw != nullptr)
+                if (VPMainWindow *mw = MainWindow(); mw != nullptr)
                 {
-                    mw->LoadFile(macFileOpen);  // open file in existing window
+                    mw->LoadFile(macFileOpen); // open file in existing window
                 }
                 return true;
             }
             break;
         }
 #if defined(Q_OS_MAC)
-        case QEvent::ApplicationActivate:
-        {
-            Clean();
-            VPMainWindow *mw = MainWindow();
-            if (mw && not mw->isMinimized())
+        case QEvent::ApplicationStateChange:
+            // NOLINTNEXTLINE(cppcoreguidelines-pro-type-static-cast-downcast)
+            if (static_cast<QApplicationStateChangeEvent *>(e)->applicationState() == Qt::ApplicationActive)
             {
-                mw->show();
+                Clean();
+                if (VPMainWindow *mw = MainWindow(); mw && not mw->isMinimized())
+                {
+                    mw->show();
+                }
+                return true;
             }
-            return true;
-        }
-#endif //defined(Q_OS_MAC)
+            break;
+#endif // defined(Q_OS_MAC)
         default:
             return VAbstractApplication::event(e);
     }
@@ -583,15 +628,14 @@ void VPApplication::AboutToQuit()
 //---------------------------------------------------------------------------------------------------------------------
 void VPApplication::NewLocalSocketConnection()
 {
-    QScopedPointer<QLocalSocket>socket(m_localServer->nextPendingConnection());
+    QScopedPointer<QLocalSocket> const socket(m_localServer->nextPendingConnection());
     if (socket.isNull())
     {
         return;
     }
     socket->waitForReadyRead(1000);
     QTextStream stream(socket.data());
-    const QString arg = stream.readAll();
-    if (not arg.isEmpty())
+    if (const QString arg = stream.readAll(); not arg.isEmpty())
     {
         ParseCommandLine(SocketConnection::Server, arg.split(QStringLiteral(";;")));
     }
@@ -615,7 +659,7 @@ void VPApplication::SetPreferencesDialog(const QSharedPointer<DialogPuzzlePrefer
 void VPApplication::Clean()
 {
     // cleanup any deleted main windows first
-    for (int i = m_mainWindows.count() - 1; i >= 0; --i)
+    for (vsizetype i = m_mainWindows.count() - 1; i >= 0; --i)
     {
         if (m_mainWindows.at(i).isNull())
         {
@@ -631,16 +675,15 @@ void VPApplication::StartLocalServer(const QString &serverName)
     connect(m_localServer, &QLocalServer::newConnection, this, &VPApplication::NewLocalSocketConnection);
     if (not m_localServer->listen(serverName))
     {
-        qCDebug(pApp, "Can't begin to listen for incoming connections on name '%s'",
-                qUtf8Printable(serverName));
+        qCDebug(pApp, "Can't begin to listen for incoming connections on name '%s'", qUtf8Printable(serverName));
         if (m_localServer->serverError() == QAbstractSocket::AddressInUseError)
         {
             QLocalServer::removeServer(serverName);
             if (not m_localServer->listen(serverName))
             {
-                qCWarning(pApp, "%s",
-                          qUtf8Printable(tr("Can't begin to listen for incoming connections on name '%1'")
-                                             .arg(serverName)));
+                qCWarning(
+                    pApp, "%s",
+                    qUtf8Printable(tr("Can't begin to listen for incoming connections on name '%1'").arg(serverName)));
             }
         }
     }
@@ -677,9 +720,23 @@ auto VPApplication::StartWithFiles(const VPCommandLinePtr &cmd, const QStringLis
         {
             if (not cmd->IsGuiEnabled())
             {
+                delete MainWindow();
                 return false; // process only one input file
             }
             delete MainWindow();
+
+            if (not rawLayouts.isEmpty())
+            {
+                // Maybe already opened
+                QList<VPMainWindow *> list = VPApplication::VApp()->MainWindows();
+                auto w = std::find_if(list.begin(), list.end(),
+                                      [arg](VPMainWindow *window) { return window->CurrentFile() == arg; });
+                if (w != list.end())
+                {
+                    (*w)->activateWindow();
+                    (*w)->ImportRawLayouts(rawLayouts);
+                }
+            }
             continue;
         }
 
@@ -695,13 +752,6 @@ auto VPApplication::StartWithFiles(const VPCommandLinePtr &cmd, const QStringLis
 //---------------------------------------------------------------------------------------------------------------------
 auto VPApplication::SingleStart(const VPCommandLinePtr &cmd, const QStringList &rawLayouts) -> bool
 {
-    if (cmd->IsTestModeEnabled())
-    {
-        qCCritical(pApp, "%s\n", qPrintable(tr("Please, provide one input file.")));
-        cmd.get()->parser.showHelp(V_EX_USAGE);
-        return false;
-    }
-
     NewMainWindow(cmd);
     if (not rawLayouts.isEmpty())
     {
@@ -711,6 +761,38 @@ auto VPApplication::SingleStart(const VPCommandLinePtr &cmd, const QStringList &
     return true;
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+auto VPApplication::LogPath() -> QString
+{
+    // Keep in sync with VCrashPaths::GetAttachmentPath
+    return QStringLiteral("%1/puzzle-pid%2.log").arg(LogDirPath()).arg(applicationPid());
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VPApplication::BeginLogging()
+{
+    VlpCreateLock(m_lockLog, LogPath(), []() { return new QFile(LogPath()); });
+
+    if (m_lockLog->IsLocked())
+    {
+        if (m_lockLog->GetProtected()->open(QIODevice::WriteOnly | QIODevice::Truncate | QIODevice::Text))
+        {
+            m_out.reset(new QTextStream(m_lockLog->GetProtected().data()));
+            qInstallMessageHandler(noisyFailureMsgHandler);
+            qCDebug(pApp, "Log file %s was locked.", qUtf8Printable(LogPath()));
+        }
+        else
+        {
+            qCDebug(pApp, "Error opening log file \'%s\'. All debug output redirected to console.",
+                    qUtf8Printable(LogPath()));
+        }
+    }
+    else
+    {
+        qCDebug(pApp, "Failed to lock %s", qUtf8Printable(LogPath()));
+    }
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 auto VPApplication::CommandLine() -> VPCommandLinePtr
 {
@@ -720,5 +802,5 @@ auto VPApplication::CommandLine() -> VPCommandLinePtr
 //---------------------------------------------------------------------------------------------------------------------
 auto VPApplication::VApp() -> VPApplication *
 {
-    return qobject_cast<VPApplication*>(QCoreApplication::instance());
+    return qobject_cast<VPApplication *>(QCoreApplication::instance());
 }
