@@ -28,34 +28,28 @@
 #ifndef VPCOMMANDLINE_H
 #define VPCOMMANDLINE_H
 
-#include <memory>
-#include <QCoreApplication>
 #include <QCommandLineParser>
-#include <ciso646>
+#include <QCoreApplication>
+#include <memory>
 
-#include "../vmisc/defglobal.h"
+// Header <ciso646> is removed in C++20.
+#if __cplusplus <= 201703L
+#include <ciso646> // and, not, or
+#endif
 
 class VPCommandLine;
 using VPCommandLinePtr = std::shared_ptr<VPCommandLine>;
 
-class VPCommandLine: public QObject
+class VPCommandLine : public QObject
 {
     Q_OBJECT // NOLINT
+
 public:
     ~VPCommandLine() override = default;
 
-    /** @brief if user enabled export from cmd */
-    auto IsExportEnabled() const -> bool;
-
-    /** @brief path to export file or empty string if not */
-    auto OptionExportFile() const -> QString;
-
     /** @brief list with paths to the raw layout data files */
     auto OptionRawLayouts() const -> QStringList;
 
-    /** @brief if user enabled test mode from cmd */
-    auto IsTestModeEnabled() const -> bool;
-
     /** @brief if gui enabled or not */
     auto IsGuiEnabled() const -> bool;
 
@@ -66,24 +60,26 @@ public:
     auto IsNoScalingEnabled() const -> bool;
 
     Q_NORETURN void ShowHelp(int exitCode = 0);
+
 protected:
     VPCommandLine();
 
     /** @brief create the single instance of the class inside vpapplication */
     static auto Instance() -> VPCommandLinePtr;
     static void ProcessInstance(VPCommandLinePtr &instance, const QStringList &arguments);
+
 private:
     // cppcheck-suppress unknownMacro
     Q_DISABLE_COPY_MOVE(VPCommandLine) // NOLINT
-    static VPCommandLinePtr instance; // NOLINT(cppcoreguidelines-avoid-non-const-global-variables)
+    static VPCommandLinePtr instance;  // NOLINT(cppcoreguidelines-avoid-non-const-global-variables)
     QCommandLineParser parser{};
-    bool isGuiEnabled{false};
+    bool isGuiEnabled{true};
     friend class VPApplication;
 
     /** @brief add options to the QCommandLineParser that there are in the cmd can be */
     void InitCommandLineOptions();
 
-    auto IsOptionSet(const QString &option)const -> bool;
+    auto IsOptionSet(const QString &option) const -> bool;
     auto OptionValue(const QString &option) const -> QString;
     auto OptionValues(const QString &option) const -> QStringList;
 };
