@@ -28,24 +28,26 @@
 #ifndef VPMAINWINDOW_H
 #define VPMAINWINDOW_H
 
+#include <QDoubleSpinBox>
 #include <QMainWindow>
 #include <QMessageBox>
-#include <QDoubleSpinBox>
 #include <QPointer>
+#include <memory>
 
-#include "../vmisc/def.h"
-#include "carousel/vpcarrousel.h"
-#include "scene/vpmaingraphicsview.h"
-#include "layout/vplayout.h"
-#include "../vlayout/vlayoutpiece.h"
-#include "vpcommandline.h"
-#include "../vwidgets/vabstractmainwindow.h"
-#include "../vmisc/vlockguard.h"
 #include "../vlayout/dialogs/vabstractlayoutdialog.h"
+#include "../vlayout/vlayoutpiece.h"
+#include "../vmisc/def.h"
+#include "../vmisc/vabstractshortcutmanager.h"
+#include "../vmisc/vlockguard.h"
+#include "../vwidgets/vabstractmainwindow.h"
+#include "carousel/vpcarrousel.h"
+#include "layout/vplayout.h"
+#include "scene/vpmaingraphicsview.h"
+#include "vpcommandline.h"
 
 namespace Ui
 {
-    class VPMainWindow;
+class VPMainWindow;
 }
 
 class QFileSystemWatcher;
@@ -59,7 +61,7 @@ class VPMainWindow : public VAbstractMainWindow
     Q_OBJECT // NOLINT
 
 public:
-    explicit VPMainWindow(const VPCommandLinePtr &cmd, QWidget *parent = nullptr);
+    explicit VPMainWindow(VPCommandLinePtr cmd, QWidget *parent = nullptr);
     ~VPMainWindow() override;
 
     auto CurrentFile() const -> QString;
@@ -70,7 +72,7 @@ public:
      * @param path path to layout
      * @return true if success
      */
-    auto LoadFile(const QString& path) -> bool;
+    auto LoadFile(const QString &path) -> bool;
 
     void LayoutWasSaved(bool saved);
     void SetCurrentFile(const QString &fileName);
@@ -106,7 +108,7 @@ public slots:
 
 protected:
     void closeEvent(QCloseEvent *event) override;
-    void changeEvent(QEvent* event) override;
+    void changeEvent(QEvent *event) override;
     auto RecentFileList() const -> QStringList override;
 
 private slots:
@@ -122,14 +124,14 @@ private slots:
      * triggered.
      * The slot is automatically connected through name convention.
      */
-    bool on_actionSave_triggered(); //NOLINT(modernize-use-trailing-return-type)
+    bool on_actionSave_triggered(); // NOLINT(modernize-use-trailing-return-type)
 
     /**
      * @brief on_actionSaveAs_triggered When the menu action File > Save As
      * is triggered.
      * The slot is automatically connected through name convention.
      */
-    bool on_actionSaveAs_triggered(); //NOLINT(modernize-use-trailing-return-type)
+    bool on_actionSaveAs_triggered(); // NOLINT(modernize-use-trailing-return-type)
 
     /**
      * @brief on_actionImportRawLayout_triggered When the menu action
@@ -284,21 +286,33 @@ private slots:
 
 #if defined(Q_OS_MAC)
     void AboutToShowDockMenu();
-#endif //defined(Q_OS_MAC)
+#endif // defined(Q_OS_MAC)
 
-    void SetDefaultGUILanguage();
+    void AskDefaultSettings();
 
     void HorizontalScaleChanged(double value);
     void VerticalScaleChanged(double value);
 
+    void LayoutWarningPieceGapePosition_toggled(bool checked);
     void LayoutWarningPiecesSuperposition_toggled(bool checked);
     void LayoutWarningPiecesOutOfBound_toggled(bool checked);
+    void LayoutCutOnFold_toggled(bool checked);
+
+    void UpdateShortcuts();
+
+    void TogetherWithNotchesChanged(bool checked);
+    void CurrentPieceShowSeamLineToggled(bool checked);
+    void ShowFullPieceToggled(bool checked);
+    void ShowMirrorLineToggled(bool checked);
+    void ShowGrainlineToggled(bool checked);
+    void CurrentPieceVerticallyFlippedToggled(bool checked);
+    void CurrentPieceHorizontallyFlippedToggled(bool checked);
 
 private:
     Q_DISABLE_COPY_MOVE(VPMainWindow) // NOLINT
-    Ui::VPMainWindow *ui;
+    std::unique_ptr<Ui::VPMainWindow> ui;
 
-    VPCarrousel *m_carrousel{nullptr};
+    std::unique_ptr<VPCarrousel> m_carrousel{nullptr};
     VPMainGraphicsView *m_graphicsView{nullptr};
 
     VPCommandLinePtr m_cmd;
@@ -315,9 +329,9 @@ private:
     /**
      * @brief mouseCoordinate pointer to label who show mouse coordinate.
      */
-    QLabel* m_mouseCoordinate{nullptr};
+    QLabel *m_mouseCoordinate{nullptr};
 
-    QLabel* m_statusLabel{nullptr};
+    QLabel *m_statusLabel{nullptr};
 
     QString curFile{};
 
@@ -339,12 +353,14 @@ private:
 
     QFileSystemWatcher *m_watermarkWatcher{nullptr};
 
+    QMultiHash<VShortcutAction, QAction *> m_actionShortcuts{};
+
     struct VPLayoutPrinterPage
     {
         VPSheetPtr sheet{};
-        bool       tilesScheme{false};
-        int        tileRow{-1};
-        int        tileCol{-1};
+        bool tilesScheme{false};
+        int tileRow{-1};
+        int tileCol{-1};
     };
 
     /**
@@ -425,9 +441,9 @@ private:
     void SetPropertyTabTilesData();
 
     /**
-    * @brief SetPropertyTabLayoutData Sets the values of UI elements
-    * in the Layout Tab to the values saved in m_layout
-    */
+     * @brief SetPropertyTabLayoutData Sets the values of UI elements
+     * in the Layout Tab to the values saved in m_layout
+     */
     void SetPropertyTabLayoutData();
 
     void ReadSettings();
@@ -473,13 +489,13 @@ private:
 
     void ExportData(const VPExportData &data);
     static void ExportApparelLayout(const VPExportData &data, const QVector<VLayoutPiece> &details, const QString &name,
-                             const QSize &size) ;
+                                    const QSize &size);
     void ExportFlatLayout(const VPExportData &data);
     void ExportScene(const VPExportData &data);
     static void ExportUnifiedPdfFile(const VPExportData &data);
     static void GenerateUnifiedPdfFile(const VPExportData &data, const QString &name);
     void ExportPdfTiledFile(const VPExportData &data);
-    auto GeneratePdfTiledFile(const VPSheetPtr &sheet, bool showTilesScheme, QPainter *painter,
+    auto GeneratePdfTiledFile(const VPSheetPtr &sheet, const VPExportData &data, QPainter *painter,
                               const QSharedPointer<QPrinter> &printer, bool &firstPage) -> bool;
 
     void UpdateScaleConnection() const;
@@ -492,9 +508,10 @@ private:
     auto AskLayoutIsInvalid(const QList<VPSheetPtr> &sheets) -> bool;
     auto CheckPiecesOutOfBound(const VPPiecePtr &piece, bool &outOfBoundChecked) -> bool;
     auto CheckSuperpositionOfPieces(const VPPiecePtr &piece, bool &pieceSuperpositionChecked) -> bool;
+    auto CheckPieceGapePosition(const VPPiecePtr &piece, bool &pieceGapePositionChecked) -> bool;
 
     void PrintLayoutSheets(QPrinter *printer, const QList<VPSheetPtr> &sheets);
-    static auto PrintLayoutSheetPage(QPrinter *printer, QPainter &painter, const VPSheetPtr& sheet) -> bool;
+    static auto PrintLayoutSheetPage(QPrinter *printer, QPainter &painter, const VPSheetPtr &sheet) -> bool;
     void PrintLayoutTiledSheets(QPrinter *printer, const QList<VPSheetPtr> &sheets);
     auto PrepareLayoutTilePages(const QList<VPSheetPtr> &sheets) -> QVector<VPLayoutPrinterPage>;
     auto PrintLayoutTiledSheetPage(QPrinter *printer, QPainter &painter, const VPLayoutPrinterPage &page,
@@ -506,9 +523,11 @@ private:
     auto AddLayoutPieces(const QVector<VLayoutPiece> &pieces) -> bool;
 
     void TranslatePieces();
-    void TranslatePieceRelatively(const VPPiecePtr &piece, const QRectF &rect, int selectedPiecesCount, qreal dx,
+    void TranslatePieceRelatively(const VPPiecePtr &piece, const QRectF &rect, vsizetype selectedPiecesCount, qreal dx,
                                   qreal dy);
     void RotatePieces();
+
+    void InitIcons();
 };
 
 #endif // VPMAINWINDOW_H
