@@ -26,52 +26,80 @@
  **
  *************************************************************************/
 #include "vpsettings.h"
+#include "../vmisc/compatibility.h"
 
+#include <QDir>
 #include <QMarginsF>
 
+using namespace Qt::Literals::StringLiterals;
+
 namespace
 {
-Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingDockWidgetPropertiesActive, (QLatin1String("dockWidget/properties"))) // NOLINT
-Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingDockPropertiesContentsActive, (QLatin1String("dockWidget/contents"))) // NOLINT
-Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingLayoutUnit, (QLatin1String("layout/unit"))) // NOLINT
-Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingLayoutSheetPaperWidth, (QLatin1String("layout/sheetPaperWidth"))) // NOLINT
-Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingLayoutSheetPaperHeight, (QLatin1String("layout/sheetPaperHeight"))) // NOLINT
-Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingLayoutTilePaperWidth, (QLatin1String("layout/tilePaperWidth"))) // NOLINT
-Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingLayoutTilePaperHeight, (QLatin1String("layout/tilePaperHeight"))) // NOLINT
-Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingLayoutSheetMargins, (QLatin1String("layout/sheetMargins"))) // NOLINT
-Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingLayoutTileMargins, (QLatin1String("layout/tileMargins"))) // NOLINT
-Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingLayoutSheetIgnoreMargins, (QLatin1String("layout/sheetIgnoreMargins"))) // NOLINT
-Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingLayoutTileIgnoreMargins, (QLatin1String("layout/tileIgnoreMargins"))) // NOLINT
-Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingLayoutTileShowTiles, (QLatin1String("layout/tileShowTiles"))) // NOLINT
-Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingLayoutTileShowWatermark, (QLatin1String("layout/tileShowWatermark"))) // NOLINT
-Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingLayoutWarningPiecesSuperposition, // NOLINT
-                          (QLatin1String("layout/warningPiecesSuperposition")))
-Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingLayoutStickyEdges, (QLatin1String("layout/stickyEdges"))) // NOLINT
-Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingLayoutWarningPiecesOutOfBound, // NOLINT
-                          (QLatin1String("layout/warningPiecesOutOfBound")))
-Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingLayoutFollowGrainline, (QLatin1String("layout/followGrainline"))) // NOLINT
-Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingLayoutPieceGap, (QLatin1String("layout/pieceGap"))) // NOLINT
-Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingLayoutExportFormat, (QLatin1String("layout/exportFormat"))) // NOLINT
-Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingLayoutLineWidth, (QLatin1String("layout/lineWidth"))) // NOLINT
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_CLANG("-Wunused-member-function")
 
-int cachedLineWidth = -1;
-}  // namespace
+// NOLINTNEXTLINE
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingDockWidgetPropertiesActive, ("dockWidget/properties"_L1))
+// NOLINTNEXTLINE
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingDockPropertiesContentsActive, ("dockWidget/contents"_L1))
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingLayoutUnit, ("layout/unit"_L1)) // NOLINT
+// NOLINTNEXTLINE
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingLayoutSheetPaperWidth, ("layout/sheetPaperWidth"_L1))
+// NOLINTNEXTLINE
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingLayoutSheetPaperHeight, ("layout/sheetPaperHeight"_L1))
+// NOLINTNEXTLINE
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingLayoutTilePaperWidth, ("layout/tilePaperWidth"_L1))
+// NOLINTNEXTLINE
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingLayoutTilePaperHeight, ("layout/tilePaperHeight"_L1))
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingLayoutSheetMargins, ("layout/sheetMargins"_L1)) // NOLINT
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingLayoutTileMargins, ("layout/tileMargins"_L1))   // NOLINT
+// NOLINTNEXTLINE
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingLayoutSheetIgnoreMargins, ("layout/sheetIgnoreMargins"_L1))
+// NOLINTNEXTLINE
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingLayoutTileIgnoreMargins, ("layout/tileIgnoreMargins"_L1))
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingLayoutTileShowTiles, ("layout/tileShowTiles"_L1)) // NOLINT
+// NOLINTNEXTLINE
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingLayoutTileShowWatermark, ("layout/tileShowWatermark"_L1))
+// NOLINTNEXTLINE
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingLayoutWarningPiecesSuperposition,
+                          ("layout/warningPiecesSuperposition"_L1))
+// NOLINTNEXTLINE
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingLayoutWarningPieceGapePosition, ("layout/warningPieceGapePosition"_L1))
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingLayoutStickyEdges, ("layout/stickyEdges"_L1)) // NOLINT
+// NOLINTNEXTLINE
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingLayoutWarningPiecesOutOfBound, ("layout/warningPiecesOutOfBound"_L1))
+// NOLINTNEXTLINE
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingLayoutFollowGrainline, ("layout/followGrainline"_L1))
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingLayoutPieceGap, ("layout/pieceGap"_L1))           // NOLINT
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingLayoutExportFormat, ("layout/exportFormat"_L1))   // NOLINT
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingDxfCompatibility, ("layout/dxfCompatibility"_L1)) // NOLINT
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingLayoutLineWidth, ("layout/lineWidth"_L1))         // NOLINT
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingLayoutShowGrainline, ("layout/showGrainline"_L1)) // NOLINT
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, settingPathsRawLayoutData, ("paths/rawLatoutData"_L1))   // NOLINT
 
-Q_DECLARE_METATYPE(QMarginsF)
+QT_WARNING_POP
+
+int cachedLineWidth = -1; // NOLINT(cppcoreguidelines-avoid-non-const-global-variables)
+
+} // namespace
+
+#ifndef QPRINTENGINE_H
+Q_DECLARE_METATYPE(QMarginsF) // NOLINT
+#endif
 
 //---------------------------------------------------------------------------------------------------------------------
 VPSettings::VPSettings(Format format, Scope scope, const QString &organization, const QString &application,
-                                 QObject *parent)
-    : VCommonSettings(format, scope, organization, application, parent)
+                       QObject *parent)
+  : VCommonSettings(format, scope, organization, application, parent)
 {
-    qRegisterMetaTypeStreamOperators<QMarginsF>("QMarginsF");
+    REGISTER_META_TYPE_STREAM_OPERATORS(QMarginsF);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 VPSettings::VPSettings(const QString &fileName, QSettings::Format format, QObject *parent)
-    : VCommonSettings(fileName, format, parent)
+  : VCommonSettings(fileName, format, parent)
 {
-    qRegisterMetaTypeStreamOperators<QMarginsF>("QMarginsF");
+    REGISTER_META_TYPE_STREAM_OPERATORS(QMarginsF);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -110,6 +138,18 @@ void VPSettings::SetDockWidgetPropertiesContentsActive(bool value)
     setValue(*settingDockPropertiesContentsActive, value);
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+auto VPSettings::GetPathRawLayoutData() const -> QString
+{
+    return value(*settingPathsRawLayoutData, QDir::homePath()).toString();
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VPSettings::SetPathRawLayoutData(const QString &value)
+{
+    setValue(*settingPathsRawLayoutData, value);
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void VPSettings::SetLayoutUnit(Unit unit)
 {
@@ -131,7 +171,7 @@ void VPSettings::SetLayoutSheetPaperWidth(qreal width)
 //---------------------------------------------------------------------------------------------------------------------
 auto VPSettings::GetLayoutSheetPaperWidth() const -> qreal
 {
-    return ValueOrDef<qreal>(*this, *settingLayoutSheetPaperWidth, UnitConvertor(841/*A0*/, Unit::Mm, Unit::Px));
+    return ValueOrDef<qreal>(*this, *settingLayoutSheetPaperWidth, UnitConvertor(841 /*A0*/, Unit::Mm, Unit::Px));
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -143,7 +183,7 @@ void VPSettings::SetLayoutSheetPaperHeight(qreal height)
 //---------------------------------------------------------------------------------------------------------------------
 auto VPSettings::GetLayoutSheetPaperHeight() const -> qreal
 {
-    return ValueOrDef<qreal>(*this, *settingLayoutSheetPaperHeight, UnitConvertor(1189/*A0*/, Unit::Mm, Unit::Px));
+    return ValueOrDef<qreal>(*this, *settingLayoutSheetPaperHeight, UnitConvertor(1189 /*A0*/, Unit::Mm, Unit::Px));
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -155,7 +195,7 @@ void VPSettings::SetLayoutTilePaperWidth(qreal width)
 //---------------------------------------------------------------------------------------------------------------------
 auto VPSettings::GetLayoutTilePaperWidth() const -> qreal
 {
-    return ValueOrDef<qreal>(*this, *settingLayoutTilePaperWidth, UnitConvertor(210/*A4*/, Unit::Mm, Unit::Px));
+    return ValueOrDef<qreal>(*this, *settingLayoutTilePaperWidth, UnitConvertor(210 /*A4*/, Unit::Mm, Unit::Px));
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -167,7 +207,7 @@ void VPSettings::SetLayoutTilePaperHeight(qreal height)
 //---------------------------------------------------------------------------------------------------------------------
 auto VPSettings::GetLayoutTilePaperHeight() const -> qreal
 {
-    return ValueOrDef<qreal>(*this, *settingLayoutTilePaperHeight, UnitConvertor(297/*A4*/, Unit::Mm, Unit::Px));
+    return ValueOrDef<qreal>(*this, *settingLayoutTilePaperHeight, UnitConvertor(297 /*A4*/, Unit::Mm, Unit::Px));
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -254,6 +294,18 @@ auto VPSettings::GetLayoutWarningPiecesSuperposition() const -> bool
     return value(*settingLayoutWarningPiecesSuperposition, true).toBool();
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void VPSettings::SetLayoutWarningPieceGapePosition(bool value)
+{
+    setValue(*settingLayoutWarningPieceGapePosition, value);
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VPSettings::GetLayoutWarningPieceGapePosition() const -> bool
+{
+    return value(*settingLayoutWarningPieceGapePosition, true).toBool();
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void VPSettings::SetLayoutStickyEdges(bool value)
 {
@@ -291,7 +343,7 @@ auto VPSettings::GetLayoutFollowGrainline() const -> bool
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-qreal VPSettings::GetMaxLayoutPieceGap()
+auto VPSettings::GetMaxLayoutPieceGap() -> qreal
 {
     return UnitConvertor(50, Unit::Cm, Unit::Px);
 }
@@ -309,9 +361,9 @@ auto VPSettings::GetLayoutPieceGap() const -> qreal
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-qint8 VPSettings::GetLayoutExportFormat() const
+auto VPSettings::GetLayoutExportFormat() const -> qint8
 {
-    return qvariant_cast<qint8>(value(*settingLayoutExportFormat, 0));
+    return CastToLayoutExportFormat(qvariant_cast<qint8>(value(*settingLayoutExportFormat, 0)));
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -320,6 +372,18 @@ void VPSettings::SetLayoutExportFormat(qint8 format)
     setValue(*settingLayoutExportFormat, format);
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+auto VPSettings::GetDxfCompatibility() const -> qint8
+{
+    return CastToLayoutExportFormat(qvariant_cast<qint8>(value(*settingDxfCompatibility, 0)));
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VPSettings::SetDxfCompatibility(qint8 type)
+{
+    setValue(*settingDxfCompatibility, type);
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 auto VPSettings::GetLayoutLineWidth() const -> int
 {
@@ -337,3 +401,15 @@ void VPSettings::SetLayoutLineWidth(int width)
     cachedLineWidth = qBound(1, width, 10);
     setValue(*settingLayoutLineWidth, cachedLineWidth);
 }
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VPSettings::GetShowGrainline() const -> bool
+{
+    return value(*settingLayoutShowGrainline, true).toBool();
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VPSettings::SetShowGrainline(bool value)
+{
+    setValue(*settingLayoutShowGrainline, value);
+}
