@@ -30,15 +30,17 @@
 
 #include <QByteArray>
 
-#include "vcommonsettings.h"
+#include "../vmisc/vcommonsettings.h"
 
 class VPSettings : public VCommonSettings
 {
     Q_OBJECT // NOLINT
+
 public:
     VPSettings(Format format, Scope scope, const QString &organization, const QString &application = QString(),
-                    QObject *parent = nullptr);
+               QObject *parent = nullptr);
     VPSettings(const QString &fileName, Format format, QObject *parent = nullptr);
+    ~VPSettings() override = default;
 
     auto IsDockWidgetPropertiesActive() const -> bool;
     static auto GetDefDockWidgetPropertiesActive() -> bool;
@@ -48,6 +50,9 @@ public:
     static auto GetDefDockWidgetPropertiesContentsActive() -> bool;
     void SetDockWidgetPropertiesContentsActive(bool value);
 
+    auto GetPathRawLayoutData() const -> QString;
+    void SetPathRawLayoutData(const QString &value);
+
     void SetLayoutUnit(Unit unit);
     auto LayoutUnit() const -> Unit;
 
@@ -84,6 +89,9 @@ public:
     void SetLayoutWarningPiecesSuperposition(bool value);
     auto GetLayoutWarningPiecesSuperposition() const -> bool;
 
+    void SetLayoutWarningPieceGapePosition(bool value);
+    auto GetLayoutWarningPieceGapePosition() const -> bool;
+
     void SetLayoutStickyEdges(bool value);
     auto GetLayoutStickyEdges() const -> bool;
 
@@ -100,9 +108,15 @@ public:
     auto GetLayoutExportFormat() const -> qint8;
     void SetLayoutExportFormat(qint8 format);
 
+    auto GetDxfCompatibility() const -> qint8;
+    void SetDxfCompatibility(qint8 type);
+
     auto GetLayoutLineWidth() const -> int;
     void SetLayoutLineWidth(int width);
 
+    auto GetShowGrainline() const -> bool;
+    void SetShowGrainline(bool value);
+
 private:
     Q_DISABLE_COPY_MOVE(VPSettings) // NOLINT
 };
