@@ -2,32 +2,106 @@
 
 #include <QtSvg>
 
-#include "../vwidgets/vmaingraphicsscene.h"
-#include "layout/vpsheet.h"
-#include "qobject.h"
-#include "scene/vpmaingraphicsview.h"
+#include "../vlayout/vprintlayout.h"
+#include "../vmisc/compatibility.h"
 #include "../vmisc/def.h"
 #include "../vmisc/literals.h"
 #include "../vmisc/vcommonsettings.h"
-#include "../vmisc/compatibility.h"
-#include "../vlayout/vprintlayout.h"
+#include "../vwidgets/vmaingraphicsscene.h"
+#include "layout/vplayout.h"
+#include "layout/vpsheet.h"
+#include "theme/vtheme.h"
+
+using namespace Qt::Literals::StringLiterals;
 
 namespace
 {
-Q_GLOBAL_STATIC_WITH_ARGS(QColor, tileColor, (180, 180, 180)) // NOLINT
-Q_GLOBAL_STATIC_WITH_ARGS(QBrush, triangleBush, (QColor(200,200,200))) // NOLINT
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_CLANG("-Wunused-member-function")
+
+Q_GLOBAL_STATIC_WITH_ARGS(QColor, tileColor, (180, 180, 180))            // NOLINT
+Q_GLOBAL_STATIC_WITH_ARGS(QBrush, triangleBush, (QColor(200, 200, 200))) // NOLINT
+
+struct WatermarkScaledImageInfo
+{
+    qint64 scaledImageSize{-1};
+    int width{0};
+    int height{0};
+};
+
+using WatermarkScaledSize = QCache<QString, WatermarkScaledImageInfo>;
+Q_GLOBAL_STATIC(WatermarkScaledSize, watermarkSizeCache) // NOLINT
+
+QT_WARNING_POP
+
+//---------------------------------------------------------------------------------------------------------------------
+inline auto GenerateWatermarkScaledSizeCacheKey(const QString &watermarkPath, qreal xScale, qreal yScale) -> QString
+{
+    return QStringLiteral("path%1+xscale%2+yscale%3")
+        .arg(watermarkPath, QString::number(xScale), QString::number(yScale));
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void CalculateAndCacheWatermarkScaledImageSize(const VWatermarkData &watermarkData, const QString &watermarkPath,
+                                               qreal xScale, qreal yScale)
+{
+    QString const imagePath = AbsoluteMPath(watermarkPath, watermarkData.path);
+    QImageReader imageReader(imagePath);
+    QImage const watermarkImage = imageReader.read();
+
+    qint64 scaledImageSize = -1;
+    if (!watermarkImage.isNull())
+    {
+        qint64 const fileSize = watermarkImage.sizeInBytes();
+        qint64 const pixelSize = fileSize / watermarkImage.height() / watermarkImage.width();
+        QSize const scaledSize(qRound(watermarkImage.width() / xScale), qRound(watermarkImage.height() / yScale));
+        scaledImageSize = pixelSize * scaledSize.width() * scaledSize.height() / 1024;
+    }
+
+    auto *info = new WatermarkScaledImageInfo;
+    info->scaledImageSize = scaledImageSize;
+    info->width = watermarkImage.width();
+    info->height = watermarkImage.height();
+
+    // Insert into the cache
+    watermarkSizeCache->insert(GenerateWatermarkScaledSizeCacheKey(watermarkPath, xScale, yScale), info);
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto GetWatermarkScaledImageInfo(const VWatermarkData &watermarkData, const QString &watermarkPath, qreal xScale,
+                                 qreal yScale) -> WatermarkScaledImageInfo
+{
+    // Check if the value is already cached
+    WatermarkScaledImageInfo *info =
+        watermarkSizeCache->object(GenerateWatermarkScaledSizeCacheKey(watermarkPath, xScale, yScale));
+    if (info != nullptr)
+    {
+        return *info;
+    }
+
+    // If not cached, calculate and cache the value
+    CalculateAndCacheWatermarkScaledImageSize(watermarkData, watermarkPath, xScale, yScale);
+    // Retrieve the calculated value from the cache
+    info = watermarkSizeCache->object(GenerateWatermarkScaledSizeCacheKey(watermarkPath, xScale, yScale));
+    if (info != nullptr)
+    {
+        return *info;
+    }
+
+    return {}; // Return an error value if caching failed
+}
 
 //---------------------------------------------------------------------------------------------------------------------
 auto Grayscale(QImage image) -> QImage
 {
     for (int ii = 0; ii < image.height(); ii++)
     {
-        uchar* scan = image.scanLine(ii);
-        int depth = 4;
+        uchar *scan = image.scanLine(ii);
+        int const depth = 4;
         for (int jj = 0; jj < image.width(); jj++)
         {
-            auto* rgbpixel = reinterpret_cast<QRgb*>(scan + jj * depth); // NOLINT
-            int gray = qGray(*rgbpixel);
+            auto *rgbpixel = reinterpret_cast<QRgb *>(scan + jj * depth); // NOLINT
+            int const gray = qGray(*rgbpixel);
             *rgbpixel = QColor(gray, gray, gray, qAlpha(*rgbpixel)).rgba();
         }
     }
@@ -40,12 +114,14 @@ auto WatermarkImageFromCache(const VWatermarkData &watermarkData, const QString
                              qreal yScale, QString &error) -> QPixmap
 {
     QPixmap pixmap;
-    QString imagePath = AbsoluteMPath(watermarkPath, watermarkData.path);
-    QString imageCacheKey = QStringLiteral("puzzle=path%1+rotation%3+grayscale%4+xscale%5+yxcale%6")
-            .arg(imagePath, QString::number(watermarkData.imageRotation),
-                 watermarkData.grayscale ? trueStr : falseStr ).arg(xScale).arg(yScale);
+    QString const imagePath = AbsoluteMPath(watermarkPath, watermarkData.path);
 
-    if (not QPixmapCache::find(imageCacheKey, &pixmap))
+    if (auto const imageCacheKey = QStringLiteral("puzzle=path%1+rotation%3+grayscale%4+xscale%5+yxcale%6")
+                                       .arg(imagePath, QString::number(watermarkData.imageRotation),
+                                            watermarkData.grayscale ? trueStr : falseStr)
+                                       .arg(xScale)
+                                       .arg(yScale);
+        not QPixmapCache::find(imageCacheKey, &pixmap))
     {
         QImageReader imageReader(imagePath);
         QImage watermark = imageReader.read();
@@ -65,9 +141,9 @@ auto WatermarkImageFromCache(const VWatermarkData &watermarkData, const QString
         watermark = watermark.transformed(t);
 
         t = QTransform();
-        t.translate(watermark.width()/2., watermark.height()/2.);
+        t.translate(watermark.width() / 2., watermark.height() / 2.);
         t.rotate(-watermarkData.imageRotation);
-        t.translate(-watermark.width()/2., -watermark.height()/2.);
+        t.translate(-watermark.width() / 2., -watermark.height() / 2.);
         watermark = watermark.transformed(t);
 
         pixmap = QPixmap::fromImage(watermark);
@@ -82,10 +158,8 @@ auto WatermarkImageFromCache(const VWatermarkData &watermarkData, const QString
 auto TriangleBasic() -> QPainterPath
 {
     // ------------- prepare triangles for position marks
-    QRectF rectBasic = QRectF(-UnitConvertor(0.5, Unit::Cm, Unit::Px),
-                              0,
-                              UnitConvertor(1, Unit::Cm, Unit::Px),
-                              UnitConvertor(0.5, Unit::Cm, Unit::Px));
+    auto const rectBasic = QRectF(-UnitConvertor(0.5, Unit::Cm, Unit::Px), 0, UnitConvertor(1, Unit::Cm, Unit::Px),
+                                  UnitConvertor(0.5, Unit::Cm, Unit::Px));
     QPainterPath triangleBasic;
     triangleBasic.moveTo(rectBasic.topLeft());
     triangleBasic.lineTo(rectBasic.topRight());
@@ -93,11 +167,11 @@ auto TriangleBasic() -> QPainterPath
     triangleBasic.lineTo(rectBasic.topLeft());
     return triangleBasic;
 }
-}  // namespace
+} // namespace
 
 //---------------------------------------------------------------------------------------------------------------------
-VPTileFactory::VPTileFactory(const VPLayoutPtr &layout, VCommonSettings *commonSettings, QObject *parent):
-    QObject(parent),
+VPTileFactory::VPTileFactory(const VPLayoutPtr &layout, VCommonSettings *commonSettings, QObject *parent)
+  : QObject(parent),
     m_layout(layout),
     m_commonSettings(commonSettings)
 {
@@ -106,11 +180,11 @@ VPTileFactory::VPTileFactory(const VPLayoutPtr &layout, VCommonSettings *commonS
 //---------------------------------------------------------------------------------------------------------------------
 void VPTileFactory::RefreshTileInfos()
 {
-    VPLayoutPtr layout = m_layout.toStrongRef();
-    if(not layout.isNull())
+    VPLayoutPtr const layout = m_layout.toStrongRef();
+    if (not layout.isNull())
     {
-        QSizeF tilesSize = layout->LayoutSettings().GetTilesSize();
-        QMarginsF tilesMargins = layout->LayoutSettings().GetTilesMargins();
+        QSizeF const tilesSize = layout->LayoutSettings().GetTilesSize();
+        QMarginsF const tilesMargins = layout->LayoutSettings().GetTilesMargins();
 
         // sets the drawing height
         m_drawingAreaHeight = tilesSize.height();
@@ -133,8 +207,8 @@ void VPTileFactory::RefreshTileInfos()
 //---------------------------------------------------------------------------------------------------------------------
 void VPTileFactory::RefreshWatermarkData()
 {
-    VPLayoutPtr layout = m_layout.toStrongRef();
-    if(not layout.isNull())
+    VPLayoutPtr const layout = m_layout.toStrongRef();
+    if (not layout.isNull())
     {
         m_watermarkData = layout->WatermarkData();
     }
@@ -150,12 +224,6 @@ void VPTileFactory::drawTile(QPainter *painter, QPrinter *printer, const VPSheet
     SCASSERT(painter != nullptr)
     SCASSERT(printer != nullptr)
 
-    VPLayoutPtr layout = m_layout.toStrongRef();
-    if(layout.isNull())
-    {
-        return;
-    }
-
     if (sheet.isNull())
     {
         return;
@@ -176,10 +244,10 @@ void VPTileFactory::drawTile(QPainter *painter, QPrinter *printer, const VPSheet
 
     painter->save();
 
-    const QPair<qreal, qreal> scale = VPrintLayout::PrinterScaleDiff(printer);
-    painter->scale(scale.first, scale.second);
+    const auto [xscale, yscale] = VPrintLayout::PrinterScaleDiff(printer);
+    painter->scale(xscale, yscale);
 
-    if(row > 0)
+    if (row > 0)
     {
         // add top triangle
         DrawTopTriangle(painter);
@@ -194,7 +262,7 @@ void VPTileFactory::drawTile(QPainter *painter, QPrinter *printer, const VPSheet
         DrawSolidTopLine(painter, col, nbCol);
     }
 
-    if(col > 0)
+    if (col > 0)
     {
         // add left triangle
         DrawLeftTriangle(painter);
@@ -209,7 +277,7 @@ void VPTileFactory::drawTile(QPainter *painter, QPrinter *printer, const VPSheet
         DrawSolidLeftLine(painter, row, nbRow);
     }
 
-    if(row < nbRow-1)
+    if (row < nbRow - 1)
     {
         // add bottom triangle
         DrawBottomTriangle(painter);
@@ -222,10 +290,10 @@ void VPTileFactory::drawTile(QPainter *painter, QPrinter *printer, const VPSheet
         DrawSolidBottomLine(painter, col, nbCol);
     }
 
-    DrawRuler(painter, scale.first);
+    DrawRuler(painter, xscale);
     DrawWatermark(painter);
 
-    if(col < nbCol-1)
+    if (col < nbCol - 1)
     {
         // add right triangle
         DrawRightTriangle(painter);
@@ -253,13 +321,12 @@ auto VPTileFactory::RowNb(const VPSheetPtr &sheet) const -> int
     }
 
     qreal yScale = 1;
-    VPLayoutPtr layout = m_layout.toStrongRef();
-    if(not layout.isNull())
+    if (VPLayoutPtr const layout = m_layout.toStrongRef(); not layout.isNull())
     {
         yScale = layout->LayoutSettings().VerticalScale();
     }
 
-    QRectF sheetSize = sheet->GetMarginsRect();
+    QRectF const sheetSize = sheet->GetMarginsRect();
     return qCeil(sheetSize.height() * yScale / (m_drawingAreaHeight - tileStripeWidth));
 }
 
@@ -272,13 +339,12 @@ auto VPTileFactory::ColNb(const VPSheetPtr &sheet) const -> int
     }
 
     qreal xScale = 1;
-    VPLayoutPtr layout = m_layout.toStrongRef();
-    if(not layout.isNull())
+    if (VPLayoutPtr const layout = m_layout.toStrongRef(); not layout.isNull())
     {
         xScale = layout->LayoutSettings().HorizontalScale();
     }
 
-    QRectF sheetSize = sheet->GetMarginsRect();
+    QRectF const sheetSize = sheet->GetMarginsRect();
     return qCeil(sheetSize.width() * xScale / (m_drawingAreaWidth - tileStripeWidth));
 }
 
@@ -303,13 +369,13 @@ auto VPTileFactory::WatermarkData() const -> const VWatermarkData &
 //---------------------------------------------------------------------------------------------------------------------
 void VPTileFactory::DrawRuler(QPainter *painter, qreal scale) const
 {
-    VPLayoutPtr layout = m_layout.toStrongRef();
-    if(layout.isNull())
+    VPLayoutPtr const layout = m_layout.toStrongRef();
+    if (layout.isNull())
     {
         return;
     }
 
-    QPen rulePen(*tileColor, 1, Qt::SolidLine);
+    QPen const rulePen(*tileColor, 1, Qt::SolidLine);
 
     painter->save();
     painter->setPen(rulePen);
@@ -317,22 +383,22 @@ void VPTileFactory::DrawRuler(QPainter *painter, qreal scale) const
     const qreal notchHeight = UnitConvertor(3, Unit::Mm, Unit::Px);
     const qreal shortNotchHeight = UnitConvertor(1.1, Unit::Mm, Unit::Px);
 
-    Unit layoutUnits = layout->LayoutSettings().GetUnit();
-    Unit rulerUnits = layoutUnits == Unit::Inch ? layoutUnits : Unit::Cm;
+    Unit const layoutUnits = layout->LayoutSettings().GetUnit();
+    Unit const rulerUnits = layoutUnits == Unit::Inch ? layoutUnits : Unit::Cm;
 
     const qreal step = UnitConvertor(1, rulerUnits, Unit::Px);
-    double marksCount = (m_drawingAreaWidth-tileStripeWidth) / step;
+    double const marksCount = (m_drawingAreaWidth - tileStripeWidth) / step;
     int i = 0;
     while (i < marksCount)
     {
         if (i != 0)
         { // don't need 0 notch
             // middle ruler line
-            painter->drawLine(QPointF(step * i - step / 2., m_drawingAreaHeight-tileStripeWidth),
+            painter->drawLine(QPointF(step * i - step / 2., m_drawingAreaHeight - tileStripeWidth),
                               QPointF(step * i - step / 2., m_drawingAreaHeight - tileStripeWidth + shortNotchHeight));
 
             // ruler line
-            painter->drawLine(QPointF(step * i, m_drawingAreaHeight-tileStripeWidth),
+            painter->drawLine(QPointF(step * i, m_drawingAreaHeight - tileStripeWidth),
                               QPointF(step * i, m_drawingAreaHeight - tileStripeWidth + notchHeight));
         }
         else
@@ -340,16 +406,17 @@ void VPTileFactory::DrawRuler(QPainter *painter, qreal scale) const
             painter->save();
 
             QFont fnt = painter->font();
-            const int size = qRound(10/scale);
+            const int size = qRound(10 / scale);
             size > 0 ? fnt.setPointSize(size) : fnt.setPointSize(10);
             painter->setFont(fnt);
 
             qreal unitsWidth = 0;
-            QFontMetrics fm(fnt);
-            QString units = rulerUnits != Unit::Inch ? tr("cm", "unit") : tr("in", "unit");
-            unitsWidth = TextWidth(fm, units);
-            painter->drawText(QPointF(step*0.5-unitsWidth*0.6,
-                                      m_drawingAreaHeight - tileStripeWidth + notchHeight+shortNotchHeight), units);
+            QFontMetrics const fm(fnt);
+            QString const units = rulerUnits != Unit::Inch ? tr("cm", "unit") : tr("in", "unit");
+            unitsWidth = fm.horizontalAdvance(units);
+            painter->drawText(QPointF(step * 0.5 - unitsWidth * 0.6,
+                                      m_drawingAreaHeight - tileStripeWidth + notchHeight + shortNotchHeight),
+                              units);
 
             painter->restore();
         }
@@ -364,22 +431,19 @@ void VPTileFactory::DrawWatermark(QPainter *painter) const
 {
     SCASSERT(painter != nullptr)
 
-    VPLayoutPtr layout = m_layout.toStrongRef();
-    if(layout.isNull())
+    VPLayoutPtr const layout = m_layout.toStrongRef();
+    if (layout.isNull())
     {
         return;
     }
 
     if (m_watermarkData.opacity > 0)
     {
-        QRectF img(0, 0,
-                   m_drawingAreaWidth - tileStripeWidth,
-                   m_drawingAreaHeight - tileStripeWidth);
+        QRectF const img(0, 0, m_drawingAreaWidth - tileStripeWidth, m_drawingAreaHeight - tileStripeWidth);
 
         if (m_watermarkData.showImage && not m_watermarkData.path.isEmpty())
         {
-            PaintWatermarkImage(painter, img, m_watermarkData,
-                                layout->LayoutSettings().WatermarkPath());
+            PaintWatermarkImage(painter, img, m_watermarkData, layout->LayoutSettings().WatermarkPath(), false);
         }
 
         if (m_watermarkData.showText && not m_watermarkData.text.isEmpty())
@@ -399,8 +463,8 @@ inline auto VPTileFactory::PenTileInfos() const -> QPen
 void VPTileFactory::DrawTilePageContent(QPainter *painter, const VPSheetPtr &sheet, int row, int col,
                                         QPrinter *printer) const
 {
-    VPLayoutPtr layout = m_layout.toStrongRef();
-    if(layout.isNull())
+    VPLayoutPtr const layout = m_layout.toStrongRef();
+    if (layout.isNull())
     {
         return;
     }
@@ -411,23 +475,19 @@ void VPTileFactory::DrawTilePageContent(QPainter *painter, const VPSheetPtr &she
         sheetMargins = sheet->GetSheetMargins();
     }
 
-    QPen penTileDrawing = QPen(Qt::black, m_commonSettings->WidthMainLine(), Qt::SolidLine, Qt::RoundCap,
-                               Qt::RoundJoin);
+    auto const penTileDrawing =
+        QPen(Qt::black, m_commonSettings->WidthMainLine(), Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin);
 
     painter->setPen(penTileDrawing);
 
     // paint the content of the page
     const qreal xScale = layout->LayoutSettings().HorizontalScale();
     const qreal yScale = layout->LayoutSettings().VerticalScale();
-    QRectF source = QRectF(sheetMargins.left() + col*(m_drawingAreaWidth - tileStripeWidth) / xScale,
-                           sheetMargins.top() + row*(m_drawingAreaHeight - tileStripeWidth) / yScale,
-                           m_drawingAreaWidth / xScale,
-                           m_drawingAreaHeight / yScale);
+    auto const source = QRectF(sheetMargins.left() + col * (m_drawingAreaWidth - tileStripeWidth) / xScale,
+                               sheetMargins.top() + row * (m_drawingAreaHeight - tileStripeWidth) / yScale,
+                               m_drawingAreaWidth / xScale, m_drawingAreaHeight / yScale);
 
-    QRectF target = QRectF(0,
-                           0,
-                           m_drawingAreaWidth,
-                           m_drawingAreaHeight);
+    auto const target = QRectF(0, 0, m_drawingAreaWidth, m_drawingAreaHeight);
     sheet->SceneData()->Scene()->render(painter, VPrintLayout::SceneTargetRect(printer, target), source,
                                         Qt::IgnoreAspectRatio);
 }
@@ -435,43 +495,35 @@ void VPTileFactory::DrawTilePageContent(QPainter *painter, const VPSheetPtr &she
 //---------------------------------------------------------------------------------------------------------------------
 void VPTileFactory::DrawTopTriangle(QPainter *painter) const
 {
-    QPainterPath triangleTop =
-            QTransform()
-            .translate(m_drawingAreaWidth/2, 0)
-            .map(TriangleBasic());
+    QPainterPath const triangleTop = QTransform().translate(m_drawingAreaWidth / 2, 0).map(TriangleBasic());
     painter->fillPath(triangleTop, *triangleBush);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void VPTileFactory::DrawLeftTriangle(QPainter *painter) const
 {
-    QPainterPath triangleLeft =
-            QTransform()
-            .translate(0, m_drawingAreaHeight/2)
-            .rotate(-90)
-            .map(TriangleBasic());
+    QPainterPath const triangleLeft =
+        QTransform().translate(0, m_drawingAreaHeight / 2).rotate(-90).map(TriangleBasic());
     painter->fillPath(triangleLeft, *triangleBush);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void VPTileFactory::DrawBottomTriangle(QPainter *painter) const
 {
-    QPainterPath triangleBottom =
-            QTransform()
-            .translate(m_drawingAreaWidth/2, m_drawingAreaHeight - tileStripeWidth)
-            .rotate(180)
-            .map(TriangleBasic());
+    QPainterPath const triangleBottom = QTransform()
+                                            .translate(m_drawingAreaWidth / 2, m_drawingAreaHeight - tileStripeWidth)
+                                            .rotate(180)
+                                            .map(TriangleBasic());
     painter->fillPath(triangleBottom, *triangleBush);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void VPTileFactory::DrawRightTriangle(QPainter *painter) const
 {
-    QPainterPath triangleRight =
-            QTransform()
-            .translate(m_drawingAreaWidth - tileStripeWidth, m_drawingAreaHeight/2)
-            .rotate(90)
-            .map(TriangleBasic());
+    QPainterPath const triangleRight = QTransform()
+                                           .translate(m_drawingAreaWidth - tileStripeWidth, m_drawingAreaHeight / 2)
+                                           .rotate(90)
+                                           .map(TriangleBasic());
     painter->fillPath(triangleRight, *triangleBush);
 }
 
@@ -479,8 +531,7 @@ void VPTileFactory::DrawRightTriangle(QPainter *painter) const
 void VPTileFactory::DrawTopLineScissors(QPainter *painter) const
 {
     QSvgRenderer svgRenderer(QStringLiteral("://puzzleicon/svg/icon_scissors_horizontal.svg"));
-    svgRenderer.render(painter, QRectF(m_drawingAreaWidth - tileStripeWidth, 0,
-                                       UnitConvertor(0.95, Unit::Cm, Unit::Px),
+    svgRenderer.render(painter, QRectF(m_drawingAreaWidth - tileStripeWidth, 0, UnitConvertor(0.95, Unit::Cm, Unit::Px),
                                        UnitConvertor(0.56, Unit::Cm, Unit::Px)));
 }
 
@@ -488,9 +539,9 @@ void VPTileFactory::DrawTopLineScissors(QPainter *painter) const
 void VPTileFactory::DrawLeftLineScissors(QPainter *painter) const
 {
     QSvgRenderer svgRenderer(QStringLiteral("://puzzleicon/svg/icon_scissors_vertical.svg"));
-    svgRenderer.render(painter, QRectF(0, m_drawingAreaHeight - tileStripeWidth,
-                                        UnitConvertor(0.56, Unit::Cm, Unit::Px),
-                                        UnitConvertor(0.95, Unit::Cm, Unit::Px)));
+    svgRenderer.render(painter,
+                       QRectF(0, m_drawingAreaHeight - tileStripeWidth, UnitConvertor(0.56, Unit::Cm, Unit::Px),
+                              UnitConvertor(0.95, Unit::Cm, Unit::Px)));
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -538,7 +589,7 @@ void VPTileFactory::DrawSolidTopLine(QPainter *painter, int col, int nbCol) cons
     penTileInfos.setStyle(Qt::SolidLine);
     painter->setPen(penTileInfos);
 
-    if(col < nbCol - 1)
+    if (col < nbCol - 1)
     {
         painter->drawLine(QPointF(), QPointF(m_drawingAreaWidth, 0));
     }
@@ -555,7 +606,7 @@ void VPTileFactory::DrawSolidLeftLine(QPainter *painter, int row, int nbRow) con
     penTileInfos.setStyle(Qt::SolidLine);
     painter->setPen(penTileInfos);
 
-    if(row < nbRow - 1)
+    if (row < nbRow - 1)
     {
         painter->drawLine(QPointF(), QPointF(0, m_drawingAreaHeight));
     }
@@ -572,7 +623,7 @@ void VPTileFactory::DrawSolidBottomLine(QPainter *painter, int col, int nbCol) c
     penTileInfos.setStyle(Qt::SolidLine);
     painter->setPen(penTileInfos);
 
-    if(col < nbCol - 1)
+    if (col < nbCol - 1)
     {
         painter->drawLine(QPointF(0, m_drawingAreaHeight - tileStripeWidth),
                           QPointF(m_drawingAreaWidth, m_drawingAreaHeight - tileStripeWidth));
@@ -580,7 +631,8 @@ void VPTileFactory::DrawSolidBottomLine(QPainter *painter, int col, int nbCol) c
     else
     {
         painter->drawLine(QPointF(0, m_drawingAreaHeight - tileStripeWidth),
-                          QPointF(m_drawingAreaWidth - tileStripeWidth, m_drawingAreaHeight - tileStripeWidth));;
+                          QPointF(m_drawingAreaWidth - tileStripeWidth, m_drawingAreaHeight - tileStripeWidth));
+        ;
     }
 }
 
@@ -591,7 +643,7 @@ void VPTileFactory::DrawSolidRightLine(QPainter *painter, int row, int nbRow) co
     penTileInfos.setStyle(Qt::SolidLine);
     painter->setPen(penTileInfos);
 
-    if(row < nbRow - 1)
+    if (row < nbRow - 1)
     {
         painter->drawLine(QPointF(m_drawingAreaWidth - tileStripeWidth, 0),
                           QPointF(m_drawingAreaWidth - tileStripeWidth, m_drawingAreaHeight));
@@ -612,18 +664,17 @@ void VPTileFactory::DrawTextInformation(QPainter *painter, int row, int col, int
 
     // paint the grid information
     const QString grid = tr("Grid ( %1 , %2 )").arg(row + 1).arg(col + 1);
-    const QString tileColorStr = QStringLiteral("%1,%2,%3")
-            .arg(tileColor->red()).arg(tileColor->green()).arg(tileColor->blue());
+    const QString tileColorStr =
+        QStringLiteral("%1,%2,%3").arg(tileColor->red()).arg(tileColor->green()).arg(tileColor->blue());
 
-    td.setHtml(QString("<table width='100%' style='color:rgb(%1);'>"
-                       "<tr>"
-                       "<td align='center'>%2</td>"
-                       "</tr>"
-                       "</table>")
-               .arg(tileColorStr, grid));
+    td.setHtml(u"<table width='100%' style='color:rgb(%1);'>"
+               u"<tr>"
+               u"<td align='center'>%2</td>"
+               u"</tr>"
+               u"</table>"_s.arg(tileColorStr, grid));
     painter->setPen(PenTileInfos());
     painter->save();
-    painter->translate(QPointF(UnitConvertor(1, Unit::Cm, Unit::Px), m_drawingAreaHeight - tileStripeWidth/1.3));
+    painter->translate(QPointF(UnitConvertor(1, Unit::Cm, Unit::Px), m_drawingAreaHeight - tileStripeWidth / 1.3));
     td.drawContents(painter);
     painter->restore();
 
@@ -632,19 +683,20 @@ void VPTileFactory::DrawTextInformation(QPainter *painter, int row, int col, int
 
     td.setPageSize(QSizeF(m_drawingAreaHeight - UnitConvertor(2, Unit::Cm, Unit::Px), m_drawingAreaWidth));
 
-    QFontMetrics metrix = QFontMetrics(td.defaultFont());
-    int maxWidth = TextWidth(metrix, QString().fill('z', 50));
-    QString clippedSheetName = metrix.elidedText(sheetName, Qt::ElideMiddle, maxWidth);
+    auto const metrix = QFontMetrics(td.defaultFont());
+    int const maxWidth = metrix.horizontalAdvance(QString().fill('z', 50));
+    QString const clippedSheetName = metrix.elidedText(sheetName, Qt::ElideMiddle, maxWidth);
 
     td.setHtml(QStringLiteral("<table width='100%' style='color:rgb(%1);'>"
                               "<tr>"
                               "<td align='center'>%2 - %3</td>"
                               "</tr>"
-                              "</table>").arg(tileColorStr, page, clippedSheetName));
+                              "</table>")
+                   .arg(tileColorStr, page, clippedSheetName));
     painter->save();
     painter->rotate(-90);
-    painter->translate(QPointF(-(m_drawingAreaHeight) + UnitConvertor(1, Unit::Cm, Unit::Px),
-                               m_drawingAreaWidth - tileStripeWidth));
+    painter->translate(
+        QPointF(-(m_drawingAreaHeight) + UnitConvertor(1, Unit::Cm, Unit::Px), m_drawingAreaWidth - tileStripeWidth));
     td.drawContents(painter);
     painter->restore();
 }
@@ -657,7 +709,7 @@ void VPTileFactory::PaintWatermarkText(QPainter *painter, const QRectF &img, con
 
     painter->save();
 
-    painter->setOpacity(watermarkData.opacity/100.);
+    painter->setOpacity(watermarkData.opacity / 100.);
 
     QPen pen = painter->pen();
     pen.setWidth(1);
@@ -678,7 +730,7 @@ void VPTileFactory::PaintWatermarkText(QPainter *painter, const QRectF &img, con
 
     text = t.map(text);
 
-    QPointF center = img.center() - text.boundingRect().center();
+    QPointF const center = img.center() - text.boundingRect().center();
     t = QTransform();
     t.translate(center.x(), center.y());
 
@@ -691,29 +743,38 @@ void VPTileFactory::PaintWatermarkText(QPainter *painter, const QRectF &img, con
 
 //---------------------------------------------------------------------------------------------------------------------
 void VPTileFactory::PaintWatermarkImage(QPainter *painter, const QRectF &img, const VWatermarkData &watermarkData,
-                         const QString &watermarkPath, qreal xScale, qreal yScale)
+                                        const QString &watermarkPath, bool folowColorScheme, qreal xScale, qreal yScale)
 {
     SCASSERT(painter != nullptr)
 
-    const qreal opacity = watermarkData.opacity/100.;
-    auto BrokenImage = [img, watermarkData, watermarkPath, opacity]()
+    const qreal opacity = watermarkData.opacity / 100.;
+    auto BrokenImage = [&img, &watermarkData, watermarkPath, opacity, folowColorScheme]()
     {
-        QPixmap watermark;
-        QString imagePath = QStringLiteral("puzzle=path%1+opacity%2_broken")
-                .arg(AbsoluteMPath(watermarkPath, watermarkData.path), QString::number(opacity));
+        auto colorScheme = QStringLiteral("light");
 
-        if (not QPixmapCache::find(imagePath, &watermark))
+        if (folowColorScheme)
         {
-            QScopedPointer<QSvgRenderer> svgRenderer(new QSvgRenderer());
+            colorScheme =
+                (VTheme::ColorSheme() == VColorSheme::Light ? QStringLiteral("light") : QStringLiteral("dark"));
+        }
 
-            QRect imageRect(0, 0, qRound(img.width()/4.), qRound(img.width()/4.));
+        QPixmap watermark;
+
+        if (QString const imagePath =
+                QStringLiteral("puzzle=colorScheme%1+path%2+opacity%3_broken")
+                    .arg(colorScheme, AbsoluteMPath(watermarkPath, watermarkData.path), QString::number(opacity));
+            not QPixmapCache::find(imagePath, &watermark))
+        {
+            QScopedPointer<QSvgRenderer> const svgRenderer(new QSvgRenderer());
+
+            QRect const imageRect(0, 0, qRound(img.width() / 4.), qRound(img.width() / 4.));
             watermark = QPixmap(imageRect.size());
             watermark.fill(Qt::transparent);
 
             QPainter imagePainter(&watermark);
             imagePainter.setOpacity(opacity);
 
-            svgRenderer->load(QStringLiteral("://puzzleicon/svg/no_watermark_image.svg"));
+            svgRenderer->load(QStringLiteral("://puzzleicon/svg/%1/no_watermark_image.svg").arg(colorScheme));
             svgRenderer->render(&imagePainter, imageRect);
 
             QPixmapCache::insert(imagePath, watermark);
@@ -724,17 +785,13 @@ void VPTileFactory::PaintWatermarkImage(QPainter *painter, const QRectF &img, co
         return watermark;
     };
 
-    QString imagePath = AbsoluteMPath(watermarkPath, watermarkData.path);
-    QFileInfo f(imagePath);
+    WatermarkScaledImageInfo const watermarkImageInfo =
+        GetWatermarkScaledImageInfo(watermarkData, watermarkPath, xScale, yScale);
 
-    QImageReader imageReader(imagePath);
-    QImage watermarkImage = imageReader.read();
-
-    if (watermarkImage.isNull())
+    if (watermarkImageInfo.scaledImageSize == -1)
     {
-        QPixmap watermarkPixmap = BrokenImage();
-
-        if (watermarkPixmap.width() < img.width() && watermarkPixmap.height() < img.height())
+        if (QPixmap const watermarkPixmap = BrokenImage();
+            watermarkPixmap.width() < img.width() && watermarkPixmap.height() < img.height())
         {
             QRect imagePosition(0, 0, watermarkPixmap.width(), watermarkPixmap.height());
             imagePosition.translate(img.center().toPoint() - imagePosition.center());
@@ -748,35 +805,26 @@ void VPTileFactory::PaintWatermarkImage(QPainter *painter, const QRectF &img, co
         return;
     }
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 10, 0)
-    qint64 fileSize = watermarkImage.byteCount();
-#else
-    qint64 fileSize = watermarkImage.sizeInBytes();
-#endif
-    qint64 pixelSize = fileSize / watermarkImage.height() / watermarkImage.width();
-    QSize scaledSize(qRound(watermarkImage.width() / xScale), qRound(watermarkImage.height() / yScale));
-    qint64 scaledImageSize = pixelSize*scaledSize.width()*scaledSize.height() / 1024;
-    int limit = QPixmapCache::cacheLimit();
-
-    if (scaledImageSize > limit && (xScale < 1 || yScale < 1))
+    if (int const limit = QPixmapCache::cacheLimit();
+        watermarkImageInfo.scaledImageSize > limit && (xScale < 1 || yScale < 1))
     {
-        QScopedPointer<QSvgRenderer> svgRenderer(new QSvgRenderer());
+        QScopedPointer<QSvgRenderer> const svgRenderer(new QSvgRenderer());
 
         painter->save();
         painter->setOpacity(opacity);
         painter->restore();
 
-        QString grayscale = watermarkData.grayscale ? QStringLiteral("_grayscale") : QString();
+        QString const grayscale = watermarkData.grayscale ? QStringLiteral("_grayscale") : QString();
         svgRenderer->load(QStringLiteral("://puzzleicon/svg/watermark_placeholder%1.svg").arg(grayscale));
-        QRect imageRect(0, 0, qRound(watermarkImage.width() / xScale), qRound(watermarkImage.height() / yScale));
+        QRect imageRect(0, 0, qRound(watermarkImageInfo.width / xScale), qRound(watermarkImageInfo.height / yScale));
         imageRect.translate(img.center().toPoint() - imageRect.center());
         svgRenderer->render(painter, imageRect);
         return;
     }
 
+    QFileInfo const f(AbsoluteMPath(watermarkPath, watermarkData.path));
     QPixmap watermark;
-    if (f.suffix() == QLatin1String("png") || f.suffix() == QLatin1String("jpg") ||
-            f.suffix() == QLatin1String("jpeg") || f.suffix() == QLatin1String("bmp"))
+    if (f.suffix() == "png"_L1 || f.suffix() == "jpg"_L1 || f.suffix() == "jpeg"_L1 || f.suffix() == "bmp"_L1)
     {
         QString error;
         watermark = WatermarkImageFromCache(watermarkData, watermarkPath, xScale, yScale, error);
@@ -792,7 +840,7 @@ void VPTileFactory::PaintWatermarkImage(QPainter *painter, const QRectF &img, co
     }
 
     painter->save();
-    painter->setOpacity(watermarkData.opacity/100.);
+    painter->setOpacity(watermarkData.opacity / 100.);
 
     QRect imagePosition(0, 0, watermark.width(), watermark.height());
     imagePosition.translate(img.center().toPoint() - imagePosition.center());
@@ -803,8 +851,8 @@ void VPTileFactory::PaintWatermarkImage(QPainter *painter, const QRectF &img, co
     }
     else
     {
-        QRect croppedRect = imagePosition.intersected(img.toRect());
-        QPixmap cropped = watermark.copy(croppedRect.translated(-imagePosition.x(), -imagePosition.y()));
+        QRect const croppedRect = imagePosition.intersected(img.toRect());
+        QPixmap const cropped = watermark.copy(croppedRect.translated(-imagePosition.x(), -imagePosition.y()));
 
         painter->drawPixmap(croppedRect, cropped);
     }
