@@ -29,21 +29,17 @@
 #ifndef VPTILEFACTORY_H
 #define VPTILEFACTORY_H
 
-#include <QtMath>
 #include <QObject>
+#include <QtMath>
 
-#include "layout/vplayout.h"
 #include "../ifc/ifcdef.h"
-
-#if QT_VERSION < QT_VERSION_CHECK(5, 13, 0)
-#include "../vmisc/defglobal.h"
-#endif // QT_VERSION < QT_VERSION_CHECK(5, 13, 0)
+#include "layout/layoutdef.h"
 
 class QGraphicsScene;
 class VCommonSettings;
 class QPainter;
 
-class VPTileFactory : QObject
+class VPTileFactory : public QObject
 {
     Q_OBJECT // NOLINT
 
@@ -102,13 +98,14 @@ public:
     static void PaintWatermarkText(QPainter *painter, const QRectF &img, const VWatermarkData &watermarkData,
                                    qreal xScale = 1.0, qreal yScale = 1.0);
     static void PaintWatermarkImage(QPainter *painter, const QRectF &img, const VWatermarkData &watermarkData,
-                                    const QString &watermarkPath, qreal xScale = 1.0, qreal yScale = 1.0);
+                                    const QString &watermarkPath, bool folowColorScheme, qreal xScale = 1.0,
+                                    qreal yScale = 1.0);
 
 private:
     // cppcheck-suppress unknownMacro
     Q_DISABLE_COPY_MOVE(VPTileFactory) // NOLINT
 
-    VPLayoutWeakPtr  m_layout;
+    VPLayoutWeakPtr m_layout;
     VCommonSettings *m_commonSettings{nullptr};
 
     /**
