@@ -26,21 +26,30 @@
  **
  ** *************************************************************************/
 
-#include <Qt>
-#include <QFont>
-#include <QXmlStreamAttributes>
-#include <ciso646>
 #include "vplayoutfilereader.h"
-#include "vplayoutliterals.h"
-#include "../layout/vpsheet.h"
-#include "../vlayout/vlayoutpiecepath.h"
-#include "../vlayout/vtextmanager.h"
 #include "../ifc/exception/vexception.h"
 #include "../ifc/exception/vexceptionconversionerror.h"
-#include "../vpatterndb/floatItemData/floatitemdef.h"
-#include "../vgeometry/vgeometrydef.h"
 #include "../layout/vplayout.h"
 #include "../layout/vppiece.h"
+#include "../layout/vpsheet.h"
+#include "../vgeometry/vgeometrydef.h"
+#include "../vgeometry/vlayoutplacelabel.h"
+#include "../vlayout/vlayoutpiecepath.h"
+#include "../vlayout/vtextmanager.h"
+#include "../vmisc/compatibility.h"
+#include "../vmisc/vcommonsettings.h"
+#include "../vpatterndb/floatItemData/floatitemdef.h"
+#include "../vwidgets/vpiecegrainline.h"
+#include "vplayoutliterals.h"
+#include <QFont>
+#include <QXmlStreamAttributes>
+
+// Header <ciso646> is removed in C++20.
+#if __cplusplus <= 201703L
+#include <ciso646> // and, not, or
+#endif
+
+using namespace Qt::Literals::StringLiterals;
 
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_CLANG("-Wmissing-prototypes")
@@ -56,18 +65,17 @@ namespace
 //---------------------------------------------------------------------------------------------------------------------
 auto StringToTransfrom(const QString &matrix) -> QTransform
 {
-    QStringList elements = matrix.split(ML::groupSep);
-    if (elements.count() == 9)
+    if (QStringList const elements = matrix.split(ML::groupSep); elements.count() == 9)
     {
-        qreal m11 = elements.at(0).toDouble();
-        qreal m12 = elements.at(1).toDouble();
-        qreal m13 = elements.at(2).toDouble();
-        qreal m21 = elements.at(3).toDouble();
-        qreal m22 = elements.at(4).toDouble();
-        qreal m23 = elements.at(5).toDouble();
-        qreal m31 = elements.at(6).toDouble();
-        qreal m32 = elements.at(7).toDouble();
-        qreal m33 = elements.at(8).toDouble();
+        qreal const m11 = elements.at(0).toDouble();
+        qreal const m12 = elements.at(1).toDouble();
+        qreal const m13 = elements.at(2).toDouble();
+        qreal const m21 = elements.at(3).toDouble();
+        qreal const m22 = elements.at(4).toDouble();
+        qreal const m23 = elements.at(5).toDouble();
+        qreal const m31 = elements.at(6).toDouble();
+        qreal const m32 = elements.at(7).toDouble();
+        qreal const m33 = elements.at(8).toDouble();
         return {m11, m12, m13, m21, m22, m23, m31, m32, m33};
     }
 
@@ -77,8 +85,7 @@ auto StringToTransfrom(const QString &matrix) -> QTransform
 //---------------------------------------------------------------------------------------------------------------------
 auto StringToPoint(const QString &point) -> QPointF
 {
-    QStringList coordinates = point.split(ML::coordintatesSep);
-    if (coordinates.count() == 2)
+    if (QStringList const coordinates = point.split(ML::coordintatesSep); coordinates.count() == 2)
     {
         return {coordinates.at(0).toDouble(), coordinates.at(1).toDouble()};
     }
@@ -90,9 +97,14 @@ auto StringToPoint(const QString &point) -> QPointF
 auto StringToPath(const QString &path) -> QVector<QPointF>
 {
     QVector<QPointF> p;
-    QStringList points = path.split(ML::pointsSep);
+    if (path.isEmpty())
+    {
+        return p;
+    }
+
+    QStringList const points = path.split(ML::pointsSep);
     p.reserve(points.size());
-    for (const auto& point : points)
+    for (const auto &point : points)
     {
         p.append(StringToPoint(point));
     }
@@ -103,25 +115,60 @@ auto StringToPath(const QString &path) -> QVector<QPointF>
 //---------------------------------------------------------------------------------------------------------------------
 auto StringToGrainlineArrowDirrection(const QString &dirrection) -> GrainlineArrowDirection
 {
-    const QStringList arrows
-    {
-        ML::atFrontStr, // 0
-        ML::atRearStr,  // 1
-        ML::atBothStr   // 2
+    const QStringList arrows{
+        ML::twoWaysUpDownStr,          // 0
+        ML::oneWayUpStr,               // 1
+        ML::oneWayDownStr,             // 2
+        ML::fourWaysStr,               // 3
+        ML::twoWaysUpLeftStr,          // 4
+        ML::twoWaysUpRightStr,         // 5
+        ML::twoWaysDownLeftStr,        // 6
+        ML::twoWaysDownRightStr,       // 7
+        ML::threeWaysUpDownLeftStr,    // 8
+        ML::threeWaysUpDownRightStr,   // 9
+        ML::threeWaysUpLeftRightStr,   // 10
+        ML::threeWaysDownLeftRightStr, // 11
     };
 
-    GrainlineArrowDirection arrowDirection = GrainlineArrowDirection::atBoth;
+    GrainlineArrowDirection arrowDirection = GrainlineArrowDirection::twoWaysUpDown;
     switch (arrows.indexOf(dirrection))
     {
-        case 0:// at front
-            arrowDirection = GrainlineArrowDirection::atFront;
+        case 1: // oneWayUp
+            arrowDirection = GrainlineArrowDirection::oneWayUp;
             break;
-        case 1:// at rear
-            arrowDirection = GrainlineArrowDirection::atRear;
+        case 2: // oneWayDown
+            arrowDirection = GrainlineArrowDirection::oneWayDown;
             break;
-        case 2:// at both
+        case 3: // fourWays
+            arrowDirection = GrainlineArrowDirection::fourWays;
+            break;
+        case 4: // twoWaysUpLeft
+            arrowDirection = GrainlineArrowDirection::twoWaysUpLeft;
+            break;
+        case 5: // twoWaysUpRight
+            arrowDirection = GrainlineArrowDirection::twoWaysUpRight;
+            break;
+        case 6: // twoWaysDownLeft
+            arrowDirection = GrainlineArrowDirection::twoWaysDownLeft;
+            break;
+        case 7: // twoWaysDownRight
+            arrowDirection = GrainlineArrowDirection::twoWaysDownRight;
+            break;
+        case 8: // threeWaysUpDownLeft
+            arrowDirection = GrainlineArrowDirection::threeWaysUpDownLeft;
+            break;
+        case 9: // threeWaysUpDownRight
+            arrowDirection = GrainlineArrowDirection::threeWaysUpDownRight;
+            break;
+        case 10: // threeWaysUpLeftRight
+            arrowDirection = GrainlineArrowDirection::threeWaysUpLeftRight;
+            break;
+        case 11: // threeWaysDownLeftRight
+            arrowDirection = GrainlineArrowDirection::threeWaysDownLeftRight;
+            break;
+        case 0: // twoWaysUpDown
         default:
-            arrowDirection = GrainlineArrowDirection::atBoth;
+            arrowDirection = GrainlineArrowDirection::twoWaysUpDown;
             break;
     }
     return arrowDirection;
@@ -130,8 +177,7 @@ auto StringToGrainlineArrowDirrection(const QString &dirrection) -> GrainlineArr
 //---------------------------------------------------------------------------------------------------------------------
 auto StringToLine(const QString &string) -> QLineF
 {
-    QStringList points = string.split(ML::groupSep);
-    if (points.count() == 2)
+    if (QStringList const points = string.split(ML::groupSep); points.count() == 2)
     {
         return {StringToPoint(points.at(0)), StringToPoint(points.at(1))};
     }
@@ -142,13 +188,13 @@ auto StringToLine(const QString &string) -> QLineF
 //---------------------------------------------------------------------------------------------------------------------
 auto StringToLines(const QString &string) -> QVector<QLineF>
 {
-    QStringList lines = string.split(ML::itemsSep);
+    QStringList const lines = string.split(ML::itemsSep);
     QVector<QLineF> path;
     path.reserve(lines.size());
 
-    for (const auto& line : lines)
+    for (const auto &line : lines)
     {
-        QLineF l = StringToLine(line);
+        QLineF const l = StringToLine(line);
         if (not l.isNull())
         {
             path.append(StringToLine(line));
@@ -161,29 +207,14 @@ auto StringToLines(const QString &string) -> QVector<QLineF>
 //---------------------------------------------------------------------------------------------------------------------
 auto StringToRect(const QString &string) -> QRectF
 {
-    QStringList points = string.split(ML::groupSep);
-    if (points.count() == 4)
+    if (QStringList const points = string.split(ML::groupSep); points.count() == 4)
     {
         return {points.at(0).toDouble(), points.at(1).toDouble(), points.at(2).toDouble(), points.at(3).toDouble()};
     }
 
     return {};
 }
-
-//---------------------------------------------------------------------------------------------------------------------
-auto StringToMarkerShape(const QString &string) -> PlaceLabelImg
-{
-    PlaceLabelImg shape;
-    QStringList paths = string.split(ML::itemsSep);
-    shape.reserve(paths.size());
-    for (const auto& path : paths)
-    {
-        shape.append(StringToPath(path));
-    }
-
-    return shape;
-}
-}  // namespace
+} // namespace
 
 //---------------------------------------------------------------------------------------------------------------------
 auto VPLayoutFileReader::ReadFile(const VPLayoutPtr &layout, QFile *file) -> bool
@@ -197,7 +228,7 @@ auto VPLayoutFileReader::ReadFile(const VPLayoutPtr &layout, QFile *file) -> boo
             ReadLayout(layout);
         }
     }
-    catch(const VException &e)
+    catch (const VException &e)
     {
         raiseError(e.ErrorMessage());
     }
@@ -210,8 +241,7 @@ void VPLayoutFileReader::ReadLayout(const VPLayoutPtr &layout)
 {
     AssertRootTag(ML::TagLayout);
 
-    const QStringList tags
-    {
+    const QStringList tags{
         ML::TagProperties,     // 0
         ML::TagUnplacedPieces, // 1
         ML::TagSheets          // 2
@@ -243,8 +273,7 @@ void VPLayoutFileReader::ReadProperties(const VPLayoutPtr &layout)
 {
     AssertRootTag(ML::TagProperties);
 
-    const QStringList tags
-    {
+    const QStringList tags{
         ML::TagUnit,        // 0
         ML::TagTitle,       // 1
         ML::TagDescription, // 2
@@ -260,15 +289,15 @@ void VPLayoutFileReader::ReadProperties(const VPLayoutPtr &layout)
 
         switch (tags.indexOf(name().toString()))
         {
-            case 0:// unit
+            case 0: // unit
                 qDebug("read unit");
                 layout->LayoutSettings().SetUnit(StrToUnits(readElementText()));
                 break;
-            case 1:// title
+            case 1: // title
                 qDebug("read title");
                 layout->LayoutSettings().SetTitle(readElementText());
                 break;
-            case 2:// description
+            case 2: // description
                 qDebug("read description");
                 layout->LayoutSettings().SetDescription(readElementText());
                 break;
@@ -301,13 +330,17 @@ void VPLayoutFileReader::ReadControl(const VPLayoutPtr &layout)
 {
     AssertRootTag(ML::TagControl);
 
-    QXmlStreamAttributes attribs = attributes();
+    QXmlStreamAttributes const attribs = attributes();
     layout->LayoutSettings().SetWarningSuperpositionOfPieces(
-                ReadAttributeBool(attribs, ML::AttrWarningSuperposition, trueStr));
+        ReadAttributeBool(attribs, ML::AttrWarningSuperposition, trueStr));
+    layout->LayoutSettings().SetWarningPieceGapePosition(ReadAttributeBool(attribs, ML::AttrWarningPieceGape, trueStr));
     layout->LayoutSettings().SetWarningPiecesOutOfBound(ReadAttributeBool(attribs, ML::AttrWarningOutOfBound, trueStr));
     layout->LayoutSettings().SetStickyEdges(ReadAttributeBool(attribs, ML::AttrStickyEdges, trueStr));
     layout->LayoutSettings().SetPiecesGap(qMax(ReadAttributeDouble(attribs, ML::AttrPiecesGap, QChar('0')), 0.0));
     layout->LayoutSettings().SetFollowGrainline(ReadAttributeBool(attribs, ML::AttrFollowGrainline, falseStr));
+    layout->LayoutSettings().SetBoundaryTogetherWithNotches(
+        ReadAttributeBool(attribs, ML::AttrBoundaryTogetherWithNotches, falseStr));
+    layout->LayoutSettings().SetCutOnFold(ReadAttributeBool(attribs, ML::AttrCutOnFold, falseStr));
 
     readElementText();
 }
@@ -325,14 +358,13 @@ void VPLayoutFileReader::ReadTiles(const VPLayoutPtr &layout)
 {
     AssertRootTag(ML::TagTiles);
 
-    QXmlStreamAttributes attribs = attributes();
+    QXmlStreamAttributes const attribs = attributes();
     layout->LayoutSettings().SetShowTiles(ReadAttributeBool(attribs, ML::AttrVisible, falseStr));
     layout->LayoutSettings().SetPrintTilesScheme(ReadAttributeBool(attribs, ML::AttrPrintScheme, falseStr));
     layout->LayoutSettings().SetShowTileNumber(ReadAttributeBool(attribs, ML::AttrTileNumber, falseStr));
-//    attribs.value(ML::AttrMatchingMarks); // TODO
+    //    attribs.value(ML::AttrMatchingMarks); // TODO
 
-    const QStringList tags
-    {
+    const QStringList tags{
         ML::TagSize,  // 0
         ML::TagMargin // 1
     };
@@ -362,7 +394,7 @@ void VPLayoutFileReader::ReadScale(const VPLayoutPtr &layout)
 {
     AssertRootTag(ML::TagScale);
 
-    QXmlStreamAttributes attribs = attributes();
+    QXmlStreamAttributes const attribs = attributes();
     layout->LayoutSettings().SetHorizontalScale(ReadAttributeDouble(attribs, ML::AttrXScale, QChar('1')));
     layout->LayoutSettings().SetVerticalScale(ReadAttributeDouble(attribs, ML::AttrYScale, QChar('1')));
 
@@ -393,13 +425,12 @@ void VPLayoutFileReader::ReadSheet(const VPLayoutPtr &layout)
 {
     AssertRootTag(ML::TagSheet);
 
-    VPSheetPtr sheet(new VPSheet(layout));
+    VPSheetPtr const sheet(new VPSheet(layout));
 
-    QXmlStreamAttributes attribs = attributes();
+    QXmlStreamAttributes const attribs = attributes();
     sheet->SetGrainlineType(StrToGrainlineType(ReadAttributeEmptyString(attribs, ML::AttrGrainlineType)));
 
-    const QStringList tags
-    {
+    const QStringList tags{
         ML::TagName,   // 0
         ML::TagSize,   // 1
         ML::TagMargin, // 2
@@ -434,7 +465,6 @@ void VPLayoutFileReader::ReadSheet(const VPLayoutPtr &layout)
     layout->AddSheet(sheet);
 }
 
-
 //---------------------------------------------------------------------------------------------------------------------
 void VPLayoutFileReader::ReadPieces(const VPLayoutPtr &layout, const VPSheetPtr &sheet)
 {
@@ -442,12 +472,12 @@ void VPLayoutFileReader::ReadPieces(const VPLayoutPtr &layout, const VPSheetPtr
     {
         if (name() == ML::TagPiece)
         {
-            VPPiecePtr piece(new VPPiece());
+            VPPiecePtr const piece(new VPPiece());
             ReadPiece(piece);
 
-            if (not piece->IsValid())
+            if (QString error; not piece->IsValid(error))
             {
-                throw VException(tr("Piece %1 invalid.").arg(piece->GetName()));
+                throw VException(tr("Piece %1 invalid. %2").arg(piece->GetName(), error));
             }
 
             piece->SetSheet(sheet);
@@ -466,10 +496,10 @@ void VPLayoutFileReader::ReadPiece(const VPPiecePtr &piece)
 {
     AssertRootTag(ML::TagPiece);
 
-    QXmlStreamAttributes attribs = attributes();
+    QXmlStreamAttributes const attribs = attributes();
     piece->SetName(ReadAttributeString(attribs, ML::AttrName, tr("Piece")));
 
-    QString uuidStr = ReadAttributeString(attribs, ML::AttrID, QUuid::createUuid().toString());
+    QString const uuidStr = ReadAttributeString(attribs, ML::AttrUID, QUuid::createUuid().toString());
     piece->SetUUID(QUuid(uuidStr));
 
     piece->SetGradationId(ReadAttributeEmptyString(attribs, ML::AttrGradationLabel));
@@ -478,20 +508,24 @@ void VPLayoutFileReader::ReadPiece(const VPPiecePtr &piece)
     piece->SetXScale(ReadAttributeDouble(attribs, ML::AttrXScale, QChar('1')));
     piece->SetYScale(ReadAttributeDouble(attribs, ML::AttrYScale, QChar('1')));
     piece->SetZValue(ReadAttributeDouble(attribs, ML::AttrZValue, QChar('1')));
-    piece->SetMirror(ReadAttributeBool(attribs, ML::AttrMirrored, falseStr));
+    piece->SetVerticallyFlipped(ReadAttributeBool(attribs, ML::AttrVerticallyFlipped, falseStr));
+    piece->SetHorizontallyFlipped(ReadAttributeBool(attribs, ML::AttrHorizontallyFlipped, falseStr));
     piece->SetForbidFlipping(ReadAttributeBool(attribs, ML::AttrForbidFlipping, falseStr));
     piece->SetForceFlipping(ReadAttributeBool(attribs, ML::AttrForceFlipping, falseStr));
+    piece->SetFollowGrainline(ReadAttributeBool(attribs, ML::AttrFollowGrainline, falseStr));
+    piece->SetSewLineOnDrawing(ReadAttributeBool(attribs, ML::AttrSewLineOnDrawing, falseStr));
     piece->SetMatrix(StringToTransfrom(ReadAttributeEmptyString(attribs, ML::AttrTransform)));
+    piece->SetShowFullPiece(ReadAttributeBool(attribs, ML::AttrShowFullPiece, trueStr));
 
-    const QStringList tags
-    {
+    const QStringList tags{
         ML::TagSeamLine,      // 0
         ML::TagSeamAllowance, // 1
         ML::TagGrainline,     // 2
         ML::TagNotches,       // 3
         ML::TagInternalPaths, // 4
         ML::TagMarkers,       // 5
-        ML::TagLabels         // 6
+        ML::TagLabels,        // 6
+        ML::TagMirrorLine     // 7
     };
 
     while (readNextStartElement())
@@ -499,7 +533,7 @@ void VPLayoutFileReader::ReadPiece(const VPPiecePtr &piece)
         switch (tags.indexOf(name().toString()))
         {
             case 0: // seam line
-                piece->SetCountourPoints(StringToPath(readElementText()));
+                ReadSeamLine(piece);
                 break;
             case 1: // seam allowance
                 ReadSeamAllowance(piece);
@@ -519,6 +553,9 @@ void VPLayoutFileReader::ReadPiece(const VPPiecePtr &piece)
             case 6: // labels
                 ReadLabels(piece);
                 break;
+            case 7: // mirror line
+                ReadMirrorLines(piece);
+                break;
             default:
                 qCDebug(MLReader, "Ignoring tag %s", qUtf8Printable(name().toString()));
                 skipCurrentElement();
@@ -527,28 +564,73 @@ void VPLayoutFileReader::ReadPiece(const VPPiecePtr &piece)
     }
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+auto VPLayoutFileReader::ReadLayoutPoint() -> VLayoutPoint
+{
+    AssertRootTag(ML::TagPoint);
+
+    VLayoutPoint point;
+
+    QXmlStreamAttributes const attribs = attributes();
+    point.setX(ReadAttributeDouble(attribs, ML::AttrX, QChar('0')));
+    point.setY(ReadAttributeDouble(attribs, ML::AttrY, QChar('0')));
+    point.SetTurnPoint(ReadAttributeBool(attribs, ML::AttrTurnPoint, falseStr));
+    point.SetCurvePoint(ReadAttributeBool(attribs, ML::AttrCurvePoint, falseStr));
+
+    readElementText();
+
+    return point;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VPLayoutFileReader::ReadLayoutPoints() -> QVector<VLayoutPoint>
+{
+    QVector<VLayoutPoint> points;
+
+    while (readNextStartElement())
+    {
+        if (name() == ML::TagPoint)
+        {
+            points.append(ReadLayoutPoint());
+        }
+        else
+        {
+            qCDebug(MLReader, "Ignoring tag %s", qUtf8Printable(name().toString()));
+            skipCurrentElement();
+        }
+    }
+
+    return points;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VPLayoutFileReader::ReadSeamLine(const VPPiecePtr &piece)
+{
+    AssertRootTag(ML::TagSeamLine);
+    piece->SetContourPoints(ReadLayoutPoints(), piece->IsHideMainPath());
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void VPLayoutFileReader::ReadSeamAllowance(const VPPiecePtr &piece)
 {
     AssertRootTag(ML::TagSeamAllowance);
 
-    QXmlStreamAttributes attribs = attributes();
-    bool enabled = ReadAttributeBool(attribs, ML::AttrEnabled, falseStr);
+    QXmlStreamAttributes const attribs = attributes();
+    bool const enabled = ReadAttributeBool(attribs, ML::AttrEnabled, falseStr);
     piece->SetSeamAllowance(enabled);
 
-    bool builtIn = ReadAttributeBool(attribs, ML::AttrBuiltIn, falseStr);
-    QVector<QPointF> path = StringToPath(readElementText());
+    bool const builtIn = ReadAttributeBool(attribs, ML::AttrBuiltIn, falseStr);
+    piece->SetSeamAllowanceBuiltIn(builtIn);
 
-    if (enabled)
+    QVector<VLayoutPoint> const path = ReadLayoutPoints();
+
+    if (enabled && not builtIn)
     {
-        if (not builtIn)
+        if (path.isEmpty())
         {
-            if (path.isEmpty())
-            {
-                throw VException(tr("Error in line %1. Seam allowance is empty.").arg(lineNumber()));
-            }
-            piece->SetSeamAllowancePoints(path);
+            throw VException(tr("Error in line %1. Seam allowance is empty.").arg(lineNumber()));
         }
+        piece->SetSeamAllowancePoints(path);
     }
 }
 
@@ -557,23 +639,28 @@ void VPLayoutFileReader::ReadGrainline(const VPPiecePtr &piece)
 {
     AssertRootTag(ML::TagGrainline);
 
-    QXmlStreamAttributes attribs = attributes();
-    bool enabled = ReadAttributeBool(attribs, ML::AttrEnabled, falseStr);
-    piece->SetGrainlineEnabled(enabled);
-    QVector<QPointF> path = StringToPath(readElementText());
+    VPieceGrainline grainline;
+
+    QXmlStreamAttributes const attribs = attributes();
+    bool const enabled = ReadAttributeBool(attribs, ML::AttrEnabled, falseStr);
+    grainline.SetEnabled(enabled);
+    QLineF const mainLine = StringToLine(readElementText());
 
     if (enabled)
     {
-        piece->SetGrainlineAngle(ReadAttributeDouble(attribs, ML::AttrAngle, QChar('0')));
-        QString arrowDirection = ReadAttributeEmptyString(attribs, ML::AttrArrowDirection);
-        piece->SetGrainlineArrowType(StringToGrainlineArrowDirrection(arrowDirection));
+        grainline.SetVisible(ReadAttributeBool(attribs, ML::AttrVisible, trueStr));
 
-        if (path.isEmpty())
+        QString const arrowDirection = ReadAttributeEmptyString(attribs, ML::AttrArrowDirection);
+        grainline.SetArrowType(StringToGrainlineArrowDirrection(arrowDirection));
+
+        if (mainLine.isNull())
         {
-            throw VException(tr("Error in line %1. Grainline is empty.").arg(lineNumber()));
+            throw VException(tr("Error in line %1. Grainline main line is empty.").arg(lineNumber()));
         }
-        piece->SetGrainlinePoints(path);
+        grainline.SetMainLine(mainLine);
     }
+
+    piece->SetVPGrainline(grainline);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -604,7 +691,7 @@ auto VPLayoutFileReader::ReadNotch() -> VLayoutPassmark
 {
     AssertRootTag(ML::TagNotch);
 
-    QXmlStreamAttributes attribs = attributes();
+    QXmlStreamAttributes const attribs = attributes();
 
     QT_WARNING_PUSH
     QT_WARNING_DISABLE_GCC("-Wnoexcept")
@@ -613,8 +700,9 @@ auto VPLayoutFileReader::ReadNotch() -> VLayoutPassmark
     passmark.isBuiltIn = ReadAttributeBool(attribs, ML::AttrBuiltIn, falseStr);
     passmark.baseLine = StringToLine(ReadAttributeEmptyString(attribs, ML::AttrBaseLine));
     passmark.lines = StringToLines(ReadAttributeEmptyString(attribs, ML::AttrPath));
+    passmark.isClockwiseOpening = ReadAttributeBool(attribs, ML::AttrClockwiseOpening, falseStr);
 
-    QString defaultType = QString::number(static_cast<int>(PassmarkLineType::OneLine));
+    QString const defaultType = QString::number(static_cast<int>(PassmarkLineType::OneLine));
     passmark.type = static_cast<PassmarkLineType>(ReadAttributeUInt(attribs, ML::AttrType, defaultType));
 
     QT_WARNING_POP
@@ -654,11 +742,12 @@ auto VPLayoutFileReader::ReadInternalPath() -> VLayoutPiecePath
 
     VLayoutPiecePath path;
 
-    QXmlStreamAttributes attribs = attributes();
+    QXmlStreamAttributes const attribs = attributes();
     path.SetCutPath(ReadAttributeBool(attribs, ML::AttrCut, falseStr));
     path.SetPenStyle(LineStyleToPenStyle(ReadAttributeString(attribs, ML::AttrPenStyle, TypeLineLine)));
+    path.SetNotMirrored(ReadAttributeBool(attribs, ML::AttrNotMirrored, falseStr));
 
-    QVector<QPointF> shape = StringToPath(readElementText());
+    QVector<VLayoutPoint> const shape = ReadLayoutPoints();
     if (shape.isEmpty())
     {
         throw VException(tr("Error in line %1. Internal path shape is empty.").arg(lineNumber()));
@@ -702,26 +791,21 @@ auto VPLayoutFileReader::ReadMarker() -> VLayoutPlaceLabel
 
     VLayoutPlaceLabel marker;
 
-    QXmlStreamAttributes attribs = attributes();
+    QXmlStreamAttributes const attribs = attributes();
 
-    QString matrix = ReadAttributeEmptyString(attribs, ML::AttrTransform);
-    marker.rotationMatrix = StringToTransfrom(matrix);
+    QString const matrix = ReadAttributeEmptyString(attribs, ML::AttrTransform);
+    marker.SetRotationMatrix(StringToTransfrom(matrix));
 
-    marker.type = static_cast<PlaceLabelType>(ReadAttributeUInt(attribs, ML::AttrType, QChar('0')));
-    marker.center = StringToPoint(ReadAttributeEmptyString(attribs, ML::AttrCenter));
-    marker.box = StringToRect(ReadAttributeEmptyString(attribs, ML::AttrBox));
-
-    PlaceLabelImg shape = StringToMarkerShape(readElementText());
-    if (shape.isEmpty())
-    {
-        throw VException(tr("Error in line %1. Marker shape is empty.").arg(lineNumber()));
-    }
-
-    marker.shape = shape;
+    marker.SetType(static_cast<PlaceLabelType>(ReadAttributeUInt(attribs, ML::AttrType, QChar('0'))));
+    marker.SetCenter(StringToPoint(ReadAttributeEmptyString(attribs, ML::AttrCenter)));
+    marker.SetBox(StringToRect(ReadAttributeEmptyString(attribs, ML::AttrBox)));
+    marker.SetNotMirrored(ReadAttributeBool(attribs, ML::AttrNotMirrored, falseStr));
 
     // cppcheck-suppress unknownMacro
     QT_WARNING_POP
 
+    readElementText();
+
     return marker;
 }
 
@@ -753,7 +837,7 @@ void VPLayoutFileReader::ReadPieceLabel(const VPPiecePtr &piece)
 {
     AssertRootTag(ML::TagPieceLabel);
 
-    QXmlStreamAttributes attribs = attributes();
+    QXmlStreamAttributes const attribs = attributes();
     piece->SetPieceLabelRect(StringToPath(ReadAttributeEmptyString(attribs, ML::AttrShape)));
 
     while (readNextStartElement())
@@ -775,7 +859,7 @@ void VPLayoutFileReader::ReadPatternLabel(const VPPiecePtr &piece)
 {
     AssertRootTag(ML::TagPatternLabel);
 
-    QXmlStreamAttributes attribs = attributes();
+    QXmlStreamAttributes const attribs = attributes();
     piece->SetPatternLabelRect(StringToPath(ReadAttributeEmptyString(attribs, ML::AttrShape)));
 
     while (readNextStartElement())
@@ -800,10 +884,19 @@ auto VPLayoutFileReader::ReadLabelLines() -> VTextManager
     VTextManager text;
     QVector<TextLine> lines;
 
-    QXmlStreamAttributes attribs = attributes();
-    QFont f;
-    f.fromString(ReadAttributeEmptyString(attribs, ML::AttrFont));
-    text.SetFont(f);
+    QXmlStreamAttributes const attribs = attributes();
+    text.SetFont(FontFromString(ReadAttributeEmptyString(attribs, ML::AttrFont)));
+
+    if (QStringList const svgFontData = ReadAttributeEmptyString(attribs, ML::AttrSVGFont).split(',');
+        !svgFontData.isEmpty())
+    {
+        text.SetSVGFontFamily(svgFontData.constFirst());
+
+        if (svgFontData.size() > 1)
+        {
+            text.SetSVGFontPointSize(svgFontData.at(1).toInt());
+        }
+    }
 
     while (readNextStartElement())
     {
@@ -830,12 +923,14 @@ auto VPLayoutFileReader::ReadLabelLine() -> TextLine
 
     TextLine line;
 
-    QXmlStreamAttributes attribs = attributes();
+    QXmlStreamAttributes const attribs = attributes();
 
-    line.m_iFontSize = ReadAttributeInt(attribs, ML::AttrFontSize, QString::number(MIN_FONT_SIZE));
+    line.m_iFontSize =
+        ReadAttributeInt(attribs, ML::AttrFontSize, QString::number(VCommonSettings::MinPieceLabelFontPointSize()));
     line.m_bold = ReadAttributeBool(attribs, ML::AttrBold, falseStr);
     line.m_italic = ReadAttributeBool(attribs, ML::AttrItalic, falseStr);
-    int alignment = ReadAttributeInt(attribs, ML::AttrAlignment, QString::number(static_cast<int>(Qt::AlignCenter)));
+    int const alignment =
+        ReadAttributeInt(attribs, ML::AttrAlignment, QString::number(static_cast<int>(Qt::AlignCenter)));
     line.m_eAlign = static_cast<Qt::Alignment>(alignment);
     line.m_qsText = readElementText();
 
@@ -847,17 +942,66 @@ void VPLayoutFileReader::ReadWatermark(const VPLayoutPtr &layout)
 {
     AssertRootTag(ML::TagWatermark);
 
-    QXmlStreamAttributes attribs = attributes();
+    QXmlStreamAttributes const attribs = attributes();
     layout->LayoutSettings().SetShowWatermark(ReadAttributeBool(attribs, ML::AttrShowPreview, falseStr));
     layout->LayoutSettings().SetWatermarkPath(readElementText());
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void VPLayoutFileReader::ReadMirrorLines(const VPPiecePtr &piece)
+{
+    AssertRootTag(ML::TagMirrorLine);
+
+    QXmlStreamAttributes const attribs = attributes();
+
+    piece->SetFoldLineType(StringToFoldLineType(
+        ReadAttributeString(attribs, ML::AttrFoldLineType, FoldLineTypeToString(FoldLineType::TwoArrowsTextAbove))));
+    piece->SetFoldLineHeight(ReadAttributeDouble(attribs, ML::AttrFoldLineHeight, QChar('0')));
+    piece->SetFoldLineWidth(ReadAttributeDouble(attribs, ML::AttrFoldLineWidth, QChar('0')));
+    piece->SetFoldLineCenterPosition(ReadAttributeDouble(attribs, ML::AttrFoldLineCenter, QString::number(0.5)));
+    piece->SetFoldLineLabelFontBold(ReadAttributeBool(attribs, ML::AttrBold, falseStr));
+    piece->SetFoldLineLabelFontItalic(ReadAttributeBool(attribs, ML::AttrItalic, falseStr));
+    piece->SetFoldLineLabelAlignment(
+        ReadAttributeInt(attribs, ML::AttrAlignment, QString::number(static_cast<int>(Qt::AlignHCenter))));
+    piece->SetFoldLineLabel(ReadAttributeEmptyString(attribs, ML::AttrFoldLineLabel));
+    piece->SetFoldLineOutlineFont(FontFromString(ReadAttributeEmptyString(attribs, ML::AttrFont)));
+    piece->SetShowMirrorLine(ReadAttributeBool(attribs, ML::AttrVisible, trueStr));
+
+    if (QStringList const svgFontData = ReadAttributeEmptyString(attribs, ML::AttrSVGFont).split(','_L1);
+        !svgFontData.isEmpty())
+    {
+        piece->SetFoldLineSVGFontFamily(svgFontData.constFirst());
+
+        if (svgFontData.size() > 1)
+        {
+            piece->SetFoldLineSvgFontSize(svgFontData.at(1).toUInt());
+        }
+    }
+
+    while (readNextStartElement())
+    {
+        if (name() == ML::TagSeamLine)
+        {
+            piece->SetSeamMirrorLine(StringToLine(readElementText()));
+        }
+        else if (name() == ML::TagSeamAllowance)
+        {
+            piece->SetSeamAllowanceMirrorLine(StringToLine(readElementText()));
+        }
+        else
+        {
+            qCDebug(MLReader, "Ignoring tag %s", qUtf8Printable(name().toString()));
+            skipCurrentElement();
+        }
+    }
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void VPLayoutFileReader::ReadLayoutMargins(const VPLayoutPtr &layout)
 {
-    QXmlStreamAttributes attribs = attributes();
+    QXmlStreamAttributes const attribs = attributes();
 
-    QMarginsF margins = QMarginsF();
+    QMarginsF margins;
     margins.setLeft(ReadAttributeDouble(attribs, ML::AttrLeft, QChar('0')));
     margins.setTop(ReadAttributeDouble(attribs, ML::AttrTop, QChar('0')));
     margins.setRight(ReadAttributeDouble(attribs, ML::AttrRight, QChar('0')));
@@ -872,9 +1016,9 @@ void VPLayoutFileReader::ReadLayoutMargins(const VPLayoutPtr &layout)
 //---------------------------------------------------------------------------------------------------------------------
 void VPLayoutFileReader::ReadSheetMargins(const VPSheetPtr &sheet)
 {
-    QXmlStreamAttributes attribs = attributes();
+    QXmlStreamAttributes const attribs = attributes();
 
-    QMarginsF margins = QMarginsF();
+    QMarginsF margins;
     margins.setLeft(ReadAttributeDouble(attribs, ML::AttrLeft, QChar('0')));
     margins.setTop(ReadAttributeDouble(attribs, ML::AttrTop, QChar('0')));
     margins.setRight(ReadAttributeDouble(attribs, ML::AttrRight, QChar('0')));
@@ -891,7 +1035,7 @@ auto VPLayoutFileReader::ReadSize() -> QSizeF
 {
     QSizeF size;
 
-    QXmlStreamAttributes attribs = attributes();
+    QXmlStreamAttributes const attribs = attributes();
     size.setWidth(ReadAttributeDouble(attribs, ML::AttrWidth, QChar('0')));
     size.setHeight(ReadAttributeDouble(attribs, ML::AttrLength, QChar('0')));
 
@@ -903,7 +1047,7 @@ auto VPLayoutFileReader::ReadSize() -> QSizeF
 //---------------------------------------------------------------------------------------------------------------------
 void VPLayoutFileReader::AssertRootTag(const QString &tag) const
 {
-    if (not (isStartElement() && name() == tag))
+    if (not(isStartElement() && name() == tag))
     {
         throw VException(tr("Unexpected tag %1 in line %2").arg(name().toString()).arg(lineNumber()));
     }
@@ -911,9 +1055,9 @@ void VPLayoutFileReader::AssertRootTag(const QString &tag) const
 
 //---------------------------------------------------------------------------------------------------------------------
 auto VPLayoutFileReader::ReadAttributeString(const QXmlStreamAttributes &attribs, const QString &name,
-                                                const QString &defValue) -> QString
+                                             const QString &defValue) -> QString
 {
-    const QString parameter = attribs.value(name).toString();
+    QString parameter = attribs.value(name).toString();
     if (parameter.isEmpty())
     {
         if (defValue.isEmpty())
@@ -943,7 +1087,7 @@ auto VPLayoutFileReader::ReadAttributeBool(const QXmlStreamAttributes &attribs,
     {
         parametr = ReadAttributeString(attribs, name, defValue);
 
-        const QStringList bools {trueStr, falseStr, QChar('1'), QChar('0')};
+        const QStringList bools{trueStr, falseStr, QChar('1'), QChar('0')};
         switch (bools.indexOf(parametr))
         {
             case 0: // true
@@ -954,7 +1098,7 @@ auto VPLayoutFileReader::ReadAttributeBool(const QXmlStreamAttributes &attribs,
             case 3: // 0
                 val = false;
                 break;
-            default:// others
+            default: // others
                 throw VExceptionConversionError(message, name);
         }
     }
@@ -979,7 +1123,7 @@ auto VPLayoutFileReader::ReadAttributeDouble(const QXmlStreamAttributes &attribs
     try
     {
         QString parametr = ReadAttributeString(attribs, name, defValue);
-        param = parametr.replace(QChar(','), QChar('.')).toDouble(&ok);
+        param = parametr.replace(','_L1, '.'_L1).toDouble(&ok);
         if (not ok)
         {
             throw VExceptionConversionError(message, name);
@@ -1005,7 +1149,7 @@ auto VPLayoutFileReader::ReadAttributeUInt(const QXmlStreamAttributes &attribs,
     try
     {
         QString parametr = ReadAttributeString(attribs, name, defValue);
-        param = parametr.replace(QChar(','), QChar('.')).toUInt(&ok);
+        param = parametr.replace(','_L1, '.'_L1).toUInt(&ok);
         if (not ok)
         {
             throw VExceptionConversionError(message, name);
@@ -1031,7 +1175,7 @@ auto VPLayoutFileReader::ReadAttributeInt(const QXmlStreamAttributes &attribs, c
     try
     {
         QString parametr = ReadAttributeString(attribs, name, defValue);
-        param = parametr.replace(QChar(','), QChar('.')).toInt(&ok);
+        param = parametr.replace(','_L1, '.'_L1).toInt(&ok);
         if (not ok)
         {
             throw VExceptionConversionError(message, name);
