@@ -29,10 +29,9 @@
 #ifndef VPLAYOUTFILEREADER_H
 #define VPLAYOUTFILEREADER_H
 
-#include <QXmlStreamReader>
 #include "../ifc/xml/vabstractconverter.h"
 #include "../layout/layoutdef.h"
-#include "../vmisc/defglobal.h"
+#include <QXmlStreamReader>
 
 #include <QLoggingCategory>
 
@@ -40,16 +39,18 @@ Q_DECLARE_LOGGING_CATEGORY(MLReader) // NOLINT
 
 struct TextLine;
 struct VLayoutPassmark;
-struct VLayoutPlaceLabel;
+class VLayoutPlaceLabel;
 class VLayoutPiecePath;
 class VTextManager;
+class VLayoutPoint;
 
 class VPLayoutFileReader : public QXmlStreamReader
 {
     Q_DECLARE_TR_FUNCTIONS(VPLayoutFileReader) // NOLINT
+
 public:
-    VPLayoutFileReader()=default;
-    ~VPLayoutFileReader()=default;
+    VPLayoutFileReader() = default;
+    ~VPLayoutFileReader() = default;
 
     auto ReadFile(const VPLayoutPtr &layout, QFile *file) -> bool;
 
@@ -65,8 +66,11 @@ private:
     void ReadUnplacedPieces(const VPLayoutPtr &layout);
     void ReadSheets(const VPLayoutPtr &layout);
     void ReadSheet(const VPLayoutPtr &layout);
-    void ReadPieces(const VPLayoutPtr &layout, const VPSheetPtr &sheet=VPSheetPtr());
+    void ReadPieces(const VPLayoutPtr &layout, const VPSheetPtr &sheet = VPSheetPtr());
     void ReadPiece(const VPPiecePtr &piece);
+    auto ReadLayoutPoint() -> VLayoutPoint;
+    auto ReadLayoutPoints() -> QVector<VLayoutPoint>;
+    void ReadSeamLine(const VPPiecePtr &piece);
     void ReadSeamAllowance(const VPPiecePtr &piece);
     void ReadGrainline(const VPPiecePtr &piece);
     void ReadNotches(const VPPiecePtr &piece);
@@ -81,6 +85,7 @@ private:
     auto ReadLabelLines() -> VTextManager;
     auto ReadLabelLine() -> TextLine;
     void ReadWatermark(const VPLayoutPtr &layout);
+    void ReadMirrorLines(const VPPiecePtr &piece);
 
     void ReadLayoutMargins(const VPLayoutPtr &layout);
     void ReadSheetMargins(const VPSheetPtr &sheet);
@@ -88,17 +93,17 @@ private:
 
     void AssertRootTag(const QString &tag) const;
 
-    static auto ReadAttributeString(const QXmlStreamAttributes &attribs, const QString &name,
-                                    const QString &defValue) -> QString;
+    static auto ReadAttributeString(const QXmlStreamAttributes &attribs, const QString &name, const QString &defValue)
+        -> QString;
     static auto ReadAttributeEmptyString(const QXmlStreamAttributes &attribs, const QString &name) -> QString;
-    static auto ReadAttributeBool(const QXmlStreamAttributes &attribs, const QString &name,
-                                  const QString &defValue) -> bool;
-    static auto ReadAttributeDouble(const QXmlStreamAttributes &attribs, const QString &name,
-                                    const QString &defValue) -> qreal;
-    static auto ReadAttributeUInt(const QXmlStreamAttributes &attribs, const QString &name,
-                                  const QString &defValue) -> quint32;
-    static auto ReadAttributeInt(const QXmlStreamAttributes &attribs, const QString &name,
-                                 const QString &defValue) -> int;
+    static auto ReadAttributeBool(const QXmlStreamAttributes &attribs, const QString &name, const QString &defValue)
+        -> bool;
+    static auto ReadAttributeDouble(const QXmlStreamAttributes &attribs, const QString &name, const QString &defValue)
+        -> qreal;
+    static auto ReadAttributeUInt(const QXmlStreamAttributes &attribs, const QString &name, const QString &defValue)
+        -> quint32;
+    static auto ReadAttributeInt(const QXmlStreamAttributes &attribs, const QString &name, const QString &defValue)
+        -> int;
 };
 
 #endif // VPLAYOUTFILEREADER_H
