@@ -27,10 +27,10 @@
  *************************************************************************/
 
 #include "dialogabouttape.h"
-#include "ui_dialogabouttape.h"
+#include "../fervor/fvupdater.h"
 #include "../vmisc/def.h"
 #include "../vmisc/projectversion.h"
-#include "../fervor/fvupdater.h"
+#include "ui_dialogabouttape.h"
 
 #include <QDate>
 #include <QDesktopServices>
@@ -39,32 +39,39 @@
 #include <QUrl>
 #include <QtDebug>
 
+#if !defined(BUILD_REVISION) && defined(QBS_BUILD)
+#include <vcsRepoState.h>
+#define BUILD_REVISION VCS_REPO_STATE_REVISION
+#endif
+
 //---------------------------------------------------------------------------------------------------------------------
 DialogAboutTape::DialogAboutTape(QWidget *parent)
-    :QDialog(parent),
-      ui(new Ui::DialogAboutTape),
-      m_isInitialized(false)
+  : QDialog(parent),
+    ui(std::make_unique<Ui::DialogAboutTape>()),
+    m_isInitialized(false)
 {
     ui->setupUi(this);
 
-    //mApp->Settings()->GetOsSeparator() ? setLocale(QLocale()) : setLocale(QLocale::c());
+    // mApp->Settings()->GetOsSeparator() ? setLocale(QLocale()) : setLocale(QLocale::c());
 
     RetranslateUi();
-    connect(ui->pushButton_Web_Site, &QPushButton::clicked, this, []()
-    {
-        if (not QDesktopServices::openUrl(
+    connect(ui->pushButton_Web_Site, &QPushButton::clicked, this,
+            []()
+            {
+                if (not QDesktopServices::openUrl(
                         QUrl(QStringLiteral("https://%1").arg(QStringLiteral(VER_COMPANYDOMAIN_STR)))))
-        {
-            qWarning() << tr("Cannot open your default browser");
-        }
-    });
+                {
+                    qWarning() << tr("Cannot open your default browser");
+                }
+            });
     connect(ui->buttonBox, &QDialogButtonBox::accepted, this, &DialogAboutTape::close);
-    connect(ui->pushButtonCheckUpdate, &QPushButton::clicked, []()
-    {
-        // Set feed URL before doing anything else
-        FvUpdater::sharedUpdater()->SetFeedURL(FvUpdater::CurrentFeedURL());
-        FvUpdater::sharedUpdater()->CheckForUpdatesNotSilent();
-    });
+    connect(ui->pushButtonCheckUpdate, &QPushButton::clicked,
+            []()
+            {
+                // Set feed URL before doing anything else
+                FvUpdater::sharedUpdater()->SetFeedURL(FvUpdater::CurrentFeedURL());
+                FvUpdater::sharedUpdater()->CheckForUpdatesNotSilent();
+            });
 
     // By default on Windows font point size 8 points we need 11 like on Linux.
     FontPointSize(ui->label_Legal_Stuff, 11);
@@ -73,10 +80,7 @@ DialogAboutTape::DialogAboutTape(QWidget *parent)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-DialogAboutTape::~DialogAboutTape()
-{
-    delete ui;
-}
+DialogAboutTape::~DialogAboutTape() = default;
 
 //---------------------------------------------------------------------------------------------------------------------
 void DialogAboutTape::changeEvent(QEvent *event)
@@ -95,8 +99,8 @@ void DialogAboutTape::changeEvent(QEvent *event)
 //---------------------------------------------------------------------------------------------------------------------
 void DialogAboutTape::showEvent(QShowEvent *event)
 {
-    QDialog::showEvent( event );
-    if ( event->spontaneous() )
+    QDialog::showEvent(event);
+    if (event->spontaneous())
     {
         return;
     }
@@ -110,7 +114,7 @@ void DialogAboutTape::showEvent(QShowEvent *event)
     setMaximumSize(size());
     setMinimumSize(size());
 
-    m_isInitialized = true;//first show windows are held
+    m_isInitialized = true; // first show windows are held
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -119,14 +123,14 @@ void DialogAboutTape::FontPointSize(QWidget *w, int pointSize)
     SCASSERT(w != nullptr)
 
     QFont font = w->font();
-    font.setPointSize(pointSize);
+    font.setPointSize(qMax(pointSize, 1));
     w->setFont(font);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void DialogAboutTape::RetranslateUi()
 {
-    ui->label_Tape_Version->setText(QStringLiteral("Tape %1").arg(APP_VERSION_STR));
+    ui->label_Tape_Version->setText(QStringLiteral("Tape %1").arg(AppVersionStr()));
     ui->labelBuildRevision->setText(tr("Build revision: %1").arg(QStringLiteral(BUILD_REVISION)));
     ui->label_QT_Version->setText(buildCompatibilityString());
 
