@@ -26,21 +26,30 @@
  **
  *************************************************************************/
 #include "dialogmeasurementscsvcolumns.h"
+#include "../vmisc/qxtcsvmodel.h"
+#include "../vtools/dialogs/dialogtoolbox.h"
 #include "ui_dialogmeasurementscsvcolumns.h"
 
-#include "../vmisc/qxtcsvmodel.h"
-#if QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
-#include "../vmisc/backport/qoverload.h"
-#endif // QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
-#include "../vtools/dialogs/dialogtoolbox.h"
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#include "../vmisc/vtextcodec.h"
+#else
+#include <QTextCodec>
+using VTextCodec = QTextCodec;
+#endif
 
 #include <QPushButton>
 #include <QShowEvent>
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
+#include "../vmisc/compatibility.h"
+#endif
+
+using namespace Qt::Literals::StringLiterals;
+
 //---------------------------------------------------------------------------------------------------------------------
 DialogMeasurementsCSVColumns::DialogMeasurementsCSVColumns(const QString &filename, MeasurementsType type,
-                                                           QWidget *parent) :
-    QDialog(parent),
+                                                           QWidget *parent)
+  : QDialog(parent),
     ui(new Ui::DialogMeasurementsCSVColumns),
     m_fileName{filename},
     m_type(type)
@@ -53,8 +62,8 @@ DialogMeasurementsCSVColumns::DialogMeasurementsCSVColumns(const QString &filena
 //---------------------------------------------------------------------------------------------------------------------
 DialogMeasurementsCSVColumns::DialogMeasurementsCSVColumns(const QString &filename, MeasurementsType type,
                                                            const QList<MeasurementDimension_p> &dimensions,
-                                                           QWidget *parent) :
-    QDialog(parent),
+                                                           QWidget *parent)
+  : QDialog(parent),
     ui(new Ui::DialogMeasurementsCSVColumns),
     m_fileName{filename},
     m_type(type),
@@ -94,8 +103,8 @@ void DialogMeasurementsCSVColumns::changeEvent(QEvent *event)
 //---------------------------------------------------------------------------------------------------------------------
 void DialogMeasurementsCSVColumns::showEvent(QShowEvent *event)
 {
-    QDialog::showEvent( event );
-    if ( event->spontaneous() )
+    QDialog::showEvent(event);
+    if (event->spontaneous())
     {
         return;
     }
@@ -116,48 +125,47 @@ void DialogMeasurementsCSVColumns::showEvent(QShowEvent *event)
         InitImportHeaders();
         ShowImportPreview();
 
-        connect(ui->comboBoxName, QOverload<int>::of(&QComboBox::currentIndexChanged),
-                this, &DialogMeasurementsCSVColumns::ColumnChanged);
-        connect(ui->comboBoxValue, QOverload<int>::of(&QComboBox::currentIndexChanged),
-                this, &DialogMeasurementsCSVColumns::ColumnChanged);
+        connect(ui->comboBoxName, QOverload<int>::of(&QComboBox::currentIndexChanged), this,
+                &DialogMeasurementsCSVColumns::ColumnChanged);
+        connect(ui->comboBoxValue, QOverload<int>::of(&QComboBox::currentIndexChanged), this,
+                &DialogMeasurementsCSVColumns::ColumnChanged);
 
         if (m_type == MeasurementsType::Multisize)
         {
             if (not m_dimensions.empty())
             {
-                connect(ui->comboBoxShiftA, QOverload<int>::of(&QComboBox::currentIndexChanged),
-                        this, &DialogMeasurementsCSVColumns::ColumnChanged);
+                connect(ui->comboBoxShiftA, QOverload<int>::of(&QComboBox::currentIndexChanged), this,
+                        &DialogMeasurementsCSVColumns::ColumnChanged);
             }
 
             if (m_dimensions.size() > 1)
             {
-                connect(ui->comboBoxShiftB, QOverload<int>::of(&QComboBox::currentIndexChanged),
-                        this, &DialogMeasurementsCSVColumns::ColumnChanged);
+                connect(ui->comboBoxShiftB, QOverload<int>::of(&QComboBox::currentIndexChanged), this,
+                        &DialogMeasurementsCSVColumns::ColumnChanged);
             }
 
             if (m_dimensions.size() > 2)
             {
-                connect(ui->comboBoxShiftC, QOverload<int>::of(&QComboBox::currentIndexChanged),
-                        this, &DialogMeasurementsCSVColumns::ColumnChanged);
+                connect(ui->comboBoxShiftC, QOverload<int>::of(&QComboBox::currentIndexChanged), this,
+                        &DialogMeasurementsCSVColumns::ColumnChanged);
             }
         }
 
-
-        connect(ui->comboBoxFullName, QOverload<int>::of(&QComboBox::currentIndexChanged),
-                this, &DialogMeasurementsCSVColumns::ColumnChanged);
-        connect(ui->comboBoxDescription, QOverload<int>::of(&QComboBox::currentIndexChanged),
-                this, &DialogMeasurementsCSVColumns::ColumnChanged);
+        connect(ui->comboBoxFullName, QOverload<int>::of(&QComboBox::currentIndexChanged), this,
+                &DialogMeasurementsCSVColumns::ColumnChanged);
+        connect(ui->comboBoxDescription, QOverload<int>::of(&QComboBox::currentIndexChanged), this,
+                &DialogMeasurementsCSVColumns::ColumnChanged);
 
         CheckStatus();
     }
 
-    m_isInitialized = true;//first show windows are held
+    m_isInitialized = true; // first show windows are held
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void DialogMeasurementsCSVColumns::ColumnChanged()
 {
-    auto *control = qobject_cast<QComboBox*>(sender());
+    auto *control = qobject_cast<QComboBox *>(sender());
 
     if (control == ui->comboBoxName)
     {
@@ -217,7 +225,7 @@ auto DialogMeasurementsCSVColumns::ColumnMandatory(int column) const -> bool
 
     if (m_dimensions.size() > 1)
     {
-        mandatory += qMin(m_dimensions.size(), 2);
+        mandatory += qMin(static_cast<int>(m_dimensions.size()), 2);
     }
 
     return static_cast<int>(column) < mandatory;
@@ -229,34 +237,36 @@ auto DialogMeasurementsCSVColumns::ColumnHeader(int column) const -> QString
     if (m_type == MeasurementsType::Individual)
     {
         const auto individualColumn = static_cast<IndividualMeasurementsColumns>(column);
-        switch(individualColumn)
+        switch (individualColumn)
         {
             case IndividualMeasurementsColumns::Name:
-                return tr("Name", "measurement column");
+                return QCoreApplication::translate("DialogMeasurementsCSVColumns", "Name", "measurement column");
             case IndividualMeasurementsColumns::Value:
-                return tr("Value", "measurement column");
+                return QCoreApplication::translate("DialogMeasurementsCSVColumns", "Value", "measurement column");
             case IndividualMeasurementsColumns::FullName:
-                return tr("Full name", "measurement column");
+                return QCoreApplication::translate("DialogMeasurementsCSVColumns", "Full name", "measurement column");
             case IndividualMeasurementsColumns::Description:
-                return tr("Description", "measurement column");
+                return QCoreApplication::translate("DialogMeasurementsCSVColumns", "Description", "measurement column");
             default:
                 return {};
         }
     }
     else
     {
+        const auto suffix = QStringLiteral(" (%1):");
         const auto multisizeColumn = static_cast<MultisizeMeasurementsColumns>(column);
-        switch(multisizeColumn)
+        switch (multisizeColumn)
         {
             case MultisizeMeasurementsColumns::Name:
-                return tr("Name", "measurement column");
+                return QCoreApplication::translate("DialogMeasurementsCSVColumns", "Name", "measurement column");
             case MultisizeMeasurementsColumns::BaseValue:
-                return tr("Base value", "measurement column");
+                return QCoreApplication::translate("DialogMeasurementsCSVColumns", "Base value", "measurement column");
             case MultisizeMeasurementsColumns::ShiftA:
                 if (not m_dimensions.empty())
                 {
-                    MeasurementDimension_p dimension = m_dimensions.at(0);
-                    return tr("Shift (%1):", "measurement column").arg(dimension->Name());
+                    MeasurementDimension_p const dimension = m_dimensions.at(0);
+                    return QCoreApplication::translate("DialogMeasurementsCSVColumns", "Shift", "measurement column") +
+                           suffix.arg(dimension->Name());
                 }
                 else
                 {
@@ -265,8 +275,9 @@ auto DialogMeasurementsCSVColumns::ColumnHeader(int column) const -> QString
             case MultisizeMeasurementsColumns::ShiftB:
                 if (m_dimensions.size() > 1)
                 {
-                    MeasurementDimension_p dimension = m_dimensions.at(1);
-                    return tr("Shift (%1):", "measurement column").arg(dimension->Name());
+                    MeasurementDimension_p const dimension = m_dimensions.at(1);
+                    return QCoreApplication::translate("DialogMeasurementsCSVColumns", "Shift", "measurement column") +
+                           suffix.arg(dimension->Name());
                 }
                 else
                 {
@@ -275,19 +286,20 @@ auto DialogMeasurementsCSVColumns::ColumnHeader(int column) const -> QString
             case MultisizeMeasurementsColumns::ShiftC:
                 if (m_dimensions.size() > 2)
                 {
-                    MeasurementDimension_p dimension = m_dimensions.at(2);
-                    return tr("Shift (%1):", "measurement column").arg(dimension->Name());
+                    MeasurementDimension_p const dimension = m_dimensions.at(2);
+                    return QCoreApplication::translate("DialogMeasurementsCSVColumns", "Shift", "measurement column") +
+                           suffix.arg(dimension->Name());
                 }
                 else
                 {
                     return QStringLiteral("Shift C");
                 }
             case MultisizeMeasurementsColumns::FullName:
-                return tr("Full name", "measurement column");
+                return QCoreApplication::translate("DialogMeasurementsCSVColumns", "Full name", "measurement column");
             case MultisizeMeasurementsColumns::Description:
-                return tr("Description", "measurement column");
+                return QCoreApplication::translate("DialogMeasurementsCSVColumns", "Description", "measurement column");
             default:
-            return {};
+                return {};
         }
     }
 }
@@ -315,7 +327,7 @@ auto DialogMeasurementsCSVColumns::MinimumColumns() const -> int
 
     if (m_dimensions.size() > 1)
     {
-        mandatory += qMin(m_dimensions.size(), 2);
+        mandatory += qMin(static_cast<int>(m_dimensions.size()), 2);
     }
 
     return mandatory;
@@ -336,9 +348,9 @@ auto DialogMeasurementsCSVColumns::ColumnsValid() -> bool
 
     const QColor errorColor = Qt::red;
 
-    auto ChangeColumnColor = [this, errorColor]
-        (QLabel *label, bool &columnFlag, MultisizeMeasurementsColumns multisizeColumn,
-         IndividualMeasurementsColumns individualColumn)
+    auto ChangeColumnColor = [this, errorColor](QLabel *label, bool &columnFlag,
+                                                MultisizeMeasurementsColumns multisizeColumn,
+                                                IndividualMeasurementsColumns individualColumn)
     {
         if (m_type == MeasurementsType::Multisize ? not ColumnValid(multisizeColumn)
                                                   : not ColumnValid(individualColumn))
@@ -355,31 +367,22 @@ auto DialogMeasurementsCSVColumns::ColumnsValid() -> bool
 
     if (m_type == MeasurementsType::Multisize)
     {
-        if (not m_dimensions.empty())
+        if (not m_dimensions.empty() && not ColumnValid(MultisizeMeasurementsColumns::ShiftA))
         {
-            if (not ColumnValid(MultisizeMeasurementsColumns::ShiftA))
-            {
-                ChangeColor(ui->labelShiftA, errorColor);
-                columnShiftAFlag = false;
-            }
+            ChangeColor(ui->labelShiftA, errorColor);
+            columnShiftAFlag = false;
         }
 
-        if (m_dimensions.size() > 1)
+        if (m_dimensions.size() > 1 && not ColumnValid(MultisizeMeasurementsColumns::ShiftB))
         {
-            if (not ColumnValid(MultisizeMeasurementsColumns::ShiftB))
-            {
-                ChangeColor(ui->labelShiftB, errorColor);
-                columnShiftBFlag = false;
-            }
+            ChangeColor(ui->labelShiftB, errorColor);
+            columnShiftBFlag = false;
         }
 
-        if (m_dimensions.size() > 2)
+        if (m_dimensions.size() > 2 && not ColumnValid(MultisizeMeasurementsColumns::ShiftC))
         {
-            if (not ColumnValid(MultisizeMeasurementsColumns::ShiftC))
-            {
-                ChangeColor(ui->labelShiftC, errorColor);
-                columnShiftCFlag = false;
-            }
+            ChangeColor(ui->labelShiftC, errorColor);
+            columnShiftCFlag = false;
         }
     }
 
@@ -421,10 +424,10 @@ void DialogMeasurementsCSVColumns::ClearColumnCollor()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogMeasurementsCSVColumns::InitColumnsMap()
 {
-    QSharedPointer<QxtCsvModel> csv = DialogMeasurementsCSVColumns::CSVModel();
+    QSharedPointer<QxtCsvModel> const csv = DialogMeasurementsCSVColumns::CSVModel();
     m_columnsMap.clear();
 
-    auto InitColumn = [this, csv](int column, int &index, bool forceSkip=false)
+    auto InitColumn = [this, csv](int column, int &index, bool forceSkip = false)
     {
         if (forceSkip)
         {
@@ -449,7 +452,7 @@ void DialogMeasurementsCSVColumns::InitColumnsMap()
         m_columnsMap.resize(static_cast<int>(IndividualMeasurementsColumns::LAST_DO_NOT_USE));
         int index = -1;
 
-        for(int column = 0; column < static_cast<int>(IndividualMeasurementsColumns::LAST_DO_NOT_USE); ++column)
+        for (int column = 0; column < static_cast<int>(IndividualMeasurementsColumns::LAST_DO_NOT_USE); ++column)
         {
             InitColumn(column, index);
         }
@@ -488,14 +491,14 @@ void DialogMeasurementsCSVColumns::InitColumnsControls()
         control->blockSignals(true);
         control->clear();
 
-        for(int i=0; i < inputColumnCount; ++i)
+        for (int i = 0; i < inputColumnCount; ++i)
         {
-            control->addItem(QString::number(i+1), i);
+            control->addItem(QString::number(i + 1), i);
         }
 
         if (not ColumnMandatory(column))
         {
-            control->addItem(tr("Skip"), -1);
+            control->addItem(QCoreApplication::translate("DialogMeasurementsCSVColumns", "Skip"), -1);
         }
 
         control->setCurrentIndex(-1);
@@ -566,7 +569,7 @@ void DialogMeasurementsCSVColumns::InitImportHeaders()
     ui->tableWidgetImport->clear();
     ui->tableWidgetImport->setColumnCount(columns);
 
-    auto AddHeader = [this](int column, bool visible=true)
+    auto AddHeader = [this](int column, bool visible = true)
     {
         auto *header = new QTableWidgetItem(ColumnHeader(column));
         ui->tableWidgetImport->setHorizontalHeaderItem(column, header);
@@ -606,7 +609,7 @@ void DialogMeasurementsCSVColumns::ShowInputPreview()
         return;
     }
 
-    QSharedPointer<QxtCsvModel> csv = DialogMeasurementsCSVColumns::CSVModel();
+    QSharedPointer<QxtCsvModel> const csv = DialogMeasurementsCSVColumns::CSVModel();
 
     const int columns = csv->columnCount();
     const int rows = csv->rowCount();
@@ -618,17 +621,17 @@ void DialogMeasurementsCSVColumns::ShowInputPreview()
     ui->tableWidgetInput->horizontalHeader()->setVisible(m_withHeader);
     if (m_withHeader)
     {
-        for(int column=0; column<columns; ++column)
+        for (int column = 0; column < columns; ++column)
         {
             auto *header = new QTableWidgetItem(csv->headerText(column));
-            header->setToolTip(QString::number(column+1));
+            header->setToolTip(QString::number(column + 1));
             ui->tableWidgetInput->setHorizontalHeaderItem(column, header);
         }
     }
 
-    for (int row=0; row < rows; ++row)
+    for (int row = 0; row < rows; ++row)
     {
-        for(int column=0; column<columns; ++column)
+        for (int column = 0; column < columns; ++column)
         {
             const QString text = csv->text(row, column);
             auto *item = new QTableWidgetItem(text);
@@ -655,7 +658,7 @@ void DialogMeasurementsCSVColumns::ShowImportPreview()
         return;
     }
 
-    QSharedPointer<QxtCsvModel> csv = DialogMeasurementsCSVColumns::CSVModel();
+    QSharedPointer<QxtCsvModel> const csv = DialogMeasurementsCSVColumns::CSVModel();
 
     const int importColumns = ImportColumnCount();
     const int columns = csv->columnCount();
@@ -664,9 +667,9 @@ void DialogMeasurementsCSVColumns::ShowImportPreview()
     ui->tableWidgetImport->clearContents();
     ui->tableWidgetImport->setRowCount(rows);
 
-    for (int row=0; row < rows; ++row)
+    for (int row = 0; row < rows; ++row)
     {
-        for(int column=0; column < importColumns; ++column)
+        for (int column = 0; column < importColumns; ++column)
         {
             const int tableColumn = m_columnsMap.at(column);
             if (tableColumn >= 0 && tableColumn < columns)
@@ -721,32 +724,43 @@ void DialogMeasurementsCSVColumns::HackColumnControls()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogMeasurementsCSVColumns::RetranslateLabels()
 {
-    ui->labelName->setText(tr("Name") + "*:");
+    ui->labelName->setText(QCoreApplication::translate("DialogMeasurementsCSVColumns", "Name", "measurement column") +
+                           "*:"_L1);
 
     if (m_type == MeasurementsType::Individual)
     {
-        ui->labelValue->setText(tr("Value") + "*:");
+        ui->labelValue->setText(
+            QCoreApplication::translate("DialogMeasurementsCSVColumns", "Value", "measurement column") + "*:"_L1);
     }
     else
     {
-        ui->labelValue->setText(tr("Base value") + "*:");
+        ui->labelValue->setText(
+            QCoreApplication::translate("DialogMeasurementsCSVColumns", "Base value", "measurement column") + "*:"_L1);
+
+        const auto suffix = QStringLiteral(" (%1)");
 
         if (not m_dimensions.empty())
         {
-            MeasurementDimension_p dimension = m_dimensions.at(0);
-            ui->labelShiftA->setText(tr("Shift (%1)*:").arg(dimension->Name()));
+            MeasurementDimension_p const dimension = m_dimensions.at(0);
+            ui->labelShiftA->setText(
+                QCoreApplication::translate("DialogMeasurementsCSVColumns", "Shift", "measurement column") +
+                suffix.arg(dimension->Name()));
         }
 
         if (m_dimensions.size() > 1)
         {
-            MeasurementDimension_p dimension = m_dimensions.at(1);
-            ui->labelShiftB->setText(tr("Shift (%1)*:").arg(dimension->Name()));
+            MeasurementDimension_p const dimension = m_dimensions.at(1);
+            ui->labelShiftB->setText(
+                QCoreApplication::translate("DialogMeasurementsCSVColumns", "Shift", "measurement column") +
+                suffix.arg(dimension->Name()));
         }
 
         if (m_dimensions.size() > 2)
         {
-            MeasurementDimension_p dimension = m_dimensions.at(2);
-            ui->labelShiftC->setText(tr("Shift (%1)*:").arg(dimension->Name()));
+            MeasurementDimension_p const dimension = m_dimensions.at(2);
+            ui->labelShiftC->setText(
+                QCoreApplication::translate("DialogMeasurementsCSVColumns", "Shift", "measurement column") +
+                suffix.arg(dimension->Name()));
         }
     }
 }
@@ -758,7 +772,7 @@ void DialogMeasurementsCSVColumns::SetDefaultColumns()
     {
         SCASSERT(control != nullptr)
 
-        int index = control->findData(m_columnsMap.at(column));
+        int const index = control->findData(m_columnsMap.at(column));
         if (index != -1)
         {
             control->setCurrentIndex(index);
@@ -811,42 +825,41 @@ void DialogMeasurementsCSVColumns::CheckStatus()
     if (m_fileName.isEmpty())
     {
         SetStatus(false);
-        ui->labelStatus->setText(tr("File path is empty"));
+        ui->labelStatus->setText(QCoreApplication::translate("DialogMeasurementsCSVColumns", "File path is empty"));
         return;
     }
 
-    QSharedPointer<QxtCsvModel> csv = DialogMeasurementsCSVColumns::CSVModel();
+    QSharedPointer<QxtCsvModel> const csv = DialogMeasurementsCSVColumns::CSVModel();
 
-    const int columns = csv->columnCount();
-    if (columns < MinimumColumns())
+    if (const int columns = csv->columnCount(); columns < MinimumColumns())
     {
         SetStatus(false);
-        ui->labelStatus->setText(tr("Not enough columns"));
+        ui->labelStatus->setText(QCoreApplication::translate("DialogMeasurementsCSVColumns", "Not enough columns"));
         return;
     }
 
-    const int rows = csv->rowCount();
-    if (rows < 1)
+    if (const int rows = csv->rowCount(); rows < 1)
     {
         SetStatus(false);
-        ui->labelStatus->setText(tr("Not enough data to import"));
+        ui->labelStatus->setText(
+            QCoreApplication::translate("DialogMeasurementsCSVColumns", "Not enough data to import"));
         return;
     }
 
     if (not ColumnsValid())
     {
         SetStatus(false);
-        ui->labelStatus->setText(tr("Please, select unique number for each column"));
+        ui->labelStatus->setText(QCoreApplication::translate("DialogMeasurementsCSVColumns",
+                                                             "Please, select unique number for each column"));
         return;
     }
 
     SetStatus(true);
-    ui->labelStatus->setText(tr("Ready"));
+    ui->labelStatus->setText(QCoreApplication::translate("DialogMeasurementsCSVColumns", "Ready"));
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-template<class T>
-void DialogMeasurementsCSVColumns::HackWidget(T **widget)
+template <class T> void DialogMeasurementsCSVColumns::HackWidget(T **widget)
 {
     delete *widget;
     *widget = new T();
@@ -854,18 +867,17 @@ void DialogMeasurementsCSVColumns::HackWidget(T **widget)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-template<class T>
-auto DialogMeasurementsCSVColumns::ColumnValid(T column) const -> bool
+template <class T> auto DialogMeasurementsCSVColumns::ColumnValid(T column) const -> bool
 {
-    const int columnNumber = static_cast<int>(column);
-    int value = m_columnsMap.at(columnNumber);
+    const auto columnNumber = static_cast<int>(column);
+    int const value = m_columnsMap.at(columnNumber);
 
     if (value == -1 && not ColumnMandatory(columnNumber))
     {
         return true;
     }
 
-    for (int c=0; c < m_columnsMap.size(); ++c)
+    for (int c = 0; c < m_columnsMap.size(); ++c)
     {
         if (c == columnNumber)
         {
@@ -882,13 +894,18 @@ auto DialogMeasurementsCSVColumns::ColumnValid(T column) const -> bool
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-template<class T>
-void DialogMeasurementsCSVColumns::SaveColum(QComboBox *control, T column)
+template <class T> void DialogMeasurementsCSVColumns::SaveColum(QComboBox *control, T column)
 {
     SCASSERT(control != nullptr)
 
-    const int columnNumber = static_cast<int>(column);
+    const auto columnNumber = static_cast<int>(column);
     m_columnsMap[columnNumber] = control->currentData().toInt();
     ShowImportPreview();
     CheckStatus();
 }
+
+//---------------------------------------------------------------------------------------------------------------------
+void DialogMeasurementsCSVColumns::SetCodec(VTextCodec *codec)
+{
+    m_codec = codec;
+}
