@@ -29,24 +29,30 @@
 #ifndef TMAINWINDOW_H
 #define TMAINWINDOW_H
 
+#include <QPointer>
 #include <QTableWidget>
+#include <QTemporaryFile>
 
-#include "../vmisc/def.h"
-#include "../vmisc/vlockguard.h"
 #include "../vformat/vmeasurements.h"
+#include "../vmisc/def.h"
+#include "../vmisc/vabstractshortcutmanager.h"
+#include "../vmisc/vlockguard.h"
 #include "../vmisc/vtablesearch.h"
 #include "../vwidgets/vabstractmainwindow.h"
 
 namespace Ui
 {
-    class TMainWindow;
+class TMainWindow;
 } // namespace Ui
 
 class QLabel;
 class QxtCsvModel;
 class VMeasurement;
+class QAbstractButton;
+class QUuid;
+class VKnownMeasurements;
 
-class TMainWindow : public VAbstractMainWindow
+class TMainWindow final : public VAbstractMainWindow
 {
     Q_OBJECT // NOLINT
 
@@ -56,22 +62,25 @@ public:
 
     auto CurrentFile() const -> QString;
 
-    void RetranslateTable();
-
-    auto SetDimensionABase(int base) -> bool;
-    auto SetDimensionBBase(int base) -> bool;
-    auto SetDimensionCBase(int base) -> bool;
+    void SetDimensionABase(qreal base);
+    void SetDimensionBBase(qreal base);
+    void SetDimensionCBase(qreal base);
     void SetPUnit(Unit unit);
 
     auto LoadFile(const QString &path) -> bool;
 
     void UpdateWindowTitle();
 
+    void SyncKnownMeasurements();
+
+public slots:
+    void ToolBarStyles();
+
 protected:
     void closeEvent(QCloseEvent *event) override;
-    void changeEvent(QEvent* event) override;
+    void changeEvent(QEvent *event) override;
     auto eventFilter(QObject *object, QEvent *event) -> bool override;
-    void ExportToCSVData(const QString &fileName, bool withHeader, int mib, const QChar &separator) final;
+    void ExportToCSVData(const QString &fileName, bool withHeader, int mib, const QChar &separator) override;
     auto RecentFileList() const -> QStringList override;
 
 private slots:
@@ -80,10 +89,8 @@ private slots:
     void OpenMultisize();
     void OpenTemplate();
     void CreateFromExisting();
-    void Preferences();
-    void ToolBarStyles();
 
-    bool FileSave(); // NOLINT(modernize-use-trailing-return-type)
+    bool FileSave();   // NOLINT(modernize-use-trailing-return-type)
     bool FileSaveAs(); // NOLINT(modernize-use-trailing-return-type)
     void AboutToShowWindowMenu();
     void ShowWindow() const;
@@ -92,14 +99,14 @@ private slots:
 #if defined(Q_OS_MAC)
     void AboutToShowDockMenu();
     void OpenAt(QAction *where);
-#endif //defined(Q_OS_MAC)
+#endif // defined(Q_OS_MAC)
 
     void SaveCustomerName();
     void SaveEmail();
     void SaveGender(int index);
-    void SaveBirthDate(const QDate & date);
+    void SaveBirthDate(const QDate &date);
     void SaveNotes();
-    void SavePMSystem(int index);
+    void SaveKnownMeasurements(int index);
 
     void Remove();
     void MoveTop();
@@ -108,6 +115,11 @@ private slots:
     void MoveBottom();
     void Fx();
 
+    void AddImage();
+    void RemoveImage();
+    void SaveImage();
+    void ShowImage();
+
     void AddCustom();
     void AddKnown();
     void AddSeparator();
@@ -146,26 +158,28 @@ private slots:
     void EditDimensionLabels();
     void DimensionCustomNames();
 
-    void SetDefaultGUILanguage();
+    void AskDefaultSettings();
+
+    void UpdateShortcuts();
 
 private:
     // cppcheck-suppress unknownMacro
     Q_DISABLE_COPY_MOVE(TMainWindow) // NOLINT
     Ui::TMainWindow *ui;
-    VMeasurements   *m_m{nullptr};
-    VContainer      *m_data{nullptr};
-    Unit             m_mUnit{Unit::Cm};
-    Unit             m_pUnit{Unit::Cm};
+    VMeasurements *m_m{nullptr};
+    VContainer *m_data{nullptr};
+    Unit m_mUnit{Unit::Cm};
+    Unit m_pUnit{Unit::Cm};
     MeasurementsType m_mType{MeasurementsType::Individual};
-    qreal            m_currentDimensionA{0};
-    qreal            m_currentDimensionB{0};
-    qreal            m_currentDimensionC{0};
-    QString          m_curFile{};
-    QComboBox       *m_gradationDimensionA{nullptr};
-    QComboBox       *m_gradationDimensionB{nullptr};
-    QComboBox       *m_gradationDimensionC{nullptr};
-    QComboBox       *m_comboBoxUnits{nullptr};
-    int              m_formulaBaseHeight;
+    qreal m_currentDimensionA{0};
+    qreal m_currentDimensionB{0};
+    qreal m_currentDimensionC{0};
+    QString m_curFile{};
+    QComboBox *m_gradationDimensionA{nullptr};
+    QComboBox *m_gradationDimensionB{nullptr};
+    QComboBox *m_gradationDimensionC{nullptr};
+    QComboBox *m_comboBoxUnits{nullptr};
+    int m_formulaBaseHeight{0};
     QSharedPointer<VLockGuard<char>> m_lock{nullptr};
     QSharedPointer<VTableSearch> m_search{};
     QLabel *m_labelGradationDimensionA{nullptr};
@@ -179,19 +193,26 @@ private:
 
     QVector<QObject *> m_hackedWidgets{};
 
+    QPointer<QTemporaryFile> m_tmpImage{};
+
     struct MultisizeMeasurement
     {
         MultisizeMeasurement() = default;
 
-        QString name{}; // NOLINT(misc-non-private-member-variables-in-classes)
-        qreal base{0}; // NOLINT(misc-non-private-member-variables-in-classes)
-        qreal shiftA{0}; // NOLINT(misc-non-private-member-variables-in-classes)
-        qreal shiftB{0}; // NOLINT(misc-non-private-member-variables-in-classes)
-        qreal shiftC{0}; // NOLINT(misc-non-private-member-variables-in-classes)
-        QString fullName{}; // NOLINT(misc-non-private-member-variables-in-classes)
-        QString description{}; // NOLINT(misc-non-private-member-variables-in-classes)
+        QString name{};           // NOLINT(misc-non-private-member-variables-in-classes)
+        qreal base{0};            // NOLINT(misc-non-private-member-variables-in-classes)
+        qreal shiftA{0};          // NOLINT(misc-non-private-member-variables-in-classes)
+        qreal shiftB{0};          // NOLINT(misc-non-private-member-variables-in-classes)
+        qreal shiftC{0};          // NOLINT(misc-non-private-member-variables-in-classes)
+        QString fullName{};       // NOLINT(misc-non-private-member-variables-in-classes)
+        QString description{};    // NOLINT(misc-non-private-member-variables-in-classes)
+        bool specialUnits{false}; // NOLINT(misc-non-private-member-variables-in-classes)
     };
 
+    QMultiHash<VShortcutAction, QAction *> m_actionShortcuts{};
+    QMultiHash<VShortcutAction, QAbstractButton *> m_buttonShortcuts{};
+    QHash<QAbstractButton *, QString> m_serachButtonTooltips{};
+
     void SetupMenu();
     void InitWindow();
     void InitMenu();
@@ -225,7 +246,7 @@ private:
     auto MaybeSave() -> bool;
 
     auto AddCell(const QString &text, int row, int column, int aligment, bool ok = true) -> QTableWidgetItem *;
-    auto AddSeparatorCell(const QString &text, int row, int column, int aligment, bool ok = true) -> QTableWidgetItem*;
+    auto AddSeparatorCell(const QString &text, int row, int column, int aligment, bool ok = true) -> QTableWidgetItem *;
 
     void RefreshData(bool freshCall = false);
     void RefreshTable(bool freshCall = false);
@@ -235,9 +256,9 @@ private:
     static auto ClearCustomName(const QString &name) -> QString;
 
     auto EvalFormula(const QString &formula, bool fromUser, VContainer *data, QLabel *label, bool specialUnits) -> bool;
-    void ShowMDiagram(const QString &name);
+    void ShowMDiagram(const QSharedPointer<VMeasurement> &m);
 
-    void Open(const QString &pathTo, const QString &filter);
+    auto Open(const QString &pathTo, const QString &filter) -> QString;
     void UpdatePadlock(bool ro);
     void MeasurementGUI();
     void Controls();
@@ -254,8 +275,7 @@ private:
 
     void CreateWindowMenu(QMenu *menu);
 
-    template <class T>
-    void HackWidget(T **widget);
+    template <class T> void HackWidget(T **widget);
     void HackDimensionBaseValue();
     void HackDimensionShifts();
 
@@ -263,10 +283,10 @@ private:
     void ShowError(const QString &text);
     void RefreshDataAfterImport();
 
-    void ImportIndividualMeasurements(const QxtCsvModel &csv, const QVector<int> &map);
-    void ImportMultisizeMeasurements(const QxtCsvModel &csv, const QVector<int> &map);
-    auto ImportMultisizeMeasurement(const QxtCsvModel &csv, int i, const QVector<int> &map,
-                                    int dimensionsCount, QSet<QString> &importedNames) -> MultisizeMeasurement;
+    void ImportIndividualMeasurements(const QxtCsvModel &csv, const QVector<int> &map, bool withHeader);
+    void ImportMultisizeMeasurements(const QxtCsvModel &csv, const QVector<int> &map, bool withHeader);
+    auto ImportMultisizeMeasurement(const QxtCsvModel &csv, int i, const QVector<int> &map, vsizetype dimensionsCount,
+                                    QSet<QString> &importedNames) -> MultisizeMeasurement;
 
     void SetCurrentPatternUnit();
 
@@ -276,7 +296,22 @@ private:
 
     auto DimensionRestrictedValues(int index, const MeasurementDimension_p &dimension) -> QVector<double>;
 
-    auto OrderedMeasurments() const -> QMap<int, QSharedPointer<VMeasurement> >;
+    auto OrderedMeasurements() const -> QMap<int, QSharedPointer<VMeasurement>>;
+
+    void InitIcons();
+
+    static auto UnknownMeasurementImage() -> QString;
+
+    void RetranslateMDiagram();
+
+    void InitKnownMeasurements(QComboBox *combo);
+    void InitKnownMeasurementsDescription();
+
+    static auto KnownMeasurementsRegistred(const QUuid &id) -> bool;
+
+    auto CSVColumnHeader(int column) const -> QString;
+    void ExportRowToCSV(QxtCsvModel &csv, int row, const QSharedPointer<VMeasurement> &meash,
+                        const VKnownMeasurements &knownDB) const;
 };
 
 #endif // TMAINWINDOW_H
