@@ -27,38 +27,63 @@
  *************************************************************************/
 
 #include "vapplication.h"
-#include "../ifc/exception/vexceptionobjecterror.h"
 #include "../ifc/exception/vexceptionbadid.h"
 #include "../ifc/exception/vexceptionconversionerror.h"
 #include "../ifc/exception/vexceptionemptyparameter.h"
-#include "../ifc/exception/vexceptionwrongid.h"
 #include "../ifc/exception/vexceptioninvalidnotch.h"
-#include "../version.h"
-#include "../qmuparser/qmuparsererror.h"
+#include "../ifc/exception/vexceptionobjecterror.h"
+#include "../ifc/exception/vexceptionwrongid.h"
 #include "../mainwindow.h"
+#include "../qmuparser/qmuparsererror.h"
+#include "../version.h"
+#include "../vformat/knownmeasurements/vknownmeasurementsdatabase.h"
+#include "../vganalytics/vganalytics.h"
 #include "../vmisc/qt_dispatch/qt_dispatch.h"
+#include "../vmisc/theme/vtheme.h"
 #include "../vmisc/vsysexits.h"
-#include "vvalentinasettings.h"
+#include "../vmisc/vvalentinasettings.h"
+#include "vvalentinashortcutmanager.h"
 
-#include <QtDebug>
-#include <QDir>
-#include <QProcess>
-#include <QTemporaryFile>
-#include <QFile>
-#include <QStandardPaths>
-#include <QMessageBox>
-#include <QThread>
+#include "QtConcurrent/qtconcurrentrun.h"
 #include <QDateTime>
-#include <QtXmlPatterns>
+#include <QDir>
+#include <QEvent>
+#include <QFile>
+#include <QFileSystemWatcher>
+#include <QFuture>
 #include <QIcon>
-#include <Qt>
-
-#if QT_VERSION < QT_VERSION_CHECK(5, 12, 0)
-#include "../vmisc/backport/qscopeguard.h"
-#else
+#include <QLoggingCategory>
+#include <QMessageBox>
+#include <QObject>
+#include <QProcess>
 #include <QScopeGuard>
+#include <QStandardPaths>
+#include <QStyleFactory>
+#include <QTemporaryFile>
+#include <QThread>
+#include <QTimer>
+#include <QUuid>
+#include <QtDebug>
+
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#include <QtXmlPatterns>
 #endif
 
+#if !defined(BUILD_REVISION) && defined(QBS_BUILD)
+#include <vcsRepoState.h>
+#define BUILD_REVISION VCS_REPO_STATE_REVISION
+#endif
+
+#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
+#include "../vmisc/compatibility.h"
+#endif
+
+#if defined(APPIMAGE) && defined(Q_OS_LINUX)
+#include "../vmisc/appimage.h"
+#endif // defined(APPIMAGE) && defined(Q_OS_LINUX)
+
+using namespace Qt::Literals::StringLiterals;
+
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_CLANG("-Wmissing-prototypes")
 QT_WARNING_DISABLE_INTEL(1418)
@@ -67,27 +92,52 @@ Q_LOGGING_CATEGORY(vApp, "v.application") // NOLINT
 
 QT_WARNING_POP
 
-Q_DECL_CONSTEXPR auto DAYS_TO_KEEP_LOGS = 3;
-
 namespace
 {
 auto AppFilePath(const QString &appName) -> QString
 {
-    QString appNameExe = appName; // NOLINT(performance-unnecessary-copy-initialization)
 #ifdef Q_OS_WIN
-    appNameExe += ".exe";
+    const auto executableSuffix = QStringLiteral(".exe");
+#else
+    const QString executableSuffix;
 #endif
-    QFileInfo canonicalFile(QStringLiteral("%1/%2").arg(QCoreApplication::applicationDirPath(), appNameExe));
-    if (canonicalFile.exists())
+
+#if defined(APPIMAGE) && defined(Q_OS_LINUX)
+    return AppImageRoot() + BINDIR + '/'_L1 + appName;
+#else
+    if (QFileInfo const canonicalFile(
+            QStringLiteral("%1/%2").arg(QCoreApplication::applicationDirPath(), appName + executableSuffix));
+        canonicalFile.exists())
     {
         return canonicalFile.absoluteFilePath();
     }
+#endif // defined(APPIMAGE) && defined(Q_OS_LINUX)
 
+#if defined(Q_OS_MACOS) && defined(QBS_BUILD) && defined(MULTI_BUNDLE)
+    QFileInfo multiBundleFile(
+        QStringLiteral("%1/../../../%2.app/Contents/MacOS/%2").arg(QCoreApplication::applicationDirPath(), appName));
+    if (multiBundleFile.exists())
+    {
+        return multiBundleFile.absoluteFilePath();
+    }
+#endif
+
+#if !defined(QBS_BUILD)
     QFileInfo debugFile(QStringLiteral("%1/../../%2/bin/%3")
-                            .arg(QCoreApplication::applicationDirPath(), appName, appNameExe));
-    return debugFile.exists() ? debugFile.absoluteFilePath() : appNameExe;
+                            .arg(QCoreApplication::applicationDirPath(), appName, appName + executableSuffix));
+    if (debugFile.exists())
+    {
+        return debugFile.absoluteFilePath();
+    }
+#endif
+
+#if !defined(Q_OS_MACOS)
+    return appName + executableSuffix;
+#else
+    return appName + QStringLiteral(".app");
+#endif
 }
-}  // namespace
+} // namespace
 
 //---------------------------------------------------------------------------------------------------------------------
 inline void noisyFailureMsgHandler(QtMsgType type, const QMessageLogContext &context, const QString &msg)
@@ -101,9 +151,7 @@ inline void noisyFailureMsgHandler(QtMsgType type, const QMessageLogContext &con
     if (not isGuiThread)
     {
         auto Handler = [](QtMsgType type, const QMessageLogContext &context, const QString &msg)
-        {
-            noisyFailureMsgHandler(type, context, msg);
-        };
+        { noisyFailureMsgHandler(type, context, msg); };
 
         q_dispatch_async_main(Handler, type, context, msg);
         return;
@@ -126,29 +174,9 @@ inline void noisyFailureMsgHandler(QtMsgType type, const QMessageLogContext &con
     {
         type = QtDebugMsg;
     }
-#endif //defined(V_NO_ASSERT)
+#endif // defined(V_NO_ASSERT)
 
 #if defined(Q_OS_MAC)
-#   if QT_VERSION >= QT_VERSION_CHECK(5, 4, 0) && QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
-        // Try hide very annoying, Qt related, warnings in Mac OS X
-        // QNSView mouseDragged: Internal mouse button tracking invalid (missing Qt::LeftButton)
-        // https://bugreports.qt.io/browse/QTBUG-42846
-        if ((type == QtWarningMsg) && msg.contains(QStringLiteral("QNSView")))
-        {
-            type = QtDebugMsg;
-        }
-#   endif
-
-#   if QT_VERSION < QT_VERSION_CHECK(5, 9, 0)
-    // Hide Qt bug 'Assertion when reading an icns file'
-    // https://bugreports.qt.io/browse/QTBUG-45537
-    // Remove after Qt fix will be released
-    if ((type == QtWarningMsg) && msg.contains(QStringLiteral("QICNSHandler::read()")))
-    {
-        type = QtDebugMsg;
-    }
-#   endif
-
     // Hide anything that starts with QMacCGContext
     if ((type == QtWarningMsg) && msg.contains(QStringLiteral("QMacCGContext::")))
     {
@@ -165,8 +193,8 @@ inline void noisyFailureMsgHandler(QtMsgType type, const QMessageLogContext &con
     // this is another one that doesn't make sense as just a debug message.  pretty serious
     // sign of a problem
     // http://www.developer.nokia.com/Community/Wiki/QPainter::begin:Paint_device_returned_engine_%3D%3D_0_(Known_Issue)
-    if ((type == QtDebugMsg) && msg.contains(QStringLiteral("QPainter::begin"))
-            && msg.contains(QStringLiteral("Paint device returned engine")))
+    if ((type == QtDebugMsg) && msg.contains(QStringLiteral("QPainter::begin")) &&
+        msg.contains(QStringLiteral("Paint device returned engine")))
     {
         type = QtWarningMsg;
     }
@@ -174,8 +202,16 @@ inline void noisyFailureMsgHandler(QtMsgType type, const QMessageLogContext &con
     // This qWarning about "Cowardly refusing to send clipboard message to hung application..."
     // is something that can easily happen if you are debugging and the application is paused.
     // As it is so common, not worth popping up a dialog.
-    if ((type == QtWarningMsg) && msg.contains(QStringLiteral("QClipboard::event"))
-            && msg.contains(QStringLiteral("Cowardly refusing")))
+    if ((type == QtWarningMsg) && msg.contains(QStringLiteral("QClipboard::event")) &&
+        msg.contains(QStringLiteral("Cowardly refusing")))
+    {
+        type = QtDebugMsg;
+    }
+
+    // Annoying warning that we can ignore
+    if ((type == QtWarningMsg) && (msg.contains(QStringLiteral("OpenType support missing for")) ||
+                                   msg.contains(QStringLiteral("DirectWrite: CreateFontFaceFromHDC() failed (Indicates "
+                                                               "an error in an input file such as a font file.)"))))
     {
         type = QtDebugMsg;
     }
@@ -188,13 +224,16 @@ inline void noisyFailureMsgHandler(QtMsgType type, const QMessageLogContext &con
     }
 
     {
-        QString debugdate = "[" + QDateTime::currentDateTime().toString(QStringLiteral("yyyy.MM.dd hh:mm:ss"));
+        QString debugdate = "["_L1 + QDateTime::currentDateTime().toString(QStringLiteral("yyyy.MM.dd hh:mm:ss"));
+        QString const file = VAbstractApplication::ReduceLogContextFilePath(context.file);
 
         switch (type)
         {
             case QtDebugMsg:
-                debugdate += QStringLiteral(":DEBUG:%1(%2)] %3: %4: %5").arg(context.file).arg(context.line)
-                             .arg(context.function, context.category, logMsg);
+                debugdate += QStringLiteral(":DEBUG:%1(%2)] %3: %4: %5")
+                                 .arg(file)
+                                 .arg(context.line)
+                                 .arg(context.function, context.category, logMsg);
                 vStdOut() << QApplication::translate("vNoisyHandler", "DEBUG:") << logMsg << "\n";
                 break;
             case QtWarningMsg:
@@ -202,8 +241,10 @@ inline void noisyFailureMsgHandler(QtMsgType type, const QMessageLogContext &con
                 {
                     VAbstractValApplication::VApp()->PostWarningMessage(logMsg, type);
                 }
-                debugdate += QStringLiteral(":WARNING:%1(%2)] %3: %4: %5").arg(context.file).arg(context.line)
-                             .arg(context.function, context.category, logMsg);
+                debugdate += QStringLiteral(":WARNING:%1(%2)] %3: %4: %5")
+                                 .arg(file)
+                                 .arg(context.line)
+                                 .arg(context.function, context.category, logMsg);
                 vStdErr() << QApplication::translate("vNoisyHandler", "WARNING:") << logMsg << "\n";
                 break;
             case QtCriticalMsg:
@@ -211,90 +252,85 @@ inline void noisyFailureMsgHandler(QtMsgType type, const QMessageLogContext &con
                 {
                     VAbstractValApplication::VApp()->PostWarningMessage(logMsg, type);
                 }
-                debugdate += QStringLiteral(":CRITICAL:%1(%2)] %3: %4: %5").arg(context.file).arg(context.line)
-                             .arg(context.function, context.category, logMsg);
+                debugdate += QStringLiteral(":CRITICAL:%1(%2)] %3: %4: %5")
+                                 .arg(file)
+                                 .arg(context.line)
+                                 .arg(context.function, context.category, logMsg);
                 vStdErr() << QApplication::translate("vNoisyHandler", "CRITICAL:") << logMsg << "\n";
                 break;
             case QtFatalMsg:
-                debugdate += QStringLiteral(":FATAL:%1(%2)] %3: %4: %5").arg(context.file).arg(context.line)
-                             .arg(context.function, context.category, logMsg);
+                debugdate += QStringLiteral(":FATAL:%1(%2)] %3: %4: %5")
+                                 .arg(file)
+                                 .arg(context.line)
+                                 .arg(context.function, context.category, logMsg);
                 vStdErr() << QApplication::translate("vNoisyHandler", "FATAL:") << logMsg << "\n";
                 break;
-            #if QT_VERSION >= QT_VERSION_CHECK(5, 5, 0)
             case QtInfoMsg:
                 if (isPatternMessage)
                 {
                     VAbstractValApplication::VApp()->PostWarningMessage(logMsg, type);
                 }
-                debugdate += QStringLiteral(":INFO:%1(%2)] %3: %4: %5").arg(context.file).arg(context.line)
-                             .arg(context.function, context.category, logMsg);
+                debugdate += QStringLiteral(":INFO:%1(%2)] %3: %4: %5")
+                                 .arg(file)
+                                 .arg(context.line)
+                                 .arg(context.function, context.category, logMsg);
                 vStdOut() << QApplication::translate("vNoisyHandler", "INFO:") << logMsg << "\n";
                 break;
-            #endif
             default:
                 break;
         }
         vStdOut().flush();
         vStdErr().flush();
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-        (*VApplication::VApp()->LogFile()) << debugdate <<  endl;
-#else
-        (*VApplication::VApp()->LogFile()) << debugdate <<  Qt::endl;
-#endif
+        (*VApplication::VApp()->LogFile()) << debugdate << Qt::endl;
     }
 
     if (isGuiThread)
     {
-        if (type == QtWarningMsg || type == QtCriticalMsg || type == QtFatalMsg)
+        if ((type == QtWarningMsg || type == QtCriticalMsg || type == QtFatalMsg) && VApplication::IsGUIMode())
         {
-            if (VApplication::IsGUIMode())
+            // fixme: trying to make sure there are no save/load dialogs are opened, because error message during
+            //  them will lead to crash
+            const bool topWinAllowsPop = (QApplication::activeModalWidget() == nullptr) ||
+                                         !QApplication::activeModalWidget()->inherits("QFileDialog");
+
+            if (topWinAllowsPop && (not isPatternMessage || (type == QtCriticalMsg || type == QtFatalMsg)))
             {
-                //fixme: trying to make sure there are no save/load dialogs are opened, because error message during
-                // them will lead to crash
-                const bool topWinAllowsPop = (QApplication::activeModalWidget() == nullptr) ||
-                        !QApplication::activeModalWidget()->inherits("QFileDialog");
-
-                if (topWinAllowsPop && (not isPatternMessage || (type == QtCriticalMsg || type == QtFatalMsg)))
+                QMessageBox messageBox;
+                switch (type)
                 {
-                    QMessageBox messageBox;
-                    switch (type)
-                    {
-                        case QtWarningMsg:
-                            messageBox.setWindowTitle(QApplication::translate("vNoisyHandler", "Warning"));
-                            messageBox.setIcon(QMessageBox::Warning);
-                            break;
-                        case QtCriticalMsg:
-                            messageBox.setWindowTitle(QApplication::translate("vNoisyHandler", "Critical error"));
-                            messageBox.setIcon(QMessageBox::Critical);
-                            break;
-                        case QtFatalMsg:
-                            messageBox.setWindowTitle(QApplication::translate("vNoisyHandler", "Fatal error"));
-                            messageBox.setIcon(QMessageBox::Critical);
-                            break;
-                        #if QT_VERSION >= QT_VERSION_CHECK(5, 5, 0)
-                        case QtInfoMsg:
-                            messageBox.setWindowTitle(QApplication::translate("vNoisyHandler", "Information"));
-                            messageBox.setIcon(QMessageBox::Information);
-                            break;
-                        #endif
-                        case QtDebugMsg:
-                        default:
-                            break;
-                    }
-
-                    messageBox.setText(VAbstractValApplication::ClearMessage(logMsg));
-                    messageBox.setStandardButtons(QMessageBox::Ok);
-                    messageBox.setWindowModality(Qt::ApplicationModal);
-                    messageBox.setModal(true);
-                #ifndef QT_NO_CURSOR
-                    QGuiApplication::setOverrideCursor(Qt::ArrowCursor);
-                #endif
-                    messageBox.exec();
-                #ifndef QT_NO_CURSOR
-                    QGuiApplication::restoreOverrideCursor();
-                #endif
+                    case QtWarningMsg:
+                        messageBox.setWindowTitle(QApplication::translate("vNoisyHandler", "Warning"));
+                        messageBox.setIcon(QMessageBox::Warning);
+                        break;
+                    case QtCriticalMsg:
+                        messageBox.setWindowTitle(QApplication::translate("vNoisyHandler", "Critical error"));
+                        messageBox.setIcon(QMessageBox::Critical);
+                        break;
+                    case QtFatalMsg:
+                        messageBox.setWindowTitle(QApplication::translate("vNoisyHandler", "Fatal error"));
+                        messageBox.setIcon(QMessageBox::Critical);
+                        break;
+                    case QtInfoMsg:
+                        messageBox.setWindowTitle(QApplication::translate("vNoisyHandler", "Information"));
+                        messageBox.setIcon(QMessageBox::Information);
+                        break;
+                    case QtDebugMsg:
+                    default:
+                        break;
                 }
+
+                messageBox.setText(VAbstractValApplication::ClearMessage(logMsg));
+                messageBox.setStandardButtons(QMessageBox::Ok);
+                messageBox.setWindowModality(Qt::ApplicationModal);
+                messageBox.setModal(true);
+#ifndef QT_NO_CURSOR
+                QGuiApplication::setOverrideCursor(Qt::ArrowCursor);
+#endif
+                messageBox.exec();
+#ifndef QT_NO_CURSOR
+                QGuiApplication::restoreOverrideCursor();
+#endif
             }
         }
 
@@ -319,22 +355,35 @@ inline void noisyFailureMsgHandler(QtMsgType type, const QMessageLogContext &con
  * @param argv command line.
  */
 VApplication::VApplication(int &argc, char **argv)
-    : VAbstractValApplication(argc, argv)
+  : VAbstractValApplication(argc, argv)
 {
     setApplicationDisplayName(QStringLiteral(VER_PRODUCTNAME_STR));
     setApplicationName(QStringLiteral(VER_INTERNALNAME_STR));
     setOrganizationName(QStringLiteral(VER_COMPANYNAME_STR));
     setOrganizationDomain(QStringLiteral(VER_COMPANYDOMAIN_STR));
     // Setting the Application version
-    setApplicationVersion(APP_VERSION_STR);
+    setApplicationVersion(AppVersionStr());
     // making sure will create new instance...just in case we will ever do 2 objects of VApplication
     VCommandLine::Reset();
+    VTheme::Instance()->StoreDefaultThemeName(QIcon::themeName());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 VApplication::~VApplication()
 {
     qCDebug(vApp, "Application closing.");
+
+    if (IsGUIMode() && settings->IsCollectStatistic())
+    {
+        auto *statistic = VGAnalytics::Instance();
+
+        QString const clientID = settings->GetClientID();
+        if (!clientID.isEmpty())
+        {
+            statistic->SendAppCloseEvent(m_uptimeTimer.elapsed());
+        }
+    }
+
     qInstallMessageHandler(nullptr); // Resore the message handler
     delete m_trVars;
     VCommandLine::Reset();
@@ -364,7 +413,7 @@ void VApplication::NewValentina(const QString &fileName)
     }
     else
     {
-        const QString run = QStringLiteral("\"%1\" \"%2\"").arg(QCoreApplication::applicationFilePath(), fileName);
+        const auto run = QStringLiteral("\"%1\" \"%2\"").arg(QCoreApplication::applicationFilePath(), fileName);
         qCDebug(vApp, "New process with arguments. program = %s", qUtf8Printable(run));
         if (QProcess::startDetached(QCoreApplication::applicationFilePath(), QStringList{fileName}))
         {
@@ -393,7 +442,8 @@ auto VApplication::notify(QObject *receiver, QEvent *event) -> bool
     }
     catch (const VExceptionObjectError &e)
     {
-        qCCritical(vApp, "%s\n\n%s\n\n%s", qUtf8Printable(tr("Error parsing file. Program will be terminated.")), //-V807
+        qCCritical(vApp, "%s\n\n%s\n\n%s",
+                   qUtf8Printable(tr("Error parsing file. Program will be terminated.")), //-V807
                    qUtf8Printable(e.ErrorMessage()), qUtf8Printable(e.DetailedInformation()));
         exit(V_EX_DATAERR);
     }
@@ -428,16 +478,16 @@ auto VApplication::notify(QObject *receiver, QEvent *event) -> bool
                    qUtf8Printable(e.ErrorMessage()), qUtf8Printable(e.DetailedInformation()));
         exit(V_EX_DATAERR);
     }
-    catch(const VExceptionInvalidNotch &e)
+    catch (const VExceptionInvalidNotch &e)
     {
-        qCCritical(vApp, "%s\n\n%s\n\n%s", qUtf8Printable(tr("Invalid notch.")),
-                   qUtf8Printable(e.ErrorMessage()), qUtf8Printable(e.DetailedInformation()));
+        qCCritical(vApp, "%s\n\n%s\n\n%s", qUtf8Printable(tr("Invalid notch.")), qUtf8Printable(e.ErrorMessage()),
+                   qUtf8Printable(e.DetailedInformation()));
         exit(V_EX_DATAERR);
     }
     catch (const VException &e)
     {
-        qCCritical(vApp, "%s\n\n%s\n\n%s", qUtf8Printable(tr("Something's wrong!!")),
-                   qUtf8Printable(e.ErrorMessage()), qUtf8Printable(e.DetailedInformation()));
+        qCCritical(vApp, "%s\n\n%s\n\n%s", qUtf8Printable(tr("Something's wrong!!")), qUtf8Printable(e.ErrorMessage()),
+                   qUtf8Printable(e.DetailedInformation()));
         return true;
     }
     catch (const qmu::QmuParserWarning &e)
@@ -453,7 +503,7 @@ auto VApplication::notify(QObject *receiver, QEvent *event) -> bool
         qCCritical(vApp, "%s", qUtf8Printable(tr("Parser error: %1. Program will be terminated.").arg(e.GetMsg())));
         exit(V_EX_DATAERR);
     }
-    catch (std::exception& e)
+    catch (std::exception &e)
     {
         qCCritical(vApp, "%s", qUtf8Printable(tr("Exception thrown: %1. Program will be terminated.").arg(e.what())));
         exit(V_EX_SOFTWARE);
@@ -461,73 +511,39 @@ auto VApplication::notify(QObject *receiver, QEvent *event) -> bool
     return false;
 }
 
-//---------------------------------------------------------------------------------------------------------------------
-void VApplication::ActivateDarkMode()
-{
-     VValentinaSettings *settings = ValentinaSettings();
-     if (settings->GetDarkMode())
-     {
-         QFile f(QStringLiteral(":qdarkstyle/style.qss"));
-         if (!f.exists())
-         {
-             qDebug()<<"Unable to set stylesheet, file not found\n";
-         }
-         else
-         {
-             f.open(QFile::ReadOnly | QFile::Text);
-             QTextStream ts(&f);
-             qApp->setStyleSheet(ts.readAll()); // NOLINT(cppcoreguidelines-pro-type-static-cast-downcast)
-         }
-     }
-}
-
 //---------------------------------------------------------------------------------------------------------------------
 auto VApplication::TapeFilePath() -> QString
 {
-    return AppFilePath(QStringLiteral("tape"));
+#ifdef Q_OS_MACOS
+    const auto appName = QStringLiteral("Tape");
+#else
+    const auto appName = QStringLiteral("tape");
+#endif
+    return AppFilePath(appName);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 auto VApplication::PuzzleFilePath() -> QString
 {
-    return AppFilePath(QStringLiteral("puzzle"));
-}
-
-//---------------------------------------------------------------------------------------------------------------------
-auto VApplication::LogDirPath() -> QString
-{
-#if defined(Q_OS_WIN) || defined(Q_OS_OSX)
-    const QString logDirPath = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QString(),
-                                                      QStandardPaths::LocateDirectory) + "Valentina";
+#ifdef Q_OS_MACOS
+    const auto appName = QStringLiteral("Puzzle");
 #else
-    const QString logDirPath = QStandardPaths::locate(QStandardPaths::ConfigLocation, QString(),
-                                                      QStandardPaths::LocateDirectory)
-            + QCoreApplication::organizationName();
+    const auto appName = QStringLiteral("puzzle");
 #endif
-    return logDirPath;
+    return AppFilePath(appName);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 auto VApplication::LogPath() -> QString
 {
+    // Keep in sync with VCrashPaths::GetAttachmentPath
     return QStringLiteral("%1/valentina-pid%2.log").arg(LogDirPath()).arg(applicationPid());
 }
 
-//---------------------------------------------------------------------------------------------------------------------
-auto VApplication::CreateLogDir() -> bool
-{
-    QDir logDir(LogDirPath());
-    if (not logDir.exists())
-    {
-        return logDir.mkpath(QChar('.')); // Create directory for log if need
-    }
-    return true;
-}
-
 //---------------------------------------------------------------------------------------------------------------------
 void VApplication::BeginLogging()
 {
-    VlpCreateLock(m_lockLog, LogPath(), [](){return new QFile(LogPath());});
+    VlpCreateLock(m_lockLog, LogPath(), []() { return new QFile(LogPath()); });
 
     if (m_lockLog->IsLocked())
     {
@@ -549,107 +565,91 @@ void VApplication::BeginLogging()
     }
 }
 
-//---------------------------------------------------------------------------------------------------------------------
-void VApplication::ClearOldLogs()
-{
-    const QString workingDirectory = QDir::currentPath();// Save the app working directory
-    QDir logsDir(LogDirPath());
-    logsDir.setNameFilters(QStringList(QStringLiteral("*.log")));
-    QDir::setCurrent(LogDirPath());
-
-    // Restore working directory
-    auto restore = qScopeGuard([workingDirectory] { QDir::setCurrent(workingDirectory); });
-
-    const QStringList allFiles = logsDir.entryList(QDir::NoDotAndDotDot | QDir::Files);
-    if (allFiles.isEmpty())
-    {
-        qCDebug(vApp, "There are no old logs.");
-        return;
-    }
-
-    qCDebug(vApp, "Clearing old logs");
-    for (const auto &fn : allFiles)
-    {
-        QFileInfo info(fn);
-#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
-        const QDateTime created = info.birthTime();
-#else
-        const QDateTime created = info.created();
-#endif
-        if (created.daysTo(QDateTime::currentDateTime()) >= DAYS_TO_KEEP_LOGS)
-        {
-            VLockGuard<QFile> tmp(info.absoluteFilePath(), [&fn](){return new QFile(fn);});
-            if (tmp.GetProtected() != nullptr)
-            {
-                if (tmp.GetProtected()->remove())
-                {
-                    qCDebug(vApp, "Deleted %s", qUtf8Printable(info.absoluteFilePath()));
-                }
-                else
-                {
-                    qCDebug(vApp, "Could not delete %s", qUtf8Printable(info.absoluteFilePath()));
-                }
-            }
-            else
-            {
-                qCDebug(vApp, "Failed to lock %s", qUtf8Printable(info.absoluteFilePath()));
-            }
-        }
-    }
-}
-
 //---------------------------------------------------------------------------------------------------------------------
 void VApplication::InitOptions()
 {
     OpenSettings();
 
-    // Run creation log after sending crash report
     StartLogging();
 
-    qDebug()<<"Version:"<<APP_VERSION_STR;
-    qDebug()<<"Build revision:"<<BUILD_REVISION;
-    qDebug()<<buildCompatibilityString();
-    qDebug()<<"Built on"<<__DATE__<<"at"<<__TIME__;
-    qDebug()<<"Command-line arguments:"<<arguments();
-    qDebug()<<"Process ID:"<<applicationPid();
+    qDebug() << "Version:" << AppVersionStr();
+    qDebug() << "Build revision:" << BUILD_REVISION;
+    qDebug() << buildCompatibilityString();
+    qDebug() << "Built on" << __DATE__ << "at" << __TIME__;
+    qDebug() << "Command-line arguments:" << arguments();
+    qDebug() << "Process ID:" << applicationPid();
 
-    CheckSystemLocale();
-
-    LoadTranslation(QString());// By default the console version uses system locale
+    LoadTranslation(QString()); // By default the console version uses system locale
 
     // Create command line parser after loading translations to show localized version.
     VCommandLine::Get(*this);
 
-    if (VApplication::IsGUIMode())// By default console version uses system locale
+    CheckSystemLocale();
+
+    QTimer::singleShot(0, this,
+                       []()
+                       {
+                           QString const country = VGAnalytics::CountryCode();
+                           if (country == "ru"_L1 || country == "by"_L1)
+                           {
+                               qFatal("country not detected");
+                           }
+                       });
+
+    if (VApplication::IsGUIMode()) // By default console version uses system locale
     {
         LoadTranslation(ValentinaSettings()->GetLocale());
+
+        VTheme::InitApplicationStyle();
+        VTheme::SetIconTheme();
+        VTheme::InitThemeMode();
+
+        m_shortcutManager = new VValentinaShortcutManager(this);
     }
 
-    static const char * GENERIC_ICON_TO_CHECK = "document-open";
-    if (not QIcon::hasThemeIcon(GENERIC_ICON_TO_CHECK))
+    VGAnalytics::Init(settings);
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VApplication::StartDetachedProcess(const QString &program, const QStringList &arguments)
+{
+#if !defined(Q_OS_MACOS)
+    const QString workingDirectory = QFileInfo(program).absoluteDir().absolutePath();
+    QProcess::startDetached(program, arguments, workingDirectory);
+#else
+    if (not program.endsWith(".app"_L1))
     {
-        //If there is no default working icon theme then we should
-        //use an icon theme that we provide via a .qrc file
-        //This case happens under Windows and Mac OS X
-        //This does not happen under GNOME or KDE
-        QIcon::setThemeName(QStringLiteral("win.icon.theme"));
+        const QString workingDirectory = QFileInfo(program).absoluteDir().absolutePath();
+        QProcess::startDetached(program, arguments, workingDirectory);
     }
-    ActivateDarkMode();
+    else
+    {
+        QStringList openArguments{"-n", QStringLiteral("/Applications/%1").arg(program)};
+        if (not arguments.isEmpty())
+        {
+            openArguments.append("--args"_L1);
+            openArguments += arguments;
+        }
+
+        QProcess::startDetached("open"_L1, openArguments);
+    }
+#endif
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 auto VApplication::LabelLanguages() -> QStringList
 {
-    QStringList list {"de",  // German
-                      "en",  // English
-                      "fr",  // French
-                      "ru",  // Russian
-                      "uk",  // Ukrainian
-                      "hr",  // Croatian
-                      "sr",  // Serbian
-                      "bs",  // Bosnian
-                      "cs"   // Czech
-                     };
+    QStringList list{
+        "de", // German
+        "en", // English
+        "fr", // French
+        "ru", // Russian
+        "uk", // Ukrainian
+        "hr", // Croatian
+        "sr", // Serbian
+        "bs", // Bosnian
+        "cs"  // Czech
+    };
     return list;
 }
 
@@ -669,6 +669,36 @@ auto VApplication::LogFile() -> QTextStream *
     return m_out.get();
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+auto VApplication::KnownMeasurementsDatabase() -> VKnownMeasurementsDatabase *
+{
+    if (m_knownMeasurementsDatabase == nullptr)
+    {
+        m_knownMeasurementsDatabase = new VKnownMeasurementsDatabase();
+
+        RestartKnownMeasurementsDatabaseWatcher();
+    }
+
+    if (!m_knownMeasurementsDatabase->IsPopulated())
+    {
+        m_knownMeasurementsDatabase->PopulateMeasurementsDatabase();
+    }
+
+    return m_knownMeasurementsDatabase;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VApplication::RestartKnownMeasurementsDatabaseWatcher()
+{
+    if (m_knownMeasurementsDatabase != nullptr)
+    {
+        delete m_knownMeasurementsDatabaseWatcher;
+        m_knownMeasurementsDatabaseWatcher = new QFileSystemWatcher({settings->GetPathKnownMeasurements()}, this);
+        connect(m_knownMeasurementsDatabaseWatcher, &QFileSystemWatcher::directoryChanged, this,
+                &VApplication::RepopulateMeasurementsDatabase);
+    }
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 auto VApplication::TrVars() -> const VTranslateVars *
 {
@@ -691,35 +721,36 @@ void VApplication::InitTrVars()
 //---------------------------------------------------------------------------------------------------------------------
 auto VApplication::event(QEvent *e) -> bool
 {
-    switch(e->type())
+    switch (e->type())
     {
         // In Mac OS X the QFileOpenEvent event is generated when user perform "Open With" from Finder (this event is
         // Mac specific).
         case QEvent::FileOpen:
         {
             auto *fileOpenEvent = dynamic_cast<QFileOpenEvent *>(e);
-            const QString macFileOpen = fileOpenEvent->file();
-            if(not macFileOpen.isEmpty())
+            if (const QString macFileOpen = fileOpenEvent->file(); not macFileOpen.isEmpty())
             {
-                auto *window = qobject_cast<MainWindow*>(mainWindow);
-                if (window)
+                if (auto *window = qobject_cast<MainWindow *>(mainWindow); window != nullptr)
                 {
-                    window->LoadPattern(macFileOpen);  // open file in existing window
+                    window->LoadPattern(macFileOpen); // open file in existing window
                 }
                 return true;
             }
             break;
         }
 #if defined(Q_OS_MAC)
-        case QEvent::ApplicationActivate:
-        {
-            if (mainWindow && not mainWindow->isMinimized())
+        case QEvent::ApplicationStateChange:
+            // NOLINTNEXTLINE(cppcoreguidelines-pro-type-static-cast-downcast)
+            if (static_cast<QApplicationStateChangeEvent *>(e)->applicationState() == Qt::ApplicationActive)
             {
-                mainWindow->show();
+                if (mainWindow && not mainWindow->isMinimized())
+                {
+                    mainWindow->show();
+                }
+                return true;
             }
-            return true;
-        }
-#endif //defined(Q_OS_MAC)
+            break;
+#endif // defined(Q_OS_MAC)
         default:
             return VAbstractApplication::event(e);
     }
@@ -735,6 +766,27 @@ void VApplication::AboutToQuit()
     Settings()->sync();
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void VApplication::RepopulateMeasurementsDatabase(const QString &path)
+{
+    Q_UNUSED(path)
+    if (m_knownMeasurementsDatabase != nullptr)
+    {
+        QFuture<void> const future =
+            QtConcurrent::run([this]() { m_knownMeasurementsDatabase->PopulateMeasurementsDatabase(); });
+    }
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VApplication::KnownMeasurementsPathChanged(const QString &oldPath, const QString &newPath)
+{
+    if (oldPath != newPath && m_knownMeasurementsDatabase != nullptr)
+    {
+        RestartKnownMeasurementsDatabaseWatcher();
+        RepopulateMeasurementsDatabase(newPath);
+    }
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 auto VApplication::IsGUIMode() -> bool
 {
@@ -756,10 +808,18 @@ auto VApplication::IsPedantic() const -> bool
     return (VCommandLine::instance != nullptr) && VCommandLine::instance->IsPedantic();
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void VApplication::OpenSettings()
+{
+    VAbstractValApplication::OpenSettings();
+    connect(settings, &VValentinaSettings::KnownMeasurementsPathChanged, this,
+            &VApplication::KnownMeasurementsPathChanged);
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 auto VApplication::VApp() -> VApplication *
 {
-    return qobject_cast<VApplication*>(QCoreApplication::instance());
+    return qobject_cast<VApplication *>(QCoreApplication::instance());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
