@@ -30,13 +30,9 @@
 
 #include <QDialog>
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 13, 0)
-#include "../vmisc/defglobal.h"
-#endif // QT_VERSION < QT_VERSION_CHECK(5, 13, 0)
-
 namespace Ui
 {
-    class DialogAddBackgroundImage;
+class DialogAddBackgroundImage;
 }
 
 class DialogAddBackgroundImage : public QDialog
