@@ -27,26 +27,31 @@
  *************************************************************************/
 
 #include "dialogfinalmeasurements.h"
-#include "ui_dialogfinalmeasurements.h"
-#include "../vmisc/vvalentinasettings.h"
-#include "../vmisc/compatibility.h"
-#include "../vmisc/vabstractvalapplication.h"
 #include "../qmuparser/qmudef.h"
+#include "../vmisc/compatibility.h"
+#include "../vmisc/theme/themeDef.h"
+#include "../vmisc/theme/vtheme.h"
+#include "../vmisc/vabstractvalapplication.h"
+#include "../vmisc/vvalentinasettings.h"
 #include "../vpatterndb/calculator.h"
+#include "../vtools/dialogs/dialogtoolbox.h"
 #include "../vtools/dialogs/support/dialogeditwrongformula.h"
+#include "ui_dialogfinalmeasurements.h"
+
 #include <QMenu>
-#include <qnumeric.h>
+
+using namespace Qt::Literals::StringLiterals;
 
 constexpr int DIALOG_MAX_FORMULA_HEIGHT = 64;
 
 //---------------------------------------------------------------------------------------------------------------------
 DialogFinalMeasurements::DialogFinalMeasurements(VPattern *doc, QWidget *parent)
-    : QDialog(parent),
-      ui(new Ui::DialogFinalMeasurements),
-      m_doc(doc),
-      m_data(doc->GetCompleteData()),
-      m_measurements(doc->GetFinalMeasurements()),
-      m_searchHistory(new QMenu(this))
+  : QDialog(parent),
+    ui(new Ui::DialogFinalMeasurements),
+    m_doc(doc),
+    m_data(doc->GetCompleteData()),
+    m_measurements(doc->GetFinalMeasurements()),
+    m_searchHistory(new QMenu(this))
 {
     ui->setupUi(this);
 
@@ -54,6 +59,10 @@ DialogFinalMeasurements::DialogFinalMeasurements(VPattern *doc, QWidget *parent)
     setWindowFlags(Qt::Window);
 #endif
 
+    InitIcons();
+
+    m_data.FillPiecesAreas(VAbstractValApplication::VApp()->patternUnits());
+
     ui->lineEditName->setClearButtonEnabled(true);
 
     ui->lineEditFind->installEventFilter(this);
@@ -73,7 +82,7 @@ DialogFinalMeasurements::DialogFinalMeasurements(VPattern *doc, QWidget *parent)
     connect(m_doc, &VPattern::FullUpdateFromFile, this, &DialogFinalMeasurements::FullUpdateFromFile);
 
     ui->lineEditName->setValidator(
-        new QRegularExpressionValidator(QRegularExpression(QStringLiteral("^$|")+NameRegExp()), this));
+        new QRegularExpressionValidator(QRegularExpression(QStringLiteral("^$|") + NameRegExp()), this));
 
     connect(ui->tableWidget, &QTableWidget::itemSelectionChanged, this,
             &DialogFinalMeasurements::ShowFinalMeasurementDetails);
@@ -93,6 +102,20 @@ DialogFinalMeasurements::DialogFinalMeasurements(VPattern *doc, QWidget *parent)
     {
         ui->tableWidget->selectRow(0);
     }
+
+    m_shortcuts.insert(VShortcutAction::CaseSensitiveMatch, ui->toolButtonCaseSensitive);
+    m_shortcuts.insert(VShortcutAction::WholeWordMatch, ui->toolButtonWholeWord);
+    m_shortcuts.insert(VShortcutAction::RegexMatch, ui->toolButtonRegexp);
+    m_shortcuts.insert(VShortcutAction::SearchHistory, ui->pushButtonSearch);
+    m_shortcuts.insert(VShortcutAction::RegexMatchUnicodeProperties, ui->toolButtonUseUnicodeProperties);
+    m_shortcuts.insert(VShortcutAction::FindNext, ui->toolButtonFindNext);
+    m_shortcuts.insert(VShortcutAction::FindPrevious, ui->toolButtonFindNext);
+
+    if (VAbstractShortcutManager *manager = VAbstractApplication::VApp()->GetShortcutManager())
+    {
+        connect(manager, &VAbstractShortcutManager::ShortcutsUpdated, this, &DialogFinalMeasurements::UpdateShortcuts);
+        UpdateShortcuts();
+    }
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -129,6 +152,13 @@ void DialogFinalMeasurements::changeEvent(QEvent *event)
         UpdateSearchControlsTooltips();
         FullUpdateFromFile();
     }
+
+    if (event->type() == QEvent::PaletteChange)
+    {
+        InitIcons();
+        InitDialogButtonBoxIcons(ui->buttonBox);
+    }
+
     // remember to call base class implementation
     QDialog::changeEvent(event);
 }
@@ -145,11 +175,11 @@ auto DialogFinalMeasurements::eventFilter(QObject *object, QEvent *event) -> boo
             {
                 if (VAbstractApplication::VApp()->Settings()->GetOsSeparator())
                 {
-                    textEdit->insert(QLocale().decimalPoint());
+                    textEdit->insert(LocaleDecimalPoint(QLocale()));
                 }
                 else
                 {
-                    textEdit->insert(QLocale::c().decimalPoint());
+                    textEdit->insert(LocaleDecimalPoint(QLocale::c()));
                 }
                 return true;
             }
@@ -160,14 +190,14 @@ auto DialogFinalMeasurements::eventFilter(QObject *object, QEvent *event) -> boo
         // pass the event on to the parent class
         return QDialog::eventFilter(object, event);
     }
-    return false;// pass the event to the widget // clazy:exclude=base-class-event
+    return false; // pass the event to the widget // clazy:exclude=base-class-event
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void DialogFinalMeasurements::showEvent(QShowEvent *event)
 {
     QDialog::showEvent(event);
-    if ( event->spontaneous() )
+    if (event->spontaneous())
     {
         return;
     }
@@ -178,13 +208,12 @@ void DialogFinalMeasurements::showEvent(QShowEvent *event)
     }
     // do your init stuff here
 
-    const QSize sz = VAbstractApplication::VApp()->Settings()->GetFinalMeasurementsDialogSize();
-    if (not sz.isEmpty())
+    if (const QSize sz = VAbstractApplication::VApp()->Settings()->GetFinalMeasurementsDialogSize(); not sz.isEmpty())
     {
         resize(sz);
     }
 
-    m_isInitialized = true;//first show windows are held
+    m_isInitialized = true; // first show windows are held
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -221,7 +250,7 @@ void DialogFinalMeasurements::ShowFinalMeasurementDetails()
         ui->plainTextEditFormula->blockSignals(true);
 
         const QString formula =
-                VTranslateVars::TryFormulaToUser(m.formula, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+            VTranslateVars::TryFormulaToUser(m.formula, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
 
         ui->plainTextEditFormula->setPlainText(formula);
         ui->plainTextEditFormula->blockSignals(false);
@@ -235,11 +264,11 @@ void DialogFinalMeasurements::ShowFinalMeasurementDetails()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogFinalMeasurements::Add()
 {
-    const int currentRow = ui->tableWidget->currentRow()+1;
+    const int currentRow = ui->tableWidget->currentRow() + 1;
 
     VFinalMeasurement m;
     m.name = tr("measurement");
-    m.formula = QLatin1Char('0');
+    m.formula = '0'_L1;
 
     m_measurements.append(m);
 
@@ -283,10 +312,10 @@ void DialogFinalMeasurements::MoveUp()
         return;
     }
 
-    Move(m_measurements, row, row-1);
+    m_measurements.move(row, row - 1);
     UpdateTree();
 
-    ui->tableWidget->selectRow(row-1);
+    ui->tableWidget->selectRow(row - 1);
     ui->tableWidget->repaint(); // Force repain to fix paint artifacts on Mac OS X
 }
 
@@ -295,15 +324,15 @@ void DialogFinalMeasurements::MoveDown()
 {
     const int row = ui->tableWidget->currentRow();
 
-    if (row == -1 || row == ui->tableWidget->rowCount()-1 || row >= m_measurements.size())
+    if (row == -1 || row == ui->tableWidget->rowCount() - 1 || row >= m_measurements.size())
     {
         return;
     }
 
-    Move(m_measurements, row, row+1);
+    m_measurements.move(row, row + 1);
     UpdateTree();
 
-    ui->tableWidget->selectRow(row+1);
+    ui->tableWidget->selectRow(row + 1);
     ui->tableWidget->repaint(); // Force repain to fix paint artifacts on Mac OS X
 }
 
@@ -359,21 +388,20 @@ void DialogFinalMeasurements::SaveFormula()
     }
 
     // Replace line return character with spaces for calc if exist
-    QString text = ui->plainTextEditFormula->toPlainText();
+    QString const text = ui->plainTextEditFormula->toPlainText();
 
-    QTableWidgetItem *formulaField = ui->tableWidget->item(row, 2);
-    if (formulaField->text() == text)
+    if (QTableWidgetItem *formulaField = ui->tableWidget->item(row, 2); formulaField->text() == text)
     {
         QTableWidgetItem *result = ui->tableWidget->item(row, 1);
-        //Show unit in dialog lable (cm, mm or inch)
+        // Show unit in dialog lable (cm, mm or inch)
         const QString postfix = UnitsToStr(VAbstractValApplication::VApp()->patternUnits());
-        ui->labelCalculatedValue->setText(result->text() + QChar(QChar::Space) +postfix);
+        ui->labelCalculatedValue->setText(result->text() + QChar(QChar::Space) + postfix);
         return;
     }
 
     if (text.isEmpty())
     {
-        //Show unit in dialog lable (cm, mm or inch)
+        // Show unit in dialog lable (cm, mm or inch)
         const QString postfix = UnitsToStr(VAbstractValApplication::VApp()->patternUnits());
         ui->labelCalculatedValue->setText(tr("Error") + " (" + postfix + "). " + tr("Empty field."));
         return;
@@ -386,8 +414,8 @@ void DialogFinalMeasurements::SaveFormula()
 
     try
     {
-        m_measurements[row].formula = VAbstractApplication::VApp()->TrVars()
-                ->FormulaFromUser(text, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+        m_measurements[row].formula = VAbstractApplication::VApp()->TrVars()->FormulaFromUser(
+            text, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
     }
     catch (qmu::QmuParserError &e) // Just in case something bad will happen
     {
@@ -413,16 +441,14 @@ void DialogFinalMeasurements::DeployFormula()
     if (ui->plainTextEditFormula->height() < DIALOG_MAX_FORMULA_HEIGHT)
     {
         ui->plainTextEditFormula->setFixedHeight(DIALOG_MAX_FORMULA_HEIGHT);
-        //Set icon from theme (internal for Windows system)
-        ui->pushButtonGrow->setIcon(QIcon::fromTheme(QStringLiteral("go-next"),
-                                                     QIcon(":/icons/win.icon.theme/16x16/actions/go-next.png")));
+        // Set icon from theme (internal for Windows system)
+        ui->pushButtonGrow->setIcon(FromTheme(VThemeIcon::GoNext));
     }
     else
     {
-       ui->plainTextEditFormula->setFixedHeight(formulaBaseHeight);
-       //Set icon from theme (internal for Windows system)
-       ui->pushButtonGrow->setIcon(QIcon::fromTheme(QStringLiteral("go-down"),
-                                                    QIcon(":/icons/win.icon.theme/16x16/actions/go-down.png")));
+        ui->plainTextEditFormula->setFixedHeight(formulaBaseHeight);
+        // Set icon from theme (internal for Windows system)
+        ui->pushButtonGrow->setIcon(FromTheme(VThemeIcon::GoDown));
     }
 
     // I found that after change size of formula field, it was filed for angle formula, field for formula became black.
@@ -445,12 +471,13 @@ void DialogFinalMeasurements::Fx()
         return;
     }
 
-    QScopedPointer<DialogEditWrongFormula> dialog(new DialogEditWrongFormula(&m_data, NULL_ID, this));
+    QScopedPointer<DialogEditWrongFormula> const dialog(new DialogEditWrongFormula(&m_data, NULL_ID, this));
     dialog->setWindowTitle(tr("Edit measurement"));
     dialog->SetFormula(VTranslateVars::TryFormulaFromUser(ui->plainTextEditFormula->toPlainText(),
                                                           VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
+    dialog->ShowPieceArea(true);
     const QString postfix = UnitsToStr(VAbstractValApplication::VApp()->patternUnits(), true);
-    dialog->setPostfix(postfix);//Show unit in dialog lable (cm, mm or inch)
+    dialog->setPostfix(postfix); // Show unit in dialog lable (cm, mm or inch)
 
     if (dialog->exec() == QDialog::Accepted)
     {
@@ -466,6 +493,7 @@ void DialogFinalMeasurements::Fx()
 void DialogFinalMeasurements::FullUpdateFromFile()
 {
     m_data = m_doc->GetCompleteData();
+    m_data.FillPiecesAreas(VAbstractValApplication::VApp()->patternUnits());
     m_measurements = m_doc->GetFinalMeasurements();
 
     FillFinalMeasurements();
@@ -473,14 +501,24 @@ void DialogFinalMeasurements::FullUpdateFromFile()
     m_search->RefreshList(ui->lineEditFind->text());
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void DialogFinalMeasurements::UpdateShortcuts()
+{
+    if (VAbstractShortcutManager *manager = VAbstractApplication::VApp()->GetShortcutManager())
+    {
+        manager->UpdateButtonShortcut(m_shortcuts);
+        UpdateSearchControlsTooltips();
+    }
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void DialogFinalMeasurements::FillFinalMeasurements(bool freshCall)
 {
     ui->tableWidget->blockSignals(true);
     ui->tableWidget->clearContents();
 
-    ui->tableWidget->setRowCount(m_measurements.size());
-    for (int i=0; i < m_measurements.size(); ++i)
+    ui->tableWidget->setRowCount(static_cast<int>(m_measurements.size()));
+    for (int i = 0; i < m_measurements.size(); ++i)
     {
         const VFinalMeasurement &m = m_measurements.at(i);
 
@@ -488,14 +526,12 @@ void DialogFinalMeasurements::FillFinalMeasurements(bool freshCall)
 
         bool ok = true;
         const qreal result = EvalFormula(m.formula, ok);
-        AddCell(VAbstractApplication::VApp()
-                ->LocaleToString(result), i, 1, Qt::AlignHCenter | Qt::AlignVCenter, ok); // calculated value
+        AddCell(VAbstractApplication::VApp()->LocaleToString(result), i, 1, Qt::AlignHCenter | Qt::AlignVCenter,
+                ok); // calculated value
 
         const QString formula =
-                VTranslateVars::TryFormulaFromUser(m.formula,
-                                                   VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+            VTranslateVars::TryFormulaFromUser(m.formula, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
         AddCell(formula, i, 2, Qt::AlignVCenter); // formula
-
     }
 
     if (freshCall)
@@ -515,14 +551,14 @@ void DialogFinalMeasurements::ShowUnits()
     {
         // calculated value
         const QString header = ui->tableWidget->horizontalHeaderItem(1)->text();
-        const QString unitHeader = QStringLiteral("%1 (%2)").arg(header, unit);
+        const auto unitHeader = QStringLiteral("%1 (%2)").arg(header, unit);
         ui->tableWidget->horizontalHeaderItem(1)->setText(unitHeader);
     }
 
     {
         // formula
         const QString header = ui->tableWidget->horizontalHeaderItem(2)->text();
-        const QString unitHeader = QStringLiteral("%1 (%2)").arg(header, unit);
+        const auto unitHeader = QStringLiteral("%1 (%2)").arg(header, unit);
         ui->tableWidget->horizontalHeaderItem(2)->setText(unitHeader);
     }
 }
@@ -531,7 +567,7 @@ void DialogFinalMeasurements::ShowUnits()
 void DialogFinalMeasurements::AddCell(const QString &text, int row, int column, int aligment, bool ok)
 {
     auto *item = new QTableWidgetItem(text);
-    item->setTextAlignment(aligment);
+    SetTextAlignment(item, static_cast<Qt::Alignment>(aligment));
 
     // set the item non-editable (view only), and non-selectable
     Qt::ItemFlags flags = item->flags();
@@ -552,7 +588,7 @@ void DialogFinalMeasurements::AddCell(const QString &text, int row, int column,
 auto DialogFinalMeasurements::EvalUserFormula(const QString &formula, bool fromUser) -> bool
 {
     const QString postfix =
-            UnitsToStr(VAbstractValApplication::VApp()->patternUnits());//Show unit in dialog lable (cm, mm or inch)
+        UnitsToStr(VAbstractValApplication::VApp()->patternUnits()); // Show unit in dialog lable (cm, mm or inch)
     if (formula.isEmpty())
     {
         ui->labelCalculatedValue->setText(tr("Error") + " (" + postfix + "). " + tr("Empty field."));
@@ -566,14 +602,14 @@ auto DialogFinalMeasurements::EvalUserFormula(const QString &formula, bool fromU
         // Replace line return character with spaces for calc if exist
         if (fromUser)
         {
-            f = VAbstractApplication::VApp()->TrVars()
-                    ->FormulaFromUser(formula, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+            f = VAbstractApplication::VApp()->TrVars()->FormulaFromUser(
+                formula, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
         }
         else
         {
             f = formula;
         }
-        QScopedPointer<Calculator> cal(new Calculator());
+        QScopedPointer<Calculator> const cal(new Calculator());
         const qreal result = cal->EvalFormula(m_data.DataVariables(), f);
 
         if (qIsInf(result) || qIsNaN(result))
@@ -584,8 +620,8 @@ auto DialogFinalMeasurements::EvalUserFormula(const QString &formula, bool fromU
             return false;
         }
 
-        ui->labelCalculatedValue->setText(
-                    VAbstractApplication::VApp()->LocaleToString(result) + QChar(QChar::Space) + postfix);
+        ui->labelCalculatedValue->setText(VAbstractApplication::VApp()->LocaleToString(result) + QChar(QChar::Space) +
+                                          postfix);
         ui->labelCalculatedValue->setToolTip(tr("Value"));
         return true;
     }
@@ -610,7 +646,7 @@ void DialogFinalMeasurements::Controls()
             ui->toolButtonUp->setEnabled(false);
             ui->toolButtonDown->setEnabled(true);
         }
-        else if (ui->tableWidget->currentRow() == ui->tableWidget->rowCount()-1)
+        else if (ui->tableWidget->currentRow() == ui->tableWidget->rowCount() - 1)
         {
             ui->toolButtonUp->setEnabled(true);
             ui->toolButtonDown->setEnabled(false);
@@ -671,7 +707,7 @@ void DialogFinalMeasurements::EnableDetails(bool enabled)
 //---------------------------------------------------------------------------------------------------------------------
 void DialogFinalMeasurements::UpdateTree()
 {
-    int row = ui->tableWidget->currentRow();
+    int const row = ui->tableWidget->currentRow();
     FillFinalMeasurements();
     ui->tableWidget->blockSignals(true);
     ui->tableWidget->selectRow(row);
@@ -693,7 +729,7 @@ auto DialogFinalMeasurements::EvalFormula(const QString &formula, bool &ok) -> q
     try
     {
         // Replace line return character with spaces for calc if exist
-        QScopedPointer<Calculator> cal(new Calculator());
+        QScopedPointer<Calculator> const cal(new Calculator());
         result = cal->EvalFormula(m_data.DataVariables(), formula);
 
         if (qIsInf(result) || qIsNaN(result))
@@ -727,105 +763,115 @@ void DialogFinalMeasurements::InitSearch()
 
     UpdateSearchControlsTooltips();
 
-    connect(ui->lineEditFind, &QLineEdit::textEdited, this, [this](const QString &term){m_search->Find(term);});
-    connect(ui->lineEditFind, &QLineEdit::editingFinished, this, [this]()
-    {
-        SaveSearchRequest();
-        InitSearchHistory();
-        m_search->Find(ui->lineEditFind->text());
-    });
-    connect(ui->toolButtonFindPrevious, &QToolButton::clicked, this, [this]()
-    {
-        SaveSearchRequest();
-        InitSearchHistory();
-        m_search->FindPrevious();
-        ui->labelResults->setText(QStringLiteral("%1/%2").arg(m_search->MatchIndex()+1).arg(m_search->MatchCount()));
-    });
-    connect(ui->toolButtonFindNext, &QToolButton::clicked, this, [this]()
-    {
-        SaveSearchRequest();
-        InitSearchHistory();
-        m_search->FindNext();
-        ui->labelResults->setText(QStringLiteral("%1/%2").arg(m_search->MatchIndex()+1).arg(m_search->MatchCount()));
-    });
+    connect(ui->lineEditFind, &QLineEdit::textEdited, this, [this](const QString &term) { m_search->Find(term); });
+    connect(ui->lineEditFind, &QLineEdit::editingFinished, this,
+            [this]()
+            {
+                SaveSearchRequest();
+                InitSearchHistory();
+                m_search->Find(ui->lineEditFind->text());
+            });
+    connect(ui->toolButtonFindPrevious, &QToolButton::clicked, this,
+            [this]()
+            {
+                SaveSearchRequest();
+                InitSearchHistory();
+                m_search->FindPrevious();
+                ui->labelResults->setText(
+                    QStringLiteral("%1/%2").arg(m_search->MatchIndex() + 1).arg(m_search->MatchCount()));
+            });
+    connect(ui->toolButtonFindNext, &QToolButton::clicked, this,
+            [this]()
+            {
+                SaveSearchRequest();
+                InitSearchHistory();
+                m_search->FindNext();
+                ui->labelResults->setText(
+                    QStringLiteral("%1/%2").arg(m_search->MatchIndex() + 1).arg(m_search->MatchCount()));
+            });
 
-    connect(m_search.data(), &VTableSearch::HasResult, this, [this] (bool state)
-    {
-        ui->toolButtonFindPrevious->setEnabled(state);
-        ui->toolButtonFindNext->setEnabled(state);
+    connect(m_search.data(), &VTableSearch::HasResult, this,
+            [this](bool state)
+            {
+                ui->toolButtonFindPrevious->setEnabled(state);
+                ui->toolButtonFindNext->setEnabled(state);
 
-        if (state)
-        {
-            ui->labelResults->setText(
-                QStringLiteral("%1/%2").arg(m_search->MatchIndex()+1).arg(m_search->MatchCount()));
-        }
-        else
-        {
-            ui->labelResults->setText(tr("0 results"));
-        }
+                if (state)
+                {
+                    ui->labelResults->setText(
+                        QStringLiteral("%1/%2").arg(m_search->MatchIndex() + 1).arg(m_search->MatchCount()));
+                }
+                else
+                {
+                    ui->labelResults->setText(tr("0 results"));
+                }
 
-        QPalette palette;
+                QPalette palette;
 
-        if (not state && not ui->lineEditFind->text().isEmpty())
-        {
-            palette.setColor(QPalette::Text, Qt::red);
-            ui->lineEditFind->setPalette(palette);
+                if (not state && not ui->lineEditFind->text().isEmpty())
+                {
+                    palette.setColor(QPalette::Text, Qt::red);
+                    ui->lineEditFind->setPalette(palette);
 
-            palette.setColor(QPalette::Active, ui->labelResults->foregroundRole(), Qt::red);
-            palette.setColor(QPalette::Inactive, ui->labelResults->foregroundRole(), Qt::red);
-            ui->labelResults->setPalette(palette);
-        }
-        else
-        {
-            ui->lineEditFind->setPalette(palette);
-            ui->labelResults->setPalette(palette);
-        }
-    });
+                    palette.setColor(QPalette::Active, ui->labelResults->foregroundRole(), Qt::red);
+                    palette.setColor(QPalette::Inactive, ui->labelResults->foregroundRole(), Qt::red);
+                    ui->labelResults->setPalette(palette);
+                }
+                else
+                {
+                    ui->lineEditFind->setPalette(palette);
+                    ui->labelResults->setPalette(palette);
+                }
+            });
 
-    connect(ui->toolButtonCaseSensitive, &QToolButton::toggled, this, [this](bool checked)
-    {
-        m_search->SetMatchCase(checked);
-        m_search->Find(ui->lineEditFind->text());
-        ui->lineEditFind->setPlaceholderText(m_search->SearchPlaceholder());
-    });
+    connect(ui->toolButtonCaseSensitive, &QToolButton::toggled, this,
+            [this](bool checked)
+            {
+                m_search->SetMatchCase(checked);
+                m_search->Find(ui->lineEditFind->text());
+                ui->lineEditFind->setPlaceholderText(m_search->SearchPlaceholder());
+            });
 
-    connect(ui->toolButtonWholeWord, &QToolButton::toggled, this, [this](bool checked)
-    {
-        m_search->SetMatchWord(checked);
-        m_search->Find(ui->lineEditFind->text());
-        ui->lineEditFind->setPlaceholderText(m_search->SearchPlaceholder());
-    });
+    connect(ui->toolButtonWholeWord, &QToolButton::toggled, this,
+            [this](bool checked)
+            {
+                m_search->SetMatchWord(checked);
+                m_search->Find(ui->lineEditFind->text());
+                ui->lineEditFind->setPlaceholderText(m_search->SearchPlaceholder());
+            });
 
-    connect(ui->toolButtonRegexp, &QToolButton::toggled, this, [this](bool checked)
-    {
-        m_search->SetMatchRegexp(checked);
+    connect(ui->toolButtonRegexp, &QToolButton::toggled, this,
+            [this](bool checked)
+            {
+                m_search->SetMatchRegexp(checked);
 
-        if (checked)
-        {
-            ui->toolButtonWholeWord->blockSignals(true);
-            ui->toolButtonWholeWord->setChecked(false);
-            ui->toolButtonWholeWord->blockSignals(false);
-            ui->toolButtonWholeWord->setEnabled(false);
+                if (checked)
+                {
+                    ui->toolButtonWholeWord->blockSignals(true);
+                    ui->toolButtonWholeWord->setChecked(false);
+                    ui->toolButtonWholeWord->blockSignals(false);
+                    ui->toolButtonWholeWord->setEnabled(false);
 
-            ui->toolButtonUseUnicodeProperties->setEnabled(true);
-        }
-        else
-        {
-            ui->toolButtonWholeWord->setEnabled(true);
-            ui->toolButtonUseUnicodeProperties->blockSignals(true);
-            ui->toolButtonUseUnicodeProperties->setChecked(false);
-            ui->toolButtonUseUnicodeProperties->blockSignals(false);
-            ui->toolButtonUseUnicodeProperties->setEnabled(false);
-        }
-        m_search->Find(ui->lineEditFind->text());
-        ui->lineEditFind->setPlaceholderText(m_search->SearchPlaceholder());
-    });
+                    ui->toolButtonUseUnicodeProperties->setEnabled(true);
+                }
+                else
+                {
+                    ui->toolButtonWholeWord->setEnabled(true);
+                    ui->toolButtonUseUnicodeProperties->blockSignals(true);
+                    ui->toolButtonUseUnicodeProperties->setChecked(false);
+                    ui->toolButtonUseUnicodeProperties->blockSignals(false);
+                    ui->toolButtonUseUnicodeProperties->setEnabled(false);
+                }
+                m_search->Find(ui->lineEditFind->text());
+                ui->lineEditFind->setPlaceholderText(m_search->SearchPlaceholder());
+            });
 
-    connect(ui->toolButtonUseUnicodeProperties, &QToolButton::toggled, this, [this](bool checked)
-    {
-        m_search->SetUseUnicodePreperties(checked);
-        m_search->Find(ui->lineEditFind->text());
-    });
+    connect(ui->toolButtonUseUnicodeProperties, &QToolButton::toggled, this,
+            [this](bool checked)
+            {
+                m_search->SetUseUnicodePreperties(checked);
+                m_search->Find(ui->lineEditFind->text());
+            });
 
     m_searchHistory->setStyleSheet(QStringLiteral("QMenu { menu-scrollable: 1; }"));
     InitSearchHistory();
@@ -835,24 +881,33 @@ void DialogFinalMeasurements::InitSearch()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogFinalMeasurements::InitSearchHistory()
 {
-    QStringList searchHistory =
-            VAbstractValApplication::VApp()->ValentinaSettings()->GetFinalMeasurementsSearchHistory();
+    QStringList const searchHistory =
+        VAbstractValApplication::VApp()->ValentinaSettings()->GetFinalMeasurementsSearchHistory();
     m_searchHistory->clear();
-    for (const auto& term : searchHistory)
+
+    if (searchHistory.isEmpty())
+    {
+        QAction *action = m_searchHistory->addAction('<'_L1 + tr("Empty", "list") + '>'_L1);
+        action->setDisabled(true);
+        return;
+    }
+
+    for (const auto &term : searchHistory)
     {
         QAction *action = m_searchHistory->addAction(term);
         action->setData(term);
-        connect(action, &QAction::triggered, this, [this]()
-        {
-            auto *action = qobject_cast<QAction *>(sender());
-            if (action != nullptr)
-            {
-                QString term = action->data().toString();
-                ui->lineEditFind->setText(term);
-                m_search->Find(term);
-                ui->lineEditFind->setFocus();
-            }
-        });
+        connect(action, &QAction::triggered, this,
+                [this]()
+                {
+                    auto *action = qobject_cast<QAction *>(sender());
+                    if (action != nullptr)
+                    {
+                        QString const term = action->data().toString();
+                        ui->lineEditFind->setText(term);
+                        m_search->Find(term);
+                        ui->lineEditFind->setFocus();
+                    }
+                });
     }
 }
 
@@ -860,8 +915,8 @@ void DialogFinalMeasurements::InitSearchHistory()
 void DialogFinalMeasurements::SaveSearchRequest()
 {
     QStringList searchHistory =
-            VAbstractValApplication::VApp()->ValentinaSettings()->GetFinalMeasurementsSearchHistory();
-    QString term = ui->lineEditFind->text();
+        VAbstractValApplication::VApp()->ValentinaSettings()->GetFinalMeasurementsSearchHistory();
+    QString const term = ui->lineEditFind->text();
     if (term.isEmpty())
     {
         return;
@@ -879,12 +934,18 @@ void DialogFinalMeasurements::SaveSearchRequest()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogFinalMeasurements::UpdateSearchControlsTooltips()
 {
-    auto UpdateToolTip = [](QAbstractButton *button)
+    auto UpdateToolTip = [this](QAbstractButton *button)
     {
-        if (button->toolTip().contains(QLatin1String("%1")))
+        if (button->toolTip().contains("%1"_L1))
         {
+            m_serachButtonTooltips.insert(button, button->toolTip());
             button->setToolTip(button->toolTip().arg(button->shortcut().toString(QKeySequence::NativeText)));
         }
+        else if (m_serachButtonTooltips.contains(button))
+        {
+            QString const tooltip = m_serachButtonTooltips.value(button);
+            button->setToolTip(tooltip.arg(button->shortcut().toString(QKeySequence::NativeText)));
+        }
     };
 
     UpdateToolTip(ui->toolButtonCaseSensitive);
@@ -895,3 +956,11 @@ void DialogFinalMeasurements::UpdateSearchControlsTooltips()
     UpdateToolTip(ui->toolButtonFindPrevious);
     UpdateToolTip(ui->toolButtonFindNext);
 }
+
+//---------------------------------------------------------------------------------------------------------------------
+void DialogFinalMeasurements::InitIcons()
+{
+    auto const resource = QStringLiteral("icon");
+
+    ui->toolButtonExpr->setIcon(VTheme::GetIconResource(resource, QStringLiteral("24x24/fx.png")));
+}
