@@ -27,35 +27,55 @@
  *************************************************************************/
 
 #include "dialoglayoutsettings.h"
-#include "ui_dialoglayoutsettings.h"
-#include "../vmisc/vvalentinasettings.h"
-#include "../vmisc/vabstractvalapplication.h"
-#if QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
-#include "../vmisc/backport/qoverload.h"
-#endif // QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
 #include "../vlayout/vlayoutgenerator.h"
+#include "../vmisc/vabstractvalapplication.h"
+#include "../vmisc/vvalentinasettings.h"
+#include "../vwidgets/vmousewheelwidgetadjustmentguard.h"
+#include "ui_dialoglayoutsettings.h"
 
 #include <QMessageBox>
-#include <QPushButton>
 #include <QPrinterInfo>
+#include <QPushButton>
+
+#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
+#include "../vmisc/compatibility.h"
+#endif
+
+using namespace Qt::Literals::StringLiterals;
 
 //---------------------------------------------------------------------------------------------------------------------
 DialogLayoutSettings::DialogLayoutSettings(VLayoutGenerator *generator, QWidget *parent, bool disableSettings)
-    : VAbstractLayoutDialog(parent), 
-      m_disableSettings(disableSettings),
-      ui(new Ui::DialogLayoutSettings), 
-      m_oldPaperUnit(Unit::Mm),
-      m_oldLayoutUnit(Unit::Mm),
-      m_generator(generator),
-      m_isInitialized(false)
+  : VAbstractLayoutDialog(parent),
+    m_disableSettings(disableSettings),
+    ui(new Ui::DialogLayoutSettings),
+    m_oldPaperUnit(Unit::Mm),
+    m_oldLayoutUnit(Unit::Mm),
+    m_generator(generator),
+    m_isInitialized(false)
 {
     ui->setupUi(this);
 
+    // Prevent stealing focus when scrolling
+    VMouseWheelWidgetAdjustmentGuard::InstallEventFilter(ui->comboBoxTemplates);
+    VMouseWheelWidgetAdjustmentGuard::InstallEventFilter(ui->doubleSpinBoxPaperWidth);
+    VMouseWheelWidgetAdjustmentGuard::InstallEventFilter(ui->doubleSpinBoxPaperHeight);
+    VMouseWheelWidgetAdjustmentGuard::InstallEventFilter(ui->comboBoxPaperSizeUnit);
+    VMouseWheelWidgetAdjustmentGuard::InstallEventFilter(ui->comboBoxPaperSizeUnit);
+    VMouseWheelWidgetAdjustmentGuard::InstallEventFilter(ui->doubleSpinBoxLeftField);
+    VMouseWheelWidgetAdjustmentGuard::InstallEventFilter(ui->doubleSpinBoxRightField);
+    VMouseWheelWidgetAdjustmentGuard::InstallEventFilter(ui->doubleSpinBoxTopField);
+    VMouseWheelWidgetAdjustmentGuard::InstallEventFilter(ui->doubleSpinBoxBottomField);
+    VMouseWheelWidgetAdjustmentGuard::InstallEventFilter(ui->doubleSpinBoxLayoutWidth);
+    VMouseWheelWidgetAdjustmentGuard::InstallEventFilter(ui->comboBoxLayoutUnit);
+    VMouseWheelWidgetAdjustmentGuard::InstallEventFilter(ui->spinBoxNestingTime);
+    VMouseWheelWidgetAdjustmentGuard::InstallEventFilter(ui->doubleSpinBoxEfficiency);
+    VMouseWheelWidgetAdjustmentGuard::InstallEventFilter(ui->spinBoxMultiplier);
+
     VAbstractValApplication::VApp()->ValentinaSettings()->GetOsSeparator() ? setLocale(QLocale())
                                                                            : setLocale(QLocale::c());
 
-    //moved from ReadSettings - well...it seems it can be done once only (i.e. constructor) because Init funcs dont
-    //even cleanse lists before adding
+    // moved from ReadSettings - well...it seems it can be done once only (i.e. constructor) because Init funcs dont
+    // even cleanse lists before adding
     InitPaperUnits();
     InitLayoutUnits();
     InitTemplates(ui->comboBoxTemplates);
@@ -63,7 +83,7 @@ DialogLayoutSettings::DialogLayoutSettings(VLayoutGenerator *generator, QWidget
     MinimumLayoutSize();
     InitPrinter();
 
-    //in export console mode going to use defaults
+    // in export console mode going to use defaults
     if (not disableSettings)
     {
         ReadSettings();
@@ -73,35 +93,35 @@ DialogLayoutSettings::DialogLayoutSettings(VLayoutGenerator *generator, QWidget
         RestoreDefaults();
     }
 
-    connect(ui->comboBoxPrinter, QOverload<int>::of(&QComboBox::currentIndexChanged),
-            this, &DialogLayoutSettings::PrinterMargins);
+    connect(ui->comboBoxPrinter, QOverload<int>::of(&QComboBox::currentIndexChanged), this,
+            &DialogLayoutSettings::PrinterMargins);
 
-    connect(ui->comboBoxTemplates, QOverload<int>::of(&QComboBox::currentIndexChanged),
-            this, &DialogLayoutSettings::TemplateSelected);
-    connect(ui->comboBoxPaperSizeUnit, QOverload<int>::of(&QComboBox::currentIndexChanged),
-            this, &DialogLayoutSettings::ConvertPaperSize);
+    connect(ui->comboBoxTemplates, QOverload<int>::of(&QComboBox::currentIndexChanged), this,
+            &DialogLayoutSettings::TemplateSelected);
+    connect(ui->comboBoxPaperSizeUnit, QOverload<int>::of(&QComboBox::currentIndexChanged), this,
+            &DialogLayoutSettings::ConvertPaperSize);
 
-    connect(ui->doubleSpinBoxPaperWidth, QOverload<double>::of(&QDoubleSpinBox::valueChanged),
-            this, &DialogLayoutSettings::PaperSizeChanged);
-    connect(ui->doubleSpinBoxPaperHeight, QOverload<double>::of(&QDoubleSpinBox::valueChanged),
-            this, &DialogLayoutSettings::PaperSizeChanged);
+    connect(ui->doubleSpinBoxPaperWidth, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this,
+            &DialogLayoutSettings::PaperSizeChanged);
+    connect(ui->doubleSpinBoxPaperHeight, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this,
+            &DialogLayoutSettings::PaperSizeChanged);
 
-    connect(ui->doubleSpinBoxPaperWidth, QOverload<double>::of(&QDoubleSpinBox::valueChanged),
-            this, &DialogLayoutSettings::FindTemplate);
-    connect(ui->doubleSpinBoxPaperHeight, QOverload<double>::of(&QDoubleSpinBox::valueChanged),
-            this, &DialogLayoutSettings::FindTemplate);
+    connect(ui->doubleSpinBoxPaperWidth, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this,
+            &DialogLayoutSettings::FindTemplate);
+    connect(ui->doubleSpinBoxPaperHeight, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this,
+            &DialogLayoutSettings::FindTemplate);
 
-    connect(ui->doubleSpinBoxPaperWidth, QOverload<double>::of(&QDoubleSpinBox::valueChanged),
-            this, &DialogLayoutSettings::CorrectMaxFileds);
-    connect(ui->doubleSpinBoxPaperHeight, QOverload<double>::of(&QDoubleSpinBox::valueChanged),
-            this, &DialogLayoutSettings::CorrectMaxFileds);
+    connect(ui->doubleSpinBoxPaperWidth, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this,
+            &DialogLayoutSettings::CorrectMaxFileds);
+    connect(ui->doubleSpinBoxPaperHeight, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this,
+            &DialogLayoutSettings::CorrectMaxFileds);
 
     connect(ui->checkBoxIgnoreFileds, &QCheckBox::stateChanged, this, &DialogLayoutSettings::IgnoreAllFields);
 
     connect(ui->toolButtonPortrait, &QToolButton::toggled, this, &DialogLayoutSettings::Swap);
     connect(ui->toolButtonLandscape, &QToolButton::toggled, this, &DialogLayoutSettings::Swap);
-    connect(ui->comboBoxLayoutUnit,  QOverload<int>::of(&QComboBox::currentIndexChanged),
-            this, &DialogLayoutSettings::ConvertLayoutSize);
+    connect(ui->comboBoxLayoutUnit, QOverload<int>::of(&QComboBox::currentIndexChanged), this,
+            &DialogLayoutSettings::ConvertLayoutSize);
 
     QPushButton *bOk = ui->buttonBox->button(QDialogButtonBox::Ok);
     connect(bOk, &QPushButton::clicked, this, &DialogLayoutSettings::DialogAccepted);
@@ -377,6 +397,30 @@ void DialogLayoutSettings::SetNestQuantity(bool state)
     ui->checkBoxNestQuantity->setChecked(state);
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void DialogLayoutSettings::SetBoundaryTogetherWithNotches(bool value)
+{
+    ui->checkBoxTogetherWithNotches->setChecked(value);
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto DialogLayoutSettings::IsBoundaryTogetherWithNotches() const -> bool
+{
+    return ui->checkBoxTogetherWithNotches->isChecked();
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void DialogLayoutSettings::SetShowLayoutAllowance(bool value)
+{
+    ui->checkBoxShowLayoutAllowance->setChecked(value);
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto DialogLayoutSettings::IsShowLayoutAllowance() const -> bool
+{
+    return ui->checkBoxShowLayoutAllowance->isChecked();
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 auto DialogLayoutSettings::SelectedPrinter() const -> QString
 {
@@ -406,15 +450,14 @@ void DialogLayoutSettings::FindTemplate()
 
     const Unit paperUnit = PaperUnit();
 
-    const int max = static_cast<int>(PaperSizeTemplate::Custom);
-    for (int i=0; i < max; ++i)
+    const auto max = static_cast<int>(PaperSizeTemplate::Custom);
+    for (int i = 0; i < max; ++i)
     {
         const QSizeF tmplSize = GetTemplateSize(static_cast<PaperSizeTemplate>(i), paperUnit);
         if (QSizeF(width, height) == tmplSize || QSizeF(height, width) == tmplSize)
         {
             ui->comboBoxTemplates->blockSignals(true);
-            const int index = ui->comboBoxTemplates->findData(i);
-            if (index != -1)
+            if (const int index = ui->comboBoxTemplates->findData(i); index != -1)
             {
                 ui->comboBoxTemplates->setCurrentIndex(index);
             }
@@ -424,8 +467,7 @@ void DialogLayoutSettings::FindTemplate()
     }
 
     ui->comboBoxTemplates->blockSignals(true);
-    const int index = ui->comboBoxTemplates->findData(max);
-    if (index != -1)
+    if (const int index = ui->comboBoxTemplates->findData(max); index != -1)
     {
         ui->comboBoxTemplates->setCurrentIndex(index);
     }
@@ -473,9 +515,9 @@ void DialogLayoutSettings::ConvertPaperSize()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-auto DialogLayoutSettings::SelectPaperUnit(const QString& units) -> bool
+auto DialogLayoutSettings::SelectPaperUnit(const QString &units) -> bool
 {
-    qint32 indexUnit = ui->comboBoxPaperSizeUnit->findData(units);
+    qint32 const indexUnit = ui->comboBoxPaperSizeUnit->findData(units);
     if (indexUnit != -1)
     {
         ui->comboBoxPaperSizeUnit->setCurrentIndex(indexUnit);
@@ -486,7 +528,7 @@ auto DialogLayoutSettings::SelectPaperUnit(const QString& units) -> bool
 //---------------------------------------------------------------------------------------------------------------------
 auto DialogLayoutSettings::SelectLayoutUnit(const QString &units) -> bool
 {
-    qint32 indexUnit = ui->comboBoxLayoutUnit->findData(units);
+    qint32 const indexUnit = ui->comboBoxLayoutUnit->findData(units);
     if (indexUnit != -1)
     {
         ui->comboBoxLayoutUnit->setCurrentIndex(indexUnit);
@@ -509,15 +551,16 @@ auto DialogLayoutSettings::PageToPixels(qreal value) const -> qreal
 //---------------------------------------------------------------------------------------------------------------------
 auto DialogLayoutSettings::MakeGroupsHelp() -> QString
 {
-    //that is REALLY dummy ... can't figure fast how to automate generation... :/
-    return tr("\n\tThree groups: big, middle, small = 0;\n\tTwo groups: big, small = 1;\n\tDescending area = 2");
+    // that is REALLY dummy ... can't figure fast how to automate generation... :/
+    return tr("\n\tThree groups: big, middle, small = 0;\n\tTwo groups: big, small = "
+              "1;\n\tDescending area = 2");
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void DialogLayoutSettings::showEvent(QShowEvent *event)
 {
-    VAbstractLayoutDialog::showEvent( event );
-    if ( event->spontaneous() )
+    VAbstractLayoutDialog::showEvent(event);
+    if (event->spontaneous())
     {
         return;
     }
@@ -528,13 +571,12 @@ void DialogLayoutSettings::showEvent(QShowEvent *event)
     }
     // do your init stuff here
 
-    const QSize sz = VAbstractApplication::VApp()->Settings()->GetLayoutSettingsDialogSize();
-    if (not sz.isEmpty())
+    if (const QSize sz = VAbstractApplication::VApp()->Settings()->GetLayoutSettingsDialogSize(); not sz.isEmpty())
     {
         resize(sz);
     }
 
-    m_isInitialized = true;//first show windows are held
+    m_isInitialized = true; // first show windows are held
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -585,9 +627,9 @@ void DialogLayoutSettings::PaperSizeChanged()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-auto DialogLayoutSettings::SelectTemplate(const PaperSizeTemplate& id) -> bool
+auto DialogLayoutSettings::SelectTemplate(const PaperSizeTemplate &id) -> bool
 {
-    int index = ui->comboBoxTemplates->findData(static_cast<VIndexType>(id));
+    int const index = ui->comboBoxTemplates->findData(static_cast<VIndexType>(id));
     if (index > -1)
     {
         ui->comboBoxTemplates->setCurrentIndex(index);
@@ -635,6 +677,8 @@ void DialogLayoutSettings::DialogAccepted()
     m_generator->SetMultiplier(GetMultiplier());
     m_generator->SetTextAsPaths(IsTextAsPaths());
     m_generator->SetNestQuantity(IsNestQuantity());
+    m_generator->SetBoundaryTogetherWithNotches(IsBoundaryTogetherWithNotches());
+    m_generator->SetShowLayoutAllowance(IsShowLayoutAllowance());
 
     if (IsIgnoreAllFields())
     {
@@ -642,8 +686,8 @@ void DialogLayoutSettings::DialogAccepted()
     }
     else
     {
-        QPrinterInfo printer = QPrinterInfo::printerInfo(ui->comboBoxPrinter->currentText());
-        if (printer.isNull())
+        if (QPrinterInfo const printer = QPrinterInfo::printerInfo(ui->comboBoxPrinter->currentText());
+            printer.isNull())
         {
             m_generator->SetPrinterFields(true, GetFields());
         }
@@ -654,11 +698,10 @@ void DialogLayoutSettings::DialogAccepted()
             if (fields.left() < minFields.left() || fields.right() < minFields.right() ||
                 fields.top() < minFields.top() || fields.bottom() < minFields.bottom())
             {
-                QMessageBox::StandardButton answer;
-                answer = QMessageBox::question(this, tr("Wrong fields."),
-                                               tr("Margins go beyond printing. \n\nApply settings anyway?"),
-                                               QMessageBox::Yes|QMessageBox::No, QMessageBox::No);
-                if (answer == QMessageBox::No)
+                if (QMessageBox::StandardButton answer = QMessageBox::question(
+                        this, tr("Wrong fields."), tr("Margins go beyond printing. \n\nApply settings anyway?"),
+                        QMessageBox::Yes | QMessageBox::No, QMessageBox::No);
+                    answer == QMessageBox::No)
                 {
                     SetMinMargins(fields, minFields);
                     m_generator->SetPrinterFields(true, GetFields());
@@ -675,7 +718,7 @@ void DialogLayoutSettings::DialogAccepted()
         }
     }
 
-    //don't want to break visual settings when cmd used
+    // don't want to break visual settings when cmd used
     if (not m_disableSettings)
     {
         WriteSettings();
@@ -687,7 +730,7 @@ void DialogLayoutSettings::DialogAccepted()
 void DialogLayoutSettings::RestoreDefaults()
 {
     ui->comboBoxTemplates->blockSignals(true);
-    ui->comboBoxTemplates->setCurrentIndex(0);//A0
+    ui->comboBoxTemplates->setCurrentIndex(0); // A0
     TemplateSelected();
     ui->comboBoxTemplates->blockSignals(false);
 
@@ -706,6 +749,7 @@ void DialogLayoutSettings::RestoreDefaults()
     SetEfficiencyCoefficient(VValentinaSettings::GetDefEfficiencyCoefficient());
     SetNestQuantity(VValentinaSettings::GetDefLayoutNestQuantity());
     SetPreferOneSheetSolution(VValentinaSettings::GetDefLayoutPreferOneSheetSolution());
+    SetBoundaryTogetherWithNotches(VValentinaSettings::GetDefLayoutBoundaryTogetherWithNotches());
 
     CorrectMaxFileds();
     IgnoreAllFields(ui->checkBoxIgnoreFileds->isChecked());
@@ -716,8 +760,8 @@ void DialogLayoutSettings::RestoreDefaults()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogLayoutSettings::PrinterMargins()
 {
-    QPrinterInfo printer = QPrinterInfo::printerInfo(ui->comboBoxPrinter->currentText());
-    if (not printer.isNull())
+    if (QPrinterInfo const printer = QPrinterInfo::printerInfo(ui->comboBoxPrinter->currentText());
+        not printer.isNull())
     {
         SetFields(GetPrinterFields(QSharedPointer<QPrinter>(new QPrinter(printer))));
     }
@@ -734,8 +778,8 @@ void DialogLayoutSettings::CorrectMaxFileds()
     const qreal height = ui->doubleSpinBoxPaperHeight->value();
 
     // 80%/2 of paper size for each field
-    const qreal widthField = (width*80.0/100.0)/2.0;
-    const qreal heightField = (height*80.0/100.0)/2.0;
+    const qreal widthField = (width * 80.0 / 100.0) / 2.0;
+    const qreal heightField = (height * 80.0 / 100.0) / 2.0;
 
     ui->doubleSpinBoxLeftField->setMaximum(widthField);
     ui->doubleSpinBoxRightField->setMaximum(widthField);
@@ -762,8 +806,8 @@ void DialogLayoutSettings::InitPaperUnits()
 
     // set default unit
     m_oldPaperUnit = StrToUnits(VAbstractValApplication::VApp()->ValentinaSettings()->GetUnit());
-    const qint32 indexUnit = ui->comboBoxPaperSizeUnit->findData(
-                VAbstractValApplication::VApp()->ValentinaSettings()->GetUnit());
+    const qint32 indexUnit =
+        ui->comboBoxPaperSizeUnit->findData(VAbstractValApplication::VApp()->ValentinaSettings()->GetUnit());
     if (indexUnit != -1)
     {
         ui->comboBoxPaperSizeUnit->setCurrentIndex(indexUnit);
@@ -779,15 +823,14 @@ void DialogLayoutSettings::InitLayoutUnits()
 
     // set default unit
     m_oldLayoutUnit = StrToUnits(VAbstractValApplication::VApp()->ValentinaSettings()->GetUnit());
-    const qint32 indexUnit = ui->comboBoxLayoutUnit->findData(
-                VAbstractValApplication::VApp()->ValentinaSettings()->GetUnit());
+    const qint32 indexUnit =
+        ui->comboBoxLayoutUnit->findData(VAbstractValApplication::VApp()->ValentinaSettings()->GetUnit());
     if (indexUnit != -1)
     {
         ui->comboBoxLayoutUnit->setCurrentIndex(indexUnit);
     }
 }
 
-
 //---------------------------------------------------------------------------------------------------------------------
 void DialogLayoutSettings::InitPrinter()
 {
@@ -801,7 +844,7 @@ void DialogLayoutSettings::InitPrinter()
     else
     {
         const int index = ui->comboBoxPrinter->findText(QPrinterInfo::defaultPrinterName());
-        if(index != -1)
+        if (index != -1)
         {
             ui->comboBoxPrinter->setCurrentIndex(index);
         }
@@ -814,19 +857,19 @@ auto DialogLayoutSettings::MakeHelpTemplateList() -> QString
     QString out = QChar('\n');
 
     auto cntr = static_cast<VIndexType>(PaperSizeTemplate::A0);
-    for (int i = 0; i < VAbstractLayoutDialog::pageFormatNames.size(); ++i)
+    for (int i = 0; i < VAbstractLayoutDialog::PageFormatNames().size(); ++i)
     {
-        if (cntr < static_cast<int>(PaperSizeTemplate::Custom))// Don't include custom template
+        if (cntr < static_cast<int>(PaperSizeTemplate::Custom)) // Don't include custom template
         {
-            out += "\t* "+VAbstractLayoutDialog::pageFormatNames.at(i)+" = "+ QString::number(cntr++);
+            out += "\t* " + VAbstractLayoutDialog::PageFormatNames().at(i) + " = " + QString::number(cntr++);
 
-            if (i < VAbstractLayoutDialog::pageFormatNames.size() - 2)
+            if (i < VAbstractLayoutDialog::PageFormatNames().size() - 2)
             {
-               out += QLatin1String(",\n");
+                out += ",\n"_L1;
             }
             else
             {
-               out += QLatin1String(".\n");
+                out += ".\n"_L1;
             }
         }
     }
@@ -840,15 +883,15 @@ auto DialogLayoutSettings::MakeHelpTiledPdfTemplateList() -> QString
 
     for (int i = 0; i <= static_cast<int>(PaperSizeTemplate::Tabloid); ++i)
     {
-        out += "\t* "+VAbstractLayoutDialog::pageFormatNames.at(i)+" = "+ QString::number(i);
+        out += "\t* " + VAbstractLayoutDialog::PageFormatNames().at(i) + " = " + QString::number(i);
 
         if (i < static_cast<int>(PaperSizeTemplate::Tabloid))
         {
-           out += QLatin1String(",\n");
+            out += ",\n"_L1;
         }
         else
         {
-           out += QLatin1String(".\n");
+            out += ".\n"_L1;
         }
     }
     return out;
@@ -857,7 +900,7 @@ auto DialogLayoutSettings::MakeHelpTiledPdfTemplateList() -> QString
 //---------------------------------------------------------------------------------------------------------------------
 auto DialogLayoutSettings::Template() -> QSizeF
 {
-    const PaperSizeTemplate temp = static_cast<PaperSizeTemplate>(ui->comboBoxTemplates->currentData().toInt());
+    const auto temp = static_cast<PaperSizeTemplate>(ui->comboBoxTemplates->currentData().toInt());
 
     const Unit paperUnit = PaperUnit();
 
@@ -911,8 +954,8 @@ auto DialogLayoutSettings::GetTemplateSize(const PaperSizeTemplate &tmpl, const
 //---------------------------------------------------------------------------------------------------------------------
 auto DialogLayoutSettings::MinPrinterFields() const -> QMarginsF
 {
-    QPrinterInfo printer = QPrinterInfo::printerInfo(ui->comboBoxPrinter->currentText());
-    if (not printer.isNull())
+    if (QPrinterInfo const printer = QPrinterInfo::printerInfo(ui->comboBoxPrinter->currentText());
+        not printer.isNull())
     {
         return GetMinPrinterFields(QSharedPointer<QPrinter>(new QPrinter(printer)));
     }
@@ -923,8 +966,8 @@ auto DialogLayoutSettings::MinPrinterFields() const -> QMarginsF
 //---------------------------------------------------------------------------------------------------------------------
 auto DialogLayoutSettings::GetDefPrinterFields() const -> QMarginsF
 {
-    QPrinterInfo printer = QPrinterInfo::printerInfo(ui->comboBoxPrinter->currentText());
-    if (not printer.isNull())
+    if (QPrinterInfo const printer = QPrinterInfo::printerInfo(ui->comboBoxPrinter->currentText());
+        not printer.isNull())
     {
         return GetPrinterFields(QSharedPointer<QPrinter>(new QPrinter(printer)));
     }
@@ -1032,6 +1075,7 @@ void DialogLayoutSettings::ReadSettings()
     SetMultiplier(settings->GetMultiplier());
     SetTextAsPaths(settings->GetTextAsPaths());
     SetNestQuantity(settings->GetLayoutNestQuantity());
+    SetBoundaryTogetherWithNotches(settings->GetLayoutBoundaryTogetherWithNotches());
 
     FindTemplate();
 
@@ -1062,6 +1106,7 @@ void DialogLayoutSettings::WriteSettings() const
     settings->SetNestingTime(GetNestingTime());
     settings->SetEfficiencyCoefficient(GetEfficiencyCoefficient());
     settings->SetLayoutNestQuantity(IsNestQuantity());
+    settings->SetLayoutBoundaryTogetherWithNotches(IsBoundaryTogetherWithNotches());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -1108,7 +1153,6 @@ void DialogLayoutSettings::SetMinMargins(const QMarginsF &fields, const QMargins
 
     if (fields.bottom() < minFields.bottom())
     {
-        ui->doubleSpinBoxBottomField->setValue(UnitConvertor(minFields.bottom(), Unit::Px,
-                                                             LayoutUnit()));
+        ui->doubleSpinBoxBottomField->setValue(UnitConvertor(minFields.bottom(), Unit::Px, LayoutUnit()));
     }
 }
