@@ -29,36 +29,40 @@
 #include "dialogpatternproperties.h"
 #include "ui_dialogpatternproperties.h"
 #include <QBuffer>
-#include <QPushButton>
-#include <QFileDialog>
-#include <QMenu>
-#include <QDate>
-#include <QMessageBox>
-#include <QRadioButton>
 #include <QCompleter>
-#include <QSet>
-#include <QImageReader>
-#include <QMimeType>
+#include <QDate>
 #include <QDesktopServices>
+#include <QFileDialog>
+#include <QImageReader>
+#include <QMenu>
+#include <QMessageBox>
+#include <QMimeType>
+#include <QPushButton>
+#include <QRadioButton>
+#include <QSet>
 #include <QUrl>
 
-#include "../xml/vpattern.h"
-#include "../vpatterndb/vcontainer.h"
 #include "../core/vapplication.h"
-#include "../vmisc/vvalentinasettings.h"
-#if QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
-#include "../vmisc/backport/qoverload.h"
-#endif // QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
-#include "../qmuparser/qmudef.h"
-#include "../ifc/xml/vpatternimage.h"
 #include "../ifc/xml/utils.h"
+#include "../ifc/xml/vpatternimage.h"
+#include "../qmuparser/qmudef.h"
+#include "../vmisc/vabstractvalapplication.h"
+#include "../vmisc/vvalentinasettings.h"
+#include "../vpatterndb/vcontainer.h"
+#include "../xml/vpattern.h"
+
+#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
+#include "../vmisc/compatibility.h"
+#endif
+
+using namespace Qt::Literals::StringLiterals;
 
 //---------------------------------------------------------------------------------------------------------------------
-DialogPatternProperties::DialogPatternProperties(VPattern *doc,  VContainer *pattern, QWidget *parent)
-    : QDialog(parent),
-      ui(new Ui::DialogPatternProperties),
-      m_doc(doc),
-      m_pattern(pattern)
+DialogPatternProperties::DialogPatternProperties(VPattern *doc, VContainer *pattern, QWidget *parent)
+  : QDialog(parent),
+    ui(new Ui::DialogPatternProperties),
+    m_doc(doc),
+    m_pattern(pattern)
 {
     ui->setupUi(this);
 
@@ -85,13 +89,11 @@ DialogPatternProperties::DialogPatternProperties(VPattern *doc,  VContainer *pat
     }
     ui->lineEditPathToFile->setCursorPosition(0);
 
-    connect(ui->pushButtonShowInExplorer, &QPushButton::clicked, this, []()
-    {
-        ShowInGraphicalShell(VAbstractValApplication::VApp()->GetPatternPath());
-    });
+    connect(ui->pushButtonShowInExplorer, &QPushButton::clicked, this,
+            []() { ShowInGraphicalShell(VAbstractValApplication::VApp()->GetPatternPath()); });
 #if defined(Q_OS_MAC)
     ui->pushButtonShowInExplorer->setText(tr("Show in Finder"));
-#endif //defined(Q_OS_MAC)
+#endif // defined(Q_OS_MAC)
 
     //----------------------- Label language
     for (auto &name : VApplication::LabelLanguages())
@@ -99,9 +101,9 @@ DialogPatternProperties::DialogPatternProperties(VPattern *doc,  VContainer *pat
         ui->comboBoxLabelLanguage->addItem(QLocale(name).nativeLanguageName(), name);
     }
 
-    int index = ui->comboBoxLabelLanguage->findData(
-                VAbstractValApplication::VApp()->ValentinaSettings()->GetLabelLanguage());
-    if (index != -1)
+    if (int const index = ui->comboBoxLabelLanguage->findData(
+            VAbstractValApplication::VApp()->ValentinaSettings()->GetLabelLanguage());
+        index != -1)
     {
         ui->comboBoxLabelLanguage->setCurrentIndex(index);
     }
@@ -131,41 +133,74 @@ DialogPatternProperties::DialogPatternProperties(VPattern *doc,  VContainer *pat
     ui->checkBoxPatternReadOnly->setChecked(readOnly);
     if (not readOnly)
     {
-        connect(ui->checkBoxPatternReadOnly, &QRadioButton::toggled, this, [this](){m_securityChanged = true;});
+        connect(ui->checkBoxPatternReadOnly, &QRadioButton::toggled, this, [this]() { m_securityChanged = true; });
     }
     else
     {
         ui->checkBoxPatternReadOnly->setDisabled(true);
     }
 
-    //----------------------- Passmark length
     m_variables = pattern->DataMeasurements().keys() + pattern->DataIncrements().keys();
-    m_completer = new QCompleter(m_variables, this);
-    m_completer->setCompletionMode(QCompleter::PopupCompletion);
-    m_completer->setModelSorting(QCompleter::UnsortedModel);
-    m_completer->setFilterMode(Qt::MatchContains);
-    m_completer->setCaseSensitivity(Qt::CaseSensitive);
-    connect(m_completer, QOverload<const QString &>::of(&QCompleter::activated), this, [this]()
-    {
-        ValidatePassmarkLength();
-        DescEdited();
-    });
 
-    ui->lineEditPassmarkLength->setCompleter(m_completer);
-    connect(ui->lineEditPassmarkLength, &QLineEdit::textEdited, this, [this]()
-    {
-        ValidatePassmarkLength();
-        DescEdited();
-    });
+    //----------------------- Passmark length
+    m_completerLength = new QCompleter(m_variables, this);
+    m_completerLength->setCompletionMode(QCompleter::PopupCompletion);
+    m_completerLength->setModelSorting(QCompleter::UnsortedModel);
+    m_completerLength->setFilterMode(Qt::MatchContains);
+    m_completerLength->setCaseSensitivity(Qt::CaseSensitive);
+    connect(m_completerLength, QOverload<const QString &>::of(&QCompleter::activated), this,
+            [this]()
+            {
+                ValidatePassmarkLength();
+                DescEdited();
+            });
+
+    ui->lineEditPassmarkLength->setCompleter(m_completerLength);
+    connect(ui->lineEditPassmarkLength, &QLineEdit::textEdited, this,
+            [this]()
+            {
+                ValidatePassmarkLength();
+                DescEdited();
+            });
 
     ui->lineEditPassmarkLength->installEventFilter(this);
     m_oldPassmarkLength = doc->GetPassmarkLengthVariable();
     ui->lineEditPassmarkLength->setText(m_oldPassmarkLength);
     ValidatePassmarkLength();
 
-    //Initialization change value. Set to default value after initialization
+    //----------------------- Passmark width
+    m_completerWidth = new QCompleter(m_variables, this);
+    m_completerWidth->setCompletionMode(QCompleter::PopupCompletion);
+    m_completerWidth->setModelSorting(QCompleter::UnsortedModel);
+    m_completerWidth->setFilterMode(Qt::MatchContains);
+    m_completerWidth->setCaseSensitivity(Qt::CaseSensitive);
+    connect(m_completerWidth, QOverload<const QString &>::of(&QCompleter::activated), this,
+            [this]()
+            {
+                ValidatePassmarkWidth();
+                DescEdited();
+            });
+
+    ui->lineEditPassmarkWidth->setCompleter(m_completerWidth);
+    connect(ui->lineEditPassmarkWidth, &QLineEdit::textEdited, this,
+            [this]()
+            {
+                ValidatePassmarkWidth();
+                DescEdited();
+            });
+
+    ui->lineEditPassmarkWidth->installEventFilter(this);
+    m_oldPassmarkWidth = doc->GetPassmarkWidthVariable();
+    ui->lineEditPassmarkWidth->setText(m_oldPassmarkWidth);
+    ValidatePassmarkWidth();
+
+    // Initialization change value. Set to default value after initialization
     m_defaultChanged = false;
     m_securityChanged = false;
+
+    connect(ui->pushButtonBrowsePieceLabelPath, &QPushButton::clicked, this, &DialogPatternProperties::BrowseLabelPath);
+    ui->lineEditPieceLabelPath->setText(m_doc->GetDefaultPieceLabelPath());
+    connect(ui->lineEditPieceLabelPath, &QLineEdit::textChanged, this, &DialogPatternProperties::LabelPathChanged);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -184,12 +219,27 @@ auto DialogPatternProperties::eventFilter(QObject *object, QEvent *event) -> boo
             auto *keyEvent = static_cast<QKeyEvent *>(event); // NOLINT(cppcoreguidelines-pro-type-static-cast-downcast)
             if ((keyEvent->key() == Qt::Key_Space) && ((keyEvent->modifiers() & Qt::ControlModifier) != 0U))
             {
-                m_completer->complete();
+                m_completerLength->complete();
                 return true;
             }
         }
 
-        return false;// clazy:exclude=base-class-event
+        return false; // clazy:exclude=base-class-event
+    }
+
+    if (ui->lineEditPassmarkWidth == qobject_cast<QLineEdit *>(object))
+    {
+        if (event->type() == QEvent::KeyPress)
+        {
+            auto *keyEvent = static_cast<QKeyEvent *>(event); // NOLINT(cppcoreguidelines-pro-type-static-cast-downcast)
+            if ((keyEvent->key() == Qt::Key_Space) && ((keyEvent->modifiers() & Qt::ControlModifier) != 0U))
+            {
+                m_completerWidth->complete();
+                return true;
+            }
+        }
+
+        return false; // clazy:exclude=base-class-event
     }
 
     return QDialog::eventFilter(object, event);
@@ -235,11 +285,25 @@ void DialogPatternProperties::SaveDescription()
         m_doc->SetDescription(ui->plainTextEditDescription->document()->toPlainText());
         m_doc->SetLabelPrefix(qvariant_cast<QString>(ui->comboBoxLabelLanguage->currentData()));
         m_doc->SetPassmarkLengthVariable(ui->lineEditPassmarkLength->text());
+        m_doc->SetPassmarkWidthVariable(ui->lineEditPassmarkWidth->text());
+        m_doc->SetDefaultPieceLabelPath(ui->lineEditPieceLabelPath->text());
 
-        if (m_oldPassmarkLength != ui->lineEditPassmarkLength->text())
+        const bool widthChanged = m_oldPassmarkWidth != ui->lineEditPassmarkWidth->text();
+
+        if (const bool lengthChanged = m_oldPassmarkLength != ui->lineEditPassmarkLength->text();
+            lengthChanged || widthChanged)
         {
             emit UpddatePieces();
-            m_oldPassmarkLength = ui->lineEditPassmarkLength->text();
+
+            if (lengthChanged)
+            {
+                m_oldPassmarkLength = ui->lineEditPassmarkLength->text();
+            }
+
+            if (widthChanged)
+            {
+                m_oldPassmarkWidth = ui->lineEditPassmarkWidth->text();
+            }
         }
 
         m_descriptionChanged = false;
@@ -265,49 +329,74 @@ void DialogPatternProperties::ValidatePassmarkLength() const
     QPalette palette = ui->lineEditPassmarkLength->palette();
     const QPalette::ColorRole foregroundRole = ui->lineEditPassmarkLength->foregroundRole();
 
-    QRegularExpression rx(NameRegExp());
     if (not text.isEmpty())
     {
-        palette.setColor(foregroundRole,
-                         rx.match(text).hasMatch() && m_variables.contains(text) ? Qt::black : Qt::red);
+        QRegularExpression const rx(NameRegExp());
+        palette.setColor(foregroundRole, rx.match(text).hasMatch() && m_variables.contains(text)
+                                             ? palette.color(QPalette::Text)
+                                             : Qt::red);
     }
     else
     {
-        palette.setColor(foregroundRole, Qt::black);
+        palette.setColor(foregroundRole, palette.color(QPalette::Text));
     }
 
     ui->lineEditPassmarkLength->setPalette(palette);
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void DialogPatternProperties::ValidatePassmarkWidth() const
+{
+    const QString text = ui->lineEditPassmarkWidth->text();
+    QPalette palette = ui->lineEditPassmarkWidth->palette();
+    const QPalette::ColorRole foregroundRole = ui->lineEditPassmarkWidth->foregroundRole();
+
+    if (not text.isEmpty())
+    {
+        QRegularExpression const rx(NameRegExp());
+        palette.setColor(foregroundRole, rx.match(text).hasMatch() && m_variables.contains(text)
+                                             ? palette.color(QPalette::Text)
+                                             : Qt::red);
+    }
+    else
+    {
+        palette.setColor(foregroundRole, palette.color(QPalette::Text));
+    }
+
+    ui->lineEditPassmarkWidth->setPalette(palette);
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void DialogPatternProperties::InitImage()
 {
     ui->imageLabel->setContextMenuPolicy(Qt::CustomContextMenu);
-    ui->imageLabel->setScaledContents(true);
-    connect(ui->imageLabel, &QWidget::customContextMenuRequested, this, [this]()
-    {
-        QMenu menu(this);
-        menu.addAction(m_deleteAction);
-        menu.addAction(m_changeImageAction);
-        menu.addAction(m_saveImageAction);
-        menu.addAction(m_showImageAction);
-        menu.exec(QCursor::pos());
-        menu.show();
-    });
+    ui->imageLabel->setAlignment(Qt::AlignHCenter | Qt::AlignVCenter);
+    connect(ui->imageLabel, &QWidget::customContextMenuRequested, this,
+            [this]()
+            {
+                QMenu menu(this);
+                menu.addAction(m_deleteAction);
+                menu.addAction(m_changeImageAction);
+                menu.addAction(m_saveImageAction);
+                menu.addAction(m_showImageAction);
+                menu.exec(QCursor::pos());
+                menu.show();
+            });
 
-    m_deleteAction      = new QAction(tr("Delete image"), this);
+    m_deleteAction = new QAction(tr("Delete image"), this);
     m_changeImageAction = new QAction(tr("Change image"), this);
-    m_saveImageAction   = new QAction(tr("Save image to file"), this);
-    m_showImageAction   = new QAction(tr("Show image"), this);
+    m_saveImageAction = new QAction(tr("Save image to file"), this);
+    m_showImageAction = new QAction(tr("Show image"), this);
 
-    connect(m_deleteAction, &QAction::triggered, this, [this]()
-    {
-        m_doc->DeleteImage();
-        ui->imageLabel->setText(tr("Change image"));
-        m_deleteAction->setEnabled(false);
-        m_saveImageAction->setEnabled(false);
-        m_showImageAction->setEnabled(false);
-    });
+    connect(m_deleteAction, &QAction::triggered, this,
+            [this]()
+            {
+                m_doc->DeleteImage();
+                ui->imageLabel->setText(tr("Change image"));
+                m_deleteAction->setEnabled(false);
+                m_saveImageAction->setEnabled(false);
+                m_showImageAction->setEnabled(false);
+            });
 
     connect(m_changeImageAction, &QAction::triggered, this, &DialogPatternProperties::ChangeImage);
     connect(m_saveImageAction, &QAction::triggered, this, &DialogPatternProperties::SaveImage);
@@ -316,7 +405,9 @@ void DialogPatternProperties::InitImage()
     const VPatternImage image = m_doc->GetImage();
     if (image.IsValid())
     {
-        ui->imageLabel->setPixmap(image.GetPixmap(ui->imageLabel->width(), ui->imageLabel->height()));
+        QPixmap const pixImage = image.GetPixmap();
+        ui->imageLabel->setPixmap(
+            pixImage.scaled(ui->imageLabel->width(), ui->imageLabel->height(), Qt::KeepAspectRatio));
     }
     else
     {
@@ -329,12 +420,19 @@ void DialogPatternProperties::InitImage()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogPatternProperties::ChangeImage()
 {
-    const QString fileName = QFileDialog::getOpenFileName(this, tr("Image for pattern"), QString(),
-                                                          PrepareImageFilters(), nullptr,
-                                                          VAbstractApplication::VApp()->NativeFileDialog());
+    VValentinaSettings *settings = VAbstractValApplication::VApp()->ValentinaSettings();
+
+    const QString fileName =
+        QFileDialog::getOpenFileName(this, tr("Image for pattern"), settings->GetPathCustomImage(),
+                                     PrepareImageFilters(), nullptr, VAbstractApplication::VApp()->NativeFileDialog());
     if (not fileName.isEmpty())
     {
-        VPatternImage image = VPatternImage::FromFile(fileName);
+        if (QFileInfo::exists(fileName))
+        {
+            settings->SetPathCustomImage(QFileInfo(fileName).absolutePath());
+        }
+
+        VPatternImage const image = VPatternImage::FromFile(fileName);
 
         if (not image.IsValid())
         {
@@ -343,7 +441,10 @@ void DialogPatternProperties::ChangeImage()
         }
 
         m_doc->SetImage(image);
-        ui->imageLabel->setPixmap(image.GetPixmap(ui->imageLabel->width(), ui->imageLabel->height()));
+
+        QPixmap const pixImage = image.GetPixmap();
+        ui->imageLabel->setPixmap(
+            pixImage.scaled(ui->imageLabel->width(), ui->imageLabel->height(), Qt::KeepAspectRatio));
 
         m_deleteAction->setEnabled(true);
         m_saveImageAction->setEnabled(true);
@@ -362,20 +463,26 @@ void DialogPatternProperties::SaveImage()
         return;
     }
 
-    QMimeType mime = image.MimeTypeFromData();
-    QString path = QDir::homePath() + QDir::separator() + tr("untitled");
+    VValentinaSettings *settings = VAbstractValApplication::VApp()->ValentinaSettings();
 
-    QStringList suffixes = mime.suffixes();
-    if (not suffixes.isEmpty())
+    QMimeType const mime = image.MimeTypeFromData();
+    QString path = settings->GetPathCustomImage() + QDir::separator() + tr("untitled");
+
+    if (QStringList const suffixes = mime.suffixes(); not suffixes.isEmpty())
     {
-        path += '.' + suffixes.at(0);
+        path += '.'_L1 + suffixes.at(0);
     }
 
-    QString filter = mime.filterString();
-    QString filename = QFileDialog::getSaveFileName(this, tr("Save Image"), path, filter, nullptr,
-                                                    VAbstractApplication::VApp()->NativeFileDialog());
+    QString const filter = mime.filterString();
+    QString const filename = QFileDialog::getSaveFileName(this, tr("Save Image"), path, filter, nullptr,
+                                                          VAbstractApplication::VApp()->NativeFileDialog());
     if (not filename.isEmpty())
     {
+        if (QFileInfo::exists(filename))
+        {
+            settings->SetPathCustomImage(QFileInfo(filename).absolutePath());
+        }
+
         QFile file(filename);
         if (file.open(QIODevice::WriteOnly))
         {
@@ -399,13 +506,12 @@ void DialogPatternProperties::ShowImage()
         return;
     }
 
-    QMimeType mime = image.MimeTypeFromData();
+    QMimeType const mime = image.MimeTypeFromData();
     QString name = QDir::tempPath() + QDir::separator() + QStringLiteral("image.XXXXXX");
 
-    QStringList suffixes = mime.suffixes();
-    if (not suffixes.isEmpty())
+    if (QStringList const suffixes = mime.suffixes(); not suffixes.isEmpty())
     {
-        name += '.' + suffixes.at(0);
+        name += '.'_L1 + suffixes.at(0);
     }
 
     delete m_tmpImage;
@@ -418,6 +524,40 @@ void DialogPatternProperties::ShowImage()
     }
     else
     {
-        qCritical() << tr("Unable to open temp file");
+        qCritical() << "Unable to open temp file";
     }
 }
+
+//---------------------------------------------------------------------------------------------------------------------
+void DialogPatternProperties::BrowseLabelPath()
+{
+    VValentinaSettings *settings = VAbstractValApplication::VApp()->ValentinaSettings();
+
+    QString path = ui->lineEditPieceLabelPath->text();
+    if (path.isEmpty())
+    {
+        path = settings->GetPathLabelTemplate();
+    }
+
+    QString const filters(tr("Label template") + "(*.xml)"_L1);
+
+    const QString filePath = QFileDialog::getOpenFileName(this, tr("Label template"), path, filters, nullptr,
+                                                          VAbstractApplication::VApp()->NativeFileDialog());
+
+    ui->lineEditPieceLabelPath->setText(filePath);
+
+    if (!filePath.isEmpty() && QFileInfo::exists(filePath))
+    {
+        settings->SetPathLabelTemplate(QFileInfo(filePath).absolutePath());
+    }
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void DialogPatternProperties::LabelPathChanged(const QString &text)
+{
+    QPalette palette = ui->lineEditPieceLabelPath->palette();
+    palette.setColor(ui->lineEditPieceLabelPath->foregroundRole(),
+                     text.isEmpty() || QFileInfo::exists(text) ? palette.color(QPalette::Text) : Qt::red);
+    ui->lineEditPieceLabelPath->setPalette(palette);
+    m_descriptionChanged = true;
+}
