@@ -33,8 +33,6 @@
 #include <QMap>
 #include <QPointer>
 
-#include "../vmisc/defglobal.h"
-
 class VPattern;
 class VContainer;
 class QCheckBox;
@@ -43,17 +41,19 @@ class QTemporaryFile;
 
 namespace Ui
 {
-    class DialogPatternProperties;
+class DialogPatternProperties;
 }
 
 class DialogPatternProperties : public QDialog
 {
     Q_OBJECT // NOLINT
+
 public:
     explicit DialogPatternProperties(VPattern *doc, VContainer *pattern, QWidget *parent = nullptr);
     ~DialogPatternProperties() override;
 signals:
     void UpddatePieces();
+
 protected:
     auto eventFilter(QObject *object, QEvent *event) -> bool override;
 private slots:
@@ -63,6 +63,9 @@ private slots:
     void ChangeImage();
     void SaveImage();
     void ShowImage();
+    void BrowseLabelPath();
+    void LabelPathChanged(const QString &text);
+
 private:
     // cppcheck-suppress unknownMacro
     Q_DISABLE_COPY_MOVE(DialogPatternProperties) // NOLINT
@@ -77,9 +80,11 @@ private:
     QAction *m_changeImageAction{nullptr};
     QAction *m_saveImageAction{nullptr};
     QAction *m_showImageAction{nullptr};
-    QCompleter *m_completer{nullptr};
+    QCompleter *m_completerLength{nullptr};
+    QCompleter *m_completerWidth{nullptr};
     QStringList m_variables{};
     QString m_oldPassmarkLength{};
+    QString m_oldPassmarkWidth{};
     QPointer<QTemporaryFile> m_tmpImage{};
 
     void SaveDescription();
@@ -88,6 +93,7 @@ private:
     void InitImage();
 
     void ValidatePassmarkLength() const;
+    void ValidatePassmarkWidth() const;
 };
 
 #endif // DIALOGPATTERNPROPERTIES_H
