@@ -27,39 +27,49 @@
  *************************************************************************/
 
 #include "dialogsavelayout.h"
-#include "ui_dialogsavelayout.h"
 #include "../core/vapplication.h"
-#include "../vmisc/vvalentinasettings.h"
-#if QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
-#include "../vmisc/backport/qoverload.h"
-#endif // QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
 #include "../ifc/exception/vexception.h"
 #include "../vlayout/vlayoutexporter.h"
+#include "../vmisc/vvalentinasettings.h"
+#include "ui_dialogsavelayout.h"
 
 #include <QDir>
 #include <QFileDialog>
+#include <QGlobalStatic>
 #include <QMessageBox>
 #include <QProcess>
-#include <QtDebug>
 #include <QRegularExpression>
 #include <QtDebug>
-#include <QGlobalStatic>
 
-#ifndef Q_OS_WIN
-    Q_GLOBAL_STATIC_WITH_ARGS(const QString, baseFilenameRegExp, (QLatin1String("^[^\\/]+$"))) // NOLINT
-#else
-    Q_GLOBAL_STATIC_WITH_ARGS(const QString, baseFilenameRegExp, (QLatin1String("^[^\\:?\"*|\\/<>]+$"))) // NOLINT
+#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
+#include "../vmisc/compatibility.h"
 #endif
 
+using namespace Qt::Literals::StringLiterals;
+
+namespace
+{
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_CLANG("-Wunused-member-function")
+
+#ifndef Q_OS_WIN
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, baseFilenameRegExp, ("^[^\\/]+$"_L1)) // NOLINT
+#else
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, baseFilenameRegExp, ("^[^\\:?\"*|\\/<>]+$"_L1)) // NOLINT
+#endif
+
+QT_WARNING_POP
+} // namespace
+
 bool DialogSaveLayout::havePdf = false; // NOLINT(cppcoreguidelines-avoid-non-const-global-variables)
-bool DialogSaveLayout::tested  = false; // NOLINT(cppcoreguidelines-avoid-non-const-global-variables)
+bool DialogSaveLayout::tested = false;  // NOLINT(cppcoreguidelines-avoid-non-const-global-variables)
 
 //---------------------------------------------------------------------------------------------------------------------
 DialogSaveLayout::DialogSaveLayout(int count, Draw mode, const QString &fileName, QWidget *parent)
-    :  VAbstractLayoutDialog(parent),
-      ui(new Ui::DialogSaveLAyout),
-      m_count(count),
-      m_mode(mode)
+  : VAbstractLayoutDialog(parent),
+    ui(new Ui::DialogSaveLAyout),
+    m_count(count),
+    m_mode(mode)
 {
     ui->setupUi(this);
 
@@ -76,9 +86,9 @@ DialogSaveLayout::DialogSaveLayout(int count, Draw mode, const QString &fileName
     SCASSERT(bOk != nullptr)
     bOk->setEnabled(false);
 
-    ui->lineEditFileName->setValidator( new QRegularExpressionValidator(QRegularExpression(*baseFilenameRegExp), this));
+    ui->lineEditFileName->setValidator(new QRegularExpressionValidator(QRegularExpression(*baseFilenameRegExp), this));
 
-    const QString mask = fileName + '_';
+    const QString mask = fileName + '_'_L1;
     if (VApplication::IsGUIMode())
     {
         ui->lineEditFileName->setText(mask);
@@ -95,15 +105,15 @@ DialogSaveLayout::DialogSaveLayout(int count, Draw mode, const QString &fileName
         }
     }
 
-    for (auto &v : InitFormats())
+    for (auto &[first, second] : InitFormats())
     {
-        ui->comboBoxFormat->addItem(v.first, QVariant(static_cast<int>(v.second)));
+        ui->comboBoxFormat->addItem(first, QVariant(static_cast<int>(second)));
     }
 #ifdef V_NO_ASSERT // Temporarily unavailable
     RemoveFormatFromList(LayoutExportFormats::OBJ);
 #endif
 
-//    RemoveFormatFromList(LayoutExportFormats::NC); // No support for now
+    //    RemoveFormatFromList(LayoutExportFormats::NC); // No support for now
 
     if (m_mode != Draw::Layout)
     {
@@ -112,38 +122,31 @@ DialogSaveLayout::DialogSaveLayout(int count, Draw mode, const QString &fileName
     else
     {
         RemoveFormatFromList(LayoutExportFormats::RLD);
-        ui->checkBoxTextAsPaths->setVisible(false);
     }
 
+    InitDxfCompatibility();
+
     connect(bOk, &QPushButton::clicked, this, &DialogSaveLayout::Save);
     connect(ui->lineEditFileName, &QLineEdit::textChanged, this, &DialogSaveLayout::ShowExample);
-    connect(ui->comboBoxFormat, QOverload<int>::of(&QComboBox::currentIndexChanged),
-            this, &DialogSaveLayout::ShowExample);
-    connect(ui->pushButtonBrowse, &QPushButton::clicked, this, [this]()
-    {
-        const QString dirPath = VAbstractValApplication::VApp()->ValentinaSettings()->GetPathLayout();
-        bool usedNotExistedDir = false;
-        QDir directory(dirPath);
-        if (not directory.exists())
-        {
-            usedNotExistedDir = directory.mkpath(QChar('.'));
-        }
+    connect(ui->comboBoxFormat, QOverload<int>::of(&QComboBox::currentIndexChanged), this,
+            &DialogSaveLayout::ShowExample);
+    connect(ui->pushButtonBrowse, &QPushButton::clicked, this,
+            [this]()
+            {
+                VValentinaSettings *settings = VAbstractValApplication::VApp()->ValentinaSettings();
+                const QString dirPath = settings->GetPathLayout();
 
-        const QString dir = QFileDialog::getExistingDirectory(
-            this, tr("Select folder"), dirPath,
-            VAbstractApplication::VApp()->NativeFileDialog(QFileDialog::ShowDirsOnly |
-                                                           QFileDialog::DontResolveSymlinks));
-        if (not dir.isEmpty())
-        {// If paths equal the signal will not be called, we will do this manually
-            dir == ui->lineEditPath->text() ? PathChanged(dir) : ui->lineEditPath->setText(dir);
-        }
+                const QString dir = QFileDialog::getExistingDirectory(
+                    this, tr("Select folder"), dirPath,
+                    VAbstractApplication::VApp()->NativeFileDialog(QFileDialog::ShowDirsOnly |
+                                                                   QFileDialog::DontResolveSymlinks));
+                if (not dir.isEmpty())
+                { // If paths equal the signal will not be called, we will do this manually
+                    dir == ui->lineEditPath->text() ? PathChanged(dir) : ui->lineEditPath->setText(dir);
 
-        if (usedNotExistedDir)
-        {
-            QDir directory(dirPath);
-            directory.rmpath(QChar('.'));
-        }
-    });
+                    settings->SetPathLayout(dir);
+                }
+            });
     connect(ui->lineEditPath, &QLineEdit::textChanged, this, &DialogSaveLayout::PathChanged);
 
     ui->lineEditPath->setText(VAbstractValApplication::VApp()->ValentinaSettings()->GetPathLayout());
@@ -152,14 +155,14 @@ DialogSaveLayout::DialogSaveLayout(int count, Draw mode, const QString &fileName
 
     connect(ui->toolButtonScaleConnected, &QToolButton::clicked, this, &DialogSaveLayout::ToggleScaleConnection);
 
-    connect(ui->doubleSpinBoxHorizontalScale, QOverload<double>::of(&QDoubleSpinBox::valueChanged),
-            this, &DialogSaveLayout::HorizontalScaleChanged);
-    connect(ui->doubleSpinBoxVerticalScale, QOverload<double>::of(&QDoubleSpinBox::valueChanged),
-            this, &DialogSaveLayout::VerticalScaleChanged);
+    connect(ui->doubleSpinBoxHorizontalScale, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this,
+            &DialogSaveLayout::HorizontalScaleChanged);
+    connect(ui->doubleSpinBoxVerticalScale, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this,
+            &DialogSaveLayout::VerticalScaleChanged);
 
     ReadSettings();
 
-    ShowExample();//Show example for current format.
+    ShowExample(); // Show example for current format.
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -182,7 +185,7 @@ void DialogSaveLayout::SelectFormat(LayoutExportFormats format)
 //---------------------------------------------------------------------------------------------------------------------
 void DialogSaveLayout::SetBinaryDXFFormat(bool binary)
 {
-    switch(Format())
+    switch (Format())
     {
         case LayoutExportFormats::DXF_AC1006_Flat:
         case LayoutExportFormats::DXF_AC1009_Flat:
@@ -193,36 +196,10 @@ void DialogSaveLayout::SetBinaryDXFFormat(bool binary)
         case LayoutExportFormats::DXF_AC1021_Flat:
         case LayoutExportFormats::DXF_AC1024_Flat:
         case LayoutExportFormats::DXF_AC1027_Flat:
-        case LayoutExportFormats::DXF_AC1006_AAMA:
-        case LayoutExportFormats::DXF_AC1009_AAMA:
-        case LayoutExportFormats::DXF_AC1012_AAMA:
-        case LayoutExportFormats::DXF_AC1014_AAMA:
-        case LayoutExportFormats::DXF_AC1015_AAMA:
-        case LayoutExportFormats::DXF_AC1018_AAMA:
-        case LayoutExportFormats::DXF_AC1021_AAMA:
-        case LayoutExportFormats::DXF_AC1024_AAMA:
-        case LayoutExportFormats::DXF_AC1027_AAMA:
-        case LayoutExportFormats::DXF_AC1006_ASTM:
-        case LayoutExportFormats::DXF_AC1009_ASTM:
-        case LayoutExportFormats::DXF_AC1012_ASTM:
-        case LayoutExportFormats::DXF_AC1014_ASTM:
-        case LayoutExportFormats::DXF_AC1015_ASTM:
-        case LayoutExportFormats::DXF_AC1018_ASTM:
-        case LayoutExportFormats::DXF_AC1021_ASTM:
-        case LayoutExportFormats::DXF_AC1024_ASTM:
-        case LayoutExportFormats::DXF_AC1027_ASTM:
+        case LayoutExportFormats::DXF_AAMA:
+        case LayoutExportFormats::DXF_ASTM:
             ui->checkBoxBinaryDXF->setChecked(binary);
             break;
-        case LayoutExportFormats::SVG:
-        case LayoutExportFormats::PDF:
-        case LayoutExportFormats::PDFTiled:
-        case LayoutExportFormats::PNG:
-        case LayoutExportFormats::OBJ:
-        case LayoutExportFormats::PS:
-        case LayoutExportFormats::EPS:
-        case LayoutExportFormats::NC:
-        case LayoutExportFormats::RLD:
-        case LayoutExportFormats::TIF:
         default:
             ui->checkBoxBinaryDXF->setChecked(false);
             break;
@@ -232,7 +209,7 @@ void DialogSaveLayout::SetBinaryDXFFormat(bool binary)
 //---------------------------------------------------------------------------------------------------------------------
 auto DialogSaveLayout::IsBinaryDXFFormat() const -> bool
 {
-    switch(Format())
+    switch (Format())
     {
         case LayoutExportFormats::DXF_AC1006_Flat:
         case LayoutExportFormats::DXF_AC1009_Flat:
@@ -243,60 +220,146 @@ auto DialogSaveLayout::IsBinaryDXFFormat() const -> bool
         case LayoutExportFormats::DXF_AC1021_Flat:
         case LayoutExportFormats::DXF_AC1024_Flat:
         case LayoutExportFormats::DXF_AC1027_Flat:
-        case LayoutExportFormats::DXF_AC1006_AAMA:
-        case LayoutExportFormats::DXF_AC1009_AAMA:
-        case LayoutExportFormats::DXF_AC1012_AAMA:
-        case LayoutExportFormats::DXF_AC1014_AAMA:
-        case LayoutExportFormats::DXF_AC1015_AAMA:
-        case LayoutExportFormats::DXF_AC1018_AAMA:
-        case LayoutExportFormats::DXF_AC1021_AAMA:
-        case LayoutExportFormats::DXF_AC1024_AAMA:
-        case LayoutExportFormats::DXF_AC1027_AAMA:
-        case LayoutExportFormats::DXF_AC1006_ASTM:
-        case LayoutExportFormats::DXF_AC1009_ASTM:
-        case LayoutExportFormats::DXF_AC1012_ASTM:
-        case LayoutExportFormats::DXF_AC1014_ASTM:
-        case LayoutExportFormats::DXF_AC1015_ASTM:
-        case LayoutExportFormats::DXF_AC1018_ASTM:
-        case LayoutExportFormats::DXF_AC1021_ASTM:
-        case LayoutExportFormats::DXF_AC1024_ASTM:
-        case LayoutExportFormats::DXF_AC1027_ASTM:
+        case LayoutExportFormats::DXF_AAMA:
+        case LayoutExportFormats::DXF_ASTM:
             return ui->checkBoxBinaryDXF->isChecked();
-        case LayoutExportFormats::SVG:
-        case LayoutExportFormats::PDF:
-        case LayoutExportFormats::PDFTiled:
-        case LayoutExportFormats::PNG:
-        case LayoutExportFormats::OBJ:
-        case LayoutExportFormats::PS:
-        case LayoutExportFormats::EPS:
-        case LayoutExportFormats::NC:
-        case LayoutExportFormats::RLD:
-        case LayoutExportFormats::TIF:
         default:
             return false;
     }
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+auto DialogSaveLayout::DxfCompatibility() const -> DXFApparelCompatibility
+{
+    switch (Format())
+    {
+        case LayoutExportFormats::DXF_AAMA:
+        case LayoutExportFormats::DXF_ASTM:
+            return static_cast<DXFApparelCompatibility>(ui->comboBoxDxfCompatibility->currentData().toInt());
+        default:
+            return DXFApparelCompatibility::STANDARD;
+    }
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void DialogSaveLayout::SetDxfCompatibility(DXFApparelCompatibility type)
+{
+    switch (Format())
+    {
+        case LayoutExportFormats::DXF_AAMA:
+        case LayoutExportFormats::DXF_ASTM:
+        {
+            if (static_cast<int>(type) < 0 || type >= DXFApparelCompatibility::COUNT)
+            {
+                break;
+            }
+
+            const int i = ui->comboBoxDxfCompatibility->findData(static_cast<int>(type));
+            if (i < 0)
+            {
+                break;
+            }
+            ui->comboBoxDxfCompatibility->setCurrentIndex(i);
+            break;
+        }
+        default:
+            break;
+    }
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void DialogSaveLayout::SetShowGrainline(bool show)
+{
+    switch (Format())
+    {
+        case LayoutExportFormats::DXF_AC1006_Flat:
+        case LayoutExportFormats::DXF_AC1009_Flat:
+        case LayoutExportFormats::DXF_AC1012_Flat:
+        case LayoutExportFormats::DXF_AC1014_Flat:
+        case LayoutExportFormats::DXF_AC1015_Flat:
+        case LayoutExportFormats::DXF_AC1018_Flat:
+        case LayoutExportFormats::DXF_AC1021_Flat:
+        case LayoutExportFormats::DXF_AC1024_Flat:
+        case LayoutExportFormats::DXF_AC1027_Flat:
+        case LayoutExportFormats::SVG:
+        case LayoutExportFormats::PDF:
+        case LayoutExportFormats::PDFTiled:
+        case LayoutExportFormats::PNG:
+        case LayoutExportFormats::PS:
+        case LayoutExportFormats::EPS:
+        case LayoutExportFormats::TIF:
+        case LayoutExportFormats::HPGL:
+        case LayoutExportFormats::HPGL2:
+            ui->checkBoxShowGrainline->setChecked(show);
+            break;
+        default:
+            ui->checkBoxShowGrainline->setChecked(true);
+            break;
+    }
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto DialogSaveLayout::IsShowGrainline() const -> bool
+{
+    switch (Format())
+    {
+        case LayoutExportFormats::DXF_AC1006_Flat:
+        case LayoutExportFormats::DXF_AC1009_Flat:
+        case LayoutExportFormats::DXF_AC1012_Flat:
+        case LayoutExportFormats::DXF_AC1014_Flat:
+        case LayoutExportFormats::DXF_AC1015_Flat:
+        case LayoutExportFormats::DXF_AC1018_Flat:
+        case LayoutExportFormats::DXF_AC1021_Flat:
+        case LayoutExportFormats::DXF_AC1024_Flat:
+        case LayoutExportFormats::DXF_AC1027_Flat:
+        case LayoutExportFormats::SVG:
+        case LayoutExportFormats::PDF:
+        case LayoutExportFormats::PDFTiled:
+        case LayoutExportFormats::PNG:
+        case LayoutExportFormats::PS:
+        case LayoutExportFormats::EPS:
+        case LayoutExportFormats::TIF:
+        case LayoutExportFormats::HPGL:
+        case LayoutExportFormats::HPGL2:
+            return ui->checkBoxShowGrainline->isChecked();
+        default:
+            return true;
+    }
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 auto DialogSaveLayout::MakeHelpFormatList() -> QString
 {
-   QString out(QStringLiteral("\n"));
-   const auto formats = InitFormats();
-   for(int i = 0; i < formats.size(); ++i)
-   {
-       out += QStringLiteral("\t* ") + formats.at(i).first + QStringLiteral(" = ")
-               + QString::number(static_cast<int>(formats.at(i).second));
+    auto out = QStringLiteral("\n");
+    const auto formats = InitFormats();
+    for (int i = 0; i < formats.size(); ++i)
+    {
+        out += "\t* "_L1 + formats.at(i).first + " = "_L1 + QString::number(static_cast<int>(formats.at(i).second));
 
-       if (i < formats.size() - 1)
-       {
-           out += QLatin1String(",\n");
-       }
-       else
-       {
-           out += QLatin1String(".\n");
-       }
-   }
-   return out;
+        if (i < formats.size() - 1)
+        {
+            out += ",\n"_L1;
+        }
+        else
+        {
+            out += ".\n"_L1;
+        }
+    }
+    return out;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto DialogSaveLayout::MakeHelpDxfApparelCompatibilityList() -> QString
+{
+    QString out("\n"_L1);
+    out += QStringLiteral("\t* %1 = %2,\n")
+               .arg(tr("By standard"))
+               .arg(static_cast<int>(DXFApparelCompatibility::STANDARD));
+    out += QStringLiteral("\t* Richpeace CAD V8 = %1,\n").arg(static_cast<int>(DXFApparelCompatibility::RPCADV08));
+    out += QStringLiteral("\t* Richpeace CAD V9 = %1,\n").arg(static_cast<int>(DXFApparelCompatibility::RPCADV09));
+    out += QStringLiteral("\t* Richpeace CAD V10 = %1.\n").arg(static_cast<int>(DXFApparelCompatibility::RPCADV10));
+
+    return out;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -360,15 +423,17 @@ void DialogSaveLayout::Save()
 {
     WriteSettings();
 
-    for (int i=0; i < m_count; ++i)
+    for (int i = 0; i < m_count; ++i)
     {
-        const QString name = Path()+'/'+FileName()+QString::number(i+1)+VLayoutExporter::ExportFormatSuffix(Format());
+        const QString name =
+            Path() + '/' + FileName() + QString::number(i + 1) + VLayoutExporter::ExportFormatSuffix(Format());
         if (QFile::exists(name))
         {
-            QMessageBox::StandardButton res = QMessageBox::question(this, tr("Name conflict"),
-                                  tr("Folder already contain file with name %1. Rewrite all conflict file names?")
-                                  .arg(name), QMessageBox::Yes|QMessageBox::No, QMessageBox::Yes);
-            if (res == QMessageBox::No)
+            if (QMessageBox::StandardButton const res = QMessageBox::question(
+                    this, tr("Name conflict"),
+                    tr("Folder already contain file with name %1. Rewrite all conflict file names?").arg(name),
+                    QMessageBox::Yes | QMessageBox::No, QMessageBox::Yes);
+                res == QMessageBox::No)
             {
                 reject();
                 return;
@@ -377,6 +442,12 @@ void DialogSaveLayout::Save()
             break;
         }
     }
+
+    if (QFile::exists(Path()))
+    {
+        VAbstractValApplication::VApp()->ValentinaSettings()->SetPathLayout(Path());
+    }
+
     accept();
 }
 
@@ -393,7 +464,7 @@ void DialogSaveLayout::PathChanged(const QString &text)
     if (not text.isEmpty() && dir.exists(text))
     {
         bOk->setEnabled(true);
-        palette.setColor(ui->lineEditPath->foregroundRole(), Qt::black);
+        palette.setColor(ui->lineEditPath->foregroundRole(), palette.color(QPalette::Text));
     }
     else
     {
@@ -408,15 +479,64 @@ void DialogSaveLayout::PathChanged(const QString &text)
 void DialogSaveLayout::ShowExample()
 {
     const LayoutExportFormats currentFormat = Format();
-    ui->labelExample->setText(tr("Example:") + FileName() + QLatin1Char('1') + VLayoutExporter::ExportFormatSuffix(currentFormat));
+    ui->labelExample->setText(tr("Example:") + FileName() + '1'_L1 +
+                              VLayoutExporter::ExportFormatSuffix(currentFormat));
 
-    ui->checkBoxBinaryDXF->setEnabled(false);
     ui->groupBoxPaperFormat->setEnabled(false);
     ui->groupBoxMargins->setEnabled(false);
-    ui->checkBoxTextAsPaths->setEnabled(true);
 
-    switch(currentFormat)
+    ui->labelOptionsNotAvailable->setVisible(false);
+    ui->checkBoxBinaryDXF->setVisible(false);
+    ui->checkBoxTextAsPaths->setVisible(false);
+    ui->checkBoxTextAsPaths->setEnabled(true);
+    ui->checkBoxShowGrainline->setVisible(false);
+    ui->checkBoxTogetherWithNotches->setVisible(false);
+    ui->labelDxfCompatibility->setVisible(false);
+    ui->comboBoxDxfCompatibility->setVisible(false);
+
+    VCommonSettings *settings = VAbstractApplication::VApp()->Settings();
+
+    switch (currentFormat)
     {
+        case LayoutExportFormats::DXF_AAMA:
+        case LayoutExportFormats::DXF_ASTM:
+            ui->checkBoxBinaryDXF->setVisible(true);
+            ui->checkBoxTogetherWithNotches->setVisible(m_mode != Draw::Layout);
+            ui->labelDxfCompatibility->setVisible(true);
+            ui->comboBoxDxfCompatibility->setVisible(true);
+            break;
+        case LayoutExportFormats::PDFTiled:
+            ui->groupBoxPaperFormat->setEnabled(true);
+            ui->groupBoxMargins->setEnabled(true);
+            ui->checkBoxTextAsPaths->setVisible(true);
+            if (settings->GetSingleLineFonts() || settings->GetSingleStrokeOutlineFont())
+            {
+                ui->checkBoxTextAsPaths->setDisabled(true);
+                ui->checkBoxTextAsPaths->setChecked(true);
+            }
+            ui->checkBoxShowGrainline->setVisible(true);
+            ui->checkBoxTogetherWithNotches->setVisible(m_mode != Draw::Layout);
+            break;
+        case LayoutExportFormats::HPGL:
+        case LayoutExportFormats::HPGL2:
+            ui->checkBoxShowGrainline->setVisible(true);
+            ui->checkBoxTogetherWithNotches->setVisible(true);
+            break;
+        case LayoutExportFormats::SVG:
+        case LayoutExportFormats::PDF:
+        case LayoutExportFormats::PS:
+        case LayoutExportFormats::EPS:
+        case LayoutExportFormats::PNG:
+        case LayoutExportFormats::TIF:
+            ui->checkBoxTextAsPaths->setVisible(true);
+            if (settings->GetSingleLineFonts() || settings->GetSingleStrokeOutlineFont())
+            {
+                ui->checkBoxTextAsPaths->setDisabled(true);
+                ui->checkBoxTextAsPaths->setChecked(true);
+            }
+            ui->checkBoxShowGrainline->setVisible(true);
+            ui->checkBoxTogetherWithNotches->setVisible(m_mode != Draw::Layout);
+            break;
         case LayoutExportFormats::DXF_AC1006_Flat:
         case LayoutExportFormats::DXF_AC1009_Flat:
         case LayoutExportFormats::DXF_AC1012_Flat:
@@ -426,42 +546,18 @@ void DialogSaveLayout::ShowExample()
         case LayoutExportFormats::DXF_AC1021_Flat:
         case LayoutExportFormats::DXF_AC1024_Flat:
         case LayoutExportFormats::DXF_AC1027_Flat:
-        case LayoutExportFormats::DXF_AC1006_AAMA:
-        case LayoutExportFormats::DXF_AC1009_AAMA:
-        case LayoutExportFormats::DXF_AC1012_AAMA:
-        case LayoutExportFormats::DXF_AC1014_AAMA:
-        case LayoutExportFormats::DXF_AC1015_AAMA:
-        case LayoutExportFormats::DXF_AC1018_AAMA:
-        case LayoutExportFormats::DXF_AC1021_AAMA:
-        case LayoutExportFormats::DXF_AC1024_AAMA:
-        case LayoutExportFormats::DXF_AC1027_AAMA:
-        case LayoutExportFormats::DXF_AC1006_ASTM:
-        case LayoutExportFormats::DXF_AC1009_ASTM:
-        case LayoutExportFormats::DXF_AC1012_ASTM:
-        case LayoutExportFormats::DXF_AC1014_ASTM:
-        case LayoutExportFormats::DXF_AC1015_ASTM:
-        case LayoutExportFormats::DXF_AC1018_ASTM:
-        case LayoutExportFormats::DXF_AC1021_ASTM:
-        case LayoutExportFormats::DXF_AC1024_ASTM:
-        case LayoutExportFormats::DXF_AC1027_ASTM:
-            ui->checkBoxBinaryDXF->setEnabled(true);
+            ui->checkBoxBinaryDXF->setVisible(true);
+            ui->checkBoxTextAsPaths->setVisible(true);
+            if (settings->GetSingleLineFonts() || settings->GetSingleStrokeOutlineFont())
+            {
+                ui->checkBoxTextAsPaths->setDisabled(true);
+                ui->checkBoxTextAsPaths->setChecked(true);
+            }
+            ui->checkBoxShowGrainline->setVisible(true);
+            ui->checkBoxTogetherWithNotches->setVisible(m_mode != Draw::Layout);
             break;
-        case LayoutExportFormats::PDFTiled:
-            ui->groupBoxPaperFormat->setEnabled(true);
-            ui->groupBoxMargins->setEnabled(true);
-            break;
-        case LayoutExportFormats::RLD:
-            ui->checkBoxTextAsPaths->setEnabled(false);
-            break;
-        case LayoutExportFormats::SVG:
-        case LayoutExportFormats::PDF:
-        case LayoutExportFormats::PNG:
-        case LayoutExportFormats::OBJ:
-        case LayoutExportFormats::PS:
-        case LayoutExportFormats::EPS:
-        case LayoutExportFormats::NC:
-        case LayoutExportFormats::TIF:
         default:
+            ui->labelOptionsNotAvailable->setVisible(true);
             break;
     }
 }
@@ -508,14 +604,7 @@ auto DialogSaveLayout::IsTextAsPaths() const -> bool
 //---------------------------------------------------------------------------------------------------------------------
 void DialogSaveLayout::SetTextAsPaths(bool textAsPaths)
 {
-    if (m_mode != Draw::Layout)
-    {
-        ui->checkBoxTextAsPaths->setChecked(textAsPaths);
-    }
-    else
-    {
-        ui->checkBoxTextAsPaths->setChecked(false);
-    }
+    ui->checkBoxTextAsPaths->setChecked(textAsPaths);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -539,12 +628,8 @@ void DialogSaveLayout::SetTiledMargins(QMarginsF margins)
 //---------------------------------------------------------------------------------------------------------------------
 auto DialogSaveLayout::GetTiledMargins() const -> QMarginsF
 {
-    QMarginsF margins = QMarginsF(
-        ui->doubleSpinBoxLeftField->value(),
-        ui->doubleSpinBoxTopField->value(),
-        ui->doubleSpinBoxRightField->value(),
-        ui->doubleSpinBoxBottomField->value()
-    );
+    auto const margins = QMarginsF(ui->doubleSpinBoxLeftField->value(), ui->doubleSpinBoxTopField->value(),
+                                   ui->doubleSpinBoxRightField->value(), ui->doubleSpinBoxBottomField->value());
 
     return UnitConvertor(margins, VAbstractValApplication::VApp()->patternUnits(), Unit::Mm);
 }
@@ -552,7 +637,7 @@ auto DialogSaveLayout::GetTiledMargins() const -> QMarginsF
 //---------------------------------------------------------------------------------------------------------------------
 void DialogSaveLayout::SetTiledPageFormat(PaperSizeTemplate format)
 {
-    int index = ui->comboBoxTemplates->findData(static_cast<int>(format));
+    int const index = ui->comboBoxTemplates->findData(static_cast<int>(format));
     if (index != -1)
     {
         ui->comboBoxTemplates->setCurrentIndex(index);
@@ -572,7 +657,7 @@ auto DialogSaveLayout::GetTiledPageFormat() const -> VAbstractLayoutDialog::Pape
 //---------------------------------------------------------------------------------------------------------------------
 void DialogSaveLayout::SetTiledPageOrientation(PageOrientation orientation)
 {
-    if(orientation == PageOrientation::Portrait)
+    if (orientation == PageOrientation::Portrait)
     {
         ui->toolButtonPortrait->setChecked(true);
     }
@@ -585,7 +670,7 @@ void DialogSaveLayout::SetTiledPageOrientation(PageOrientation orientation)
 //---------------------------------------------------------------------------------------------------------------------
 auto DialogSaveLayout::GetTiledPageOrientation() const -> PageOrientation
 {
-    if(ui->toolButtonPortrait->isChecked())
+    if (ui->toolButtonPortrait->isChecked())
     {
         return PageOrientation::Portrait;
     }
@@ -617,11 +702,23 @@ auto DialogSaveLayout::GetYScale() const -> qreal
     return ui->doubleSpinBoxVerticalScale->value() / 100.;
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void DialogSaveLayout::SetBoundaryTogetherWithNotches(bool value)
+{
+    ui->checkBoxTogetherWithNotches->setChecked(value);
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto DialogSaveLayout::IsBoundaryTogetherWithNotches() const -> bool
+{
+    return ui->checkBoxTogetherWithNotches->isChecked();
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void DialogSaveLayout::showEvent(QShowEvent *event)
 {
-    QDialog::showEvent( event );
-    if ( event->spontaneous() )
+    QDialog::showEvent(event);
+    if (event->spontaneous())
     {
         return;
     }
@@ -634,7 +731,7 @@ void DialogSaveLayout::showEvent(QShowEvent *event)
 
     setFixedHeight(size().height());
 
-    m_isInitialized = true;//first show windows are held
+    m_isInitialized = true; // first show windows are held
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -649,14 +746,12 @@ auto DialogSaveLayout::SupportPSTest() -> bool
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-auto DialogSaveLayout::InitFormats() -> QVector<std::pair<QString, LayoutExportFormats> >
+auto DialogSaveLayout::InitFormats() -> QVector<std::pair<QString, LayoutExportFormats>>
 {
     QVector<std::pair<QString, LayoutExportFormats>> list;
 
     auto InitFormat = [&list](LayoutExportFormats format)
-    {
-        list.append(std::make_pair(VLayoutExporter::ExportFormatDescription(format), format));
-    };
+    { list.append(std::make_pair(VLayoutExporter::ExportFormatDescription(format), format)); };
 
     InitFormat(LayoutExportFormats::SVG);
     InitFormat(LayoutExportFormats::PDF);
@@ -676,28 +771,14 @@ auto DialogSaveLayout::InitFormats() -> QVector<std::pair<QString, LayoutExportF
     InitFormat(LayoutExportFormats::DXF_AC1021_Flat);
     InitFormat(LayoutExportFormats::DXF_AC1024_Flat);
     InitFormat(LayoutExportFormats::DXF_AC1027_Flat);
-    InitFormat(LayoutExportFormats::DXF_AC1006_AAMA);
-    InitFormat(LayoutExportFormats::DXF_AC1009_AAMA);
-    InitFormat(LayoutExportFormats::DXF_AC1012_AAMA);
-    InitFormat(LayoutExportFormats::DXF_AC1014_AAMA);
-    InitFormat(LayoutExportFormats::DXF_AC1015_AAMA);
-    InitFormat(LayoutExportFormats::DXF_AC1018_AAMA);
-    InitFormat(LayoutExportFormats::DXF_AC1021_AAMA);
-    InitFormat(LayoutExportFormats::DXF_AC1024_AAMA);
-    InitFormat(LayoutExportFormats::DXF_AC1027_AAMA);
-    InitFormat(LayoutExportFormats::DXF_AC1006_ASTM);
-    InitFormat(LayoutExportFormats::DXF_AC1009_ASTM);
-    InitFormat(LayoutExportFormats::DXF_AC1012_ASTM);
-    InitFormat(LayoutExportFormats::DXF_AC1014_ASTM);
-    InitFormat(LayoutExportFormats::DXF_AC1015_ASTM);
-    InitFormat(LayoutExportFormats::DXF_AC1018_ASTM);
-    InitFormat(LayoutExportFormats::DXF_AC1021_ASTM);
-    InitFormat(LayoutExportFormats::DXF_AC1024_ASTM);
-    InitFormat(LayoutExportFormats::DXF_AC1027_ASTM);
-    InitFormat(LayoutExportFormats::PDFTiled); 
-//    InitFormat(LayoutExportFormats::NC);
+    InitFormat(LayoutExportFormats::DXF_AAMA);
+    InitFormat(LayoutExportFormats::DXF_ASTM);
+    InitFormat(LayoutExportFormats::PDFTiled);
+    //    InitFormat(LayoutExportFormats::NC);
     InitFormat(LayoutExportFormats::RLD);
     InitFormat(LayoutExportFormats::TIF);
+    InitFormat(LayoutExportFormats::HPGL);
+    InitFormat(LayoutExportFormats::HPGL2);
 
     return list;
 }
@@ -737,10 +818,11 @@ void DialogSaveLayout::ReadSettings()
     ui->doubleSpinBoxBottomField->setSuffix(UnitsToStr(unit, true));
 
     // read Template
-    const QSizeF size = QSizeF(settings->GetTiledPDFPaperWidth(Unit::Mm), settings->GetTiledPDFPaperHeight(Unit::Mm));
+    const QSizeF size = VAbstractLayoutDialog::RoundTemplateSize(settings->GetTiledPDFPaperWidth(Unit::Mm),
+                                                                 settings->GetTiledPDFPaperHeight(Unit::Mm), Unit::Mm);
 
-    const int max = static_cast<int>(PaperSizeTemplate::Custom);
-    for (int i=0; i < max; ++i)
+    const auto max = static_cast<int>(PaperSizeTemplate::Custom);
+    for (int i = 0; i < max; ++i)
     {
 
         const QSizeF tmplSize = GetTemplateSize(static_cast<PaperSizeTemplate>(i), Unit::Mm);
@@ -752,7 +834,7 @@ void DialogSaveLayout::ReadSettings()
     }
 
     // read Orientation
-    if(settings->GetTiledPDFOrientation() == PageOrientation::Portrait)
+    if (settings->GetTiledPDFOrientation() == PageOrientation::Portrait)
     {
         ui->toolButtonPortrait->setChecked(true);
     }
@@ -763,12 +845,29 @@ void DialogSaveLayout::ReadSettings()
 
     if (m_mode != Draw::Layout)
     {
-        SelectFormat(static_cast<LayoutExportFormats>(settings->GetDetailExportFormat()));
+        try
+        {
+            SelectFormat(static_cast<LayoutExportFormats>(settings->GetDetailExportFormat()));
+        }
+        catch (VException &e)
+        {
+            qDebug() << qUtf8Printable(e.ErrorMessage());
+        }
     }
     else
     {
-        SelectFormat(static_cast<LayoutExportFormats>(settings->GetLayoutExportFormat()));
+        try
+        {
+            SelectFormat(static_cast<LayoutExportFormats>(settings->GetLayoutExportFormat()));
+        }
+        catch (VException &e)
+        {
+            qDebug() << qUtf8Printable(e.ErrorMessage());
+        }
+        SetShowGrainline(settings->GetShowGrainline());
     }
+
+    SetDxfCompatibility(static_cast<DXFApparelCompatibility>(settings->GetDxfCompatibility()));
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -787,23 +886,19 @@ void DialogSaveLayout::WriteSettings() const
     const Unit unit = VAbstractValApplication::VApp()->patternUnits();
 
     // write Margins top, right, bottom, left
-    QMarginsF margins = QMarginsF(
-        ui->doubleSpinBoxLeftField->value(),
-        ui->doubleSpinBoxTopField->value(),
-        ui->doubleSpinBoxRightField->value(),
-        ui->doubleSpinBoxBottomField->value()
-    );
-    settings->SetTiledPDFMargins(margins,unit);
+    auto const margins = QMarginsF(ui->doubleSpinBoxLeftField->value(), ui->doubleSpinBoxTopField->value(),
+                                   ui->doubleSpinBoxRightField->value(), ui->doubleSpinBoxBottomField->value());
+    settings->SetTiledPDFMargins(margins, unit);
 
     // write Template
-    const PaperSizeTemplate temp = static_cast<PaperSizeTemplate>(ui->comboBoxTemplates->currentData().toInt());
+    const auto temp = static_cast<PaperSizeTemplate>(ui->comboBoxTemplates->currentData().toInt());
     const QSizeF size = GetTemplateSize(temp, Unit::Mm);
 
     settings->SetTiledPDFPaperHeight(size.height(), Unit::Mm);
     settings->SetTiledPDFPaperWidth(size.width(), Unit::Mm);
 
     // write Orientation
-    if(ui->toolButtonPortrait->isChecked())
+    if (ui->toolButtonPortrait->isChecked())
     {
         settings->SetTiledPDFOrientation(PageOrientation::Portrait);
     }
@@ -819,6 +914,21 @@ void DialogSaveLayout::WriteSettings() const
     else
     {
         settings->SetLayoutExportFormat(static_cast<qint8>(Format()));
+        settings->SetShowGrainline(IsShowGrainline());
     }
+
+    settings->SetDxfCompatibility(static_cast<qint8>(DxfCompatibility()));
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void DialogSaveLayout::InitDxfCompatibility()
+{
+    ui->comboBoxDxfCompatibility->addItem(tr("By standard"),
+                                          QVariant(static_cast<int>(DXFApparelCompatibility::STANDARD)));
+    ui->comboBoxDxfCompatibility->addItem("Richpeace CAD V8"_L1,
+                                          QVariant(static_cast<int>(DXFApparelCompatibility::RPCADV08)));
+    ui->comboBoxDxfCompatibility->addItem("Richpeace CAD V9"_L1,
+                                          QVariant(static_cast<int>(DXFApparelCompatibility::RPCADV09)));
+    ui->comboBoxDxfCompatibility->addItem("Richpeace CAD V10"_L1,
+                                          QVariant(static_cast<int>(DXFApparelCompatibility::RPCADV10)));
+}
