@@ -29,16 +29,17 @@
 #ifndef DIALOGSAVELAYOUT_H
 #define DIALOGSAVELAYOUT_H
 
+#include "../vdxf/dxfdef.h"
 #include "../vlayout/dialogs/vabstractlayoutdialog.h"
 #include "../vlayout/vlayoutdef.h"
 #include "../vmisc/def.h"
 
 namespace Ui
 {
-    class DialogSaveLAyout;
+class DialogSaveLAyout;
 }
 
-class DialogSaveLayout : public  VAbstractLayoutDialog
+class DialogSaveLayout : public VAbstractLayoutDialog
 {
     Q_OBJECT // NOLINT
 
@@ -56,8 +57,16 @@ public:
     void SetBinaryDXFFormat(bool binary);
     auto IsBinaryDXFFormat() const -> bool;
 
+    auto DxfCompatibility() const -> DXFApparelCompatibility;
+    void SetDxfCompatibility(DXFApparelCompatibility type);
+
+    void SetShowGrainline(bool show);
+    auto IsShowGrainline() const -> bool;
+
     static auto MakeHelpFormatList() -> QString;
-    void SetDestinationPath(const QString& cmdDestinationPath);
+    static auto MakeHelpDxfApparelCompatibilityList() -> QString;
+
+    void SetDestinationPath(const QString &cmdDestinationPath);
 
     auto Mode() const -> Draw;
 
@@ -81,6 +90,9 @@ public:
     void SetYScale(qreal scale);
     auto GetYScale() const -> qreal;
 
+    void SetBoundaryTogetherWithNotches(bool value);
+    auto IsBoundaryTogetherWithNotches() const -> bool;
+
 protected:
     void showEvent(QShowEvent *event) override;
 
@@ -91,6 +103,7 @@ private slots:
     void ToggleScaleConnection();
     void HorizontalScaleChanged(double d);
     void VerticalScaleChanged(double d);
+
 private:
     // cppcheck-suppress unknownMacro
     Q_DISABLE_COPY_MOVE(DialogSaveLayout) // NOLINT
@@ -102,14 +115,16 @@ private:
     bool m_scaleConnected{true};
 
     static bool havePdf; // NOLINT(cppcoreguidelines-avoid-non-const-global-variables)
-    static bool tested; // NOLINT(cppcoreguidelines-avoid-non-const-global-variables)
+    static bool tested;  // NOLINT(cppcoreguidelines-avoid-non-const-global-variables)
     static auto SupportPSTest() -> bool;
-    static auto InitFormats() -> QVector<std::pair<QString, LayoutExportFormats> >;
+    static auto InitFormats() -> QVector<std::pair<QString, LayoutExportFormats>>;
 
     void RemoveFormatFromList(LayoutExportFormats format);
 
     void ReadSettings();
     void WriteSettings() const;
+
+    void InitDxfCompatibility();
 };
 
 #endif // DIALOGSAVELAYOUT_H
