@@ -26,26 +26,25 @@
  **
  *************************************************************************/
 #include "vwidgetbackgroundimages.h"
-#include "ui_vwidgetbackgroundimages.h"
-
-#include "../vmisc/def.h"
 #include "../ifc/xml/vabstractpattern.h"
 #include "../ifc/xml/vbackgroundpatternimage.h"
-#include "../vtools/undocommands/image/holdbackgroundimage.h"
-#include "../vtools/undocommands/image/renamebackgroundimage.h"
-#include "../vtools/undocommands/image/hidebackgroundimage.h"
+#include "../vmisc/def.h"
+#include "../vmisc/lambdaconstants.h"
+#include "../vmisc/theme/themeDef.h"
+#include "../vmisc/theme/vtheme.h"
+#include "../vmisc/vabstractapplication.h"
 #include "../vtools/undocommands/image/hideallbackgroundimages.h"
+#include "../vtools/undocommands/image/hidebackgroundimage.h"
 #include "../vtools/undocommands/image/holdallbackgroundimages.h"
-#include "../vtools/undocommands/image/zvaluemovebackgroundimage.h"
+#include "../vtools/undocommands/image/holdbackgroundimage.h"
 #include "../vtools/undocommands/image/movebackgroundimage.h"
+#include "../vtools/undocommands/image/renamebackgroundimage.h"
+#include "../vtools/undocommands/image/resetbackgroundimage.h"
 #include "../vtools/undocommands/image/rotatebackgroundimage.h"
 #include "../vtools/undocommands/image/scalebackgroundimage.h"
-#include "../vtools/undocommands/image/resetbackgroundimage.h"
-#include "../vmisc/vabstractapplication.h"
-#include "../vmisc/lambdaconstants.h"
-#if QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
-#include "../vmisc/backport/qoverload.h"
-#endif // QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
+#include "../vtools/undocommands/image/zvaluemovebackgroundimage.h"
+#include "../vwidgets/vmousewheelwidgetadjustmentguard.h"
+#include "ui_vwidgetbackgroundimages.h"
 
 #include <QMenu>
 #include <QPushButton>
@@ -64,8 +63,9 @@ void SetImageHold(QTableWidgetItem *item, const VBackgroundPatternImage &image)
 {
     if (item)
     {
-        (image.Hold()) ? item->setIcon(QIcon(QStringLiteral("://icon/16x16/hold_image.png")))
-                       : item->setIcon(QIcon(QStringLiteral("://icon/16x16/not_hold_image.png")));
+        const auto resource = QStringLiteral("icon");
+        (image.Hold()) ? item->setIcon(VTheme::GetIconResource(resource, QStringLiteral("16x16/hold_image.png")))
+                       : item->setIcon(VTheme::GetIconResource(resource, QStringLiteral("16x16/not_hold_image.png")));
     }
 }
 
@@ -74,8 +74,9 @@ void SetImageVisibility(QTableWidgetItem *item, const VBackgroundPatternImage &i
 {
     if (item)
     {
-        (image.Visible()) ? item->setIcon(QIcon(QStringLiteral("://icon/16x16/open_eye.png")))
-                          : item->setIcon(QIcon(QStringLiteral("://icon/16x16/closed_eye.png")));
+        const auto resource = QStringLiteral("icon");
+        item->setIcon(image.Visible() ? VTheme::GetIconResource(resource, QStringLiteral("16x16/open_eye.png"))
+                                      : VTheme::GetIconResource(resource, QStringLiteral("16x16/closed_eye.png")));
     }
 }
 
@@ -149,12 +150,21 @@ auto ScaleUnitConvertor(qreal base, qreal value, ScaleUnit from, ScaleUnit to) -
 
 //---------------------------------------------------------------------------------------------------------------------
 VWidgetBackgroundImages::VWidgetBackgroundImages(VAbstractPattern *doc, QWidget *parent)
-    : QWidget(parent),
-      ui(new Ui::VWidgetBackgroundImages),
-      m_doc(doc)
+  : QWidget(parent),
+    ui(new Ui::VWidgetBackgroundImages),
+    m_doc(doc)
 {
     ui->setupUi(this);
 
+    // Prevent stealing focus when scrolling
+    VMouseWheelWidgetAdjustmentGuard::InstallEventFilter(ui->doubleSpinBoxImageHorizontalTranslate);
+    VMouseWheelWidgetAdjustmentGuard::InstallEventFilter(ui->comboBoxTranslateUnit);
+    VMouseWheelWidgetAdjustmentGuard::InstallEventFilter(ui->doubleSpinBoxImageVerticalTranslate);
+    VMouseWheelWidgetAdjustmentGuard::InstallEventFilter(ui->doubleSpinBoxScaleWidth);
+    VMouseWheelWidgetAdjustmentGuard::InstallEventFilter(ui->comboBoxScaleUnit);
+    VMouseWheelWidgetAdjustmentGuard::InstallEventFilter(ui->doubleSpinBoxScaleHeight);
+    VMouseWheelWidgetAdjustmentGuard::InstallEventFilter(ui->doubleSpinBoxRotationAngle);
+
     SCASSERT(doc != nullptr)
 
     UpdateImages();
@@ -200,13 +210,13 @@ void VWidgetBackgroundImages::UpdateImages()
 //---------------------------------------------------------------------------------------------------------------------
 void VWidgetBackgroundImages::UpdateImage(const QUuid &id)
 {
-    int row = ImageRow(id);
+    int const row = ImageRow(id);
     if (row == -1)
     {
         return;
     }
 
-    VBackgroundPatternImage image = m_doc->GetBackgroundImage(id);
+    VBackgroundPatternImage const image = m_doc->GetBackgroundImage(id);
     if (image.IsNull())
     {
         return;
@@ -229,7 +239,7 @@ void VWidgetBackgroundImages::UpdateImage(const QUuid &id)
 //---------------------------------------------------------------------------------------------------------------------
 void VWidgetBackgroundImages::ImageSelected(const QUuid &id)
 {
-    int row = ImageRow(id);
+    int const row = ImageRow(id);
 
     ui->tableWidget->blockSignals(true);
     ui->tableWidget->setCurrentCell(row, ImageData::Name);
@@ -291,7 +301,7 @@ void VWidgetBackgroundImages::ImageNameChanged(int row, int column)
 void VWidgetBackgroundImages::ContextMenu(const QPoint &pos)
 {
     QTableWidgetItem *item = ui->tableWidget->itemAt(pos);
-    if(item == nullptr)
+    if (item == nullptr)
     {
         return;
     }
@@ -299,7 +309,7 @@ void VWidgetBackgroundImages::ContextMenu(const QPoint &pos)
     const int row = item->row();
     item = ui->tableWidget->item(row, 0);
     const QUuid id = item->data(Qt::UserRole).toUuid();
-    VBackgroundPatternImage image = m_doc->GetBackgroundImage(id);
+    VBackgroundPatternImage const image = m_doc->GetBackgroundImage(id);
     if (image.IsNull())
     {
         return;
@@ -346,7 +356,7 @@ void VWidgetBackgroundImages::ContextMenu(const QPoint &pos)
     QAction *actionReset = menu.addAction(tr("Reset transformation"));
     actionReset->setEnabled(not image.Hold());
 
-    QAction *actionDelete = menu.addAction(QIcon::fromTheme(editDeleteIcon), tr("Delete"));
+    QAction *actionDelete = menu.addAction(FromTheme(VThemeIcon::EditDelete), tr("Delete"));
 
     menu.addSeparator();
     QAction *actionHoldAll = menu.addAction(tr("Hold All"));
@@ -401,7 +411,8 @@ void VWidgetBackgroundImages::ContextMenu(const QPoint &pos)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VWidgetBackgroundImages::CurrentImageChanged(int currentRow, int currentColumn, int previousRow, int previousColumn)
+void VWidgetBackgroundImages::CurrentImageChanged(int currentRow, int currentColumn, int previousRow,
+                                                  int previousColumn)
 {
     Q_UNUSED(currentColumn)
     Q_UNUSED(previousColumn)
@@ -418,7 +429,7 @@ void VWidgetBackgroundImages::CurrentImageChanged(int currentRow, int currentCol
 //---------------------------------------------------------------------------------------------------------------------
 void VWidgetBackgroundImages::MoveImageOnTop()
 {
-    int row = ui->tableWidget->currentRow();
+    int const row = ui->tableWidget->currentRow();
     if (row == -1)
     {
         return;
@@ -427,8 +438,8 @@ void VWidgetBackgroundImages::MoveImageOnTop()
     QTableWidgetItem *item = ui->tableWidget->item(row, 0);
     if (item != nullptr)
     {
-        QUuid id = item->data(Qt::UserRole).toUuid();
-        auto *command = new ZValueMoveBackgroundImage(id, ZValueMove::Top, m_doc);
+        QUuid const id = item->data(Qt::UserRole).toUuid();
+        auto *command = new ZValueMoveBackgroundImage(id, ZValueMoveType::Top, m_doc);
         VAbstractApplication::VApp()->getUndoStack()->push(command);
     }
 }
@@ -436,7 +447,7 @@ void VWidgetBackgroundImages::MoveImageOnTop()
 //---------------------------------------------------------------------------------------------------------------------
 void VWidgetBackgroundImages::MoveImageUp()
 {
-    int row = ui->tableWidget->currentRow();
+    int const row = ui->tableWidget->currentRow();
     if (row == -1)
     {
         return;
@@ -445,8 +456,8 @@ void VWidgetBackgroundImages::MoveImageUp()
     QTableWidgetItem *item = ui->tableWidget->item(row, 0);
     if (item != nullptr)
     {
-        QUuid id = item->data(Qt::UserRole).toUuid();
-        auto *command = new ZValueMoveBackgroundImage(id, ZValueMove::Up, m_doc);
+        QUuid const id = item->data(Qt::UserRole).toUuid();
+        auto *command = new ZValueMoveBackgroundImage(id, ZValueMoveType::Up, m_doc);
         VAbstractApplication::VApp()->getUndoStack()->push(command);
     }
 }
@@ -454,7 +465,7 @@ void VWidgetBackgroundImages::MoveImageUp()
 //---------------------------------------------------------------------------------------------------------------------
 void VWidgetBackgroundImages::MoveImageDown()
 {
-    int row = ui->tableWidget->currentRow();
+    int const row = ui->tableWidget->currentRow();
     if (row == -1)
     {
         return;
@@ -463,8 +474,8 @@ void VWidgetBackgroundImages::MoveImageDown()
     QTableWidgetItem *item = ui->tableWidget->item(row, 0);
     if (item != nullptr)
     {
-        QUuid id = item->data(Qt::UserRole).toUuid();
-        auto *command = new ZValueMoveBackgroundImage(id, ZValueMove::Down, m_doc);
+        QUuid const id = item->data(Qt::UserRole).toUuid();
+        auto *command = new ZValueMoveBackgroundImage(id, ZValueMoveType::Down, m_doc);
         VAbstractApplication::VApp()->getUndoStack()->push(command);
     }
 }
@@ -472,7 +483,7 @@ void VWidgetBackgroundImages::MoveImageDown()
 //---------------------------------------------------------------------------------------------------------------------
 void VWidgetBackgroundImages::MoveImageBottom()
 {
-    int row = ui->tableWidget->currentRow();
+    int const row = ui->tableWidget->currentRow();
     if (row == -1)
     {
         return;
@@ -481,8 +492,8 @@ void VWidgetBackgroundImages::MoveImageBottom()
     QTableWidgetItem *item = ui->tableWidget->item(row, 0);
     if (item != nullptr)
     {
-        QUuid id = item->data(Qt::UserRole).toUuid();
-        auto *command = new ZValueMoveBackgroundImage(id, ZValueMove::Bottom, m_doc);
+        QUuid const id = item->data(Qt::UserRole).toUuid();
+        auto *command = new ZValueMoveBackgroundImage(id, ZValueMoveType::Bottom, m_doc);
         VAbstractApplication::VApp()->getUndoStack()->push(command);
     }
 }
@@ -490,7 +501,7 @@ void VWidgetBackgroundImages::MoveImageBottom()
 //---------------------------------------------------------------------------------------------------------------------
 void VWidgetBackgroundImages::ApplyImageTransformation()
 {
-    int row = ui->tableWidget->currentRow();
+    int const row = ui->tableWidget->currentRow();
     if (row == -1)
     {
         return;
@@ -502,8 +513,8 @@ void VWidgetBackgroundImages::ApplyImageTransformation()
         return;
     }
 
-    QUuid id = item->data(Qt::UserRole).toUuid();
-    VBackgroundPatternImage image = m_doc->GetBackgroundImage(id);
+    QUuid const id = item->data(Qt::UserRole).toUuid();
+    VBackgroundPatternImage const image = m_doc->GetBackgroundImage(id);
 
     if (image.IsNull() || image.Hold())
     {
@@ -518,7 +529,7 @@ void VWidgetBackgroundImages::ApplyImageTransformation()
 
         if (not ui->checkBoxRelativeTranslation->isChecked())
         {
-            QRectF rect = image.BoundingRect();
+            QRectF const rect = image.BoundingRect();
             dx = dx - rect.topLeft().x();
             dy = dy - rect.topLeft().y();
         }
@@ -528,13 +539,14 @@ void VWidgetBackgroundImages::ApplyImageTransformation()
     }
     else if (ui->tabWidgetImageTransformation->indexOf(ui->tabScale) == index)
     { // scale
-        qreal sx = WidthScaleUnitConvertor(ui->doubleSpinBoxScaleWidth->value(), CurrentScaleUnit(),
-                                           ScaleUnit::Percent) / 100;
-        qreal sy = HeightScaleUnitConvertor(ui->doubleSpinBoxScaleHeight->value(), CurrentScaleUnit(),
-                                            ScaleUnit::Percent) / 100;
+        qreal const sx =
+            WidthScaleUnitConvertor(ui->doubleSpinBoxScaleWidth->value(), CurrentScaleUnit(), ScaleUnit::Percent) / 100;
+        qreal const sy =
+            HeightScaleUnitConvertor(ui->doubleSpinBoxScaleHeight->value(), CurrentScaleUnit(), ScaleUnit::Percent) /
+            100;
 
         QTransform imageMatrix = image.Matrix();
-        QPointF originPos = image.BoundingRect().center();
+        QPointF const originPos = image.BoundingRect().center();
 
         QTransform m;
         m.translate(originPos.x(), originPos.y());
@@ -544,7 +556,6 @@ void VWidgetBackgroundImages::ApplyImageTransformation()
 
         auto *command = new ScaleBackgroundImage(id, imageMatrix, m_doc);
         VAbstractApplication::VApp()->getUndoStack()->push(command);
-
     }
     else if (ui->tabWidgetImageTransformation->indexOf(ui->tabRotate) == index)
     { // rotate
@@ -557,7 +568,7 @@ void VWidgetBackgroundImages::ApplyImageTransformation()
 
         QTransform imageMatrix = image.Matrix();
 
-        QPointF originPos = image.BoundingRect().center();
+        QPointF const originPos = image.BoundingRect().center();
 
         QTransform m;
         m.translate(originPos.x(), originPos.y());
@@ -590,7 +601,7 @@ void VWidgetBackgroundImages::ResetImageTransformationSettings()
             }
         }
 
-        int unitIndex = ui->comboBoxTranslateUnit->findData(QVariant(static_cast<int>(Unit::Px)));
+        int const unitIndex = ui->comboBoxTranslateUnit->findData(QVariant(static_cast<int>(Unit::Px)));
         if (unitIndex != -1)
         {
             ui->comboBoxTranslateUnit->setCurrentIndex(unitIndex);
@@ -598,8 +609,8 @@ void VWidgetBackgroundImages::ResetImageTransformationSettings()
     }
     else if (ui->tabWidgetImageTransformation->indexOf(ui->tabScale) == index)
     { // scale
-        int unitIndex = ui->comboBoxScaleUnit->findData(QVariant(static_cast<int>(ScaleUnit::Percent)));
-        if (unitIndex != -1)
+        if (int const unitIndex = ui->comboBoxScaleUnit->findData(QVariant(static_cast<int>(ScaleUnit::Percent)));
+            unitIndex != -1)
         {
             ui->comboBoxScaleUnit->setCurrentIndex(unitIndex);
         }
@@ -623,7 +634,7 @@ void VWidgetBackgroundImages::RelativeTranslationChanged(bool checked)
     }
     else
     {
-        int row = ui->tableWidget->currentRow();
+        int const row = ui->tableWidget->currentRow();
         if (row == -1)
         {
             return;
@@ -632,7 +643,7 @@ void VWidgetBackgroundImages::RelativeTranslationChanged(bool checked)
         QTableWidgetItem *item = ui->tableWidget->item(row, 0);
         if (item != nullptr)
         {
-            QUuid id = item->data(Qt::UserRole).toUuid();
+            QUuid const id = item->data(Qt::UserRole).toUuid();
             SetAbsolutePisition(id);
         }
     }
@@ -643,7 +654,7 @@ void VWidgetBackgroundImages::ScaleProportionallyChanged(bool checked)
 {
     if (checked)
     {
-        qreal value = ui->doubleSpinBoxScaleWidth->value();
+        qreal const value = ui->doubleSpinBoxScaleWidth->value();
         ui->doubleSpinBoxScaleHeight->setValue(value);
     }
 }
@@ -653,7 +664,7 @@ void VWidgetBackgroundImages::ScaleWidthChanged(double value)
 {
     if (ui->checkBoxScaleProportionally->isChecked())
     {
-        ScaleUnit unit = CurrentScaleUnit();
+        ScaleUnit const unit = CurrentScaleUnit();
         if (unit == ScaleUnit::Percent)
         {
             ui->doubleSpinBoxScaleHeight->blockSignals(true);
@@ -662,9 +673,9 @@ void VWidgetBackgroundImages::ScaleWidthChanged(double value)
         }
         else
         {
-            qreal factor = WidthScaleUnitConvertor(value, unit, ScaleUnit::Percent) / 100.;
-            qreal heightPx = ImageHeight() * factor;
-            qreal height = HeightScaleUnitConvertor(heightPx, ScaleUnit::Px, unit);
+            qreal const factor = WidthScaleUnitConvertor(value, unit, ScaleUnit::Percent) / 100.;
+            qreal const heightPx = ImageHeight() * factor;
+            qreal const height = HeightScaleUnitConvertor(heightPx, ScaleUnit::Px, unit);
 
             ui->doubleSpinBoxScaleHeight->blockSignals(true);
             ui->doubleSpinBoxScaleHeight->setValue(height);
@@ -678,7 +689,7 @@ void VWidgetBackgroundImages::ScaleHeightChanged(double value)
 {
     if (ui->checkBoxScaleProportionally->isChecked())
     {
-        ScaleUnit unit = CurrentScaleUnit();
+        ScaleUnit const unit = CurrentScaleUnit();
         if (unit == ScaleUnit::Percent)
         {
             ui->doubleSpinBoxScaleWidth->blockSignals(true);
@@ -687,9 +698,9 @@ void VWidgetBackgroundImages::ScaleHeightChanged(double value)
         }
         else
         {
-            qreal factor = HeightScaleUnitConvertor(value, unit, ScaleUnit::Percent) / 100.;
-            qreal widthPx = ImageWidth() * factor;
-            qreal width = WidthScaleUnitConvertor(widthPx, ScaleUnit::Px, unit);
+            qreal const factor = HeightScaleUnitConvertor(value, unit, ScaleUnit::Percent) / 100.;
+            qreal const widthPx = ImageWidth() * factor;
+            qreal const width = WidthScaleUnitConvertor(widthPx, ScaleUnit::Px, unit);
 
             ui->doubleSpinBoxScaleHeight->blockSignals(true);
             ui->doubleSpinBoxScaleHeight->setValue(width);
@@ -706,7 +717,7 @@ void VWidgetBackgroundImages::ImagePositionChanged(const QUuid &id)
         return;
     }
 
-    int row = ui->tableWidget->currentRow();
+    int const row = ui->tableWidget->currentRow();
     if (row == -1)
     {
         return;
@@ -715,8 +726,7 @@ void VWidgetBackgroundImages::ImagePositionChanged(const QUuid &id)
     QTableWidgetItem *item = ui->tableWidget->item(row, 0);
     if (item != nullptr)
     {
-        QUuid curentId = item->data(Qt::UserRole).toUuid();
-        if (curentId != id)
+        if (QUuid const curentId = item->data(Qt::UserRole).toUuid(); curentId != id)
         {
             return;
         }
@@ -732,7 +742,7 @@ void VWidgetBackgroundImages::FillTable(const QVector<VBackgroundPatternImage> &
     ui->tableWidget->clear();
 
     ui->tableWidget->setColumnCount(3);
-    ui->tableWidget->setRowCount(images.size());
+    ui->tableWidget->setRowCount(static_cast<int>(images.size()));
     qint32 currentRow = -1;
 
     auto ReadOnly = [](QTableWidgetItem *item)
@@ -778,7 +788,7 @@ void VWidgetBackgroundImages::FillTable(const QVector<VBackgroundPatternImage> &
 //---------------------------------------------------------------------------------------------------------------------
 void VWidgetBackgroundImages::ToggleImageHold(const QUuid &id) const
 {
-    VBackgroundPatternImage image = m_doc->GetBackgroundImage(id);
+    VBackgroundPatternImage const image = m_doc->GetBackgroundImage(id);
     if (not image.IsNull())
     {
         auto *command = new HoldBackgroundImage(image.Id(), not image.Hold(), m_doc);
@@ -789,7 +799,7 @@ void VWidgetBackgroundImages::ToggleImageHold(const QUuid &id) const
 //---------------------------------------------------------------------------------------------------------------------
 void VWidgetBackgroundImages::ToggleImageVisibility(const QUuid &id) const
 {
-    VBackgroundPatternImage image = m_doc->GetBackgroundImage(id);
+    VBackgroundPatternImage const image = m_doc->GetBackgroundImage(id);
     if (not image.IsNull())
     {
         auto *command = new HideBackgroundImage(image.Id(), image.Visible(), m_doc);
@@ -841,37 +851,37 @@ void VWidgetBackgroundImages::InitImageTranslation()
     const int maxTranslate = 10000;
 
     ui->doubleSpinBoxImageHorizontalTranslate->setMinimum(
-                UnitConvertor(minTranslate, Unit::Cm, m_oldImageTranslationUnit));
+        UnitConvertor(minTranslate, Unit::Cm, m_oldImageTranslationUnit));
     ui->doubleSpinBoxImageHorizontalTranslate->setMaximum(
-                UnitConvertor(maxTranslate, Unit::Cm, m_oldImageTranslationUnit));
+        UnitConvertor(maxTranslate, Unit::Cm, m_oldImageTranslationUnit));
     ui->doubleSpinBoxImageHorizontalTranslate->setValue(0);
 
     ui->doubleSpinBoxImageVerticalTranslate->setMinimum(
-                UnitConvertor(minTranslate, Unit::Cm, m_oldImageTranslationUnit));
+        UnitConvertor(minTranslate, Unit::Cm, m_oldImageTranslationUnit));
     ui->doubleSpinBoxImageVerticalTranslate->setMaximum(
-                UnitConvertor(maxTranslate, Unit::Cm, m_oldImageTranslationUnit));
+        UnitConvertor(maxTranslate, Unit::Cm, m_oldImageTranslationUnit));
     ui->doubleSpinBoxImageVerticalTranslate->setValue(0);
 
     connect(ui->comboBoxTranslateUnit, QOverload<int>::of(&QComboBox::currentIndexChanged), this,
             [this V_LAMBDA_CONSTANTS(minTranslate, maxTranslate)]()
-    {
-        const Unit newUnit = CurrentTranslateUnit();
-        const qreal oldTranslateX = ui->doubleSpinBoxImageHorizontalTranslate->value();
-        const qreal oldTranslateY = ui->doubleSpinBoxImageVerticalTranslate->value();
+            {
+                const Unit newUnit = CurrentTranslateUnit();
+                const qreal oldTranslateX = ui->doubleSpinBoxImageHorizontalTranslate->value();
+                const qreal oldTranslateY = ui->doubleSpinBoxImageVerticalTranslate->value();
 
-        ui->doubleSpinBoxImageHorizontalTranslate->setMinimum(UnitConvertor(minTranslate, Unit::Cm, newUnit));
-        ui->doubleSpinBoxImageHorizontalTranslate->setMaximum(UnitConvertor(maxTranslate, Unit::Cm, newUnit));
+                ui->doubleSpinBoxImageHorizontalTranslate->setMinimum(UnitConvertor(minTranslate, Unit::Cm, newUnit));
+                ui->doubleSpinBoxImageHorizontalTranslate->setMaximum(UnitConvertor(maxTranslate, Unit::Cm, newUnit));
 
-        ui->doubleSpinBoxImageVerticalTranslate->setMinimum(UnitConvertor(minTranslate, Unit::Cm, newUnit));
-        ui->doubleSpinBoxImageVerticalTranslate->setMaximum(UnitConvertor(maxTranslate, Unit::Cm, newUnit));
+                ui->doubleSpinBoxImageVerticalTranslate->setMinimum(UnitConvertor(minTranslate, Unit::Cm, newUnit));
+                ui->doubleSpinBoxImageVerticalTranslate->setMaximum(UnitConvertor(maxTranslate, Unit::Cm, newUnit));
 
-        ui->doubleSpinBoxImageHorizontalTranslate->setValue(
+                ui->doubleSpinBoxImageHorizontalTranslate->setValue(
                     UnitConvertor(oldTranslateX, m_oldImageTranslationUnit, newUnit));
-        ui->doubleSpinBoxImageVerticalTranslate->setValue(
+                ui->doubleSpinBoxImageVerticalTranslate->setValue(
                     UnitConvertor(oldTranslateY, m_oldImageTranslationUnit, newUnit));
 
-        m_oldImageTranslationUnit = newUnit;
-    });
+                m_oldImageTranslationUnit = newUnit;
+            });
 
     SetCheckBoxValue(ui->checkBoxRelativeTranslation, true);
     connect(ui->checkBoxRelativeTranslation, &QCheckBox::toggled, this,
@@ -899,40 +909,40 @@ void VWidgetBackgroundImages::InitImageTranslation()
     ui->doubleSpinBoxScaleHeight->setMaximum(maxScale);
     ui->doubleSpinBoxScaleHeight->setValue(100);
 
-    connect(ui->comboBoxScaleUnit, QOverload<int>::of(&QComboBox::currentIndexChanged), this,
-            [this V_LAMBDA_CONSTANTS(minScale, maxScale)]()
-    {
-        const ScaleUnit newUnit = CurrentScaleUnit();
-        const qreal oldScaleWidth = ui->doubleSpinBoxScaleWidth->value();
-        const qreal oldScaleHeight = ui->doubleSpinBoxScaleHeight->value();
-
-        ui->doubleSpinBoxScaleWidth->blockSignals(true);
-
-        ui->doubleSpinBoxScaleWidth->setMinimum(WidthScaleUnitConvertor(minScale, ScaleUnit::Percent, newUnit));
-        ui->doubleSpinBoxScaleWidth->setMinimum(WidthScaleUnitConvertor(minScale, ScaleUnit::Percent, newUnit));
-
-        ui->doubleSpinBoxScaleWidth->setValue(
-                    WidthScaleUnitConvertor(oldScaleWidth, m_oldImageScaleUnit, newUnit));
-        ui->doubleSpinBoxScaleWidth->blockSignals(false);
-
-        ui->doubleSpinBoxScaleHeight->blockSignals(true);
-
-        ui->doubleSpinBoxScaleHeight->setMaximum(HeightScaleUnitConvertor(maxScale, ScaleUnit::Percent, newUnit));
-        ui->doubleSpinBoxScaleHeight->setMaximum(HeightScaleUnitConvertor(maxScale, ScaleUnit::Percent, newUnit));
-
-        if (ui->checkBoxScaleProportionally->isChecked() && newUnit == ScaleUnit::Percent)
+    connect(
+        ui->comboBoxScaleUnit, QOverload<int>::of(&QComboBox::currentIndexChanged), this,
+        [this V_LAMBDA_CONSTANTS(minScale, maxScale)]()
         {
-            ui->doubleSpinBoxScaleHeight->setValue(ui->doubleSpinBoxScaleWidth->value());
-        }
-        else
-        {
-            ui->doubleSpinBoxScaleHeight->setValue(
-                        HeightScaleUnitConvertor(oldScaleHeight, m_oldImageScaleUnit, newUnit));
-        }
-        ui->doubleSpinBoxScaleHeight->blockSignals(false);
+            const ScaleUnit newUnit = CurrentScaleUnit();
+            const qreal oldScaleWidth = ui->doubleSpinBoxScaleWidth->value();
+            const qreal oldScaleHeight = ui->doubleSpinBoxScaleHeight->value();
 
-        m_oldImageScaleUnit = newUnit;
-    });
+            ui->doubleSpinBoxScaleWidth->blockSignals(true);
+
+            ui->doubleSpinBoxScaleWidth->setMinimum(WidthScaleUnitConvertor(minScale, ScaleUnit::Percent, newUnit));
+            ui->doubleSpinBoxScaleWidth->setMinimum(WidthScaleUnitConvertor(minScale, ScaleUnit::Percent, newUnit));
+
+            ui->doubleSpinBoxScaleWidth->setValue(WidthScaleUnitConvertor(oldScaleWidth, m_oldImageScaleUnit, newUnit));
+            ui->doubleSpinBoxScaleWidth->blockSignals(false);
+
+            ui->doubleSpinBoxScaleHeight->blockSignals(true);
+
+            ui->doubleSpinBoxScaleHeight->setMaximum(HeightScaleUnitConvertor(maxScale, ScaleUnit::Percent, newUnit));
+            ui->doubleSpinBoxScaleHeight->setMaximum(HeightScaleUnitConvertor(maxScale, ScaleUnit::Percent, newUnit));
+
+            if (ui->checkBoxScaleProportionally->isChecked() && newUnit == ScaleUnit::Percent)
+            {
+                ui->doubleSpinBoxScaleHeight->setValue(ui->doubleSpinBoxScaleWidth->value());
+            }
+            else
+            {
+                ui->doubleSpinBoxScaleHeight->setValue(
+                    HeightScaleUnitConvertor(oldScaleHeight, m_oldImageScaleUnit, newUnit));
+            }
+            ui->doubleSpinBoxScaleHeight->blockSignals(false);
+
+            m_oldImageScaleUnit = newUnit;
+        });
 
     connect(ui->doubleSpinBoxScaleHeight, QOverload<double>::of(&QDoubleSpinBox::valueChanged), this,
             &VWidgetBackgroundImages::ScaleHeightChanged);
@@ -962,14 +972,13 @@ auto VWidgetBackgroundImages::ImageWidth() const -> qreal
 {
     qreal width = 0;
 
-    int row = ui->tableWidget->currentRow();
-    if (row != -1)
+    if (int const row = ui->tableWidget->currentRow(); row != -1)
     {
         QTableWidgetItem *item = ui->tableWidget->item(row, 0);
         if (item != nullptr)
         {
-            QUuid id = item->data(Qt::UserRole).toUuid();
-            VBackgroundPatternImage image = m_doc->GetBackgroundImage(id);
+            QUuid const id = item->data(Qt::UserRole).toUuid();
+            VBackgroundPatternImage const image = m_doc->GetBackgroundImage(id);
             width = image.Size().width();
         }
     }
@@ -982,14 +991,13 @@ auto VWidgetBackgroundImages::ImageHeight() const -> qreal
 {
     qreal height = 0;
 
-    int row = ui->tableWidget->currentRow();
-    if (row != -1)
+    if (int const row = ui->tableWidget->currentRow(); row != -1)
     {
         QTableWidgetItem *item = ui->tableWidget->item(row, 0);
         if (item != nullptr)
         {
-            QUuid id = item->data(Qt::UserRole).toUuid();
-            VBackgroundPatternImage image = m_doc->GetBackgroundImage(id);
+            QUuid const id = item->data(Qt::UserRole).toUuid();
+            VBackgroundPatternImage const image = m_doc->GetBackgroundImage(id);
             height = image.Size().height();
         }
     }
@@ -1012,11 +1020,11 @@ auto VWidgetBackgroundImages::HeightScaleUnitConvertor(qreal value, ScaleUnit fr
 //---------------------------------------------------------------------------------------------------------------------
 void VWidgetBackgroundImages::SetAbsolutePisition(const QUuid &id)
 {
-    VBackgroundPatternImage image = m_doc->GetBackgroundImage(id);
-    QRectF rect = image.BoundingRect();
+    VBackgroundPatternImage const image = m_doc->GetBackgroundImage(id);
+    QRectF const rect = image.BoundingRect();
 
     ui->doubleSpinBoxImageHorizontalTranslate->setValue(
-                UnitConvertor(rect.topLeft().x(), Unit::Px, CurrentTranslateUnit()));
+        UnitConvertor(rect.topLeft().x(), Unit::Px, CurrentTranslateUnit()));
     ui->doubleSpinBoxImageVerticalTranslate->setValue(
-                UnitConvertor(rect.topLeft().y(), Unit::Px, CurrentTranslateUnit()));
+        UnitConvertor(rect.topLeft().y(), Unit::Px, CurrentTranslateUnit()));
 }
