@@ -32,7 +32,7 @@
 #include <QtGlobal>
 #ifdef Q_OS_WIN
 //   extern Q_CORE_EXPORT int qt_ntfs_permission_lookup;
-#  include <qt_windows.h>
+#include <qt_windows.h>
 #endif /*Q_OS_WIN*/
 
 #include <QColor>
@@ -40,34 +40,32 @@
 #include <QString>
 #include <QStringList>
 
-#include "../vmisc/typedef.h"
 #include "../vmisc/def.h"
-#if QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
-#include "../vmisc/diagnostic.h"
-#endif // QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
+#include "../vmisc/typedef.h"
 
 extern const QString CustomMSign;
 extern const QString CustomIncrSign;
 
 // Detect whether the compiler supports C++11 noexcept exception specifications.
-#  if   defined(__clang__)
-#    if __has_feature(cxx_noexcept)
-#      define V_NOEXCEPT_EXPR(x) noexcept(x) // Clang 3.0 and above have noexcept
-#    endif
-#  elif defined(__GNUC__)
-#    if (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6)) && defined(__GXX_EXPERIMENTAL_CXX0X__)
-#      define V_NOEXCEPT_EXPR(x) noexcept(x) // GCC 4.7 and following have noexcept
-#    endif
-#  elif defined(_MSC_FULL_VER) && _MSC_FULL_VER >= 190023026
-#    define V_NOEXCEPT_EXPR(x) noexcept(x) // Visual Studio 2015 and following have noexcept
-#  else
-#    define V_NOEXCEPT_EXPR(x)
-#  endif
+#if defined(__clang__)
+#if __has_feature(cxx_noexcept)
+#define V_NOEXCEPT_EXPR(x) noexcept(x) // Clang 3.0 and above have noexcept
+#endif
+#elif defined(__GNUC__)
+#if (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6)) && defined(__GXX_EXPERIMENTAL_CXX0X__)
+#define V_NOEXCEPT_EXPR(x) noexcept(x) // GCC 4.7 and following have noexcept
+#endif
+#elif defined(_MSC_FULL_VER) && _MSC_FULL_VER >= 190023026
+#define V_NOEXCEPT_EXPR(x) noexcept(x) // Visual Studio 2015 and following have noexcept
+#else
+#define V_NOEXCEPT_EXPR(x)
+#endif
 
 extern const QString AttrType;
 extern const QString AttrMx;
 extern const QString AttrMy;
 extern const QString AttrName;
+extern const QString AttrShortName;
 extern const QString AttrUUID;
 extern const QString AttrGradationLabel;
 extern const QString AttrMx1;
@@ -111,9 +109,9 @@ extern const QString AttrPoint1;
 extern const QString AttrPoint2;
 extern const QString AttrPoint3;
 extern const QString AttrPoint4;
-extern const QString AttrKAsm1;// TODO. Delete if minimal supported version is 0.2.7
-extern const QString AttrKAsm2;// TODO. Delete if minimal supported version is 0.2.7
-extern const QString AttrKCurve;// TODO. Delete if minimal supported version is 0.2.7
+extern const QString AttrKAsm1;  // TODO. Delete if minimal supported version is 0.2.7
+extern const QString AttrKAsm2;  // TODO. Delete if minimal supported version is 0.2.7
+extern const QString AttrKCurve; // TODO. Delete if minimal supported version is 0.2.7
 extern const QString AttrDuplicate;
 extern const QString AttrAScale;
 extern const QString AttrPathPoint;
@@ -146,6 +144,8 @@ extern const QString AttrIdObject;
 extern const QString AttrInLayout;
 extern const QString AttrForbidFlipping;
 extern const QString AttrForceFlipping;
+extern const QString AttrFollowGrainline;
+extern const QString AttrSewLineOnDrawing;
 extern const QString AttrClosed;
 extern const QString AttrShowLabel;
 extern const QString AttrShowLabel1;
@@ -154,8 +154,8 @@ extern const QString AttrWidth;
 extern const QString AttrHeight;
 extern const QString AttrPlaceLabelType;
 extern const QString AttrVersion;
-extern const QString AttrFirstToCountour;
-extern const QString AttrLastToCountour;
+extern const QString AttrFirstToContour;
+extern const QString AttrLastToContour;
 extern const QString AttrNotes;
 extern const QString AttrAlias;
 extern const QString AttrAlias1;
@@ -165,6 +165,8 @@ extern const QString AttrCurve1Alias2;
 extern const QString AttrCurve2Alias1;
 extern const QString AttrCurve2Alias2;
 extern const QString AttrLayoutVersion;
+extern const QString AttrKMVersion;
+extern const QString AttrNotMirrored;
 
 extern const QString TypeLineDefault;
 extern const QString TypeLineNone;
@@ -174,12 +176,12 @@ extern const QString TypeLineDotLine;
 extern const QString TypeLineDashDotLine;
 extern const QString TypeLineDashDotDotLine;
 
-QStringList          StylesList();
-Qt::PenStyle         LineStyleToPenStyle(const QString &typeLine);
-QString              PenStyleToLineStyle(Qt::PenStyle penStyle);
-QIcon                PenStylePic(Qt::PenStyle style);
-QMap<QString, QIcon> LineStylesPics();
-QMap<QString, QIcon> CurvePenStylesPics();
+auto StylesList() -> QStringList;
+auto LineStyleToPenStyle(const QString &typeLine) -> Qt::PenStyle;
+auto PenStyleToLineStyle(Qt::PenStyle penStyle) -> QString;
+auto PenStylePic(QColor backgroundColor, QColor textColor, Qt::PenStyle style) -> QIcon;
+auto LineStylesPics(QColor backgroundColor, QColor textColor) -> QMap<QString, QIcon>;
+auto CurvePenStylesPics(QColor backgroundColor, QColor textColor) -> QMap<QString, QIcon>;
 
 extern const QString ColorDefault;
 extern const QString ColorBlack;
@@ -200,7 +202,6 @@ extern const QString ColorLime;
 extern const QString ColorDeepSkyBlue;
 extern const QString ColorCornFlowerBlue;
 
-
 // variables name
 // Hacks for avoiding the linker error "undefined reference to"
 #define SPL_ "Spl_"
@@ -240,8 +241,10 @@ extern const QString currentLength;
 extern const QString currentSeamAllowance;
 extern const QString rotation_V;
 extern const QString rotationElArc_;
+extern const QString pieceArea_;
+extern const QString pieceSeamLineArea_;
 
-extern const QStringList builInVariables;
+auto BuilInVariables() -> QStringList;
 
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_GCC("-Weffc++")
@@ -249,25 +252,32 @@ QT_WARNING_DISABLE_GCC("-Weffc++")
 struct VLabelTemplateLine
 {
     QString line;
-    bool    bold;
-    bool    italic;
-    int     alignment;
-    int     fontSizeIncrement;
+    bool bold;
+    bool italic;
+    int alignment;
+    int fontSizeIncrement;
 };
 
 struct VWatermarkData
 {
-    int     opacity{20};
-    bool    showText{true};
-    QString text{};
-    int     textRotation{0};
-    QFont   font{};
-    bool    showImage{true};
-    QString path{};
-    int     imageRotation{0};
-    bool    grayscale{false};
-    bool    invalidFile{false};
-    QColor  textColor{Qt::black};
+    int opacity{20};             // NOLINT(misc-non-private-member-variables-in-classes)
+    bool showText{true};         // NOLINT(misc-non-private-member-variables-in-classes)
+    QString text{};              // NOLINT(misc-non-private-member-variables-in-classes)
+    int textRotation{0};         // NOLINT(misc-non-private-member-variables-in-classes)
+    QFont font{};                // NOLINT(misc-non-private-member-variables-in-classes)
+    bool showImage{true};        // NOLINT(misc-non-private-member-variables-in-classes)
+    QString path{};              // NOLINT(misc-non-private-member-variables-in-classes)
+    int imageRotation{0};        // NOLINT(misc-non-private-member-variables-in-classes)
+    bool grayscale{false};       // NOLINT(misc-non-private-member-variables-in-classes)
+    bool invalidFile{false};     // NOLINT(misc-non-private-member-variables-in-classes)
+    QColor textColor{Qt::black}; // NOLINT(misc-non-private-member-variables-in-classes)
+
+    VWatermarkData() = default;
+    VWatermarkData(VWatermarkData &&) noexcept = default;
+    auto operator=(VWatermarkData &&) noexcept -> VWatermarkData & = default;
+    VWatermarkData(const VWatermarkData &) = default;
+    auto operator=(const VWatermarkData &) -> VWatermarkData & = default;
+    ~VWatermarkData() = default;
 };
 
 QT_WARNING_POP
