@@ -27,8 +27,16 @@
  *************************************************************************/
 
 #include "vabstractconverter.h"
+#include "vparsererrorhandler.h"
+
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#include <xercesc/framework/MemBufInputSource.hpp>
+#include <xercesc/parsers/XercesDOMParser.hpp>
+#else
+#include <QXmlSchema>
+#include <QXmlSchemaValidator>
+#endif // QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
 
-#include <QAbstractMessageHandler>
 #include <QDir>
 #include <QDomElement>
 #include <QDomNode>
@@ -39,87 +47,30 @@
 #include <QMap>
 #include <QRegularExpression>
 #include <QRegularExpressionMatch>
-#include <QSourceLocation>
-#include <QStaticStringData>
-#include <QStringData>
-#include <QStringDataPtr>
 #include <QStringList>
 #include <QTextDocument>
 #include <QUrl>
-#include <QXmlSchema>
-#include <QXmlSchemaValidator>
 
 #include "../exception/vexception.h"
 #include "vdomdocument.h"
 
-//This class need for validation pattern file using XSD shema
-class MessageHandler : public QAbstractMessageHandler
-{
-public:
-    MessageHandler()
-        : QAbstractMessageHandler(),
-          m_messageType(QtMsgType()),
-          m_description(),
-          m_sourceLocation(QSourceLocation())
-    {}
+#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
+#include "../vmisc/compatibility.h"
+#endif
 
-    QString statusMessage() const;
-    qint64  line() const;
-    qint64  column() const;
-protected:
-    // cppcheck-suppress unusedFunction
-    virtual void handleMessage(QtMsgType type, const QString &description,
-                               const QUrl &identifier, const QSourceLocation &sourceLocation) override;
-private:
-    QtMsgType       m_messageType;
-    QString         m_description;
-    QSourceLocation m_sourceLocation;
-};
-
-//---------------------------------------------------------------------------------------------------------------------
-QString MessageHandler::statusMessage() const
-{
-    QTextDocument doc;
-    doc.setHtml(m_description);
-    return doc.toPlainText();
-}
-
-//---------------------------------------------------------------------------------------------------------------------
-inline qint64  MessageHandler::line() const
-{
-    return m_sourceLocation.line();
-}
-
-//---------------------------------------------------------------------------------------------------------------------
-inline qint64  MessageHandler::column() const
-{
-    return m_sourceLocation.column();
-}
-
-//---------------------------------------------------------------------------------------------------------------------
-// cppcheck-suppress unusedFunction
-void MessageHandler::handleMessage(QtMsgType type, const QString &description, const QUrl &identifier,
-                                   const QSourceLocation &sourceLocation)
-{
-    Q_UNUSED(type)
-    Q_UNUSED(identifier)
-
-    m_messageType = type;
-    m_description = description;
-    m_sourceLocation = sourceLocation;
-}
+using namespace Qt::Literals::StringLiterals;
 
 //---------------------------------------------------------------------------------------------------------------------
 VAbstractConverter::VAbstractConverter(const QString &fileName)
-    : m_ver(0x0),
-      m_originalFileName(fileName),
-      m_convertedFileName(fileName)
+  : m_ver(0x0),
+    m_originalFileName(fileName),
+    m_convertedFileName(fileName)
 {
-    setXMLContent(m_convertedFileName);// Throw an exception on error
+    setXMLContent(m_convertedFileName); // Throw an exception on error
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VAbstractConverter::Convert()
+auto VAbstractConverter::Convert() -> QString
 {
     if (m_ver == MaxVer())
     {
@@ -154,21 +105,26 @@ auto VAbstractConverter::GetCurrentFormatVersion() const -> unsigned
 //---------------------------------------------------------------------------------------------------------------------
 void VAbstractConverter::ReserveFile() const
 {
-    //It's not possible in all cases make conversion without lose data.
-    //For such cases we will store old version in a reserve file.
+    // It's not possible in all cases make conversion without lose data.
+    // For such cases we will store old version in a reserve file.
     QString error;
-    QFileInfo info(m_convertedFileName);
-    const QString reserveFileName = QString("%1/%2(v%3).%4.bak")
-            .arg(info.absoluteDir().absolutePath(), info.baseName(), GetFormatVersionStr(), info.completeSuffix());
+    QFileInfo const info(m_convertedFileName);
+#if defined(Q_OS_UNIX) || defined(Q_OS_MACOS)
+    const QString hidden = QChar('.');
+#else
+    const QString hidden;
+#endif
+    const QString reserveFileName = u"%1/%2%3(v%4).%5.bak"_s.arg(
+        info.absoluteDir().absolutePath(), hidden, info.baseName(), GetFormatVersionStr(), info.completeSuffix());
     if (not SafeCopy(m_convertedFileName, reserveFileName, error))
     {
-//#ifdef Q_OS_WIN32
-//        qt_ntfs_permission_lookup++; // turn checking on
-//#endif /*Q_OS_WIN32*/
+        // #ifdef Q_OS_WIN32
+        //         qt_ntfs_permission_lookup++; // turn checking on
+        // #endif /*Q_OS_WIN32*/
         const bool isFileWritable = info.isWritable();
-//#ifdef Q_OS_WIN32
-//        qt_ntfs_permission_lookup--; // turn it off again
-//#endif /*Q_OS_WIN32*/
+        // #ifdef Q_OS_WIN32
+        //         qt_ntfs_permission_lookup--; // turn it off again
+        // #endif /*Q_OS_WIN32*/
         if (not IsReadOnly() && isFileWritable)
         {
             const QString errorMsg(tr("Error creating a reserv copy: %1.").arg(error));
@@ -178,38 +134,39 @@ void VAbstractConverter::ReserveFile() const
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VAbstractConverter::Replace(QString &formula, const QString &newName, int position, const QString &token,
-                                 int &bias) const
+void VAbstractConverter::Replace(QString &formula, const QString &newName, vsizetype position, const QString &token,
+                                 vsizetype &bias) const
 {
     formula.replace(position, token.length(), newName);
     bias = token.length() - newName.length();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VAbstractConverter::CorrectionsPositions(int position, int bias, QMap<int, QString> &tokens) const
+void VAbstractConverter::CorrectionsPositions(vsizetype position, vsizetype bias,
+                                              QMap<vsizetype, QString> &tokens) const
 {
     if (bias == 0)
     {
-        return;// Nothing to correct;
+        return; // Nothing to correct;
     }
 
     BiasTokens(position, bias, tokens);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VAbstractConverter::BiasTokens(int position, int bias, QMap<int, QString> &tokens)
+void VAbstractConverter::BiasTokens(vsizetype position, vsizetype bias, QMap<vsizetype, QString> &tokens)
 {
-    QMap<int, QString> newTokens;
-    QMap<int, QString>::const_iterator i = tokens.constBegin();
+    QMap<vsizetype, QString> newTokens;
+    QMap<vsizetype, QString>::const_iterator i = tokens.constBegin();
     while (i != tokens.constEnd())
     {
-        if (i.key()<= position)
+        if (i.key() <= position)
         { // Tokens before position "position" did not change his positions.
             newTokens.insert(i.key(), i.value());
         }
         else
         {
-            newTokens.insert(i.key()-bias, i.value());
+            newTokens.insert(i.key() - bias, i.value());
         }
         ++i;
     }
@@ -224,6 +181,55 @@ void VAbstractConverter::BiasTokens(int position, int bias, QMap<int, QString> &
 void VAbstractConverter::ValidateXML(const QString &schema) const
 {
     qCDebug(vXML, "Validation xml file %s.", qUtf8Printable(m_convertedFileName));
+
+    QFile fileSchema(schema);
+    if (not fileSchema.open(QIODevice::ReadOnly))
+    {
+        const QString errorMsg(tr("Can't open schema file %1:\n%2.").arg(schema, fileSchema.errorString()));
+        throw VException(errorMsg);
+    }
+
+    VParserErrorHandler parserErrorHandler;
+
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    XERCES_CPP_NAMESPACE::XercesDOMParser domParser;
+    domParser.setCreateEntityReferenceNodes(true);
+    domParser.setDisableDefaultEntityResolution(true);
+    domParser.setErrorHandler(&parserErrorHandler);
+
+    QByteArray const data = fileSchema.readAll();
+    const char *schemaData = data.constData();
+    const auto schemaSize = static_cast<size_t>(data.size());
+
+    QScopedPointer<XERCES_CPP_NAMESPACE::InputSource> const grammarSource(new XERCES_CPP_NAMESPACE::MemBufInputSource(
+        reinterpret_cast<const XMLByte *>(schemaData), schemaSize, "schema"));
+
+    if (domParser.loadGrammar(*grammarSource, XERCES_CPP_NAMESPACE::Grammar::SchemaGrammarType, true) == nullptr)
+    {
+        VException e(parserErrorHandler.StatusMessage());
+        e.AddMoreInformation(tr("Could not load schema file '%1'.").arg(fileSchema.fileName()));
+        throw e;
+    }
+
+    qCDebug(vXML, "Schema loaded.");
+
+    if (parserErrorHandler.HasError())
+    {
+        VException e(parserErrorHandler.StatusMessage());
+        e.AddMoreInformation(tr("Schema file %3 invalid in line %1 column %2")
+                                 .arg(parserErrorHandler.Line())
+                                 .arg(parserErrorHandler.Column())
+                                 .arg(fileSchema.fileName()));
+        throw e;
+    }
+
+    domParser.setValidationScheme(XERCES_CPP_NAMESPACE::XercesDOMParser::Val_Always);
+    domParser.setDoNamespaces(true);
+    domParser.setDoSchema(true);
+    domParser.setValidationConstraintFatal(true);
+    domParser.setValidationSchemaFullChecking(true);
+    domParser.useCachedGrammarInParse(true);
+
     QFile pattern(m_convertedFileName);
     if (not pattern.open(QIODevice::ReadOnly))
     {
@@ -231,22 +237,37 @@ void VAbstractConverter::ValidateXML(const QString &schema) const
         throw VException(errorMsg);
     }
 
-    QFile fileSchema(schema);
-    if (not fileSchema.open(QIODevice::ReadOnly))
+    QByteArray const patternFileData = pattern.readAll();
+    const char *patternData = patternFileData.constData();
+    const auto patternSize = static_cast<size_t>(patternFileData.size());
+
+    QScopedPointer<XERCES_CPP_NAMESPACE::InputSource> const patternSource(new XERCES_CPP_NAMESPACE::MemBufInputSource(
+        reinterpret_cast<const XMLByte *>(patternData), patternSize, "pattern"));
+
+    domParser.parse(*patternSource);
+
+    if (domParser.getErrorCount() > 0)
     {
-        pattern.close();
-        const QString errorMsg(tr("Can't open schema file %1:\n%2.").arg(schema, fileSchema.errorString()));
+        VException e(parserErrorHandler.StatusMessage());
+        e.AddMoreInformation(tr("Validation error file %3 in line %1 column %2")
+                                 .arg(parserErrorHandler.Line())
+                                 .arg(parserErrorHandler.Column())
+                                 .arg(m_originalFileName));
+        throw e;
+    }
+#else
+    QFile pattern(m_convertedFileName);
+    if (not pattern.open(QIODevice::ReadOnly))
+    {
+        const QString errorMsg(tr("Can't open file %1:\n%2.").arg(m_convertedFileName, pattern.errorString()));
         throw VException(errorMsg);
     }
 
-    MessageHandler messageHandler;
     QXmlSchema sch;
-    sch.setMessageHandler(&messageHandler);
-    if (sch.load(&fileSchema, QUrl::fromLocalFile(fileSchema.fileName()))==false)
+    sch.setMessageHandler(&parserErrorHandler);
+    if (sch.load(&fileSchema, QUrl::fromLocalFile(fileSchema.fileName())) == false)
     {
-        pattern.close();
-        fileSchema.close();
-        VException e(messageHandler.statusMessage());
+        VException e(parserErrorHandler.StatusMessage());
         e.AddMoreInformation(tr("Could not load schema file '%1'.").arg(fileSchema.fileName()));
         throw e;
     }
@@ -268,15 +289,14 @@ void VAbstractConverter::ValidateXML(const QString &schema) const
 
     if (errorOccurred)
     {
-        pattern.close();
-        fileSchema.close();
-        VException e(messageHandler.statusMessage());
-        e.AddMoreInformation(tr("Validation error file %3 in line %1 column %2").arg(messageHandler.line())
-                             .arg(messageHandler.column()).arg(m_originalFileName));
+        VException e(parserErrorHandler.StatusMessage());
+        e.AddMoreInformation(tr("Validation error file %3 in line %1 column %2")
+                                 .arg(parserErrorHandler.Line())
+                                 .arg(parserErrorHandler.Column())
+                                 .arg(m_originalFileName));
         throw e;
     }
-    pattern.close();
-    fileSchema.close();
+#endif // QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -306,7 +326,7 @@ void VAbstractConverter::ValidateInputFile(const QString &currentSchema) const
     {
         schema = XSDSchema(m_ver);
     }
-    catch(const VException &e)
+    catch (const VException &e)
     {
         if (m_ver < MinVer())
         { // Version less than minimally supported version. Can't do anything.
@@ -319,7 +339,7 @@ void VAbstractConverter::ValidateInputFile(const QString &currentSchema) const
             { // Try to open like the current version.
                 ValidateXML(currentSchema);
             }
-            catch(const VException &exp)
+            catch (const VException &exp)
             { // Nope, we can't.
                 Q_UNUSED(exp)
                 throw e;
@@ -339,10 +359,12 @@ void VAbstractConverter::ValidateInputFile(const QString &currentSchema) const
 //---------------------------------------------------------------------------------------------------------------------
 void VAbstractConverter::Save()
 {
-    m_tmpFile.resize(0);//clear previous content
+    m_tmpFile.resize(0); // clear previous content
     const int indent = 4;
     QTextStream out(&m_tmpFile);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     out.setCodec("UTF-8");
+#endif
     save(out, indent);
 
     if (not m_tmpFile.flush())
@@ -358,7 +380,19 @@ void VAbstractConverter::SetVersion(const QString &version)
 
     if (setTagText(TagVersion, version) == false)
     {
-        VException e(tr("Could not change version."));
+        VException const e(tr("Could not change version."));
         throw e;
     }
 }
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VAbstractConverter::XSDSchema(unsigned int ver) const -> QString
+{
+    const QHash<unsigned, QString> schemas = Schemas();
+    if (schemas.contains(ver))
+    {
+        return schemas.value(ver);
+    }
+
+    InvalidVersion(ver);
+}
