@@ -28,38 +28,53 @@
 
 #include "vdomdocument.h"
 
-#include <qcompilerdetection.h>
-#include <qdom.h>
 #include <QSaveFile>
+#include <qdom.h>
 
+#include "../exception/vexception.h"
 #include "../exception/vexceptionbadid.h"
 #include "../exception/vexceptionconversionerror.h"
 #include "../exception/vexceptionemptyparameter.h"
 #include "../exception/vexceptionwrongid.h"
-#include "../exception/vexception.h"
 #include "../ifcdef.h"
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <QAbstractMessageHandler>
+#include <QSourceLocation>
+#endif
+
 #include <QByteArray>
+#include <QDir>
 #include <QDomNodeList>
 #include <QDomText>
 #include <QFile>
+#include <QFileInfo>
+#include <QFutureWatcher>
 #include <QIODevice>
 #include <QMessageLogger>
 #include <QObject>
-#include <QSourceLocation>
+#include <QRegularExpression>
 #include <QStringList>
 #include <QTemporaryFile>
 #include <QTextDocument>
 #include <QTextStream>
+#include <QTimer>
 #include <QUrl>
 #include <QVector>
-#include <QtDebug>
 #include <QXmlStreamWriter>
-#include <QTimer>
 #include <QtConcurrentRun>
-#include <QFutureWatcher>
-#include <QRegularExpression>
+#include <QtDebug>
+
+#ifdef Q_OS_UNIX
+#include <fcntl.h>
+#include <unistd.h>
+#endif
+
+#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
+#include "../vmisc/compatibility.h"
+#endif
+
+using namespace Qt::Literals::StringLiterals;
 
 namespace
 {
@@ -68,7 +83,7 @@ void SaveNodeCanonically(QXmlStreamWriter &stream, const QDomNode &domNode)
 {
     if (stream.hasError())
     {
-       return;
+        return;
     }
 
     if (domNode.isElement())
@@ -120,9 +135,9 @@ void SaveNodeCanonically(QXmlStreamWriter &stream, const QDomNode &domNode)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QList<QDomNode> GetChildElements(const QDomNode& e)
+auto GetChildElements(const QDomNode &e) -> QList<QDomNode>
 {
-    QDomNodeList children = e.childNodes();
+    QDomNodeList const children = e.childNodes();
     QList<QDomNode> r;
     r.reserve(children.size());
     for (int k = 0; k < children.size(); ++k)
@@ -133,9 +148,9 @@ QList<QDomNode> GetChildElements(const QDomNode& e)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QList<QDomNode> GetElementAttributes(const QDomNode& e)
+auto GetElementAttributes(const QDomNode &e) -> QList<QDomNode>
 {
-    QDomNamedNodeMap attributes = e.attributes();
+    QDomNamedNodeMap const attributes = e.attributes();
     QList<QDomNode> r;
     r.reserve(attributes.size());
     for (int k = 0; k < attributes.size(); ++k)
@@ -146,27 +161,27 @@ QList<QDomNode> GetElementAttributes(const QDomNode& e)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool LessThen(const QDomNode &element1, const QDomNode &element2)
+auto LessThen(const QDomNode &element1, const QDomNode &element2) -> bool
 {
     if (element1.nodeType() != element2.nodeType())
     {
         return element1.nodeType() < element2.nodeType();
     }
 
-    QString tag1 = element1.nodeName();
-    QString tag2 = element2.nodeName();
+    QString const tag1 = element1.nodeName();
+    QString const tag2 = element2.nodeName();
 
-    //qDebug() << tag1 <<tag2;
+    // qDebug() << tag1 <<tag2;
     if (tag1 != tag2)
     {
         return tag1 < tag2;
     }
 
     // Compare attributes
-    QList<QDomNode> attributes1 = GetElementAttributes(element1);
-    QList<QDomNode> attributes2 = GetElementAttributes(element2);
+    QList<QDomNode> const attributes1 = GetElementAttributes(element1);
+    QList<QDomNode> const attributes2 = GetElementAttributes(element2);
 
-    if(attributes1.size() != attributes2.size())
+    if (attributes1.size() != attributes2.size())
     {
         return attributes1.size() < attributes2.size();
     }
@@ -176,22 +191,22 @@ bool LessThen(const QDomNode &element1, const QDomNode &element2)
         *stop = false;
         std::sort(list1.begin(), list1.end(), LessThen);
         std::sort(list2.begin(), list2.end(), LessThen);
-        //qDebug() << "comparing sorted lists";
-        for(int k = 0; k < list1.size(); ++k)
+        // qDebug() << "comparing sorted lists";
+        for (int k = 0; k < list1.size(); ++k)
         {
             if (!LessThen(list1[k], list2[k]))
             {
                 if (LessThen(list2[k], list1[k]))
                 {
                     *stop = true;
-                    //qDebug() << "false!";
+                    // qDebug() << "false!";
                     return false;
                 }
             }
             else
             {
                 *stop = true;
-                //qDebug() << "true!";
+                // qDebug() << "true!";
                 return true;
             }
         }
@@ -206,22 +221,23 @@ bool LessThen(const QDomNode &element1, const QDomNode &element2)
     }
 
     // Compare children
-    QList<QDomNode> elts1 = GetChildElements(element1);
-    QList<QDomNode> elts2 = GetChildElements(element2);
+    QList<QDomNode> const elts1 = GetChildElements(element1);
+    QList<QDomNode> const elts2 = GetChildElements(element2);
 
-    QString value1, value2;
+    QString value1;
+    QString value2;
 
-    if(elts1.size() != elts2.size())
+    if (elts1.size() != elts2.size())
     {
         return elts1.size() < elts2.size();
     }
 
-    if(elts1.isEmpty())
+    if (elts1.isEmpty())
     {
         value1 = element1.nodeValue();
         value2 = element2.nodeValue();
 
-        //qDebug() <<value1 << value2 << (value1 < value2);
+        // qDebug() <<value1 << value2 << (value1 < value2);
         return value1 < value2;
     }
 
@@ -232,7 +248,7 @@ bool LessThen(const QDomNode &element1, const QDomNode &element2)
     }
     return false;
 }
-}  // namespace
+} // namespace
 
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_CLANG("-Wmissing-prototypes")
@@ -242,24 +258,30 @@ Q_LOGGING_CATEGORY(vXML, "v.xml") // NOLINT
 
 QT_WARNING_POP
 
-const QString VDomDocument::AttrId          = QStringLiteral("id");
-const QString VDomDocument::AttrText        = QStringLiteral("text");
-const QString VDomDocument::AttrBold        = QStringLiteral("bold");
-const QString VDomDocument::AttrItalic      = QStringLiteral("italic");
-const QString VDomDocument::AttrAlignment   = QStringLiteral("alignment");
+const QString VDomDocument::AttrId = QStringLiteral("id");
+const QString VDomDocument::AttrText = QStringLiteral("text");
+const QString VDomDocument::AttrBold = QStringLiteral("bold");
+const QString VDomDocument::AttrItalic = QStringLiteral("italic");
+const QString VDomDocument::AttrAlignment = QStringLiteral("alignment");
 const QString VDomDocument::AttrFSIncrement = QStringLiteral("sfIncrement");
 
 const QString VDomDocument::TagVersion = QStringLiteral("version");
-const QString VDomDocument::TagUnit    = QStringLiteral("unit");
-const QString VDomDocument::TagLine    = QStringLiteral("line");
+const QString VDomDocument::TagUnit = QStringLiteral("unit");
+const QString VDomDocument::TagLine = QStringLiteral("line");
 
 //---------------------------------------------------------------------------------------------------------------------
 VDomDocument::VDomDocument(QObject *parent)
-    : QObject(parent),
-      QDomDocument(),
-      m_elementIdCache(),
-      m_watcher(new QFutureWatcher<QHash<quint32, QDomElement>>(this))
+  : QObject(parent),
+    QDomDocument(),
+    m_elementIdCache(),
+    m_watcher(new QFutureWatcher<QHash<quint32, QDomElement>>(this))
 {
+    connect(qApp, &QCoreApplication::aboutToQuit, m_watcher,
+            [this]()
+            {
+                m_watcher->cancel();
+                m_watcher->waitForFinished();
+            });
     connect(m_watcher, &QFutureWatcher<QHash<quint32, QDomElement>>::finished, this, &VDomDocument::CacheRefreshed);
 }
 
@@ -270,7 +292,7 @@ VDomDocument::~VDomDocument()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QDomElement VDomDocument::elementById(quint32 id, const QString &tagName, bool updateCache)
+auto VDomDocument::elementById(quint32 id, const QString &tagName, bool updateCache) -> QDomElement
 {
     if (id == 0)
     {
@@ -297,7 +319,7 @@ QDomElement VDomDocument::elementById(quint32 id, const QString &tagName, bool u
     }
 
     if (updateCache)
-    {   // Cached missed
+    { // Cached missed
         RefreshElementIdCache();
     }
 
@@ -313,7 +335,7 @@ QDomElement VDomDocument::elementById(quint32 id, const QString &tagName, bool u
     else
     {
         const QDomNodeList list = elementsByTagName(tagName);
-        for (int i=0; i < list.size(); ++i)
+        for (int i = 0; i < list.size(); ++i)
         {
             const QDomElement domElement = list.at(i).toElement();
             if (not domElement.isNull() && domElement.hasAttribute(AttrId))
@@ -339,41 +361,43 @@ QDomElement VDomDocument::elementById(quint32 id, const QString &tagName, bool u
  * @param id id value
  * @return true if found
  */
-bool VDomDocument::find(QHash<quint32, QDomElement> &cache, const QDomElement &node, quint32 id)
+auto VDomDocument::find(QHash<quint32, QDomElement> &cache, const QDomElement &node, quint32 id) -> bool
 {
     if (node.hasAttribute(AttrId))
     {
-        const quint32 elementId = GetParametrUInt(node, AttrId, NULL_ID_STR);
-
-        if (cache.contains(elementId))
+        try
         {
-            qWarning() << tr("Not unique id (%1)").arg(elementId);
-        }
+            const quint32 elementId = GetParametrUInt(node, AttrId, NULL_ID_STR);
 
-        cache.insert(elementId, node);
-        if (elementId == id)
-        {
-            return true;
-        }
-    }
+            if (cache.contains(elementId))
+            {
+                qWarning() << tr("Not unique id (%1)").arg(elementId);
+            }
 
-    for (qint32 i=0; i<node.childNodes().length(); ++i)
-    {
-        const QDomNode n = node.childNodes().at(i);
-        if (n.isElement())
-        {
-            if (VDomDocument::find(cache, n.toElement(), id))
+            cache.insert(elementId, node);
+            if (elementId == id)
             {
                 return true;
             }
         }
+        catch (const VExceptionConversionError &)
+        {
+            // ignore
+        }
+    }
+
+    for (qint32 i = 0; i < node.childNodes().length(); ++i)
+    {
+        if (const QDomNode n = node.childNodes().at(i); n.isElement() && VDomDocument::find(cache, n.toElement(), id))
+        {
+            return true;
+        }
     }
     return false;
 }
 
-
 //---------------------------------------------------------------------------------------------------------------------
-QHash<quint32, QDomElement> VDomDocument::RefreshCache(const QDomElement &root) const
+auto VDomDocument::RefreshCache(const QDomElement &root) const -> QHash<quint32, QDomElement>
 {
     QHash<quint32, QDomElement> cache;
     VDomDocument::find(cache, root, NULL_ID);
@@ -381,7 +405,7 @@ QHash<quint32, QDomElement> VDomDocument::RefreshCache(const QDomElement &root)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VDomDocument::SaveCanonicalXML(QIODevice *file, int indent, QString &error) const
+auto VDomDocument::SaveCanonicalXML(QIODevice *file, int indent, QString &error) const -> bool
 {
     SCASSERT(file != nullptr)
 
@@ -418,7 +442,8 @@ bool VDomDocument::SaveCanonicalXML(QIODevice *file, int indent, QString &error)
  * @param name attribute name
  * @return long long value
  */
-quint32 VDomDocument::GetParametrUInt(const QDomElement &domElement, const QString &name, const QString &defValue)
+auto VDomDocument::GetParametrUInt(const QDomElement &domElement, const QString &name, const QString &defValue)
+    -> quint32
 {
     Q_ASSERT_X(not name.isEmpty(), Q_FUNC_INFO, "name of parametr is empty");
     Q_ASSERT_X(not domElement.isNull(), Q_FUNC_INFO, "domElement is null"); //-V591
@@ -431,7 +456,7 @@ quint32 VDomDocument::GetParametrUInt(const QDomElement &domElement, const QStri
     {
         parametr = GetParametrString(domElement, name, defValue);
         id = parametr.toUInt(&ok);
-        if (ok == false)
+        if (!ok)
         {
             throw VExceptionConversionError(QObject::tr("Can't convert toUInt parameter"), name);
         }
@@ -447,7 +472,7 @@ quint32 VDomDocument::GetParametrUInt(const QDomElement &domElement, const QStri
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-int VDomDocument::GetParametrInt(const QDomElement &domElement, const QString &name, const QString &defValue)
+auto VDomDocument::GetParametrInt(const QDomElement &domElement, const QString &name, const QString &defValue) -> int
 {
     Q_ASSERT_X(not name.isEmpty(), Q_FUNC_INFO, "name of parametr is empty");
     Q_ASSERT_X(not domElement.isNull(), Q_FUNC_INFO, "domElement is null"); //-V591
@@ -476,7 +501,7 @@ int VDomDocument::GetParametrInt(const QDomElement &domElement, const QString &n
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VDomDocument::GetParametrBool(const QDomElement &domElement, const QString &name, const QString &defValue)
+auto VDomDocument::GetParametrBool(const QDomElement &domElement, const QString &name, const QString &defValue) -> bool
 {
     Q_ASSERT_X(not name.isEmpty(), Q_FUNC_INFO, "name of parametr is empty");
     Q_ASSERT_X(not domElement.isNull(), Q_FUNC_INFO, "domElement is null");
@@ -489,7 +514,7 @@ bool VDomDocument::GetParametrBool(const QDomElement &domElement, const QString
     {
         parametr = GetParametrString(domElement, name, defValue);
 
-        const QStringList bools {trueStr, falseStr, QChar('1'), QChar('0')};
+        const QStringList bools{trueStr, falseStr, QChar('1'), QChar('0')};
         switch (bools.indexOf(parametr))
         {
             case 0: // true
@@ -500,7 +525,7 @@ bool VDomDocument::GetParametrBool(const QDomElement &domElement, const QString
             case 3: // 0
                 val = false;
                 break;
-            default:// others
+            default: // others
                 throw VExceptionConversionError(message, name);
         }
     }
@@ -515,17 +540,14 @@ bool VDomDocument::GetParametrBool(const QDomElement &domElement, const QString
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-NodeUsage VDomDocument::GetParametrUsage(const QDomElement &domElement, const QString &name)
+auto VDomDocument::GetParametrUsage(const QDomElement &domElement, const QString &name) -> NodeUsage
 {
     const bool value = GetParametrBool(domElement, name, trueStr);
     if (value)
     {
         return NodeUsage::InUse;
     }
-    else
-    {
-        return NodeUsage::NotInUse;
-    }
+    return NodeUsage::NotInUse;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -549,28 +571,25 @@ void VDomDocument::SetParametrUsage(QDomElement &domElement, const QString &name
  * @return attribute value
  * @throw VExceptionEmptyParameter when attribute is empty
  */
-QString VDomDocument::GetParametrString(const QDomElement &domElement, const QString &name,
-                                        const QString &defValue)
+auto VDomDocument::GetParametrString(const QDomElement &domElement, const QString &name, const QString &defValue)
+    -> QString
 {
     Q_ASSERT_X(not name.isEmpty(), Q_FUNC_INFO, "name of parametr is empty");
     Q_ASSERT_X(not domElement.isNull(), Q_FUNC_INFO, "domElement is null");
-    const QString parameter = domElement.attribute(name, defValue);
+    QString parameter = domElement.attribute(name, defValue);
     if (parameter.isEmpty())
     {
         if (defValue.isEmpty())
         {
             throw VExceptionEmptyParameter(QObject::tr("Got empty parameter"), name, domElement);
         }
-        else
-        {
-            return defValue;
-        }
+        return defValue;
     }
     return parameter;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VDomDocument::GetParametrEmptyString(const QDomElement &domElement, const QString &name)
+auto VDomDocument::GetParametrEmptyString(const QDomElement &domElement, const QString &name) -> QString
 {
     Q_ASSERT_X(not name.isEmpty(), Q_FUNC_INFO, "name of parametr is empty");
     Q_ASSERT_X(not domElement.isNull(), Q_FUNC_INFO, "domElement is null");
@@ -584,7 +603,8 @@ QString VDomDocument::GetParametrEmptyString(const QDomElement &domElement, cons
  * @param name attribute name
  * @return double value
  */
-qreal VDomDocument::GetParametrDouble(const QDomElement &domElement, const QString &name, const QString &defValue)
+auto VDomDocument::GetParametrDouble(const QDomElement &domElement, const QString &name, const QString &defValue)
+    -> qreal
 {
     Q_ASSERT_X(not name.isEmpty(), Q_FUNC_INFO, "name of parametr is empty");
     Q_ASSERT_X(not domElement.isNull(), Q_FUNC_INFO, "domElement is null");
@@ -595,7 +615,7 @@ qreal VDomDocument::GetParametrDouble(const QDomElement &domElement, const QStri
     try
     {
         QString parametr = GetParametrString(domElement, name, defValue);
-        param = parametr.replace(QChar(','), QChar('.')).toDouble(&ok);
+        param = parametr.replace(','_L1, '.'_L1).toDouble(&ok);
         if (ok == false)
         {
             throw VExceptionConversionError(QObject::tr("Can't convert toDouble parameter"), name);
@@ -616,7 +636,7 @@ qreal VDomDocument::GetParametrDouble(const QDomElement &domElement, const QStri
  * @param domElement tag in xml tree.
  * @return id value.
  */
-quint32 VDomDocument::GetParametrId(const QDomElement &domElement)
+auto VDomDocument::GetParametrId(const QDomElement &domElement) -> quint32
 {
     Q_ASSERT_X(not domElement.isNull(), Q_FUNC_INFO, "domElement is null");
 
@@ -643,10 +663,10 @@ quint32 VDomDocument::GetParametrId(const QDomElement &domElement)
 //---------------------------------------------------------------------------------------------------------------------
 auto VDomDocument::UniqueTagText(const QString &tagName, const QString &defVal) const -> QString
 {
-    QDomElement domElement = UniqueTag(tagName);
+    QDomElement const domElement = UniqueTag(tagName);
     if (not domElement.isNull())
     {
-        const QString text = domElement.text();
+        QString text = domElement.text();
         if (text.isEmpty())
         {
             return defVal;
@@ -681,7 +701,7 @@ void VDomDocument::CollectId(const QDomElement &node, QVector<quint32> &vector)
         vector.append(id);
     }
 
-    for (qint32 i=0; i<node.childNodes().length(); ++i)
+    for (qint32 i = 0; i < node.childNodes().length(); ++i)
     {
         const QDomNode n = node.childNodes().at(i);
         if (n.isElement())
@@ -696,20 +716,25 @@ void VDomDocument::RefreshElementIdCache()
 {
     if (m_watcher->isFinished())
     {
-        m_watcher->setFuture(QtConcurrent::run(this, &VDomDocument::RefreshCache, documentElement()));
+        m_watcher->setFuture(QtConcurrent::run([this]() { return RefreshCache(documentElement()); }));
     }
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VDomDocument::Compare(const QDomElement &element1, const QDomElement &element2)
+auto VDomDocument::Compare(const QDomElement &element1, const QDomElement &element2) -> bool
 {
-    QFuture<bool> lessThen2 = QtConcurrent::run(LessThen, element2, element1);
+    QFuture<bool> const lessThen2 = QtConcurrent::run(LessThen, element2, element1);
     return !LessThen(element1, element2) && !lessThen2.result();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void VDomDocument::CacheRefreshed()
 {
+    if (m_watcher->isCanceled())
+    {
+        return;
+    }
+
     m_elementIdCache = m_watcher->future().result();
 }
 
@@ -730,8 +755,8 @@ void VDomDocument::setXMLContent(const QString &fileName)
     {
         file.close();
         VException e(errorMsg);
-        e.AddMoreInformation(tr("Parsing error file %3 in line %1 column %2").arg(errorLine).arg(errorColumn)
-                             .arg(fileName));
+        e.AddMoreInformation(
+            tr("Parsing error file %3 in line %1 column %2").arg(errorLine).arg(errorColumn).arg(fileName));
         throw e;
     }
 
@@ -739,10 +764,10 @@ void VDomDocument::setXMLContent(const QString &fileName)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VDomDocument::UnitsHelpString()
+auto VDomDocument::UnitsHelpString() -> QString
 {
     QString r;
-    for (auto i = static_cast<int>(Unit::Mm), last = static_cast<int>(Unit::LAST_UNIT_DO_NOT_USE); i < last;++i)
+    for (auto i = static_cast<int>(Unit::Mm), last = static_cast<int>(Unit::LAST_UNIT_DO_NOT_USE); i < last; ++i)
     {
         r += UnitsToStr(static_cast<Unit>(i));
         if (i < last - 1)
@@ -754,7 +779,7 @@ QString VDomDocument::UnitsHelpString()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QDomElement VDomDocument::CreateElementWithText(const QString &tagName, const QString &text)
+auto VDomDocument::CreateElementWithText(const QString &tagName, const QString &text) -> QDomElement
 {
     QDomElement tag = createElement(tagName);
     tag.appendChild(createTextNode(text));
@@ -762,11 +787,11 @@ QDomElement VDomDocument::CreateElementWithText(const QString &tagName, const QS
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VDomDocument::SaveDocument(const QString &fileName, QString &error)
+auto VDomDocument::SaveDocument(const QString &fileName, QString &error) -> bool
 {
     if (fileName.isEmpty())
     {
-        qDebug()<<"Got empty file name.";
+        qDebug() << "Got empty file name.";
         return false;
     }
     bool success = false;
@@ -781,10 +806,26 @@ bool VDomDocument::SaveDocument(const QString &fileName, QString &error)
         }
         // Left these strings in case we will need them for testing purposes
         // QTextStream out(&file);
-        // out.setCodec("UTF-8");
-        // save(out, indent);
+        // #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+        //  out.setCodec("UTF-8");
+        // #endif
+        //  save(out, indent);
 
         success = file.commit();
+
+#if defined(_POSIX_SYNCHRONIZED_IO) && _POSIX_SYNCHRONIZED_IO > 0
+        if (success)
+        {
+            // https://stackoverflow.com/questions/74051505/does-qsavefilecommit-fsync-the-file-to-the-filesystem
+            QString const directoryPath = QFileInfo(file.fileName()).absoluteDir().path();
+            int const dirFd = ::open(directoryPath.toLocal8Bit().data(), O_RDONLY | O_DIRECTORY);
+            if (dirFd != -1)
+            {
+                ::fsync(dirFd);
+                ::close(dirFd);
+            }
+        }
+#endif
     }
 
     if (not success)
@@ -797,33 +838,33 @@ bool VDomDocument::SaveDocument(const QString &fileName, QString &error)
 
 //---------------------------------------------------------------------------------------------------------------------
 // cppcheck-suppress unusedFunction
-QString VDomDocument::Major() const
+auto VDomDocument::Major() const -> QString
 {
-    QString version = UniqueTagText(TagVersion, "0.0.0");
-    QStringList v = version.split(QChar('.'));
+    QString const version = UniqueTagText(TagVersion, "0.0.0"_L1);
+    QStringList const v = version.split('.'_L1);
     return v.at(0);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 // cppcheck-suppress unusedFunction
-QString VDomDocument::Minor() const
+auto VDomDocument::Minor() const -> QString
 {
-    QString version = UniqueTagText(TagVersion, "0.0.0");
-    QStringList v = version.split(QChar('.'));
+    QString const version = UniqueTagText(TagVersion, "0.0.0"_L1);
+    QStringList const v = version.split('.'_L1);
     return v.at(1);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 // cppcheck-suppress unusedFunction
-QString VDomDocument::Patch() const
+auto VDomDocument::Patch() const -> QString
 {
-    QString version = UniqueTagText(TagVersion, "0.0.0");
-    QStringList v = version.split(QChar('.'));
+    QString const version = UniqueTagText(TagVersion, "0.0.0"_L1);
+    QStringList const v = version.split('.'_L1);
     return v.at(2);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VDomDocument::GetFormatVersionStr() const
+auto VDomDocument::GetFormatVersionStr() const -> QString
 {
     const QDomNodeList nodeList = this->elementsByTagName(TagVersion);
     if (nodeList.isEmpty())
@@ -847,7 +888,7 @@ QString VDomDocument::GetFormatVersionStr() const
             return domElement.text();
         }
     }
-    return QString(QStringLiteral("0.0.0"));
+    return "0.0.0"_L1;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -855,7 +896,7 @@ auto VDomDocument::GetFormatVersion(const QString &version) -> unsigned
 {
     ValidateVersion(version);
 
-    const QStringList ver = version.split(QChar('.'));
+    const QStringList ver = version.split('.'_L1);
 
     bool ok = false;
     const unsigned major = ver.at(0).toUInt(&ok);
@@ -878,7 +919,7 @@ auto VDomDocument::GetFormatVersion(const QString &version) -> unsigned
         return 0x0;
     }
 
-    return (major<<16u)|(minor<<8u)|(patch);
+    return (major << 16u) | (minor << 8u) | (patch);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -887,11 +928,11 @@ auto VDomDocument::setTagText(const QString &tag, const QString &text) -> bool
     const QDomNodeList nodeList = this->elementsByTagName(tag);
     if (nodeList.isEmpty())
     {
-        qDebug()<<"Can't save tag "<<tag<<Q_FUNC_INFO;
+        qDebug() << "Can't save tag " << tag << Q_FUNC_INFO;
     }
     else
     {
-        QDomNode domNode = nodeList.at(0);
+        QDomNode const domNode = nodeList.at(0);
         if (not domNode.isNull() && domNode.isElement())
         {
             QDomElement domElement = domNode.toElement();
@@ -906,7 +947,7 @@ auto VDomDocument::setTagText(QDomElement &domElement, const QString &text) -> b
 {
     if (not domElement.isNull())
     {
-        QDomNode oldText = domElement.firstChild();
+        QDomNode const oldText = domElement.firstChild();
         const QDomText newText = createTextNode(text);
 
         if (oldText.isNull())
@@ -932,7 +973,7 @@ auto VDomDocument::setTagText(QDomElement &domElement, const QString &text) -> b
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QDomElement VDomDocument::UniqueTag(const QString &tagName) const
+auto VDomDocument::UniqueTag(const QString &tagName) const -> QDomElement
 {
     const QDomNodeList nodeList = this->elementsByTagName(tagName);
     if (nodeList.isEmpty())
@@ -959,33 +1000,33 @@ QDomElement VDomDocument::UniqueTag(const QString &tagName) const
  */
 void VDomDocument::RemoveAllChildren(QDomElement &domElement)
 {
-    if ( domElement.hasChildNodes() )
+    if (domElement.hasChildNodes())
     {
-        while ( domElement.childNodes().length() >= 1 )
+        while (domElement.childNodes().length() >= 1)
         {
-            domElement.removeChild( domElement.firstChild() );
+            domElement.removeChild(domElement.firstChild());
         }
     }
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QDomNode VDomDocument::ParentNodeById(const quint32 &nodeId)
+auto VDomDocument::ParentNodeById(const quint32 &nodeId) -> QDomNode
 {
-    QDomElement domElement = NodeById(nodeId);
+    QDomElement const domElement = NodeById(nodeId);
     return domElement.parentNode();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QDomElement VDomDocument::CloneNodeById(const quint32 &nodeId)
+auto VDomDocument::CloneNodeById(const quint32 &nodeId) -> QDomElement
 {
-    QDomElement domElement = NodeById(nodeId);
+    QDomElement const domElement = NodeById(nodeId);
     return domElement.cloneNode().toElement();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QDomElement VDomDocument::NodeById(const quint32 &nodeId, const QString &tagName)
+auto VDomDocument::NodeById(const quint32 &nodeId, const QString &tagName) -> QDomElement
 {
-    QDomElement domElement = elementById(nodeId, tagName);
+    QDomElement const domElement = elementById(nodeId, tagName);
     if (domElement.isNull() || domElement.isElement() == false)
     {
         throw VExceptionBadId(tr("Couldn't get node"), nodeId);
@@ -994,16 +1035,16 @@ QDomElement VDomDocument::NodeById(const quint32 &nodeId, const QString &tagName
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VDomDocument::SafeCopy(const QString &source, const QString &destination, QString &error)
+auto VDomDocument::SafeCopy(const QString &source, const QString &destination, QString &error) -> bool
 {
     bool result = false;
 
-//#ifdef Q_OS_WIN32
-//    qt_ntfs_permission_lookup++; // turn checking on
-//#endif /*Q_OS_WIN32*/
+    // #ifdef Q_OS_WIN32
+    //     qt_ntfs_permission_lookup++; // turn checking on
+    // #endif /*Q_OS_WIN32*/
 
-    QTemporaryFile destFile(destination + QLatin1String(".XXXXXX"));
-    destFile.setAutoRemove(false);// Will be renamed to be destination file
+    QTemporaryFile destFile(destination + ".XXXXXX"_L1);
+    destFile.setAutoRemove(false); // Will be renamed to be destination file
     if (not destFile.open())
     {
         error = destFile.errorString();
@@ -1052,15 +1093,15 @@ bool VDomDocument::SafeCopy(const QString &source, const QString &destination, Q
         }
     }
 
-//#ifdef Q_OS_WIN32
-//    qt_ntfs_permission_lookup--; // turn off check permission again
-//#endif /*Q_OS_WIN32*/
+    // #ifdef Q_OS_WIN32
+    //     qt_ntfs_permission_lookup--; // turn off check permission again
+    // #endif /*Q_OS_WIN32*/
 
     return result;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QVector<VLabelTemplateLine> VDomDocument::GetLabelTemplate(const QDomElement &element) const
+auto VDomDocument::GetLabelTemplate(const QDomElement &element) const -> QVector<VLabelTemplateLine>
 {
     // We use implicit conversion. That's why check if values are still the same as excpected.
     Q_STATIC_ASSERT(Qt::AlignLeft == 1);
@@ -1077,7 +1118,8 @@ QVector<VLabelTemplateLine> VDomDocument::GetLabelTemplate(const QDomElement &el
             if (tagLine.tagName() == TagLine)
             {
                 VLabelTemplateLine line;
-                line.line = GetParametrString(tagLine, AttrText, tr("<empty>"));
+                line.line =
+                    GetParametrString(tagLine, AttrText, QCoreApplication::translate("VDomDocument", "<empty>"));
                 line.bold = GetParametrBool(tagLine, AttrBold, falseStr);
                 line.italic = GetParametrBool(tagLine, AttrItalic, falseStr);
                 line.alignment = static_cast<int>(GetParametrUInt(tagLine, AttrAlignment, QChar('0')));
@@ -1096,7 +1138,7 @@ void VDomDocument::SetLabelTemplate(QDomElement &element, const QVector<VLabelTe
 {
     if (not element.isNull())
     {
-        for (auto &line : lines)
+        for (const auto &line : lines)
         {
             QDomElement tagLine = createElement(TagLine);
 
@@ -1114,16 +1156,17 @@ void VDomDocument::SetLabelTemplate(QDomElement &element, const QVector<VLabelTe
 //---------------------------------------------------------------------------------------------------------------------
 void VDomDocument::ValidateVersion(const QString &version)
 {
-    const QRegularExpression rx(QStringLiteral("^([0-9]|[1-9][0-9]|[1-2][0-5][0-5]).([0-9]|[1-9][0-9]|[1-2][0-5][0-5])"
-                                               ".([0-9]|[1-9][0-9]|[1-2][0-5][0-5])$"));
+    static const QRegularExpression rx(
+        QStringLiteral("^([0-9]|[1-9][0-9]|[1-2][0-5][0-5]).([0-9]|[1-9][0-9]|[1-2][0-5][0-5])"
+                       ".([0-9]|[1-9][0-9]|[1-2][0-5][0-5])$"));
 
-    if (rx.match(version).hasMatch() == false)
+    if (!rx.match(version).hasMatch())
     {
         const QString errorMsg(tr("Version \"%1\" invalid.").arg(version));
         throw VException(errorMsg);
     }
 
-    if (version == QLatin1String("0.0.0"))
+    if (version == "0.0.0"_L1)
     {
         const QString errorMsg(tr("Version \"0.0.0\" invalid."));
         throw VException(errorMsg);
