@@ -32,19 +32,21 @@
 #include <QDomNodeList>
 #include <QDomText>
 #include <QFile>
+#include <QGlobalStatic>
 #include <QLatin1String>
 #include <QList>
 #include <QMap>
 #include <QMultiMap>
-#include <QStaticStringData>
-#include <QStringData>
-#include <QStringDataPtr>
-#include <QGlobalStatic>
 
-#include "../exception/vexception.h"
 #include "../vmisc/def.h"
 #include "vabstractmconverter.h"
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
+#include "../vmisc/compatibility.h"
+#endif
+
+using namespace Qt::Literals::StringLiterals;
+
 /*
  * Version rules:
  * 1. Version have three parts "major.minor.patch";
@@ -54,32 +56,36 @@
  */
 
 const QString VVSTConverter::MeasurementMinVerStr = QStringLiteral("0.3.0");
-const QString VVSTConverter::MeasurementMaxVerStr = QStringLiteral("0.5.4");
-const QString VVSTConverter::CurrentSchema        = QStringLiteral("://schema/multisize_measurements/v0.5.4.xsd");
+const QString VVSTConverter::MeasurementMaxVerStr = QStringLiteral("0.6.1");
+const QString VVSTConverter::CurrentSchema = QStringLiteral("://schema/multisize_measurements/v0.6.1.xsd");
 
-//VVSTConverter::MeasurementMinVer; // <== DON'T FORGET TO UPDATE TOO!!!!
-//VVSTConverter::MeasurementMaxVer; // <== DON'T FORGET TO UPDATE TOO!!!!
+// VVSTConverter::MeasurementMinVer; // <== DON'T FORGET TO UPDATE TOO!!!!
+// VVSTConverter::MeasurementMaxVer; // <== DON'T FORGET TO UPDATE TOO!!!!
 
 namespace
 {
-Q_GLOBAL_STATIC_WITH_ARGS(const QString, strTagRead_Only, (QLatin1String("read-only"))) // NOLINT
-Q_GLOBAL_STATIC_WITH_ARGS(const QString, strAttrCircumference, (QLatin1String("circumference"))) // NOLINT
-Q_GLOBAL_STATIC_WITH_ARGS(const QString, strAttrMeasurement, (QLatin1String("measurement"))) // NOLINT
-Q_GLOBAL_STATIC_WITH_ARGS(const QString, strTagDimension, (QLatin1String("dimension"))) // NOLINT
-}
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_CLANG("-Wunused-member-function")
+
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, strTagRead_Only, ("read-only"_L1))          // NOLINT
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, strAttrCircumference, ("circumference"_L1)) // NOLINT
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, strAttrMeasurement, ("measurement"_L1))     // NOLINT
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, strTagDimension, ("dimension"_L1))          // NOLINT
+
+QT_WARNING_POP
+} // namespace
 
 //---------------------------------------------------------------------------------------------------------------------
 VVSTConverter::VVSTConverter(const QString &fileName)
-    :VAbstractMConverter(fileName)
+  : VAbstractMConverter(fileName)
 {
     ValidateInputFile(CurrentSchema);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-auto VVSTConverter::XSDSchema(unsigned ver) const -> QString
+auto VVSTConverter::XSDSchemas() -> QHash<unsigned int, QString>
 {
-    QHash <unsigned, QString> schemas =
-    {
+    static auto schemas = QHash<unsigned, QString>{
         std::make_pair(FormatVersion(0, 3, 0), QStringLiteral("://schema/multisize_measurements/v0.3.0.xsd")),
         std::make_pair(FormatVersion(0, 4, 0), QStringLiteral("://schema/multisize_measurements/v0.4.0.xsd")),
         std::make_pair(FormatVersion(0, 4, 1), QStringLiteral("://schema/multisize_measurements/v0.4.1.xsd")),
@@ -90,15 +96,12 @@ auto VVSTConverter::XSDSchema(unsigned ver) const -> QString
         std::make_pair(FormatVersion(0, 5, 1), QStringLiteral("://schema/multisize_measurements/v0.5.1.xsd")),
         std::make_pair(FormatVersion(0, 5, 2), QStringLiteral("://schema/multisize_measurements/v0.5.2.xsd")),
         std::make_pair(FormatVersion(0, 5, 3), QStringLiteral("://schema/multisize_measurements/v0.5.3.xsd")),
-        std::make_pair(FormatVersion(0, 5, 4), CurrentSchema),
+        std::make_pair(FormatVersion(0, 5, 4), QStringLiteral("://schema/multisize_measurements/v0.5.4.xsd")),
+        std::make_pair(FormatVersion(0, 6, 0), QStringLiteral("://schema/multisize_measurements/v0.6.0.xsd")),
+        std::make_pair(FormatVersion(0, 6, 1), CurrentSchema),
     };
 
-    if (schemas.contains(ver))
-    {
-        return schemas.value(ver);
-    }
-
-    InvalidVersion(ver);
+    return schemas;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -125,9 +128,13 @@ void VVSTConverter::ApplyPatches()
         case (FormatVersion(0, 5, 2)):
         case (FormatVersion(0, 5, 3)):
             ToV0_5_4();
-            ValidateXML(CurrentSchema);
             Q_FALLTHROUGH();
         case (FormatVersion(0, 5, 4)):
+        case (FormatVersion(0, 6, 0)):
+            ToV0_6_1();
+            ValidateXML(CurrentSchema);
+            Q_FALLTHROUGH();
+        case (FormatVersion(0, 6, 1)):
             break;
         default:
             InvalidVersion(m_ver);
@@ -146,8 +153,7 @@ void VVSTConverter::DowngradeToCurrentMaxVersion()
 auto VVSTConverter::IsReadOnly() const -> bool
 {
     // Check if attribute read-only was not changed in file format
-    Q_STATIC_ASSERT_X(VVSTConverter::MeasurementMaxVer == FormatVersion(0, 5, 4),
-                      "Check attribute read-only.");
+    Q_STATIC_ASSERT_X(VVSTConverter::MeasurementMaxVer == FormatVersion(0, 6, 1), "Check attribute read-only.");
 
     // Possibly in future attribute read-only will change position etc.
     // For now position is the same for all supported format versions.
@@ -156,28 +162,32 @@ auto VVSTConverter::IsReadOnly() const -> bool
     return UniqueTagText(*strTagRead_Only, falseStr) == trueStr;
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+auto VVSTConverter::Schemas() const -> QHash<unsigned int, QString>
+{
+    return XSDSchemas();
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void VVSTConverter::AddNewTagsForV0_4_0()
 {
     // TODO. Delete if minimal supported version is 0.4.0
-    Q_STATIC_ASSERT_X(VVSTConverter::MeasurementMinVer < FormatVersion(0, 4, 0),
-                      "Time to refactor the code.");
+    Q_STATIC_ASSERT_X(VVSTConverter::MeasurementMinVer < FormatVersion(0, 4, 0), "Time to refactor the code.");
 
     QDomElement rootElement = this->documentElement();
     QDomNode refChild = rootElement.firstChildElement(QStringLiteral("version"));
 
     refChild = rootElement.insertAfter(CreateElementWithText(QStringLiteral("read-only"), falseStr), refChild);
 
-    rootElement.insertAfter(CreateElementWithText(QStringLiteral("notes"),
-                                                  UniqueTagText(QStringLiteral("description"))), refChild);
+    rootElement.insertAfter(
+        CreateElementWithText(QStringLiteral("notes"), UniqueTagText(QStringLiteral("description"))), refChild);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void VVSTConverter::RemoveTagsForV0_4_0()
 {
     // TODO. Delete if minimal supported version is 0.4.0
-    Q_STATIC_ASSERT_X(VVSTConverter::MeasurementMinVer < FormatVersion(0, 4, 0),
-                      "Time to refactor the code.");
+    Q_STATIC_ASSERT_X(VVSTConverter::MeasurementMinVer < FormatVersion(0, 4, 0), "Time to refactor the code.");
 
     QDomElement rootElement = this->documentElement();
 
@@ -202,24 +212,23 @@ void VVSTConverter::RemoveTagsForV0_4_0()
 void VVSTConverter::ConvertMeasurementsToV0_4_0()
 {
     // TODO. Delete if minimal supported version is 0.4.0
-    Q_STATIC_ASSERT_X(VVSTConverter::MeasurementMinVer < FormatVersion(0, 4, 0),
-                      "Time to refactor the code.");
+    Q_STATIC_ASSERT_X(VVSTConverter::MeasurementMinVer < FormatVersion(0, 4, 0), "Time to refactor the code.");
 
-    const QString tagBM = QStringLiteral("body-measurements");
+    const auto tagBM = QStringLiteral("body-measurements");
 
     QDomElement bm = createElement(tagBM);
 
     const QMultiMap<QString, QString> names = OldNamesToNewNames_InV0_3_0();
     const QList<QString> keys = names.uniqueKeys();
-    for (auto &key : keys)
+    for (const auto &key : keys)
     {
         qreal resValue = 0;
         qreal resSizeIncrease = 0;
         qreal resHeightIncrease = 0;
 
         // This has the same effect as a .values(), just isn't as elegant
-        const QList<QString> list = names.values( key );
-        for(const auto &val : list)
+        const QList<QString> list = names.values(key);
+        for (const auto &val : list)
         {
             const QDomNodeList nodeList = this->elementsByTagName(val);
             if (nodeList.isEmpty())
@@ -227,10 +236,11 @@ void VVSTConverter::ConvertMeasurementsToV0_4_0()
                 continue;
             }
 
-            QDomElement m = nodeList.at(0).toElement();
-            const qreal value = GetParametrDouble(m, QStringLiteral("value"), "0.0");
-            const qreal size_increase = GetParametrDouble(m, QStringLiteral("size_increase"), "0.0");
-            const qreal height_increase = GetParametrDouble(m, QStringLiteral("height_increase"), "0.0");
+            QDomElement const m = nodeList.at(0).toElement();
+            const qreal value = GetParametrDouble(m, QStringLiteral("value"), QStringLiteral("0.0"));
+            const qreal size_increase = GetParametrDouble(m, QStringLiteral("size_increase"), QStringLiteral("0.0"));
+            const qreal height_increase =
+                GetParametrDouble(m, QStringLiteral("height_increase"), QStringLiteral("0.0"));
 
             if (not qFuzzyIsNull(value))
             {
@@ -249,11 +259,11 @@ void VVSTConverter::ConvertMeasurementsToV0_4_0()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QDomElement VVSTConverter::AddMV0_4_0(const QString &name, qreal value, qreal sizeIncrease, qreal heightIncrease)
+auto VVSTConverter::AddMV0_4_0(const QString &name, qreal value, qreal sizeIncrease, qreal heightIncrease)
+    -> QDomElement
 {
     // TODO. Delete if minimal supported version is 0.4.0
-    Q_STATIC_ASSERT_X(VVSTConverter::MeasurementMinVer < FormatVersion(0, 4, 0),
-                      "Time to refactor the code.");
+    Q_STATIC_ASSERT_X(VVSTConverter::MeasurementMinVer < FormatVersion(0, 4, 0), "Time to refactor the code.");
 
     QDomElement element = createElement(QStringLiteral("m"));
 
@@ -261,7 +271,7 @@ QDomElement VVSTConverter::AddMV0_4_0(const QString &name, qreal value, qreal si
     SetAttribute(element, QStringLiteral("base"), QString().setNum(value));
     SetAttribute(element, QStringLiteral("size_increase"), QString().setNum(sizeIncrease));
     SetAttribute(element, QStringLiteral("height_increase"), QString().setNum(heightIncrease));
-    SetAttribute(element, QStringLiteral("description"),QString());
+    SetAttribute(element, QStringLiteral("description"), QString());
     SetAttribute(element, QStringLiteral("full_name"), QString());
 
     return element;
@@ -271,11 +281,10 @@ QDomElement VVSTConverter::AddMV0_4_0(const QString &name, qreal value, qreal si
 void VVSTConverter::PM_SystemV0_4_1()
 {
     // TODO. Delete if minimal supported version is 0.4.1
-    Q_STATIC_ASSERT_X(VVSTConverter::MeasurementMinVer < FormatVersion(0, 4, 1),
-                      "Time to refactor the code.");
+    Q_STATIC_ASSERT_X(VVSTConverter::MeasurementMinVer < FormatVersion(0, 4, 1), "Time to refactor the code.");
 
     const QDomNodeList nodeList = this->elementsByTagName(QStringLiteral("size"));
-    QDomElement personal = nodeList.at(0).toElement();
+    QDomElement const personal = nodeList.at(0).toElement();
 
     QDomElement parent = personal.parentNode().toElement();
     parent.insertBefore(CreateElementWithText(QStringLiteral("pm_system"), QStringLiteral("998")), personal);
@@ -285,8 +294,7 @@ void VVSTConverter::PM_SystemV0_4_1()
 void VVSTConverter::ConvertMeasurementsToV0_4_2()
 {
     // TODO. Delete if minimal supported version is 0.4.2
-    Q_STATIC_ASSERT_X(VVSTConverter::MeasurementMinVer < FormatVersion(0, 4, 2),
-                      "Time to refactor the code.");
+    Q_STATIC_ASSERT_X(VVSTConverter::MeasurementMinVer < FormatVersion(0, 4, 2), "Time to refactor the code.");
 
     const QMap<QString, QString> names = OldNamesToNewNames_InV0_3_3();
     auto i = names.constBegin();
@@ -301,7 +309,7 @@ void VVSTConverter::ConvertMeasurementsToV0_4_2()
 
         for (int ii = 0; ii < nodeList.size(); ++ii)
         {
-            const QString attrName = QStringLiteral("name");
+            const auto attrName = QStringLiteral("name");
             QDomElement element = nodeList.at(ii).toElement();
             const QString name = GetParametrString(element, attrName);
             if (name == i.value())
@@ -318,8 +326,7 @@ void VVSTConverter::ConvertMeasurementsToV0_4_2()
 void VVSTConverter::AddNewTagsForV0_5_0()
 {
     // TODO. Delete if minimal supported version is 0.5.0
-    Q_STATIC_ASSERT_X(VVSTConverter::MeasurementMinVer < FormatVersion(0, 5, 0),
-                      "Time to refactor the code.");
+    Q_STATIC_ASSERT_X(VVSTConverter::MeasurementMinVer < FormatVersion(0, 5, 0), "Time to refactor the code.");
 
     QDomElement root = documentElement();
     const QDomElement pmSystemTag = root.firstChildElement(QStringLiteral("pm_system"));
@@ -345,9 +352,9 @@ void VVSTConverter::AddNewTagsForV0_5_0()
     const Unit units = Units();
 
     {
-        const int step = static_cast<int>(UnitConvertor(6, Unit::Cm, units));
-        const int min = static_cast<int>(UnitConvertor(50, Unit::Cm, units));
-        const int max = static_cast<int>(UnitConvertor(200, Unit::Cm, units));
+        const auto step = static_cast<int>(UnitConvertor(6, Unit::Cm, units));
+        const auto min = static_cast<int>(UnitConvertor(50, Unit::Cm, units));
+        const auto max = static_cast<int>(UnitConvertor(200, Unit::Cm, units));
 
         QDomElement dimensionX = createElement(QStringLiteral("dimension"));
         SetAttribute(dimensionX, QStringLiteral("type"), QChar('x'));
@@ -359,9 +366,9 @@ void VVSTConverter::AddNewTagsForV0_5_0()
     }
 
     {
-        const int step = static_cast<int>(UnitConvertor(2, Unit::Cm, units));
-        const int min = static_cast<int>(UnitConvertor(22, Unit::Cm, units));
-        const int max = static_cast<int>(UnitConvertor(72, Unit::Cm, units));
+        const auto step = static_cast<int>(UnitConvertor(2, Unit::Cm, units));
+        const auto min = static_cast<int>(UnitConvertor(22, Unit::Cm, units));
+        const auto max = static_cast<int>(UnitConvertor(72, Unit::Cm, units));
 
         QDomElement dimensionY = createElement(QStringLiteral("dimension"));
         SetAttribute(dimensionY, QStringLiteral("type"), QChar('y'));
@@ -382,8 +389,7 @@ void VVSTConverter::AddNewTagsForV0_5_0()
 void VVSTConverter::RemoveTagsForV0_5_0()
 {
     // TODO. Delete if minimal supported version is 0.5.0
-    Q_STATIC_ASSERT_X(VVSTConverter::MeasurementMinVer < FormatVersion(0, 5, 0),
-                      "Time to refactor the code.");
+    Q_STATIC_ASSERT_X(VVSTConverter::MeasurementMinVer < FormatVersion(0, 5, 0), "Time to refactor the code.");
 
     QDomElement root = documentElement();
 
@@ -404,8 +410,7 @@ void VVSTConverter::RemoveTagsForV0_5_0()
 void VVSTConverter::ConvertMeasurementsToV0_5_0()
 {
     // TODO. Delete if minimal supported version is 0.5.0
-    Q_STATIC_ASSERT_X(VVSTConverter::MeasurementMinVer < FormatVersion(0, 5, 0),
-                      "Time to refactor the code.");
+    Q_STATIC_ASSERT_X(VVSTConverter::MeasurementMinVer < FormatVersion(0, 5, 0), "Time to refactor the code.");
 
     const QDomNodeList measurements = elementsByTagName(QStringLiteral("m"));
     for (int i = 0; i < measurements.size(); ++i)
@@ -424,24 +429,29 @@ void VVSTConverter::ConvertMeasurementsToV0_5_0()
 void VVSTConverter::ConvertCircumferenceAttreibuteToV0_5_4()
 {
     const QDomNodeList list = elementsByTagName(*strTagDimension);
-    for (int i=0; i < list.size(); ++i)
+    for (int i = 0; i < list.size(); ++i)
     {
         QDomElement dom = list.at(i).toElement();
         if (dom.hasAttribute(*strAttrCircumference))
         {
-            bool m = GetParametrBool(dom, *strAttrCircumference, trueStr);
+            bool const m = GetParametrBool(dom, *strAttrCircumference, trueStr);
             dom.removeAttribute(*strAttrCircumference);
             SetAttribute(dom, *strAttrMeasurement, m);
         }
     }
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void VVSTConverter::ConvertPMSystemToV0_6_1()
+{
+    setTagText(QStringLiteral("pm_system"), QString());
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void VVSTConverter::ToV0_4_0()
 {
     // TODO. Delete if minimal supported version is 0.4.0
-    Q_STATIC_ASSERT_X(VVSTConverter::MeasurementMinVer < FormatVersion(0, 4, 0),
-                      "Time to refactor the code.");
+    Q_STATIC_ASSERT_X(VVSTConverter::MeasurementMinVer < FormatVersion(0, 4, 0), "Time to refactor the code.");
 
     AddRootComment();
     SetVersion(QStringLiteral("0.4.0"));
@@ -455,8 +465,7 @@ void VVSTConverter::ToV0_4_0()
 void VVSTConverter::ToV0_4_1()
 {
     // TODO. Delete if minimal supported version is 0.4.1
-    Q_STATIC_ASSERT_X(VVSTConverter::MeasurementMinVer < FormatVersion(0, 4, 1),
-                      "Time to refactor the code.");
+    Q_STATIC_ASSERT_X(VVSTConverter::MeasurementMinVer < FormatVersion(0, 4, 1), "Time to refactor the code.");
 
     SetVersion(QStringLiteral("0.4.1"));
     PM_SystemV0_4_1();
@@ -467,8 +476,7 @@ void VVSTConverter::ToV0_4_1()
 void VVSTConverter::ToV0_4_2()
 {
     // TODO. Delete if minimal supported version is 0.4.2
-    Q_STATIC_ASSERT_X(VVSTConverter::MeasurementMinVer < FormatVersion(0, 4, 2),
-                      "Time to refactor the code.");
+    Q_STATIC_ASSERT_X(VVSTConverter::MeasurementMinVer < FormatVersion(0, 4, 2), "Time to refactor the code.");
 
     SetVersion(QStringLiteral("0.4.2"));
     ConvertMeasurementsToV0_4_2();
@@ -479,8 +487,7 @@ void VVSTConverter::ToV0_4_2()
 void VVSTConverter::ToV0_5_0()
 {
     // TODO. Delete if minimal supported version is 0.5.0
-    Q_STATIC_ASSERT_X(VVSTConverter::MeasurementMinVer < FormatVersion(0, 5, 0),
-                      "Time to refactor the code.");
+    Q_STATIC_ASSERT_X(VVSTConverter::MeasurementMinVer < FormatVersion(0, 5, 0), "Time to refactor the code.");
 
     SetVersion(QStringLiteral("0.5.0"));
     AddNewTagsForV0_5_0();
@@ -493,10 +500,20 @@ void VVSTConverter::ToV0_5_0()
 void VVSTConverter::ToV0_5_4()
 {
     // TODO. Delete if minimal supported version is 0.5.4
-    Q_STATIC_ASSERT_X(VVSTConverter::MeasurementMinVer < FormatVersion(0, 5, 4),
-                      "Time to refactor the code.");
+    Q_STATIC_ASSERT_X(VVSTConverter::MeasurementMinVer < FormatVersion(0, 5, 4), "Time to refactor the code.");
 
     SetVersion(QStringLiteral("0.5.4"));
     ConvertCircumferenceAttreibuteToV0_5_4();
     Save();
 }
+
+//---------------------------------------------------------------------------------------------------------------------
+void VVSTConverter::ToV0_6_1()
+{
+    // TODO. Delete if minimal supported version is 0.6.1
+    Q_STATIC_ASSERT_X(VVSTConverter::MeasurementMinVer < FormatVersion(0, 6, 1), "Time to refactor the code.");
+
+    SetVersion(QStringLiteral("0.6.1"));
+    ConvertPMSystemToV0_6_1();
+    Save();
+}
