@@ -53,44 +53,39 @@ VWatermarkConverter::VWatermarkConverter(const QString &fileName)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-unsigned VWatermarkConverter::MinVer() const
+auto VWatermarkConverter::XSDSchemas() -> QHash<unsigned int, QString>
 {
-    return WatermarkMinVer;
-}
-
-//---------------------------------------------------------------------------------------------------------------------
-unsigned VWatermarkConverter::MaxVer() const
-{
-    return WatermarkMaxVer;
-}
-
-//---------------------------------------------------------------------------------------------------------------------
-QString VWatermarkConverter::MinVerStr() const
-{
-    return WatermarkMinVerStr;
-}
-
-//---------------------------------------------------------------------------------------------------------------------
-QString VWatermarkConverter::MaxVerStr() const
-{
-    return WatermarkMaxVerStr;
-}
-
-//---------------------------------------------------------------------------------------------------------------------
-QString VWatermarkConverter::XSDSchema(unsigned ver) const
-{
-    QHash <unsigned, QString> schemas =
+    static auto schemas = QHash <unsigned, QString>
     {
         std::make_pair(FormatVersion(1, 0, 0), QStringLiteral("://schema/watermark/v1.0.0.xsd")),
         std::make_pair(FormatVersion(1, 1, 0), CurrentSchema)
     };
 
-    if (schemas.contains(ver))
-    {
-        return schemas.value(ver);
-    }
+    return schemas;
+}
 
-    InvalidVersion(ver);
+//---------------------------------------------------------------------------------------------------------------------
+auto VWatermarkConverter::MinVer() const -> unsigned
+{
+    return WatermarkMinVer;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VWatermarkConverter::MaxVer() const -> unsigned
+{
+    return WatermarkMaxVer;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VWatermarkConverter::MinVerStr() const -> QString
+{
+    return WatermarkMinVerStr;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VWatermarkConverter::MaxVerStr() const -> QString
+{
+    return WatermarkMaxVerStr;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -116,6 +111,12 @@ void VWatermarkConverter::DowngradeToCurrentMaxVersion()
     Save();
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+auto VWatermarkConverter::Schemas() const -> QHash<unsigned int, QString>
+{
+    return XSDSchemas();
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void VWatermarkConverter::ToV1_1_0()
 {
