@@ -29,23 +29,26 @@
 namespace qmu
 {
 //---------------------------------------------------------------------------------------------------------------------
-QmuParserCallback::QmuParserCallback ( fun_type0 a_pFun, bool a_bAllowOpti )
-    : d (new QmuParserCallbackData(a_pFun, a_bAllowOpti))
-{}
+QmuParserCallback::QmuParserCallback(fun_type0 a_pFun, bool a_bAllowOpti)
+  : d(new QmuParserCallbackData(a_pFun, a_bAllowOpti))
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-QmuParserCallback::QmuParserCallback ( fun_type1 a_pFun, bool a_bAllowOpti, int a_iPrec, ECmdCode a_iCode )
-    : d (new QmuParserCallbackData(a_pFun, a_bAllowOpti, a_iPrec, a_iCode))
-{}
+QmuParserCallback::QmuParserCallback(fun_type1 a_pFun, bool a_bAllowOpti, int a_iPrec, ECmdCode a_iCode)
+  : d(new QmuParserCallbackData(a_pFun, a_bAllowOpti, a_iPrec, a_iCode))
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
 /**
  * @brief Constructor for constructing funcstion callbacks taking two arguments.
  * @throw nothrow
  */
-QmuParserCallback::QmuParserCallback ( fun_type2 a_pFun, bool a_bAllowOpti )
-    : d (new QmuParserCallbackData(a_pFun, a_bAllowOpti))
-{}
+QmuParserCallback::QmuParserCallback(fun_type2 a_pFun, bool a_bAllowOpti)
+  : d(new QmuParserCallbackData(a_pFun, a_bAllowOpti))
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
 /**
@@ -56,128 +59,152 @@ QmuParserCallback::QmuParserCallback ( fun_type2 a_pFun, bool a_bAllowOpti )
  * @param a_eOprtAsct The operators associativity
  * @throw nothrow
  */
-QmuParserCallback::QmuParserCallback (fun_type2 a_pFun, bool a_bAllowOpti, int a_iPrec, EOprtAssociativity a_eOprtAsct)
-    : d (new QmuParserCallbackData(a_pFun, a_bAllowOpti, a_iPrec, a_eOprtAsct))
-{}
+QmuParserCallback::QmuParserCallback(fun_type2 a_pFun, bool a_bAllowOpti, int a_iPrec, EOprtAssociativity a_eOprtAsct)
+  : d(new QmuParserCallbackData(a_pFun, a_bAllowOpti, a_iPrec, a_eOprtAsct))
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-QmuParserCallback::QmuParserCallback ( fun_type3 a_pFun, bool a_bAllowOpti )
-    : d (new QmuParserCallbackData(a_pFun, a_bAllowOpti))
-{}
+QmuParserCallback::QmuParserCallback(fun_type3 a_pFun, bool a_bAllowOpti)
+  : d(new QmuParserCallbackData(a_pFun, a_bAllowOpti))
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-QmuParserCallback::QmuParserCallback ( fun_type4 a_pFun, bool a_bAllowOpti )
-    : d (new QmuParserCallbackData(a_pFun, a_bAllowOpti))
-{}
+QmuParserCallback::QmuParserCallback(fun_type4 a_pFun, bool a_bAllowOpti)
+  : d(new QmuParserCallbackData(a_pFun, a_bAllowOpti))
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-QmuParserCallback::QmuParserCallback ( fun_type5 a_pFun, bool a_bAllowOpti )
-    : d (new QmuParserCallbackData(a_pFun, a_bAllowOpti))
-{}
+QmuParserCallback::QmuParserCallback(fun_type5 a_pFun, bool a_bAllowOpti)
+  : d(new QmuParserCallbackData(a_pFun, a_bAllowOpti))
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-QmuParserCallback::QmuParserCallback ( fun_type6 a_pFun, bool a_bAllowOpti )
-    : d (new QmuParserCallbackData(a_pFun, a_bAllowOpti))
-{}
+QmuParserCallback::QmuParserCallback(fun_type6 a_pFun, bool a_bAllowOpti)
+  : d(new QmuParserCallbackData(a_pFun, a_bAllowOpti))
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-QmuParserCallback::QmuParserCallback ( fun_type7 a_pFun, bool a_bAllowOpti )
-    : d (new QmuParserCallbackData(a_pFun, a_bAllowOpti))
-{}
+QmuParserCallback::QmuParserCallback(fun_type7 a_pFun, bool a_bAllowOpti)
+  : d(new QmuParserCallbackData(a_pFun, a_bAllowOpti))
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-QmuParserCallback::QmuParserCallback ( fun_type8 a_pFun, bool a_bAllowOpti )
-    : d (new QmuParserCallbackData(a_pFun, a_bAllowOpti))
-{}
+QmuParserCallback::QmuParserCallback(fun_type8 a_pFun, bool a_bAllowOpti)
+  : d(new QmuParserCallbackData(a_pFun, a_bAllowOpti))
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-QmuParserCallback::QmuParserCallback ( fun_type9 a_pFun, bool a_bAllowOpti )
-    : d (new QmuParserCallbackData(a_pFun, a_bAllowOpti))
-{}
+QmuParserCallback::QmuParserCallback(fun_type9 a_pFun, bool a_bAllowOpti)
+  : d(new QmuParserCallbackData(a_pFun, a_bAllowOpti))
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-QmuParserCallback::QmuParserCallback ( fun_type10 a_pFun, bool a_bAllowOpti )
-    : d (new QmuParserCallbackData(a_pFun, a_bAllowOpti))
-{}
+QmuParserCallback::QmuParserCallback(fun_type10 a_pFun, bool a_bAllowOpti)
+  : d(new QmuParserCallbackData(a_pFun, a_bAllowOpti))
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-QmuParserCallback::QmuParserCallback ( bulkfun_type0 a_pFun, bool a_bAllowOpti )
-    : d (new QmuParserCallbackData(a_pFun, a_bAllowOpti))
-{}
+QmuParserCallback::QmuParserCallback(bulkfun_type0 a_pFun, bool a_bAllowOpti)
+  : d(new QmuParserCallbackData(a_pFun, a_bAllowOpti))
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-QmuParserCallback::QmuParserCallback ( bulkfun_type1 a_pFun, bool a_bAllowOpti )
-    : d (new QmuParserCallbackData(a_pFun, a_bAllowOpti))
-{}
+QmuParserCallback::QmuParserCallback(bulkfun_type1 a_pFun, bool a_bAllowOpti)
+  : d(new QmuParserCallbackData(a_pFun, a_bAllowOpti))
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
 /**
  * @brief Constructor for constructing funcstion callbacks taking two arguments.
  * @throw nothrow
  */
-QmuParserCallback::QmuParserCallback ( bulkfun_type2 a_pFun, bool a_bAllowOpti )
-    : d (new QmuParserCallbackData(a_pFun, a_bAllowOpti))
-{}
+QmuParserCallback::QmuParserCallback(bulkfun_type2 a_pFun, bool a_bAllowOpti)
+  : d(new QmuParserCallbackData(a_pFun, a_bAllowOpti))
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-QmuParserCallback::QmuParserCallback ( bulkfun_type3 a_pFun, bool a_bAllowOpti )
-    : d (new QmuParserCallbackData(a_pFun, a_bAllowOpti))
-{}
+QmuParserCallback::QmuParserCallback(bulkfun_type3 a_pFun, bool a_bAllowOpti)
+  : d(new QmuParserCallbackData(a_pFun, a_bAllowOpti))
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-QmuParserCallback::QmuParserCallback ( bulkfun_type4 a_pFun, bool a_bAllowOpti )
-    : d (new QmuParserCallbackData(a_pFun, a_bAllowOpti))
-{}
+QmuParserCallback::QmuParserCallback(bulkfun_type4 a_pFun, bool a_bAllowOpti)
+  : d(new QmuParserCallbackData(a_pFun, a_bAllowOpti))
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-QmuParserCallback::QmuParserCallback ( bulkfun_type5 a_pFun, bool a_bAllowOpti )
-    : d (new QmuParserCallbackData(a_pFun, a_bAllowOpti))
-{}
+QmuParserCallback::QmuParserCallback(bulkfun_type5 a_pFun, bool a_bAllowOpti)
+  : d(new QmuParserCallbackData(a_pFun, a_bAllowOpti))
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-QmuParserCallback::QmuParserCallback ( bulkfun_type6 a_pFun, bool a_bAllowOpti )
-    : d (new QmuParserCallbackData(a_pFun, a_bAllowOpti))
-{}
+QmuParserCallback::QmuParserCallback(bulkfun_type6 a_pFun, bool a_bAllowOpti)
+  : d(new QmuParserCallbackData(a_pFun, a_bAllowOpti))
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-QmuParserCallback::QmuParserCallback ( bulkfun_type7 a_pFun, bool a_bAllowOpti )
-    : d (new QmuParserCallbackData(a_pFun, a_bAllowOpti))
-{}
+QmuParserCallback::QmuParserCallback(bulkfun_type7 a_pFun, bool a_bAllowOpti)
+  : d(new QmuParserCallbackData(a_pFun, a_bAllowOpti))
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-QmuParserCallback::QmuParserCallback ( bulkfun_type8 a_pFun, bool a_bAllowOpti )
-    : d (new QmuParserCallbackData(a_pFun, a_bAllowOpti))
-{}
+QmuParserCallback::QmuParserCallback(bulkfun_type8 a_pFun, bool a_bAllowOpti)
+  : d(new QmuParserCallbackData(a_pFun, a_bAllowOpti))
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-QmuParserCallback::QmuParserCallback ( bulkfun_type9 a_pFun, bool a_bAllowOpti )
-    : d (new QmuParserCallbackData(a_pFun, a_bAllowOpti))
-{}
+QmuParserCallback::QmuParserCallback(bulkfun_type9 a_pFun, bool a_bAllowOpti)
+  : d(new QmuParserCallbackData(a_pFun, a_bAllowOpti))
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-QmuParserCallback::QmuParserCallback ( bulkfun_type10 a_pFun, bool a_bAllowOpti )
-    : d (new QmuParserCallbackData(a_pFun, a_bAllowOpti))
-{}
+QmuParserCallback::QmuParserCallback(bulkfun_type10 a_pFun, bool a_bAllowOpti)
+  : d(new QmuParserCallbackData(a_pFun, a_bAllowOpti))
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-QmuParserCallback::QmuParserCallback ( multfun_type a_pFun, bool a_bAllowOpti )
-    : d (new QmuParserCallbackData(a_pFun, a_bAllowOpti))
-{}
+QmuParserCallback::QmuParserCallback(multfun_type a_pFun, bool a_bAllowOpti)
+  : d(new QmuParserCallbackData(a_pFun, a_bAllowOpti))
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-QmuParserCallback::QmuParserCallback ( strfun_type1 a_pFun, bool a_bAllowOpti )
-    : d (new QmuParserCallbackData(a_pFun, a_bAllowOpti))
-{}
+QmuParserCallback::QmuParserCallback(strfun_type1 a_pFun, bool a_bAllowOpti)
+  : d(new QmuParserCallbackData(a_pFun, a_bAllowOpti))
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-QmuParserCallback::QmuParserCallback ( strfun_type2 a_pFun, bool a_bAllowOpti )
-    : d (new QmuParserCallbackData(a_pFun, a_bAllowOpti))
-{}
+QmuParserCallback::QmuParserCallback(strfun_type2 a_pFun, bool a_bAllowOpti)
+  : d(new QmuParserCallbackData(a_pFun, a_bAllowOpti))
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-QmuParserCallback::QmuParserCallback ( strfun_type3 a_pFun, bool a_bAllowOpti )
-    : d (new QmuParserCallbackData(a_pFun, a_bAllowOpti))
-{}
+QmuParserCallback::QmuParserCallback(strfun_type3 a_pFun, bool a_bAllowOpti)
+  : d(new QmuParserCallbackData(a_pFun, a_bAllowOpti))
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
 /**
@@ -185,22 +212,24 @@ QmuParserCallback::QmuParserCallback ( strfun_type3 a_pFun, bool a_bAllowOpti )
  * @throw nothrow
  */
 QmuParserCallback::QmuParserCallback()
-    : d (new QmuParserCallbackData)
-{}
+  : d(new QmuParserCallbackData)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
 /**
  * @brief Copy constructor.
  * @throw nothrow
  */
-QmuParserCallback::QmuParserCallback (const QmuParserCallback &a_Fun )
-    : d (a_Fun.d)
-{}
+QmuParserCallback::QmuParserCallback(const QmuParserCallback &a_Fun)
+  : d(a_Fun.d)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-QmuParserCallback &QmuParserCallback::operator=(const QmuParserCallback &a_Fun)
+auto QmuParserCallback::operator=(const QmuParserCallback &a_Fun) -> QmuParserCallback &
 {
-    if ( &a_Fun == this )
+    if (&a_Fun == this)
     {
         return *this;
     }
@@ -208,19 +237,18 @@ QmuParserCallback &QmuParserCallback::operator=(const QmuParserCallback &a_Fun)
     return *this;
 }
 
-#ifdef Q_COMPILER_RVALUE_REFS
 //---------------------------------------------------------------------------------------------------------------------
-QmuParserCallback::QmuParserCallback(QmuParserCallback &&a_Fun) Q_DECL_NOTHROW
-    : d (std::move(a_Fun.d))
-{}
+QmuParserCallback::QmuParserCallback(QmuParserCallback &&a_Fun) noexcept
+  : d(std::move(a_Fun.d))
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-QmuParserCallback &QmuParserCallback::operator=(QmuParserCallback &&a_Fun) Q_DECL_NOTHROW
+auto QmuParserCallback::operator=(QmuParserCallback &&a_Fun) noexcept -> QmuParserCallback &
 {
     std::swap(d, a_Fun.d);
     return *this;
 }
-#endif
 
 //---------------------------------------------------------------------------------------------------------------------
 /**
@@ -230,7 +258,7 @@ QmuParserCallback &QmuParserCallback::operator=(QmuParserCallback &&a_Fun) Q_DEC
  * @throw nothrow
  */
 // cppcheck-suppress unusedFunction
-bool QmuParserCallback::IsOptimizable() const
+auto QmuParserCallback::IsOptimizable() const -> bool
 {
     return d->m_bAllowOpti;
 }
@@ -244,7 +272,7 @@ bool QmuParserCallback::IsOptimizable() const
  * @throw nothrow
  * @return #pFun
  */
-void* QmuParserCallback::GetAddr() const
+auto QmuParserCallback::GetAddr() const -> void *
 {
     return d->m_pFun;
 }
@@ -252,14 +280,14 @@ void* QmuParserCallback::GetAddr() const
 //---------------------------------------------------------------------------------------------------------------------
 /**
  * @brief Return the callback code.
-*/
-ECmdCode  QmuParserCallback::GetCode() const
+ */
+auto QmuParserCallback::GetCode() const -> ECmdCode
 {
     return d->m_iCode;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-ETypeCode QmuParserCallback::GetType() const
+auto QmuParserCallback::GetType() const -> ETypeCode
 {
     return d->m_iType;
 }
@@ -271,7 +299,7 @@ ETypeCode QmuParserCallback::GetType() const
  *
  * Only valid if the callback token is an operator token (binary or infix).
  */
-int QmuParserCallback::GetPri()  const
+auto QmuParserCallback::GetPri() const -> int
 {
     return d->m_iPri;
 }
@@ -283,7 +311,7 @@ int QmuParserCallback::GetPri()  const
  *
  * Only valid if the callback token is a binary operator token.
  */
-EOprtAssociativity QmuParserCallback::GetAssociativity() const
+auto QmuParserCallback::GetAssociativity() const -> EOprtAssociativity
 {
     return d->m_eOprtAsct;
 }
@@ -292,272 +320,444 @@ EOprtAssociativity QmuParserCallback::GetAssociativity() const
 /**
  * @brief Returns the number of function Arguments.
  */
-int QmuParserCallback::GetArgc() const
+auto QmuParserCallback::GetArgc() const -> int
 {
     return d->m_iArgc;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-//Supressing specific warnings on gcc/g++ http://www.mr-edd.co.uk/blog/supressing_gcc_warnings
+// Supressing specific warnings on gcc/g++ http://www.mr-edd.co.uk/blog/supressing_gcc_warnings
 #ifdef __GNUC__
 __extension__
 #endif
-QmuParserCallbackData::QmuParserCallbackData()
-    : m_pFun ( nullptr ), m_iArgc ( 0 ), m_iPri ( -1 ), m_eOprtAsct ( oaNONE ), m_iCode ( cmUNKNOWN ),
-      m_iType ( tpVOID ), m_bAllowOpti ( 0 )
-{}
+    QmuParserCallbackData::QmuParserCallbackData()
+  : m_pFun(nullptr),
+    m_iArgc(0),
+    m_iPri(-1),
+    m_eOprtAsct(oaNONE),
+    m_iCode(cmUNKNOWN),
+    m_iType(tpVOID),
+    m_bAllowOpti(false)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
 #ifdef __GNUC__
 __extension__
 #endif
-QmuParserCallbackData::QmuParserCallbackData ( fun_type0 a_pFun, bool a_bAllowOpti )
-    : m_pFun ( reinterpret_cast<void*> ( a_pFun ) ), m_iArgc ( 0 ), m_iPri ( -1 ), m_eOprtAsct ( oaNONE ),
-      m_iCode ( cmFUNC ), m_iType ( tpDBL ), m_bAllowOpti ( a_bAllowOpti )
-{}
+    QmuParserCallbackData::QmuParserCallbackData(fun_type0 a_pFun, bool a_bAllowOpti)
+  : m_pFun(reinterpret_cast<void *>(a_pFun)),
+    m_iArgc(0),
+    m_iPri(-1),
+    m_eOprtAsct(oaNONE),
+    m_iCode(cmFUNC),
+    m_iType(tpDBL),
+    m_bAllowOpti(a_bAllowOpti)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
 #ifdef __GNUC__
 __extension__
 #endif
-QmuParserCallbackData::QmuParserCallbackData ( fun_type1 a_pFun, bool a_bAllowOpti, int a_iPrec, ECmdCode a_iCode )
-    : m_pFun ( reinterpret_cast<void*> ( a_pFun ) ), m_iArgc ( 1 ), m_iPri ( a_iPrec ), m_eOprtAsct ( oaNONE ),
-      m_iCode ( a_iCode ), m_iType ( tpDBL ), m_bAllowOpti ( a_bAllowOpti )
-{}
+    QmuParserCallbackData::QmuParserCallbackData(fun_type1 a_pFun, bool a_bAllowOpti, int a_iPrec, ECmdCode a_iCode)
+  : m_pFun(reinterpret_cast<void *>(a_pFun)),
+    m_iArgc(1),
+    m_iPri(a_iPrec),
+    m_eOprtAsct(oaNONE),
+    m_iCode(a_iCode),
+    m_iType(tpDBL),
+    m_bAllowOpti(a_bAllowOpti)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
 #ifdef __GNUC__
 __extension__
 #endif
-QmuParserCallbackData::QmuParserCallbackData ( fun_type2 a_pFun, bool a_bAllowOpti )
-    : m_pFun ( reinterpret_cast<void*> ( a_pFun ) ), m_iArgc ( 2 ), m_iPri ( -1 ), m_eOprtAsct ( oaNONE ),
-      m_iCode ( cmFUNC ), m_iType ( tpDBL ), m_bAllowOpti ( a_bAllowOpti )
-{}
+    QmuParserCallbackData::QmuParserCallbackData(fun_type2 a_pFun, bool a_bAllowOpti)
+  : m_pFun(reinterpret_cast<void *>(a_pFun)),
+    m_iArgc(2),
+    m_iPri(-1),
+    m_eOprtAsct(oaNONE),
+    m_iCode(cmFUNC),
+    m_iType(tpDBL),
+    m_bAllowOpti(a_bAllowOpti)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
 #ifdef __GNUC__
 __extension__
 #endif
-QmuParserCallbackData::QmuParserCallbackData (fun_type2 a_pFun, bool a_bAllowOpti, int a_iPrec, EOprtAssociativity a_eOprtAsct)
-    : m_pFun ( reinterpret_cast<void*> ( a_pFun ) ), m_iArgc ( 2 ), m_iPri ( a_iPrec ), m_eOprtAsct ( a_eOprtAsct ),
-      m_iCode ( cmOPRT_BIN ), m_iType ( tpDBL ), m_bAllowOpti ( a_bAllowOpti )
-{}
+    QmuParserCallbackData::QmuParserCallbackData(fun_type2 a_pFun, bool a_bAllowOpti, int a_iPrec,
+                                                 EOprtAssociativity a_eOprtAsct)
+  : m_pFun(reinterpret_cast<void *>(a_pFun)),
+    m_iArgc(2),
+    m_iPri(a_iPrec),
+    m_eOprtAsct(a_eOprtAsct),
+    m_iCode(cmOPRT_BIN),
+    m_iType(tpDBL),
+    m_bAllowOpti(a_bAllowOpti)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
 #ifdef __GNUC__
 __extension__
 #endif
-QmuParserCallbackData::QmuParserCallbackData ( fun_type3 a_pFun, bool a_bAllowOpti )
-    : m_pFun ( reinterpret_cast<void*> ( a_pFun ) ), m_iArgc ( 3 ), m_iPri ( -1 ), m_eOprtAsct ( oaNONE ),
-      m_iCode ( cmFUNC ), m_iType ( tpDBL ), m_bAllowOpti ( a_bAllowOpti )
-{}
+    QmuParserCallbackData::QmuParserCallbackData(fun_type3 a_pFun, bool a_bAllowOpti)
+  : m_pFun(reinterpret_cast<void *>(a_pFun)),
+    m_iArgc(3),
+    m_iPri(-1),
+    m_eOprtAsct(oaNONE),
+    m_iCode(cmFUNC),
+    m_iType(tpDBL),
+    m_bAllowOpti(a_bAllowOpti)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
 #ifdef __GNUC__
 __extension__
 #endif
-QmuParserCallbackData::QmuParserCallbackData ( fun_type4 a_pFun, bool a_bAllowOpti )
-    : m_pFun ( reinterpret_cast<void*> ( a_pFun ) ), m_iArgc ( 4 ), m_iPri ( -1 ), m_eOprtAsct ( oaNONE ),
-      m_iCode ( cmFUNC ), m_iType ( tpDBL ), m_bAllowOpti ( a_bAllowOpti )
-{}
+    QmuParserCallbackData::QmuParserCallbackData(fun_type4 a_pFun, bool a_bAllowOpti)
+  : m_pFun(reinterpret_cast<void *>(a_pFun)),
+    m_iArgc(4),
+    m_iPri(-1),
+    m_eOprtAsct(oaNONE),
+    m_iCode(cmFUNC),
+    m_iType(tpDBL),
+    m_bAllowOpti(a_bAllowOpti)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
 #ifdef __GNUC__
 __extension__
 #endif
-QmuParserCallbackData::QmuParserCallbackData ( fun_type5 a_pFun, bool a_bAllowOpti )
-    : m_pFun ( reinterpret_cast<void*> ( a_pFun ) ), m_iArgc ( 5 ), m_iPri ( -1 ), m_eOprtAsct ( oaNONE ),
-      m_iCode ( cmFUNC ), m_iType ( tpDBL ), m_bAllowOpti ( a_bAllowOpti )
-{}
+    QmuParserCallbackData::QmuParserCallbackData(fun_type5 a_pFun, bool a_bAllowOpti)
+  : m_pFun(reinterpret_cast<void *>(a_pFun)),
+    m_iArgc(5),
+    m_iPri(-1),
+    m_eOprtAsct(oaNONE),
+    m_iCode(cmFUNC),
+    m_iType(tpDBL),
+    m_bAllowOpti(a_bAllowOpti)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
 #ifdef __GNUC__
 __extension__
 #endif
-QmuParserCallbackData::QmuParserCallbackData ( fun_type6 a_pFun, bool a_bAllowOpti )
-    : m_pFun ( reinterpret_cast<void*> ( a_pFun ) ), m_iArgc ( 6 ), m_iPri ( -1 ), m_eOprtAsct ( oaNONE ),
-      m_iCode ( cmFUNC ), m_iType ( tpDBL ), m_bAllowOpti ( a_bAllowOpti )
-{}
+    QmuParserCallbackData::QmuParserCallbackData(fun_type6 a_pFun, bool a_bAllowOpti)
+  : m_pFun(reinterpret_cast<void *>(a_pFun)),
+    m_iArgc(6),
+    m_iPri(-1),
+    m_eOprtAsct(oaNONE),
+    m_iCode(cmFUNC),
+    m_iType(tpDBL),
+    m_bAllowOpti(a_bAllowOpti)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
 #ifdef __GNUC__
 __extension__
 #endif
-QmuParserCallbackData::QmuParserCallbackData ( fun_type7 a_pFun, bool a_bAllowOpti )
-    : m_pFun ( reinterpret_cast<void*> ( a_pFun ) ), m_iArgc ( 7 ), m_iPri ( -1 ), m_eOprtAsct ( oaNONE ),
-      m_iCode ( cmFUNC ), m_iType ( tpDBL ), m_bAllowOpti ( a_bAllowOpti )
-{}
+    QmuParserCallbackData::QmuParserCallbackData(fun_type7 a_pFun, bool a_bAllowOpti)
+  : m_pFun(reinterpret_cast<void *>(a_pFun)),
+    m_iArgc(7),
+    m_iPri(-1),
+    m_eOprtAsct(oaNONE),
+    m_iCode(cmFUNC),
+    m_iType(tpDBL),
+    m_bAllowOpti(a_bAllowOpti)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
 #ifdef __GNUC__
 __extension__
 #endif
-QmuParserCallbackData::QmuParserCallbackData ( fun_type8 a_pFun, bool a_bAllowOpti )
-    : m_pFun ( reinterpret_cast<void*> ( a_pFun ) ), m_iArgc ( 8 ), m_iPri ( -1 ), m_eOprtAsct ( oaNONE ),
-      m_iCode ( cmFUNC ), m_iType ( tpDBL ), m_bAllowOpti ( a_bAllowOpti )
-{}
+    QmuParserCallbackData::QmuParserCallbackData(fun_type8 a_pFun, bool a_bAllowOpti)
+  : m_pFun(reinterpret_cast<void *>(a_pFun)),
+    m_iArgc(8),
+    m_iPri(-1),
+    m_eOprtAsct(oaNONE),
+    m_iCode(cmFUNC),
+    m_iType(tpDBL),
+    m_bAllowOpti(a_bAllowOpti)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
 #ifdef __GNUC__
 __extension__
 #endif
-QmuParserCallbackData::QmuParserCallbackData ( fun_type9 a_pFun, bool a_bAllowOpti )
-    : m_pFun ( reinterpret_cast<void*> ( a_pFun ) ), m_iArgc ( 9 ), m_iPri ( -1 ), m_eOprtAsct ( oaNONE ),
-      m_iCode ( cmFUNC ), m_iType ( tpDBL ), m_bAllowOpti ( a_bAllowOpti )
-{}
+    QmuParserCallbackData::QmuParserCallbackData(fun_type9 a_pFun, bool a_bAllowOpti)
+  : m_pFun(reinterpret_cast<void *>(a_pFun)),
+    m_iArgc(9),
+    m_iPri(-1),
+    m_eOprtAsct(oaNONE),
+    m_iCode(cmFUNC),
+    m_iType(tpDBL),
+    m_bAllowOpti(a_bAllowOpti)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
 #ifdef __GNUC__
 __extension__
 #endif
-QmuParserCallbackData::QmuParserCallbackData ( fun_type10 a_pFun, bool a_bAllowOpti )
-    : m_pFun ( reinterpret_cast<void*> ( a_pFun ) ), m_iArgc ( 10 ), m_iPri ( -1 ), m_eOprtAsct ( oaNONE ),
-      m_iCode ( cmFUNC ), m_iType ( tpDBL ), m_bAllowOpti ( a_bAllowOpti )
-{}
+    QmuParserCallbackData::QmuParserCallbackData(fun_type10 a_pFun, bool a_bAllowOpti)
+  : m_pFun(reinterpret_cast<void *>(a_pFun)),
+    m_iArgc(10),
+    m_iPri(-1),
+    m_eOprtAsct(oaNONE),
+    m_iCode(cmFUNC),
+    m_iType(tpDBL),
+    m_bAllowOpti(a_bAllowOpti)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
 #ifdef __GNUC__
 __extension__
 #endif
-QmuParserCallbackData::QmuParserCallbackData ( bulkfun_type0 a_pFun, bool a_bAllowOpti )
-    : m_pFun ( reinterpret_cast<void*> ( a_pFun ) ), m_iArgc ( 0 ), m_iPri ( -1 ), m_eOprtAsct ( oaNONE ),
-      m_iCode ( cmFUNC_BULK ), m_iType ( tpDBL ), m_bAllowOpti ( a_bAllowOpti )
-{}
+    QmuParserCallbackData::QmuParserCallbackData(bulkfun_type0 a_pFun, bool a_bAllowOpti)
+  : m_pFun(reinterpret_cast<void *>(a_pFun)),
+    m_iArgc(0),
+    m_iPri(-1),
+    m_eOprtAsct(oaNONE),
+    m_iCode(cmFUNC_BULK),
+    m_iType(tpDBL),
+    m_bAllowOpti(a_bAllowOpti)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
 #ifdef __GNUC__
 __extension__
 #endif
-QmuParserCallbackData::QmuParserCallbackData ( bulkfun_type1 a_pFun, bool a_bAllowOpti )
-    : m_pFun ( reinterpret_cast<void*> ( a_pFun ) ), m_iArgc ( 1 ), m_iPri ( -1 ), m_eOprtAsct ( oaNONE ),
-      m_iCode ( cmFUNC_BULK ), m_iType ( tpDBL ), m_bAllowOpti ( a_bAllowOpti )
-{}
+    QmuParserCallbackData::QmuParserCallbackData(bulkfun_type1 a_pFun, bool a_bAllowOpti)
+  : m_pFun(reinterpret_cast<void *>(a_pFun)),
+    m_iArgc(1),
+    m_iPri(-1),
+    m_eOprtAsct(oaNONE),
+    m_iCode(cmFUNC_BULK),
+    m_iType(tpDBL),
+    m_bAllowOpti(a_bAllowOpti)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
 #ifdef __GNUC__
 __extension__
 #endif
-QmuParserCallbackData::QmuParserCallbackData ( bulkfun_type2 a_pFun, bool a_bAllowOpti )
-    : m_pFun ( reinterpret_cast<void*> ( a_pFun ) ), m_iArgc ( 2 ), m_iPri ( -1 ), m_eOprtAsct ( oaNONE ),
-      m_iCode ( cmFUNC_BULK ), m_iType ( tpDBL ), m_bAllowOpti ( a_bAllowOpti )
-{}
+    QmuParserCallbackData::QmuParserCallbackData(bulkfun_type2 a_pFun, bool a_bAllowOpti)
+  : m_pFun(reinterpret_cast<void *>(a_pFun)),
+    m_iArgc(2),
+    m_iPri(-1),
+    m_eOprtAsct(oaNONE),
+    m_iCode(cmFUNC_BULK),
+    m_iType(tpDBL),
+    m_bAllowOpti(a_bAllowOpti)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
 #ifdef __GNUC__
 __extension__
 #endif
-QmuParserCallbackData::QmuParserCallbackData ( bulkfun_type3 a_pFun, bool a_bAllowOpti )
-    : m_pFun ( reinterpret_cast<void*> ( a_pFun ) ), m_iArgc ( 3 ), m_iPri ( -1 ), m_eOprtAsct ( oaNONE ),
-      m_iCode ( cmFUNC_BULK ), m_iType ( tpDBL ), m_bAllowOpti ( a_bAllowOpti )
-{}
+    QmuParserCallbackData::QmuParserCallbackData(bulkfun_type3 a_pFun, bool a_bAllowOpti)
+  : m_pFun(reinterpret_cast<void *>(a_pFun)),
+    m_iArgc(3),
+    m_iPri(-1),
+    m_eOprtAsct(oaNONE),
+    m_iCode(cmFUNC_BULK),
+    m_iType(tpDBL),
+    m_bAllowOpti(a_bAllowOpti)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
 #ifdef __GNUC__
 __extension__
 #endif
-QmuParserCallbackData::QmuParserCallbackData ( bulkfun_type4 a_pFun, bool a_bAllowOpti )
-    : m_pFun ( reinterpret_cast<void*> ( a_pFun ) ), m_iArgc ( 4 ), m_iPri ( -1 ), m_eOprtAsct ( oaNONE ),
-      m_iCode ( cmFUNC_BULK ), m_iType ( tpDBL ), m_bAllowOpti ( a_bAllowOpti )
-{}
+    QmuParserCallbackData::QmuParserCallbackData(bulkfun_type4 a_pFun, bool a_bAllowOpti)
+  : m_pFun(reinterpret_cast<void *>(a_pFun)),
+    m_iArgc(4),
+    m_iPri(-1),
+    m_eOprtAsct(oaNONE),
+    m_iCode(cmFUNC_BULK),
+    m_iType(tpDBL),
+    m_bAllowOpti(a_bAllowOpti)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
 #ifdef __GNUC__
 __extension__
 #endif
-QmuParserCallbackData::QmuParserCallbackData ( bulkfun_type5 a_pFun, bool a_bAllowOpti )
-    : m_pFun ( reinterpret_cast<void*> ( a_pFun ) ), m_iArgc ( 5 ), m_iPri ( -1 ), m_eOprtAsct ( oaNONE ),
-      m_iCode ( cmFUNC_BULK ), m_iType ( tpDBL ), m_bAllowOpti ( a_bAllowOpti )
-{}
+    QmuParserCallbackData::QmuParserCallbackData(bulkfun_type5 a_pFun, bool a_bAllowOpti)
+  : m_pFun(reinterpret_cast<void *>(a_pFun)),
+    m_iArgc(5),
+    m_iPri(-1),
+    m_eOprtAsct(oaNONE),
+    m_iCode(cmFUNC_BULK),
+    m_iType(tpDBL),
+    m_bAllowOpti(a_bAllowOpti)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
 #ifdef __GNUC__
 __extension__
 #endif
-QmuParserCallbackData::QmuParserCallbackData ( bulkfun_type6 a_pFun, bool a_bAllowOpti )
-    : m_pFun ( reinterpret_cast<void*> ( a_pFun ) ), m_iArgc ( 6 ), m_iPri ( -1 ), m_eOprtAsct ( oaNONE ),
-      m_iCode ( cmFUNC_BULK ), m_iType ( tpDBL ), m_bAllowOpti ( a_bAllowOpti )
-{}
+    QmuParserCallbackData::QmuParserCallbackData(bulkfun_type6 a_pFun, bool a_bAllowOpti)
+  : m_pFun(reinterpret_cast<void *>(a_pFun)),
+    m_iArgc(6),
+    m_iPri(-1),
+    m_eOprtAsct(oaNONE),
+    m_iCode(cmFUNC_BULK),
+    m_iType(tpDBL),
+    m_bAllowOpti(a_bAllowOpti)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
 #ifdef __GNUC__
 __extension__
 #endif
-QmuParserCallbackData::QmuParserCallbackData ( bulkfun_type7 a_pFun, bool a_bAllowOpti )
-    : m_pFun ( reinterpret_cast<void*> ( a_pFun ) ), m_iArgc ( 7 ), m_iPri ( -1 ), m_eOprtAsct ( oaNONE ),
-      m_iCode ( cmFUNC_BULK ), m_iType ( tpDBL ), m_bAllowOpti ( a_bAllowOpti )
-{}
+    QmuParserCallbackData::QmuParserCallbackData(bulkfun_type7 a_pFun, bool a_bAllowOpti)
+  : m_pFun(reinterpret_cast<void *>(a_pFun)),
+    m_iArgc(7),
+    m_iPri(-1),
+    m_eOprtAsct(oaNONE),
+    m_iCode(cmFUNC_BULK),
+    m_iType(tpDBL),
+    m_bAllowOpti(a_bAllowOpti)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
 #ifdef __GNUC__
 __extension__
 #endif
-QmuParserCallbackData::QmuParserCallbackData ( bulkfun_type8 a_pFun, bool a_bAllowOpti )
-    : m_pFun ( reinterpret_cast<void*> ( a_pFun ) ), m_iArgc ( 8 ), m_iPri ( -1 ), m_eOprtAsct ( oaNONE ),
-      m_iCode ( cmFUNC_BULK ), m_iType ( tpDBL ), m_bAllowOpti ( a_bAllowOpti )
-{}
+    QmuParserCallbackData::QmuParserCallbackData(bulkfun_type8 a_pFun, bool a_bAllowOpti)
+  : m_pFun(reinterpret_cast<void *>(a_pFun)),
+    m_iArgc(8),
+    m_iPri(-1),
+    m_eOprtAsct(oaNONE),
+    m_iCode(cmFUNC_BULK),
+    m_iType(tpDBL),
+    m_bAllowOpti(a_bAllowOpti)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
 #ifdef __GNUC__
 __extension__
 #endif
-QmuParserCallbackData::QmuParserCallbackData ( bulkfun_type9 a_pFun, bool a_bAllowOpti )
-    : m_pFun ( reinterpret_cast<void*> ( a_pFun ) ), m_iArgc ( 9 ), m_iPri ( -1 ), m_eOprtAsct ( oaNONE ),
-      m_iCode ( cmFUNC_BULK ), m_iType ( tpDBL ), m_bAllowOpti ( a_bAllowOpti )
-{}
+    QmuParserCallbackData::QmuParserCallbackData(bulkfun_type9 a_pFun, bool a_bAllowOpti)
+  : m_pFun(reinterpret_cast<void *>(a_pFun)),
+    m_iArgc(9),
+    m_iPri(-1),
+    m_eOprtAsct(oaNONE),
+    m_iCode(cmFUNC_BULK),
+    m_iType(tpDBL),
+    m_bAllowOpti(a_bAllowOpti)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
 #ifdef __GNUC__
 __extension__
 #endif
-QmuParserCallbackData::QmuParserCallbackData ( bulkfun_type10 a_pFun, bool a_bAllowOpti )
-    : m_pFun ( reinterpret_cast<void*> ( a_pFun ) ), m_iArgc ( 10 ), m_iPri ( -1 ), m_eOprtAsct ( oaNONE ),
-      m_iCode ( cmFUNC_BULK ), m_iType ( tpDBL ), m_bAllowOpti ( a_bAllowOpti )
-{}
+    QmuParserCallbackData::QmuParserCallbackData(bulkfun_type10 a_pFun, bool a_bAllowOpti)
+  : m_pFun(reinterpret_cast<void *>(a_pFun)),
+    m_iArgc(10),
+    m_iPri(-1),
+    m_eOprtAsct(oaNONE),
+    m_iCode(cmFUNC_BULK),
+    m_iType(tpDBL),
+    m_bAllowOpti(a_bAllowOpti)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
 #ifdef __GNUC__
 __extension__
 #endif
-QmuParserCallbackData::QmuParserCallbackData ( multfun_type a_pFun, bool a_bAllowOpti )
-    : m_pFun ( reinterpret_cast<void*> ( a_pFun ) ), m_iArgc ( -1 ), m_iPri ( -1 ), m_eOprtAsct ( oaNONE ),
-      m_iCode ( cmFUNC ), m_iType ( tpDBL ), m_bAllowOpti ( a_bAllowOpti )
-{}
+    QmuParserCallbackData::QmuParserCallbackData(multfun_type a_pFun, bool a_bAllowOpti)
+  : m_pFun(reinterpret_cast<void *>(a_pFun)),
+    m_iArgc(-1),
+    m_iPri(-1),
+    m_eOprtAsct(oaNONE),
+    m_iCode(cmFUNC),
+    m_iType(tpDBL),
+    m_bAllowOpti(a_bAllowOpti)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
 #ifdef __GNUC__
 __extension__
 #endif
-QmuParserCallbackData::QmuParserCallbackData ( strfun_type1 a_pFun, bool a_bAllowOpti )
-    : m_pFun ( reinterpret_cast<void*> ( a_pFun ) ), m_iArgc ( 0 ), m_iPri ( -1 ), m_eOprtAsct ( oaNONE ),
-      m_iCode ( cmFUNC_STR ), m_iType ( tpSTR ), m_bAllowOpti ( a_bAllowOpti )
-{}
+    QmuParserCallbackData::QmuParserCallbackData(strfun_type1 a_pFun, bool a_bAllowOpti)
+  : m_pFun(reinterpret_cast<void *>(a_pFun)),
+    m_iArgc(0),
+    m_iPri(-1),
+    m_eOprtAsct(oaNONE),
+    m_iCode(cmFUNC_STR),
+    m_iType(tpSTR),
+    m_bAllowOpti(a_bAllowOpti)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
 #ifdef __GNUC__
 __extension__
 #endif
-QmuParserCallbackData::QmuParserCallbackData ( strfun_type2 a_pFun, bool a_bAllowOpti )
-    : m_pFun ( reinterpret_cast<void*> ( a_pFun ) ), m_iArgc ( 1 ), m_iPri ( -1 ), m_eOprtAsct ( oaNONE ),
-      m_iCode ( cmFUNC_STR ), m_iType ( tpSTR ), m_bAllowOpti ( a_bAllowOpti )
-{}
+    QmuParserCallbackData::QmuParserCallbackData(strfun_type2 a_pFun, bool a_bAllowOpti)
+  : m_pFun(reinterpret_cast<void *>(a_pFun)),
+    m_iArgc(1),
+    m_iPri(-1),
+    m_eOprtAsct(oaNONE),
+    m_iCode(cmFUNC_STR),
+    m_iType(tpSTR),
+    m_bAllowOpti(a_bAllowOpti)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
 #ifdef __GNUC__
 __extension__
 #endif
-QmuParserCallbackData::QmuParserCallbackData ( strfun_type3 a_pFun, bool a_bAllowOpti )
-    : m_pFun ( reinterpret_cast<void*> ( a_pFun ) ), m_iArgc ( 2 ), m_iPri ( -1 ), m_eOprtAsct ( oaNONE ),
-      m_iCode ( cmFUNC_STR ), m_iType ( tpSTR ), m_bAllowOpti ( a_bAllowOpti )
-{}
+    QmuParserCallbackData::QmuParserCallbackData(strfun_type3 a_pFun, bool a_bAllowOpti)
+  : m_pFun(reinterpret_cast<void *>(a_pFun)),
+    m_iArgc(2),
+    m_iPri(-1),
+    m_eOprtAsct(oaNONE),
+    m_iCode(cmFUNC_STR),
+    m_iType(tpSTR),
+    m_bAllowOpti(a_bAllowOpti)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
 QmuParserCallbackData::QmuParserCallbackData(const QmuParserCallbackData &a_Fun)
-    : QSharedData(a_Fun), m_pFun(a_Fun.m_pFun), m_iArgc(a_Fun.m_iArgc), m_iPri(a_Fun.m_iPri),
-      m_eOprtAsct(a_Fun.m_eOprtAsct), m_iCode(a_Fun.m_iCode), m_iType(a_Fun.m_iType), m_bAllowOpti(a_Fun.m_bAllowOpti)
-{}
-
-//---------------------------------------------------------------------------------------------------------------------
-QmuParserCallbackData::~QmuParserCallbackData()
-{}
+  : QSharedData(a_Fun),
+    m_pFun(a_Fun.m_pFun),
+    m_iArgc(a_Fun.m_iArgc),
+    m_iPri(a_Fun.m_iPri),
+    m_eOprtAsct(a_Fun.m_eOprtAsct),
+    m_iCode(a_Fun.m_iCode),
+    m_iType(a_Fun.m_iType),
+    m_bAllowOpti(a_Fun.m_bAllowOpti)
+{
+}
 
 } // namespace qmu
