@@ -22,7 +22,6 @@
 #include "qmuparsertokenreader.h"
 
 #include <cassert>
-#include <QCharRef>
 #include <QList>
 #include <QMessageLogger>
 #include <QStringList>
@@ -284,7 +283,7 @@ auto QmuParserTokenReader::ReadNextToken(const QLocale &locale, bool cNumbers, c
     // !!! From this point on there is no exit without an exception possible...
     //
     QString strTok;
-    int iEnd = ExtractToken ( m_pParser->ValidNameChars(), strTok, m_iPos );
+    qmusizetype const iEnd = ExtractToken(m_pParser->ValidNameChars(), strTok, m_iPos);
     if ( iEnd != m_iPos )
     {
         Error ( ecUNASSIGNABLE_TOKEN, m_iPos, strTok );
@@ -319,9 +318,10 @@ void QmuParserTokenReader::SetParent ( QmuParserBase *a_pParent )
  */
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_MSVC(4309)
-auto QmuParserTokenReader::ExtractToken ( const QString &a_szCharSet, QString &a_sTok, int a_iPos ) const -> int
+auto QmuParserTokenReader::ExtractToken ( const QString &a_szCharSet, QString &a_sTok,
+                                          qmusizetype a_iPos ) const -> qmusizetype
 {
-    int iEnd = FindFirstNotOf(m_strFormula, a_szCharSet, a_iPos);
+    qmusizetype iEnd = FindFirstNotOf(m_strFormula, a_szCharSet, a_iPos);
 
     if (iEnd == -1)
     {
@@ -345,9 +345,9 @@ auto QmuParserTokenReader::ExtractToken ( const QString &a_szCharSet, QString &a
  * alphabetic characters are allowed in operator tokens. To avoid this this function checks specifically
  * for operator tokens.
  */
-auto QmuParserTokenReader::ExtractOperatorToken ( QString &a_sTok, int a_iPos ) const -> int
+auto QmuParserTokenReader::ExtractOperatorToken ( QString &a_sTok, qmusizetype a_iPos ) const -> qmusizetype
 {
-    int iEnd = FindFirstNotOf(m_strFormula, m_pParser->ValidOprtChars(), a_iPos);
+    qmusizetype iEnd = FindFirstNotOf(m_strFormula, m_pParser->ValidOprtChars(), a_iPos);
 
     if ( iEnd == -1 )
     {
@@ -381,7 +381,7 @@ auto QmuParserTokenReader::IsBuiltIn ( token_type &a_Tok ) -> bool
     // check string for operator/function
     for ( int i = 0; i < pOprtDef.size(); ++i )
     {
-        int len = pOprtDef.at ( i ).length();
+        qmusizetype const len = pOprtDef.at(i).length();
         if ( pOprtDef.at ( i ) == m_strFormula.mid ( m_iPos, len ) )
         {
             if (i >= cmLE && i <= cmASSIGN)
@@ -485,9 +485,7 @@ auto QmuParserTokenReader::IsArgSep ( token_type &a_Tok ) -> bool
     if ( m_strFormula.at ( m_iPos ) == m_cArgSep )
     {
         // copy the separator into null terminated string
-        QString szSep;
-        szSep[0] = m_cArgSep;
-        szSep[1] = 0;
+        QString const szSep(m_cArgSep);
 
         if ( m_iSynFlags & noARG_SEP )
         {
@@ -550,7 +548,7 @@ auto QmuParserTokenReader::IsEOF ( token_type &a_Tok ) -> bool
 auto QmuParserTokenReader::IsInfixOpTok ( token_type &a_Tok ) -> bool
 {
     QString sTok;
-    int iEnd = ExtractToken ( m_pParser->ValidInfixOprtChars(), sTok, m_iPos );
+    qmusizetype const iEnd = ExtractToken(m_pParser->ValidInfixOprtChars(), sTok, m_iPos);
     if ( iEnd == m_iPos )
     {
         return false;
@@ -589,7 +587,7 @@ auto QmuParserTokenReader::IsInfixOpTok ( token_type &a_Tok ) -> bool
 auto QmuParserTokenReader::IsFunTok ( token_type &a_Tok ) -> bool
 {
     QString strTok;
-    int iEnd = ExtractToken ( m_pParser->ValidNameChars(), strTok, m_iPos );
+    qmusizetype const iEnd = ExtractToken(m_pParser->ValidNameChars(), strTok, m_iPos);
     if ( iEnd == m_iPos )
     {
         return false;
@@ -629,7 +627,7 @@ auto QmuParserTokenReader::IsOprt ( token_type &a_Tok ) -> bool
 {
     QString strTok;
 
-    int iEnd = ExtractOperatorToken ( strTok, m_iPos );
+    qmusizetype const iEnd = ExtractOperatorToken(strTok, m_iPos);
     if ( iEnd == m_iPos )
     {
         return false;
@@ -672,13 +670,10 @@ auto QmuParserTokenReader::IsOprt ( token_type &a_Tok ) -> bool
                 {
                     return true;
                 }
-                else
-                {
-                    // nope, no infix operator
-                    return false;
-                    //Error(ecUNEXPECTED_OPERATOR, m_iPos, a_Tok.GetAsString());
-                }
 
+                // nope, no infix operator
+                return false;
+                // Error(ecUNEXPECTED_OPERATOR, m_iPos, a_Tok.GetAsString());
             }
 
             m_iPos += sID.length();
@@ -719,7 +714,7 @@ auto QmuParserTokenReader::IsPostOpTok ( token_type &a_Tok ) -> bool
 
     // Test if there could be a postfix operator
     QString sTok;
-    int iEnd = ExtractToken ( m_pParser->ValidOprtChars(), sTok, m_iPos );
+    qmusizetype const iEnd = ExtractToken(m_pParser->ValidOprtChars(), sTok, m_iPos);
     if ( iEnd == m_iPos )
     {
         return false;
@@ -759,7 +754,7 @@ auto QmuParserTokenReader::IsValTok ( token_type &a_Tok, const QLocale &locale,
 
     QString strTok;
     qreal fVal ( 0 );
-    int iEnd ( 0 );
+    qmusizetype iEnd ( 0 );
 
     // 2.) Check for user defined constant
     // Read everything that could be a constant name
@@ -787,7 +782,7 @@ auto QmuParserTokenReader::IsValTok ( token_type &a_Tok, const QLocale &locale,
     auto item = m_vIdentFun.begin();
     for ( item = m_vIdentFun.begin(); item != m_vIdentFun.end(); ++item )
     {
-        int iStart = m_iPos;
+        qmusizetype const iStart = m_iPos;
         if ( ( *item ) ( m_strFormula.mid ( m_iPos ), &m_iPos, &fVal, locale, cNumbers, decimal, thousand ) == 1 )
         {
             // 2013-11-27 Issue 2:  https://code.google.com/p/muparser/issues/detail?id=2
@@ -820,7 +815,7 @@ auto QmuParserTokenReader::IsVarTok ( token_type &a_Tok ) -> bool
     }
 
     QString strTok;
-    int iEnd = ExtractToken ( m_pParser->ValidNameChars(), strTok, m_iPos );
+    qmusizetype iEnd = ExtractToken ( m_pParser->ValidNameChars(), strTok, m_iPos );
     if ( iEnd == m_iPos )
     {
         return false;
@@ -859,7 +854,7 @@ auto QmuParserTokenReader::IsStrVarTok ( token_type &a_Tok ) -> bool
     }
 
     QString strTok;
-    int iEnd = ExtractToken ( m_pParser->ValidNameChars(), strTok, m_iPos );
+    qmusizetype const iEnd = ExtractToken(m_pParser->ValidNameChars(), strTok, m_iPos);
     if ( iEnd == m_iPos )
     {
         return false;
@@ -900,7 +895,7 @@ auto QmuParserTokenReader::IsStrVarTok ( token_type &a_Tok ) -> bool
 auto QmuParserTokenReader::IsUndefVarTok ( token_type &a_Tok ) -> bool
 {
     QString strTok;
-    int iEnd ( ExtractToken ( m_pParser->ValidNameChars(), strTok, m_iPos ) );
+    qmusizetype const iEnd(ExtractToken(m_pParser->ValidNameChars(), strTok, m_iPos));
     if ( iEnd == m_iPos )
     {
         return false;
@@ -967,7 +962,7 @@ auto QmuParserTokenReader::IsString ( token_type &a_Tok ) -> bool
     }
 
     QString strBuf (m_strFormula.mid(m_iPos + 1));
-    int iEnd ( 0 ), iSkip ( 0 );
+    qmusizetype iEnd ( 0 ), iSkip ( 0 );
 
     // parser over escaped '\"' end replace them with '"'
     for ( iEnd = strBuf.indexOf ( "\"" ); iEnd != 0 && iEnd != -1; iEnd = strBuf.indexOf ( "\"", iEnd ) )
@@ -985,7 +980,7 @@ auto QmuParserTokenReader::IsString ( token_type &a_Tok ) -> bool
         Error ( ecUNTERMINATED_STRING, m_iPos, "\"" );
     }
 
-    QString strTok = strBuf.mid ( 0, iEnd );
+    QString const strTok = strBuf.mid(0, iEnd);
 
     if ( m_iSynFlags & noSTR )
     {
@@ -1012,7 +1007,7 @@ auto QmuParserTokenReader::IsString ( token_type &a_Tok ) -> bool
  * @param a_sTok [in] The token string representation associated with the error.
  * @throw ParserException always throws thats the only purpose of this function.
  */
-void Q_NORETURN QmuParserTokenReader::Error ( EErrorCodes a_iErrc, int a_iPos, const QString &a_sTok ) const
+Q_NORETURN void QmuParserTokenReader::Error (EErrorCodes a_iErrc, qmusizetype a_iPos, const QString &a_sTok ) const
 {
     m_pParser->Error ( a_iErrc, a_iPos, a_sTok );
 }
