@@ -16,12 +16,8 @@
 #include <cstring>
 
 #include "drw_entities.h"
-#include "drw_objects.h"
 #include "drw_header.h"
-
-#if QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
-#include "../vmisc/diagnostic.h"
-#endif // QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
+#include "drw_objects.h"
 
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_GCC("-Wsuggest-final-types")
@@ -34,27 +30,27 @@ QT_WARNING_DISABLE_GCC("-Wsuggest-final-methods")
  *
  * @author Rallaz
  */
-class DRW_Interface {
+class DRW_Interface
+{
 public:
-    DRW_Interface() {
-    }
+    DRW_Interface() {}
     virtual ~DRW_Interface() = default;
 
     /** Called when header is parsed.  */
-    virtual void addHeader(const DRW_Header *) { }
+    virtual void addHeader(const DRW_Header *) {}
 
     /** Called for every line Type.  */
-    virtual void addLType(const DRW_LType &) { }
+    virtual void addLType(const DRW_LType &) {}
     /** Called for every layer. */
-    virtual void addLayer(const DRW_Layer &) { }
+    virtual void addLayer(const DRW_Layer &) {}
     /** Called for every dim style. */
-    virtual void addDimStyle(const DRW_Dimstyle &) { }
+    virtual void addDimStyle(const DRW_Dimstyle &) {}
     /** Called for every VPORT table. */
-    virtual void addVport(const DRW_Vport &) { }
+    virtual void addVport(const DRW_Vport &) {}
     /** Called for every text style. */
-    virtual void addTextStyle(const DRW_Textstyle &) { }
+    virtual void addTextStyle(const DRW_Textstyle &) {}
     /** Called for every AppId entry. */
-    virtual void addAppId(const DRW_AppId &) { }
+    virtual void addAppId(const DRW_AppId &) {}
 
     /**
      * Called for every block. Note: all entities added after this
@@ -62,143 +58,142 @@ public:
      *
      * @see endBlock()
      */
-    virtual void addBlock(const DRW_Block &) { }
+    virtual void addBlock(const DRW_Block &) {}
 
     /** Called to end the current block */
-    virtual void endBlock() { }
+    virtual void endBlock() {}
 
     /** Called for every point */
-    virtual void addPoint(const DRW_Point &) { }
+    virtual void addPoint(const DRW_Point &) {}
 
     /** Called for every line */
-    virtual void addLine(const DRW_Line &) { }
+    virtual void addLine(const DRW_Line &) {}
 
     /** Called for every ray */
-    virtual void addRay(const DRW_Ray &) { }
+    virtual void addRay(const DRW_Ray &) {}
 
     /** Called for every xline */
-    virtual void addXline(const DRW_Xline &) { }
+    virtual void addXline(const DRW_Xline &) {}
 
     /** Called for every arc */
-    virtual void addArc(const DRW_Arc &) { }
+    virtual void addArc(const DRW_Arc &) {}
 
     /** Called for every circle */
-    virtual void addCircle(const DRW_Circle &) { }
+    virtual void addCircle(const DRW_Circle &) {}
 
     /** Called for every ellipse */
-    virtual void addEllipse(const DRW_Ellipse &) { }
+    virtual void addEllipse(const DRW_Ellipse &) {}
 
     /** Called for every lwpolyline */
-    virtual void addLWPolyline(const DRW_LWPolyline &) { }
+    virtual void addLWPolyline(const DRW_LWPolyline &) {}
 
     /** Called for every polyline start */
-    virtual void addPolyline(const DRW_Polyline &) { }
+    virtual void addPolyline(const DRW_Polyline &) {}
 
     /** Called for every spline */
-    virtual void addSpline(const DRW_Spline *) { }
+    virtual void addSpline(const DRW_Spline *) {}
 
-	/** Called for every spline knot value */
-    virtual void addKnot(const DRW_Entity &) { }
+    /** Called for every spline knot value */
+    virtual void addKnot(const DRW_Entity &) {}
 
     /** Called for every insert. */
-    virtual void addInsert(const DRW_Insert &) { }
+    virtual void addInsert(const DRW_Insert &) {}
 
     /** Called for every trace start */
-    virtual void addTrace(const DRW_Trace &) { }
+    virtual void addTrace(const DRW_Trace &) {}
 
     /** Called for every 3dface start */
-    virtual void add3dFace(const DRW_3Dface &) { }
+    virtual void add3dFace(const DRW_3Dface &) {}
 
     /** Called for every solid start */
-    virtual void addSolid(const DRW_Solid &) { }
-
+    virtual void addSolid(const DRW_Solid &) {}
 
     /** Called for every Multi Text entity. */
-    virtual void addMText(const DRW_MText &) { }
+    virtual void addMText(const DRW_MText &) {}
 
     /** Called for every Text entity. */
-    virtual void addText(const DRW_Text &) { }
+    virtual void addText(const DRW_Text &) {}
 
     /**
      * Called for every aligned dimension entity.
      */
-    virtual void addDimAlign(const DRW_DimAligned *) { }
+    virtual void addDimAlign(const DRW_DimAligned *) {}
     /**
      * Called for every linear or rotated dimension entity.
      */
-    virtual void addDimLinear(const DRW_DimLinear *) { }
+    virtual void addDimLinear(const DRW_DimLinear *) {}
 
-	/**
+    /**
      * Called for every radial dimension entity.
      */
-    virtual void addDimRadial(const DRW_DimRadial *) { }
+    virtual void addDimRadial(const DRW_DimRadial *) {}
 
-	/**
+    /**
      * Called for every diametric dimension entity.
      */
-    virtual void addDimDiametric(const DRW_DimDiametric *) { }
+    virtual void addDimDiametric(const DRW_DimDiametric *) {}
 
-	/**
+    /**
      * Called for every angular dimension (2 lines version) entity.
      */
-    virtual void addDimAngular(const DRW_DimAngular *) { }
+    virtual void addDimAngular(const DRW_DimAngular *) {}
 
-	/**
+    /**
      * Called for every angular dimension (3 points version) entity.
      */
-    virtual void addDimAngular3P(const DRW_DimAngular3p *) { }
+    virtual void addDimAngular3P(const DRW_DimAngular3p *) {}
 
     /**
      * Called for every ordinate dimension entity.
      */
-    virtual void addDimOrdinate(const DRW_DimOrdinate *) { }
+    virtual void addDimOrdinate(const DRW_DimOrdinate *) {}
 
     /**
-	 * Called for every leader start.
-	 */
-    virtual void addLeader(const DRW_Leader *) { }
+     * Called for every leader start.
+     */
+    virtual void addLeader(const DRW_Leader *) {}
 
-	/**
-	 * Called for every hatch entity.
-	 */
-    virtual void addHatch(const DRW_Hatch *) { }
+    /**
+     * Called for every hatch entity.
+     */
+    virtual void addHatch(const DRW_Hatch *) {}
 
     /**
      * Called for every viewport entity.
      */
-    virtual void addViewport(const DRW_Viewport &) { }
+    virtual void addViewport(const DRW_Viewport &) {}
 
     /**
-	 * Called for every image entity.
-	 */
-    virtual void addImage(const DRW_Image *) { }
+     * Called for every image entity.
+     */
+    virtual void addImage(const DRW_Image *) {}
 
-	/**
-	 * Called for every image definition.
-	 */
-    virtual void linkImage(const DRW_ImageDef *) { }
+    /**
+     * Called for every image definition.
+     */
+    virtual void linkImage(const DRW_ImageDef *) {}
 
     /**
      * Called for every comment in the DXF file (code 999).
      */
-    virtual void addComment(const char *) { }
+    virtual void addComment(const char *) {}
 
     /**
      * Called for PLOTSETTINGS object definition.
      */
     virtual void addPlotSettings(const DRW_PlotSettings *) {}
 
-    virtual void writeHeader(DRW_Header &) { }
-    virtual void writeBlocks() { }
-    virtual void writeBlockRecords() { }
-    virtual void writeEntities() { }
-    virtual void writeLTypes() { }
-    virtual void writeLayers() { }
-    virtual void writeTextstyles() { }
-    virtual void writeVports() { }
-    virtual void writeDimstyles() { }
+    virtual void writeHeader(DRW_Header &) {}
+    virtual void writeBlocks() {}
+    virtual void writeBlockRecords() {}
+    virtual void writeEntities() {}
+    virtual void writeLTypes() {}
+    virtual void writeLayers() {}
+    virtual void writeTextstyles() {}
+    virtual void writeVports() {}
+    virtual void writeDimstyles() {}
     virtual void writeObjects() {}
-    virtual void writeAppId() { }
+    virtual void writeAppId() {}
 };
 
 QT_WARNING_POP
