@@ -29,7 +29,6 @@
 #ifndef VMEASUREMENTS_H
 #define VMEASUREMENTS_H
 
-#include <qcompilerdetection.h>
 #include <QCoreApplication>
 #include <QDomElement>
 #include <QString>
@@ -41,26 +40,35 @@
 #include "vdimensions.h"
 
 class VContainer;
+class VPatternImage;
+class VMeasurement;
 
-enum class GenderType : qint8 { Male, Female, Unknown };
+enum class GenderType : qint8
+{
+    Male,
+    Female,
+    Unknown
+};
 
 using VDimensions = QMap<MeasurementDimension, MeasurementDimension_p>;
 
 class VMeasurements : public VDomDocument
 {
-    Q_DECLARE_TR_FUNCTIONS(VMeasurements) // NOLINT
+    Q_OBJECT // NOLINT
+
 public:
-    explicit VMeasurements(VContainer *data);
-    VMeasurements(Unit unit, VContainer *data);
-    VMeasurements(Unit unit, const QVector<MeasurementDimension_p > &dimensions,
-                  VContainer *data);
-    virtual ~VMeasurements() = default;
+    explicit VMeasurements(VContainer *data, QObject *parent = nullptr);
+    VMeasurements(Unit unit, VContainer *data, QObject *parent = nullptr);
+    VMeasurements(Unit unit, const QVector<MeasurementDimension_p> &dimensions, VContainer *data,
+                  QObject *parent = nullptr);
+    ~VMeasurements() override = default;
 
-    virtual void setXMLContent(const QString &fileName) override;
-    virtual bool SaveDocument(const QString &fileName, QString &error) override;
+    void setXMLContent(const QString &fileName) override;
+    auto SaveDocument(const QString &fileName, QString &error) -> bool override;
 
-    void AddEmpty(const QString &name, const QString &formula = QString());
-    void AddEmptyAfter(const QString &after, const QString &name, const QString &formula = QString());
+    void AddEmpty(const QString &name, const QString &formula = QString(), bool specialUnits = false);
+    void AddEmptyAfter(const QString &after, const QString &name, const QString &formula = QString(),
+                       bool specialUnits = false);
     void AddSeparator(const QString &name);
     void AddSeparatorAfter(const QString &after, const QString &name);
     void Remove(const QString &name);
@@ -73,41 +81,41 @@ public:
 
     void StoreNames(bool store);
 
-    void ReadMeasurements(qreal baseA, qreal baseB=0, qreal baseC=0) const;
+    void ReadMeasurements(qreal baseA, qreal baseB = 0, qreal baseC = 0) const;
     void ClearForExport();
 
-    MeasurementsType Type() const;
-    qreal DimensionABase() const;
-    qreal DimensionBBase() const;
-    qreal DimensionCBase() const;
+    auto Type() const -> MeasurementsType;
+    auto DimensionABase() const -> qreal;
+    auto DimensionBBase() const -> qreal;
+    auto DimensionCBase() const -> qreal;
 
-    qreal DimensionAStep() const;
-    qreal DimensionBStep() const;
-    qreal DimensionCStep() const;
+    auto DimensionAStep() const -> qreal;
+    auto DimensionBStep() const -> qreal;
+    auto DimensionCStep() const -> qreal;
 
-    QString Notes() const;
-    void    SetNotes(const QString &text);
+    auto Notes() const -> QString;
+    void SetNotes(const QString &text);
 
-    QString Customer() const;
-    void    SetCustomer(const QString &text);
+    auto Customer() const -> QString;
+    void SetCustomer(const QString &text);
 
-    QDate   BirthDate() const;
-    void    SetBirthDate(const QDate &date);
+    auto BirthDate() const -> QDate;
+    void SetBirthDate(const QDate &date);
 
-    GenderType Gender() const;
-    void       SetGender(const GenderType &gender);
+    auto Gender() const -> GenderType;
+    void SetGender(const GenderType &gender);
 
-    QString PMSystem() const;
-    void    SetPMSystem(const QString &system);
+    auto KnownMeasurements() const -> QUuid;
+    void SetKnownMeasurements(const QUuid &system);
 
-    QString Email() const;
-    void    SetEmail(const QString &text);
+    auto Email() const -> QString;
+    void SetEmail(const QString &text);
 
-    bool    IsReadOnly() const;
-    void    SetReadOnly(bool ro);
+    auto IsReadOnly() const -> bool;
+    void SetReadOnly(bool ro);
 
-    bool    IsFullCircumference() const;
-    void    SetFullCircumference(bool fc);
+    auto IsFullCircumference() const -> bool;
+    void SetFullCircumference(bool fc);
 
     void SetMName(const QString &name, const QString &text);
     void SetMValue(const QString &name, const QString &text);
@@ -120,14 +128,15 @@ public:
     void SetMDescription(const QString &name, const QString &text);
     void SetMFullName(const QString &name, const QString &text);
     void SetMDimension(const QString &name, IMD type);
+    void SetMImage(const QString &name, const VPatternImage &image);
 
-    QString MeasurementForDimension(IMD type) const;
+    auto MeasurementForDimension(IMD type) const -> QString;
 
     auto Dimensions() const -> VDimensions;
 
-    auto GetRestrictions() const -> QMap<QString, VDimensionRestriction >;
-    void SetRestrictions(const QMap<QString, VDimensionRestriction > &restrictions);
-    auto Restriction(qreal base, qreal base2=0) const -> VDimensionRestriction;
+    auto GetRestrictions() const -> QMap<QString, VDimensionRestriction>;
+    void SetRestrictions(const QMap<QString, VDimensionRestriction> &restrictions);
+    auto Restriction(qreal base, qreal base2 = 0) const -> VDimensionRestriction;
 
     void SetDimensionLabels(const QMap<MeasurementDimension, DimesionLabels> &labels);
     void SetDimensionCustomNames(const QMap<MeasurementDimension, QString> &names);
@@ -152,6 +161,7 @@ public:
     static const QString TagCorrection;
     static const QString TagLabels;
     static const QString TagLabel;
+    static const QString TagImage;
 
     static const QString AttrBase;
     static const QString AttrValue;
@@ -173,6 +183,7 @@ public:
     static const QString AttrLabel;
     static const QString AttrDimension;
     static const QString AttrCustomName;
+    static const QString AttrContentType;
 
     static const QString GenderMale;
     static const QString GenderFemale;
@@ -184,29 +195,27 @@ public:
     static const QString DimensionW;
     static const QString DimensionZ;
 
-    static QString GenderToStr(const GenderType &sex);
-    static GenderType StrToGender(const QString &sex);
+    static auto GenderToStr(const GenderType &sex) -> QString;
+    static auto StrToGender(const QString &sex) -> GenderType;
 
-    static QString DimensionTypeToStr(const MeasurementDimension &type);
-    static MeasurementDimension StrToDimensionType(const QString &type);
+    static auto DimensionTypeToStr(const MeasurementDimension &type) -> QString;
+    static auto StrToDimensionType(const QString &type) -> MeasurementDimension;
 
-    static QString IMDToStr(const IMD &type);
-    static IMD StrToIMD(const QString &type);
+    static auto IMDToStr(const IMD &type) -> QString;
+    static auto StrToIMD(const QString &type) -> IMD;
 
-    static QString IMDName(IMD type);
+    static auto IMDName(IMD type) -> QString;
 
-    QStringList ListAll() const;
-    QStringList ListKnown() const;
+    auto ListAll() const -> QStringList;
+    auto ListKnown() const -> QStringList;
 
-    bool IsDefinedKnownNamesValid() const;
-
-    VContainer *GetData() const;
+    auto GetData() const -> VContainer *;
 
 private:
     Q_DISABLE_COPY_MOVE(VMeasurements) // NOLINT
 
     /** @brief data container with data. */
-    VContainer     *data;
+    VContainer *data;
     MeasurementsType type;
 
     // Cache data to quick access
@@ -216,30 +225,35 @@ private:
     /** @brief m_keepNames store names in container to check uniqueness. */
     bool m_keepNames{true};
 
-    void CreateEmptyMultisizeFile(Unit unit, const QVector<MeasurementDimension_p > &dimensions);
+    void CreateEmptyMultisizeFile(Unit unit, const QVector<MeasurementDimension_p> &dimensions);
     void CreateEmptyIndividualFile(Unit unit);
 
-    QDomElement CreateDimensions(const QVector<MeasurementDimension_p > &dimensions);
+    auto CreateDimensions(const QVector<MeasurementDimension_p> &dimensions) -> QDomElement;
 
-    qreal UniqueTagAttr(const QString &tag, const QString &attr, qreal defValue) const;
+    auto UniqueTagAttr(const QString &tag, const QString &attr, qreal defValue) const -> qreal;
 
-    QDomElement MakeEmpty(const QString &name, const QString &formula, MeasurementType varType);
-    QDomElement FindM(const QString &name) const;
-    MeasurementsType ReadType() const;
+    auto MakeEmpty(const QString &name, const QString &formula, MeasurementType varType) -> QDomElement;
+    auto FindM(const QString &name) const -> QDomElement;
+    auto ReadType() const -> MeasurementsType;
     auto ReadUnits() const -> Unit;
     auto ReadDimensions() const -> VDimensions;
 
-    qreal EvalFormula(VContainer *data, const QString &formula, bool *ok) const;
+    auto EvalFormula(VContainer *data, const QString &formula, bool *ok) const -> qreal;
 
-    QString ClearPMCode(const QString &code) const;
+    auto ReadCorrections(const QDomElement &mElement) const -> QMap<QString, qreal>;
+    void WriteCorrections(QDomElement &mElement, const QMap<QString, qreal> &corrections);
 
-    QMap<QString, qreal> ReadCorrections(const QDomElement &mElement) const;
-    void                 WriteCorrections(QDomElement &mElement, const QMap<QString, qreal> &corrections);
+    static auto ReadImage(const QDomElement &mElement) -> VPatternImage;
+    void WriteImage(QDomElement &mElement, const VPatternImage &image);
 
-    void           SaveDimesionLabels(QDomElement &dElement, const DimesionLabels &labels);
-    DimesionLabels ReadDimensionLabels(const QDomElement &dElement) const;
+    void SaveDimesionLabels(QDomElement &dElement, const DimesionLabels &labels);
+    auto ReadDimensionLabels(const QDomElement &dElement) const -> DimesionLabels;
 
     void ClearDimension(IMD type);
+
+    void ReadMeasurement(const QDomElement &dom, QSharedPointer<VContainer> &tempData,
+                         QSharedPointer<VMeasurement> &meash, QSharedPointer<VMeasurement> &tempMeash, int i,
+                         qreal baseA, qreal baseB, qreal baseC) const;
 };
 
 #endif // VMEASUREMENTS_H
