@@ -34,25 +34,60 @@
 #include <QPainterPath>
 #include <QPoint>
 #include <QtDebug>
+#include <QtMath>
 
-#include "vabstractcurve_p.h"
-#include "../vmisc/vabstractvalapplication.h"
-#include "../vmisc/compatibility.h"
 #include "../ifc/exception/vexceptionobjecterror.h"
+#include "../vmisc/compatibility.h"
+#include "../vmisc/vabstractvalapplication.h"
+#include "vabstractcurve_p.h"
 
-VAbstractCurve::VAbstractCurve(const GOType &type, const quint32 &idObject, const Draw &mode)
-    :VGObject(type, idObject, mode), d (new VAbstractCurveData())
-{}
+namespace
+{
+//---------------------------------------------------------------------------------------------------------------------
+auto NodeCurvature(const QPointF &p1, const QPointF &p2, const QPointF &p3, double length) -> double
+{
+    QLineF l1(p2, p1);
+    l1.setAngle(l1.angle() + 180);
+
+    QLineF const l2(p2, p3);
+    double const angle = qDegreesToRadians(l2.angleTo(l1));
+
+    return qSin(angle / 2.0) / length;
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-VAbstractCurve::VAbstractCurve(const VAbstractCurve &curve) // NOLINT(modernize-use-equals-default)
-    :VGObject(curve), d (curve.d)
-{}
+auto MinimalLength(const QVector<QPointF> &points) -> double
+{
+    vsizetype const numPoints = points.size();
+    double smallestDistance = std::numeric_limits<double>::max();
+
+    for (int i = 0; i < numPoints - 1; ++i)
+    {
+        double const distance = QLineF(points[i], points[i + 1]).length();
+        if (!qFuzzyIsNull(distance))
+        {
+            smallestDistance = std::min(smallestDistance, distance);
+        }
+    }
+
+    return smallestDistance;
+}
+} // namespace
+
+//---------------------------------------------------------------------------------------------------------------------
+VAbstractCurve::VAbstractCurve(const GOType &type, const quint32 &idObject, const Draw &mode)
+  : VGObject(type, idObject, mode),
+    d(new VAbstractCurveData())
+{
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+COPY_CONSTRUCTOR_IMPL_2(VAbstractCurve, VGObject)
 
 //---------------------------------------------------------------------------------------------------------------------
 auto VAbstractCurve::operator=(const VAbstractCurve &curve) -> VAbstractCurve &
 {
-    if ( &curve == this )
+    if (&curve == this)
     {
         return *this;
     }
@@ -61,24 +96,23 @@ auto VAbstractCurve::operator=(const VAbstractCurve &curve) -> VAbstractCurve &
     return *this;
 }
 
-#ifdef Q_COMPILER_RVALUE_REFS
 //---------------------------------------------------------------------------------------------------------------------
-VAbstractCurve::VAbstractCurve(VAbstractCurve &&curve) Q_DECL_NOTHROW
-    :VGObject(std::move(curve)), d (std::move(curve.d))
-{}
+VAbstractCurve::VAbstractCurve(VAbstractCurve &&curve) noexcept
+  : VGObject(std::move(curve)),
+    d(std::move(curve.d))
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-auto VAbstractCurve::operator=(VAbstractCurve &&curve) Q_DECL_NOTHROW -> VAbstractCurve &
+auto VAbstractCurve::operator=(VAbstractCurve &&curve) noexcept -> VAbstractCurve &
 {
     VGObject::operator=(curve);
     std::swap(d, curve.d);
     return *this;
 }
-#endif
 
 //---------------------------------------------------------------------------------------------------------------------
-VAbstractCurve::~VAbstractCurve() // NOLINT(modernize-use-equals-default)
-{}
+VAbstractCurve::~VAbstractCurve() = default;
 
 //---------------------------------------------------------------------------------------------------------------------
 auto VAbstractCurve::GetSegmentPoints(const QVector<QPointF> &points, const QPointF &begin, const QPointF &end,
@@ -95,8 +129,8 @@ auto VAbstractCurve::GetSegmentPoints(const QVector<QPointF> &points, const QPoi
 
     if (begin == end)
     {
-        start = ConstFirst(segment);
-        finish = ConstLast(segment);
+        start = segment.constFirst();
+        finish = segment.constLast();
     }
 
     bool ok = false;
@@ -137,16 +171,16 @@ auto VAbstractCurve::GetSegmentPoints(const QPointF &begin, const QPointF &end,
         QString errorMsg;
         if (piece.isEmpty())
         {
-            errorMsg = QObject::tr("Error calculating segment for curve '%1'. %2")
-                                         .arg(name(), error);
+            errorMsg = QObject::tr("Error calculating segment for curve '%1'. %2").arg(name(), error);
         }
         else
         {
             errorMsg = QObject::tr("Error in path '%1'. Calculating segment for curve '%2' has failed. %3")
                            .arg(piece, name(), error);
         }
-        VAbstractApplication::VApp()->IsPedantic() ? throw VExceptionObjectError(errorMsg) :
-                                              qWarning() << VAbstractValApplication::warningMessageSignature + errorMsg;
+        VAbstractApplication::VApp()->IsPedantic()
+            ? throw VExceptionObjectError(errorMsg)
+            : qWarning() << VAbstractValApplication::warningMessageSignature + errorMsg;
     }
 
     return segment;
@@ -155,69 +189,65 @@ auto VAbstractCurve::GetSegmentPoints(const QPointF &begin, const QPointF &end,
 //---------------------------------------------------------------------------------------------------------------------
 auto VAbstractCurve::FromBegin(const QVector<QPointF> &points, const QPointF &begin, bool *ok) -> QVector<QPointF>
 {
-    if (points.count() >= 2)
+    auto SetResult = [&ok](bool res)
     {
-        if (ConstFirst(points).toPoint() == begin.toPoint())
-        {
-            if (ok != nullptr)
-            {
-                *ok = true;
-            }
-            return points;
-        }
-
-        QVector<QPointF> segment;
-        bool theBegin = false;
-        for (qint32 i = 0; i < points.count()-1; ++i)
-        {
-            if (not theBegin)
-            {
-                if (IsPointOnLineSegment(begin, points.at(i), points.at(i+1)))
-                {
-                    theBegin = true;
-
-                    if (not VFuzzyComparePoints(begin, points.at(i+1)))
-                    {
-                        segment.append(begin);
-                    }
-
-                    if (i == points.count()-2)
-                    {
-                         segment.append(points.at(i+1));
-                    }
-                }
-            }
-            else
-            {
-                segment.append(points.at(i));
-                if (i == points.count()-2)
-                {
-                     segment.append(points.at(i+1));
-                }
-            }
-        }
-
-        if (segment.isEmpty())
-        {
-            if (ok != nullptr)
-            {
-                *ok = false;
-            }
-            return points;
-        }
-
         if (ok != nullptr)
         {
-            *ok = true;
+            *ok = res;
         }
-        return segment;
+    };
+
+    if (points.count() < 2)
+    {
+        SetResult(false);
+        return points;
     }
 
-    if (ok != nullptr)
+    if (points.constFirst().toPoint() == begin.toPoint())
     {
-        *ok = false;
+        SetResult(true);
+        return points;
     }
-    return points;
+
+    QVector<QPointF> segment;
+    bool theBegin = false;
+    for (qint32 i = 0; i < points.count() - 1; ++i)
+    {
+        if (not theBegin)
+        {
+            if (IsPointOnLineSegment(begin, points.at(i), points.at(i + 1)))
+            {
+                theBegin = true;
+
+                if (not VFuzzyComparePoints(begin, points.at(i + 1)))
+                {
+                    segment.append(begin);
+                }
+
+                if (i == points.count() - 2)
+                {
+                    segment.append(points.at(i + 1));
+                }
+            }
+        }
+        else
+        {
+            segment.append(points.at(i));
+            if (i == points.count() - 2)
+            {
+                segment.append(points.at(i + 1));
+            }
+        }
+    }
+
+    if (segment.isEmpty())
+    {
+        SetResult(false);
+        return points;
+    }
+
+    SetResult(true);
+    return segment;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -237,20 +267,41 @@ auto VAbstractCurve::ClosestPoint(QPointF scenePoint) const -> QPointF
         return {};
     }
 
-    if (VFuzzyComparePoints(ConstFirst(points), scenePoint))
+    if (VFuzzyComparePoints(points.constFirst(), scenePoint))
     {
-        return ConstFirst(points);
+        return points.constFirst();
+    }
+
+    if (VFuzzyComparePoints(points.constLast(), scenePoint))
+    {
+        return points.constLast();
     }
 
     QPointF candidatePoint;
     qreal bestDistance = INT_MAX;
     bool found = false;
 
-    for (qint32 i = 0; i < points.count()-1; ++i)
+    for (qint32 i = 0; i < points.count() - 1; ++i)
     {
-        const QPointF cPoint = VGObject::ClosestPoint(QLineF(points.at(i), points.at(i+1)), scenePoint);
+        qreal length = QLineF(points.at(i), scenePoint).length();
+        if (length < bestDistance)
+        {
+            candidatePoint = points.at(i);
+            bestDistance = length;
+            found = true;
+        }
 
-        if (IsPointOnLineSegment(cPoint, points.at(i), points.at(i+1)))
+        length = QLineF(points.at(i + 1), scenePoint).length();
+        if (length < bestDistance)
+        {
+            candidatePoint = points.at(i + 1);
+            bestDistance = length;
+            found = true;
+        }
+
+        const QPointF cPoint = VGObject::ClosestPoint(QLineF(points.at(i), points.at(i + 1)), scenePoint);
+
+        if (IsPointOnLineSegment(cPoint, points.at(i), points.at(i + 1)))
         {
             const qreal length = QLineF(scenePoint, cPoint).length();
             if (length < bestDistance)
@@ -266,10 +317,8 @@ auto VAbstractCurve::ClosestPoint(QPointF scenePoint) const -> QPointF
     {
         return candidatePoint;
     }
-    else
-    {
-        return {};
-    }
+
+    return {};
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -284,7 +333,7 @@ auto VAbstractCurve::GetPath() const -> QPainterPath
     }
     else
     {
-        qDebug()<<"points.count() < 2"<<Q_FUNC_INFO;
+        qDebug() << "points.count() < 2" << Q_FUNC_INFO;
     }
     return path;
 }
@@ -298,7 +347,7 @@ auto VAbstractCurve::GetLengthByPoint(const QPointF &point) const -> qreal
         return -1;
     }
 
-    if (ConstFirst(points).toPoint() == point.toPoint())
+    if (points.constFirst().toPoint() == point.toPoint())
     {
         return 0;
     }
@@ -343,9 +392,9 @@ auto VAbstractCurve::IsPointOnCurve(const QVector<QPointF> &points, const QPoint
         return points.at(0) == p;
     }
 
-    for (qint32 i = 0; i < points.count()-1; ++i)
+    for (qint32 i = 0; i < points.count() - 1; ++i)
     {
-        if (IsPointOnLineSegment(p, points.at(i), points.at(i+1)))
+        if (IsPointOnLineSegment(p, points.at(i), points.at(i + 1)))
         {
             return true;
         }
@@ -360,74 +409,6 @@ auto VAbstractCurve::IsPointOnCurve(const QPointF &p) const -> bool
     return IsPointOnCurve(GetPoints(), p);
 }
 
-//---------------------------------------------------------------------------------------------------------------------
-auto VAbstractCurve::SubdividePath(const QVector<QPointF> &points, QPointF p, QVector<QPointF> &sub1,
-                                   QVector<QPointF> &sub2) -> bool
-{
-    if (points.size() < 2)
-    {
-        return false;
-    }
-
-    bool found = false;
-    sub1.clear();
-    sub2.clear();
-
-    for (qint32 i = 0; i < points.count()-1; ++i)
-    {
-        if (not found)
-        {
-            if (IsPointOnLineSegment(p, points.at(i), points.at(i+1)))
-            {
-                if (not VFuzzyComparePoints(points.at(i), p))
-                {
-                    sub1.append(points.at(i));
-                    sub1.append(p);
-                }
-                else
-                {
-                    if (not sub1.isEmpty())
-                    {
-                        sub1.append(p);
-                    }
-                }
-
-                if (not VFuzzyComparePoints(points.at(i+1), p))
-                {
-                    sub2.append(p);
-
-                    if (i+1 == points.count()-1)
-                    {
-                        sub2.append(points.at(i+1));
-                    }
-                }
-
-                found = true;
-            }
-            else
-            {
-                sub1.append(points.at(i));
-            }
-        }
-        else
-        {
-            sub2.append(points.at(i));
-
-            if (i+1 == points.count()-1)
-            {
-                sub2.append(points.at(i+1));
-            }
-        }
-    }
-
-    if (not found)
-    {
-        sub1.clear();
-    }
-
-    return found;
-}
-
 //---------------------------------------------------------------------------------------------------------------------
 auto VAbstractCurve::GetDuplicate() const -> quint32
 {
@@ -481,16 +462,16 @@ void VAbstractCurve::SetApproximationScale(qreal value)
 auto VAbstractCurve::CurveIntersectLine(const QVector<QPointF> &points, const QLineF &line) -> QVector<QPointF>
 {
     QVector<QPointF> intersections;
-    intersections.reserve(points.count()-1);
-    for ( auto i = 0; i < points.count()-1; ++i )
+    intersections.reserve(points.count() - 1);
+    for (auto i = 0; i < points.count() - 1; ++i)
     {
         QPointF crosPoint;
-        auto type = Intersects(line, QLineF(points.at(i), points.at(i+1)), &crosPoint);
+        auto type = line.intersects(QLineF(points.at(i), points.at(i + 1)), &crosPoint);
 
         // QLineF::intersects not always accurate on edge cases
         if (type == QLineF::BoundedIntersection ||
-            (VGObject::IsPointOnLineSegment (crosPoint, points.at(i), points.at(i+1)) &&
-             VGObject::IsPointOnLineSegment (crosPoint, line.p1(), line.p2())))
+            (VGObject::IsPointOnLineSegment(crosPoint, points.at(i), points.at(i + 1)) &&
+             VGObject::IsPointOnLineSegment(crosPoint, line.p1(), line.p2())))
         {
             intersections.append(crosPoint);
         }
@@ -506,16 +487,16 @@ auto VAbstractCurve::CurveIntersectAxis(const QPointF &point, qreal angle, const
 
     // Normalize an angle
     {
-        QLineF line(QPointF(10,10), QPointF(100, 10));
+        QLineF line(QPointF(10, 10), QPointF(100, 10));
         line.setAngle(angle);
         angle = line.angle();
     }
 
-    QRectF rec = QRectF(0, 0, INT_MAX, INT_MAX);
-    rec.translate(-INT_MAX/2.0, -INT_MAX/2.0);
+    auto rec = QRectF(0, 0, INT_MAX, INT_MAX);
+    rec.translate(-INT_MAX / 2.0, -INT_MAX / 2.0);
 
     // Instead of using axis compare two rays. See issue #963.
-    QLineF axis = QLineF(point, VGObject::BuildRay(point, angle, rec));
+    auto axis = QLineF(point, VGObject::BuildRay(point, angle, rec));
     QVector<QPointF> points = VAbstractCurve::CurveIntersectLine(curvePoints, axis);
 
     axis = QLineF(point, VGObject::BuildRay(point, angle + 180, rec));
@@ -532,7 +513,7 @@ auto VAbstractCurve::CurveIntersectAxis(const QPointF &point, qreal angle, const
         QMap<qreal, int> forward;
         QMap<qreal, int> backward;
 
-        for ( qint32 i = 0; i < points.size(); ++i )
+        for (qint32 i = 0; i < points.size(); ++i)
         {
             if (VFuzzyComparePoints(points.at(i), point))
             { // Always seek unique intersection
@@ -540,7 +521,7 @@ auto VAbstractCurve::CurveIntersectAxis(const QPointF &point, qreal angle, const
             }
 
             const QLineF length(point, points.at(i));
-            if (qAbs(length.angle()-angle) < 0.1)
+            if (qAbs(length.angle() - angle) < 0.1)
             {
                 forward.insert(length.length(), i);
             }
@@ -591,33 +572,33 @@ auto VAbstractCurve::DirectionArrows() const -> QVector<DirectionArrow>
     {
         /*Need find coordinate midle of curve.
           Universal way is take all points and find sum.*/
-        const qreal seek_length = qAbs(GetLength())/2.0;
+        const qreal seek_length = qAbs(GetLength()) / 2.0;
         qreal found_length = 0;
         QLineF arrow;
-        for (qint32 i = 1; i <= points.size()-1; ++i)
+        for (qint32 i = 1; i <= points.size() - 1; ++i)
         {
-            arrow = QLineF(points.at(i-1), points.at(i));
-            found_length += arrow.length();//Length that we aready find
+            arrow = QLineF(points.at(i - 1), points.at(i));
+            found_length += arrow.length(); // Length that we aready find
 
-            if (seek_length <= found_length)// if have found more that need stop.
+            if (seek_length <= found_length) // if have found more that need stop.
             {
-                //subtract length in last line and you will find position of the middle point.
+                // subtract length in last line and you will find position of the middle point.
                 arrow.setLength(arrow.length() - (found_length - seek_length));
                 break;
             }
         }
 
-        //Reverse line because we want start arrow from this point
-        arrow = QLineF(arrow.p2(), arrow.p1());
-        const qreal angle = arrow.angle();//we each time change line angle, better save original angle value
+        // Reverse line because we want start arrow from this point
+        Swap(arrow);
+        const qreal angle = arrow.angle(); // we each time change line angle, better save original angle value
         arrow.setLength(VAbstractCurve::LengthCurveDirectionArrow());
 
         DirectionArrow dArrow;
 
-        arrow.setAngle(angle-35);
+        arrow.setAngle(angle - 35);
         dArrow.first = arrow;
 
-        arrow.setAngle(angle+35);
+        arrow.setAngle(angle + 35);
         dArrow.second = arrow;
 
         arrows.append(dArrow);
@@ -630,18 +611,18 @@ auto VAbstractCurve::ShowDirection(const QVector<DirectionArrow> &arrows, qreal
 {
     QPainterPath path;
 
-    for (auto arrow : arrows)
+    for (const auto &[first, second] : arrows)
     {
-        if (not arrow.first.isNull() && not arrow.second.isNull())
+        if (not first.isNull() && not second.isNull())
         {
             QPainterPath arrowPath;
 
-            QLineF line = arrow.first;
+            QLineF line = first;
             line.setLength(width);
             arrowPath.moveTo(line.p1());
             arrowPath.lineTo(line.p2());
 
-            line = arrow.second;
+            line = second;
             line.setLength(width);
             arrowPath.moveTo(line.p1());
             arrowPath.lineTo(line.p2());
@@ -665,6 +646,27 @@ void VAbstractCurve::SetAliasSuffix(const QString &aliasSuffix)
     CreateAlias();
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+auto VAbstractCurve::Curvature(const QVector<QPointF> &vertices) -> double
+{
+    vsizetype const numVertices = vertices.size();
+    if (numVertices < 3)
+    {
+        // A polygonal chain needs at least 3 vertices
+        return 0.0;
+    }
+
+    qreal const minLength = MinimalLength(vertices);
+
+    double sumCurvature = 0.0;
+    for (vsizetype i = 1; i < vertices.size() - 1; ++i)
+    {
+        sumCurvature += NodeCurvature(vertices[i - 1], vertices[i], vertices[i + 1], minLength);
+    }
+
+    return sumCurvature / static_cast<double>(vertices.size() - 2);
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 auto VAbstractCurve::PathLength(const QVector<QPointF> &path) -> qreal
 {
