@@ -32,23 +32,26 @@
 #include <QPointF>
 #include <QtDebug>
 
-#include "../vmisc/def.h"
-#include "../vmisc/vmath.h"
-#include "../vmisc/compatibility.h"
+#include "../ifc/exception/vexception.h"
 #include "../ifc/ifcdef.h"
+#include "../vmisc/compatibility.h"
+#include "../vmisc/def.h"
+#include "../vmisc/defglobal.h"
+#include "../vmisc/vabstractapplication.h"
+#include "../vmisc/vmath.h"
 #include "vabstractcurve.h"
 #include "varc_p.h"
 #include "vspline.h"
-#include "../ifc/exception/vexception.h"
 
 //---------------------------------------------------------------------------------------------------------------------
 /**
  * @brief VArc default constructor.
  */
-VArc::VArc ()
-    : VAbstractArc(GOType::Arc),
-      d (new VArcData)
-{}
+VArc::VArc()
+  : VAbstractArc(GOType::Arc),
+    d(new VArcData)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
 /**
@@ -58,27 +61,29 @@ VArc::VArc ()
  * @param f1 start angle (degree).
  * @param f2 end angle (degree).
  */
-VArc::VArc (const VPointF &center, qreal radius, const QString &formulaRadius, qreal f1, const QString &formulaF1,
-            qreal f2, const QString &formulaF2, quint32 idObject, Draw mode)
-    : VAbstractArc(GOType::Arc, center, f1, formulaF1, f2, formulaF2, idObject, mode),
-      d (new VArcData(radius, formulaRadius))
+VArc::VArc(const VPointF &center, qreal radius, const QString &formulaRadius, qreal f1, const QString &formulaF1,
+           qreal f2, const QString &formulaF2, quint32 idObject, Draw mode)
+  : VAbstractArc(GOType::Arc, center, f1, formulaF1, f2, formulaF2, idObject, mode),
+    d(new VArcData(radius, formulaRadius))
 {
     CreateName();
+    SetFlipped(radius < 0);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 VArc::VArc(const VPointF &center, qreal radius, qreal f1, qreal f2)
-    : VAbstractArc(GOType::Arc, center, f1, f2, NULL_ID, Draw::Calculation),
-      d (new VArcData(radius))
+  : VAbstractArc(GOType::Arc, center, f1, f2, NULL_ID, Draw::Calculation),
+    d(new VArcData(radius))
 {
     CreateName();
+    SetFlipped(radius < 0);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 VArc::VArc(qreal length, const QString &formulaLength, const VPointF &center, qreal radius,
            const QString &formulaRadius, qreal f1, const QString &formulaF1, quint32 idObject, Draw mode)
-    : VAbstractArc(GOType::Arc, formulaLength, center, f1, formulaF1, idObject, mode),
-      d (new VArcData(radius, formulaRadius))
+  : VAbstractArc(GOType::Arc, formulaLength, center, f1, formulaF1, idObject, mode),
+    d(new VArcData(radius, formulaRadius))
 {
     CreateName();
     FindF2(length);
@@ -86,21 +91,15 @@ VArc::VArc(qreal length, const QString &formulaLength, const VPointF &center, qr
 
 //---------------------------------------------------------------------------------------------------------------------
 VArc::VArc(qreal length, const VPointF &center, qreal radius, qreal f1)
-    : VAbstractArc(GOType::Arc, center, f1, NULL_ID, Draw::Calculation),
-      d (new VArcData(radius))
+  : VAbstractArc(GOType::Arc, center, f1, NULL_ID, Draw::Calculation),
+    d(new VArcData(radius))
 {
     CreateName();
     FindF2(length);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-/**
- * @brief VArc copy constructor
- * @param arc arc
- */
-VArc::VArc(const VArc &arc)
-    : VAbstractArc(arc), d (arc.d)
-{}
+COPY_CONSTRUCTOR_IMPL_2(VArc, VAbstractArc)
 
 //---------------------------------------------------------------------------------------------------------------------
 /**
@@ -108,9 +107,9 @@ VArc::VArc(const VArc &arc)
  * @param arc arc
  * @return arc
  */
-auto VArc::operator =(const VArc &arc) -> VArc &
+auto VArc::operator=(const VArc &arc) -> VArc &
 {
-    if ( &arc == this )
+    if (&arc == this)
     {
         return *this;
     }
@@ -119,20 +118,20 @@ auto VArc::operator =(const VArc &arc) -> VArc &
     return *this;
 }
 
-#ifdef Q_COMPILER_RVALUE_REFS
 //---------------------------------------------------------------------------------------------------------------------
-VArc::VArc(VArc &&arc) Q_DECL_NOTHROW
-    : VAbstractArc(std::move(arc)), d (std::move(arc.d))
-{}
+VArc::VArc(VArc &&arc) noexcept
+  : VAbstractArc(std::move(arc)),
+    d(std::move(arc.d)) // NOLINT(bugprone-use-after-move)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-auto VArc::operator=(VArc &&arc) Q_DECL_NOTHROW -> VArc &
+auto VArc::operator=(VArc &&arc) noexcept -> VArc &
 {
     VAbstractArc::operator=(arc);
     std::swap(d, arc.d);
     return *this;
 }
-#endif
 
 //---------------------------------------------------------------------------------------------------------------------
 auto VArc::Rotate(const QPointF &originPoint, qreal degrees, const QString &prefix) const -> VArc
@@ -145,7 +144,7 @@ auto VArc::Rotate(const QPointF &originPoint, qreal degrees, const QString &pref
     const qreal f1 = QLineF(static_cast<QPointF>(center), p1).angle();
     const qreal f2 = QLineF(static_cast<QPointF>(center), p2).angle();
 
-    VArc arc(center, GetRadius(), f1, f2);
+    VArc arc(center, d->radius, f1, f2);
     arc.setName(name() + prefix);
 
     if (not GetAliasSuffix().isEmpty())
@@ -171,7 +170,7 @@ auto VArc::Flip(const QLineF &axis, const QString &prefix) const -> VArc
     const qreal f1 = QLineF(static_cast<QPointF>(center), p1).angle();
     const qreal f2 = QLineF(static_cast<QPointF>(center), p2).angle();
 
-    VArc arc(center, GetRadius(), f1, f2);
+    VArc arc(center, d->radius, f1, f2);
     arc.setName(name() + prefix);
 
     if (not GetAliasSuffix().isEmpty())
@@ -197,7 +196,7 @@ auto VArc::Move(qreal length, qreal angle, const QString &prefix) const -> VArc
     const qreal f1 = QLineF(static_cast<QPointF>(center), p1).angle();
     const qreal f2 = QLineF(static_cast<QPointF>(center), p2).angle();
 
-    VArc arc(center, GetRadius(), f1, f2);
+    VArc arc(center, d->radius, f1, f2);
     arc.setName(name() + prefix);
 
     if (not GetAliasSuffix().isEmpty())
@@ -213,8 +212,7 @@ auto VArc::Move(qreal length, qreal angle, const QString &prefix) const -> VArc
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VArc::~VArc() // NOLINT(hicpp-use-equals-default, modernize-use-equals-default)
-{}
+VArc::~VArc() = default;
 
 //---------------------------------------------------------------------------------------------------------------------
 /**
@@ -223,7 +221,7 @@ VArc::~VArc() // NOLINT(hicpp-use-equals-default, modernize-use-equals-default)
  */
 auto VArc::GetLength() const -> qreal
 {
-    qreal length = d->radius * qDegreesToRadians(AngleArc());
+    qreal length = qAbs(d->radius) * qDegreesToRadians(AngleArc());
     if (IsFlipped())
     {
         length *= -1;
@@ -239,7 +237,7 @@ auto VArc::GetLength() const -> qreal
  */
 auto VArc::GetP1() const -> QPointF
 {
-    QPointF p1 ( GetCenter().x () + d->radius, GetCenter().y () );
+    QPointF const p1(GetCenter().x() + qAbs(d->radius), GetCenter().y());
     QLineF centerP1(static_cast<QPointF>(GetCenter()), p1);
     centerP1.setAngle(GetStartAngle());
     return centerP1.p2();
@@ -250,9 +248,9 @@ auto VArc::GetP1() const -> QPointF
  * @brief GetP2 return point associated with end angle.
  * @return точку point.
  */
-auto VArc::GetP2 () const -> QPointF
+auto VArc::GetP2() const -> QPointF
 {
-    QPointF p2 ( GetCenter().x () + d->radius, GetCenter().y () );
+    QPointF const p2(GetCenter().x() + qAbs(d->radius), GetCenter().y());
     QLineF centerP2(static_cast<QPointF>(GetCenter()), p2);
     centerP2.setAngle(GetEndAngle());
     return centerP2.p2();
@@ -265,7 +263,7 @@ auto VArc::GetP2 () const -> QPointF
  */
 auto VArc::GetPoints() const -> QVector<QPointF>
 {
-    if (qFuzzyIsNull(GetRadius()))
+    if (qFuzzyIsNull(d->radius))
     {
         return {GetCenter().toQPointF()};
     }
@@ -285,15 +283,15 @@ auto VArc::GetPoints() const -> QVector<QPointF>
         }
 
         if (angle > 360 || angle < 0)
-        {// Filter incorect value
-            QLineF dummy(0,0, 100, 0);
+        { // Filter incorect value
+            QLineF dummy(0, 0, 100, 0);
             dummy.setAngle(angle);
             angle = dummy.angle();
         }
 
-        const qreal angleInterpolation = 45; //degree
+        const qreal angleInterpolation = 45; // degree
         const int sections = qFloor(angle / angleInterpolation);
-        sectionAngle.reserve(sections+1);
+        sectionAngle.reserve(sections + 1);
         for (int i = 0; i < sections; ++i)
         {
             sectionAngle.append(angleInterpolation);
@@ -308,9 +306,9 @@ auto VArc::GetPoints() const -> QVector<QPointF>
 
     for (int i = 0; i < sectionAngle.size(); ++i)
     {
-        const qreal lDistance = GetRadius() * 4.0/3.0 * qTan(qDegreesToRadians(sectionAngle.at(i)) * 0.25);
+        const qreal lDistance = qAbs(d->radius) * 4.0 / 3.0 * qTan(qDegreesToRadians(sectionAngle.at(i)) * 0.25);
 
-        const QPointF center = static_cast<QPointF>(GetCenter());
+        const auto center = static_cast<QPointF>(GetCenter());
 
         QLineF lineP1P2(pStart, center);
         lineP1P2.setAngle(lineP1P2.angle() - 90.0);
@@ -318,7 +316,7 @@ auto VArc::GetPoints() const -> QVector<QPointF>
 
         QLineF lineP4P3(center, pStart);
         lineP4P3.setAngle(lineP4P3.angle() + sectionAngle.at(i));
-        lineP4P3.setLength(GetRadius());//in case of computing error
+        lineP4P3.setLength(qAbs(d->radius)); // in case of computing error
         lineP4P3 = QLineF(lineP4P3.p2(), center);
         lineP4P3.setAngle(lineP4P3.angle() + 90.0);
         lineP4P3.setLength(lDistance);
@@ -348,23 +346,43 @@ auto VArc::GetPoints() const -> QVector<QPointF>
  */
 auto VArc::CutArc(qreal length, VArc &arc1, VArc &arc2, const QString &pointName) const -> QPointF
 {
-    //Always need return two arcs, so we must correct wrong length.
     const qreal fullLength = GetLength();
 
-    if (qAbs(fullLength) < ToPixel(2, Unit::Mm))
+    if (qFuzzyIsNull(fullLength) || qFuzzyIsNull(d->radius))
     {
-        arc1 = VArc();
-        arc2 = VArc();
-
-        const QString errorMsg = tr("Unable to cut curve '%1'. The curve is too short.").arg(name());
-        VAbstractApplication::VApp()->IsPedantic() ? throw VException(errorMsg) :
-                                          qWarning() << VAbstractApplication::warningMessageSignature + errorMsg;
-
-        return {};
+        arc1 = *this;
+        arc2 = *this;
+        return GetCenter().toQPointF();
     }
 
-    QLineF line = not IsFlipped() ? CutPoint(length, fullLength, pointName)
-                                  : CutPointFlipped(length, fullLength, pointName);
+    if (qFuzzyIsNull(length) || qFuzzyIsNull(length + fullLength))
+    {
+        arc1 = VArc(GetCenter(), d->radius, d->formulaRadius, GetStartAngle(), GetFormulaF1(), GetStartAngle(),
+                    GetFormulaF1(), getIdObject(), getMode());
+        arc1.SetApproximationScale(GetApproximationScale());
+        arc1.SetFlipped(IsFlipped());
+        arc1.SetAllowEmpty(true);
+
+        arc2 = *this;
+
+        return GetP1();
+    }
+
+    if (VFuzzyComparePossibleNulls(length, fullLength))
+    {
+        arc1 = *this;
+
+        arc2 = VArc(GetCenter(), d->radius, d->formulaRadius, GetEndAngle(), GetFormulaF2(), GetEndAngle(),
+                    GetFormulaF2(), getIdObject(), getMode());
+        arc2.SetApproximationScale(GetApproximationScale());
+        arc2.SetFlipped(IsFlipped());
+        arc2.SetAllowEmpty(true);
+
+        return GetP2();
+    }
+
+    QLineF const line =
+        not IsFlipped() ? CutPoint(length, fullLength, pointName) : CutPointFlipped(length, fullLength, pointName);
 
     arc1 = VArc(GetCenter(), d->radius, d->formulaRadius, GetStartAngle(), GetFormulaF1(), line.angle(),
                 QString().setNum(line.angle()), getIdObject(), getMode());
@@ -378,20 +396,46 @@ auto VArc::CutArc(qreal length, VArc &arc1, VArc &arc2, const QString &pointName
     return line.p2();
 }
 
-
 //---------------------------------------------------------------------------------------------------------------------
 auto VArc::CutArc(qreal length, const QString &pointName) const -> QPointF
 {
     VArc arc1;
     VArc arc2;
-    return this->CutArc(length, arc1, arc2, pointName);
+    return CutArc(length, arc1, arc2, pointName);
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VArc::OptimalApproximationScale(qreal radius, qreal f1, qreal f2, qreal tolerance) -> qreal
+{
+    if (qFuzzyIsNull(radius))
+    {
+        return maxCurveApproximationScale;
+    }
+
+    const qreal expectedCurvature = 1 / qAbs(radius);
+    qreal scale = minCurveApproximationScale;
+
+    do
+    {
+        VArc arc(VPointF(), radius, f1, f2);
+        arc.SetApproximationScale(scale);
+        qreal const curvature = Curvature(arc.GetPoints());
+
+        if (expectedCurvature - curvature <= expectedCurvature * tolerance)
+        {
+            return scale;
+        }
+        scale += 0.1;
+    } while (scale <= maxCurveApproximationScale);
+
+    return maxCurveApproximationScale;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void VArc::CreateName()
 {
     QString name = ARC_ + this->GetCenter().name();
-    const QString nameStr = QStringLiteral("_%1");
+    const auto nameStr = QStringLiteral("_%1");
 
     if (getMode() == Draw::Modeling && getIdObject() != NULL_ID)
     {
@@ -426,14 +470,14 @@ void VArc::CreateAlias()
 //---------------------------------------------------------------------------------------------------------------------
 void VArc::FindF2(qreal length)
 {
-    SetFlipped(length < 0);
+    SetFlipped(length < 0 || d->radius < 0);
 
-    if (length >= MaxLength())
+    if (qAbs(length) >= qAbs(MaxLength()))
     {
         length = MaxLength();
     }
 
-    qreal arcAngle = qAbs(qRadiansToDegrees(length/d->radius));
+    qreal arcAngle = qAbs(qRadiansToDegrees(qAbs(length) / qAbs(d->radius)));
 
     if (IsFlipped())
     {
@@ -441,7 +485,7 @@ void VArc::FindF2(qreal length)
     }
 
     QLineF startAngle(0, 0, 100, 0);
-    startAngle.setAngle(GetStartAngle() + arcAngle);// We use QLineF just because it is easy way correct angle value
+    startAngle.setAngle(GetStartAngle() + arcAngle); // We use QLineF just because it is easy way to correct angle value
 
     SetFormulaF2(QString::number(startAngle.angle()), startAngle.angle());
 }
@@ -449,7 +493,7 @@ void VArc::FindF2(qreal length)
 //---------------------------------------------------------------------------------------------------------------------
 auto VArc::MaxLength() const -> qreal
 {
-    return M_2PI*d->radius;
+    return M_2PI * d->radius;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -460,46 +504,49 @@ auto VArc::CutPoint(qreal length, qreal fullLength, const QString &pointName) co
         length = fullLength + length;
     }
 
-    const qreal maxLength = fullLength - minLength;
-
-    if (length < minLength)
+    if (length < 0)
     {
         QString errorMsg;
         if (not pointName.isEmpty())
         {
             errorMsg = tr("Curve '%1'. Length of a cut segment (%2) is too small. Optimize it to minimal value.")
-                    .arg(name(), pointName);
+                           .arg(name(), pointName);
         }
         else
         {
-            errorMsg = tr("Curve '%1'. Length of a cut segment is too small. Optimize it to minimal value.")
-                    .arg(name());
+            errorMsg =
+                tr("Curve '%1'. Length of a cut segment is too small. Optimize it to minimal value.").arg(name());
         }
-        VAbstractApplication::VApp()->IsPedantic() ? throw VException(errorMsg) :
-                                          qWarning() << VAbstractApplication::warningMessageSignature + errorMsg;
+        VAbstractApplication::VApp()->IsPedantic()
+            ? throw VException(errorMsg)
+            : qWarning() << VAbstractApplication::warningMessageSignature + errorMsg;
     }
-    else if (length > maxLength)
+    else if (length > fullLength)
     {
         QString errorMsg;
         if (not pointName.isEmpty())
         {
             errorMsg = tr("Curve '%1'. Length of a cut segment (%2) is too big. Optimize it to maximal value.")
-                    .arg(name(), pointName);
+                           .arg(name(), pointName);
         }
         else
         {
-
-            errorMsg = tr("Curve '%1'. Length of a cut segment is too big. Optimize it to maximal value.")
-                    .arg(name());
+            errorMsg = tr("Curve '%1'. Length of a cut segment is too big. Optimize it to maximal value.").arg(name());
         }
-        VAbstractApplication::VApp()->IsPedantic() ? throw VException(errorMsg) :
-                                          qWarning() << VAbstractApplication::warningMessageSignature + errorMsg;
+        VAbstractApplication::VApp()->IsPedantic()
+            ? throw VException(errorMsg)
+            : qWarning() << VAbstractApplication::warningMessageSignature + errorMsg;
     }
 
-    length = qBound(minLength, length, maxLength);
+    if (qFuzzyIsNull(d->radius))
+    {
+        return {static_cast<QPointF>(GetCenter()), static_cast<QPointF>(GetCenter())};
+    }
+
+    length = qBound(0.0, length, fullLength);
 
     QLineF line(static_cast<QPointF>(GetCenter()), GetP1());
-    line.setAngle(line.angle() + qRadiansToDegrees(length/d->radius));
+    line.setAngle(line.angle() + qRadiansToDegrees(length / d->radius));
     return line;
 }
 
@@ -511,46 +558,49 @@ auto VArc::CutPointFlipped(qreal length, qreal fullLength, const QString &pointN
         length = fullLength + length;
     }
 
-    const qreal minLengthFlipped = fullLength + minLength;
-    const qreal maxLengthFlipped = -minLength;
-
-    if (length < minLengthFlipped)
+    if (length < fullLength)
     {
         QString errorMsg;
         if (not pointName.isEmpty())
         {
             errorMsg = tr("Curve '%1'. Length of a cut segment (%2) is too small. Optimize it to minimal value.")
-                    .arg(name(), pointName);
+                           .arg(name(), pointName);
         }
         else
         {
-            errorMsg = tr("Curve '%1'. Length of a cut segment is too small. Optimize it to minimal value.")
-                    .arg(name());
+            errorMsg =
+                tr("Curve '%1'. Length of a cut segment is too small. Optimize it to minimal value.").arg(name());
         }
-        VAbstractApplication::VApp()->IsPedantic() ? throw VException(errorMsg) :
-                                          qWarning() << VAbstractApplication::warningMessageSignature + errorMsg;
+        VAbstractApplication::VApp()->IsPedantic()
+            ? throw VException(errorMsg)
+            : qWarning() << VAbstractApplication::warningMessageSignature + errorMsg;
     }
-    else if (length > maxLengthFlipped)
+    else if (length > 0)
     {
         QString errorMsg;
         if (not pointName.isEmpty())
         {
             errorMsg = tr("Curve '%1'. Length of a cut segment (%2) is too big. Optimize it to maximal value.")
-                    .arg(name(), errorMsg);
+                           .arg(name(), errorMsg);
         }
         else
         {
-            errorMsg = tr("Curve '%1'. Length of a cut segment is too big. Optimize it to maximal value.")
-                    .arg(name());
+            errorMsg = tr("Curve '%1'. Length of a cut segment is too big. Optimize it to maximal value.").arg(name());
         }
-        VAbstractApplication::VApp()->IsPedantic() ? throw VException(errorMsg) :
-                                          qWarning() << VAbstractApplication::warningMessageSignature + errorMsg;
+        VAbstractApplication::VApp()->IsPedantic()
+            ? throw VException(errorMsg)
+            : qWarning() << VAbstractApplication::warningMessageSignature + errorMsg;
     }
 
-    length = qBound(minLengthFlipped, length, maxLengthFlipped);
+    if (qFuzzyIsNull(d->radius))
+    {
+        return {static_cast<QPointF>(GetCenter()), static_cast<QPointF>(GetCenter())};
+    }
+
+    length = qBound(fullLength, length, 0.0);
 
     QLineF line(static_cast<QPointF>(GetCenter()), GetP1());
-    line.setAngle(line.angle() - qRadiansToDegrees(qAbs(length)/d->radius));
+    line.setAngle(line.angle() - qRadiansToDegrees(qAbs(length) / d->radius));
     return line;
 }
 
