@@ -29,24 +29,24 @@
 #include "vellipticalarc.h"
 
 #include <QLineF>
-#include <QPoint>
 #include <QPainterPath>
+#include <QPoint>
 #include <QtDebug>
 
-#include "../vmisc/def.h"
-#include "../ifc/ifcdef.h"
 #include "../ifc/exception/vexception.h"
-#include "../vmisc/vabstractapplication.h"
+#include "../ifc/ifcdef.h"
+#include "../vmisc/compatibility.h"
+#include "../vmisc/def.h"
 #include "../vmisc/fpm/fixed.hpp"
 #include "../vmisc/fpm/math.hpp"
-#include "../vmisc/compatibility.h"
+#include "../vmisc/vabstractapplication.h"
+#include "../vmisc/vmath.h"
 #include "vabstractcurve.h"
 #include "vellipticalarc_p.h"
-#include "../vmisc/vmath.h"
 
 namespace
 {
-constexpr qreal tolerance = accuracyPointOnLine/8;
+constexpr qreal tolerance = accuracyPointOnLine / 8;
 
 // Because of overflow we cannot generate arcs more than maxRadius
 constexpr int maxRadius = 10000;
@@ -58,22 +58,22 @@ auto VLen(fpm::fixed_16_16 x, fpm::fixed_16_16 y) -> fpm::fixed_16_16
     y = fpm::abs(y);
     if (x > y)
     {
-        return x + qMax(y/8, y/2 - x/8);
+        return x + qMax(y / 8, y / 2 - x / 8);
     }
 
-    return y + qMax(x/8, x/2 - y/8);
+    return y + qMax(x / 8, x / 2 - y / 8);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 auto AuxRadius(fpm::fixed_16_16 xP, fpm::fixed_16_16 yP, fpm::fixed_16_16 xQ, fpm::fixed_16_16 yQ) -> fpm::fixed_16_16
 {
-    fpm::fixed_16_16 dP = VLen(xP, yP);
-    fpm::fixed_16_16 dQ = VLen(xQ, yQ);
-    fpm::fixed_16_16 dJ = VLen(xP + xQ, yP + yQ);
-    fpm::fixed_16_16 dK = VLen(xP - xQ, yP - yQ);
-    fpm::fixed_16_16 r1 = qMax(dP, dQ);
-    fpm::fixed_16_16 r2 = qMax(dJ, dK);
-    return qMax(r1 + r1/16, r2 - r2/4);
+    fpm::fixed_16_16 const dP = VLen(xP, yP);
+    fpm::fixed_16_16 const dQ = VLen(xQ, yQ);
+    fpm::fixed_16_16 const dJ = VLen(xP + xQ, yP + yQ);
+    fpm::fixed_16_16 const dK = VLen(xP - xQ, yP - yQ);
+    fpm::fixed_16_16 const r1 = qMax(dP, dQ);
+    fpm::fixed_16_16 const r2 = qMax(dJ, dK);
+    return qMax(r1 + r1 / 16, r2 - r2 / 4);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -81,7 +81,7 @@ auto AngularInc(fpm::fixed_16_16 xP, fpm::fixed_16_16 yP, fpm::fixed_16_16 xQ, f
                 fpm::fixed_16_16 flatness) -> int
 {
 
-    fpm::fixed_16_16 r = AuxRadius(xP, yP, xQ, yQ);
+    fpm::fixed_16_16 const r = AuxRadius(xP, yP, xQ, yQ);
     fpm::fixed_16_16 err2{r >> 3};
     // 2nd-order term
     fpm::fixed_16_16 err4{r >> 7};
@@ -100,7 +100,7 @@ auto AngularInc(fpm::fixed_16_16 xP, fpm::fixed_16_16 yP, fpm::fixed_16_16 xQ, f
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-inline void CircleGen(fpm::fixed_16_16& u, fpm::fixed_16_16& v, uint k)
+inline void CircleGen(fpm::fixed_16_16 &u, fpm::fixed_16_16 &v, uint k)
 {
     u -= v >> k;
     v += u >> k;
@@ -109,8 +109,8 @@ inline void CircleGen(fpm::fixed_16_16& u, fpm::fixed_16_16& v, uint k)
 //---------------------------------------------------------------------------------------------------------------------
 auto InitialValue(fpm::fixed_16_16 u0, fpm::fixed_16_16 v0, uint k) -> fpm::fixed_16_16
 {
-    uint shift = 2*k + 3;
-    fpm::fixed_16_16 w {u0 >> shift};
+    uint const shift = 2 * k + 3;
+    fpm::fixed_16_16 w{u0 >> shift};
 
     fpm::fixed_16_16 U0 = u0 - w + (v0 >> (k + 1));
     w >>= (shift + 1);
@@ -122,11 +122,11 @@ auto InitialValue(fpm::fixed_16_16 u0, fpm::fixed_16_16 v0, uint k) -> fpm::fixe
 
 //---------------------------------------------------------------------------------------------------------------------
 auto EllipseCore(fpm::fixed_16_16 xC, fpm::fixed_16_16 yC, fpm::fixed_16_16 xP, fpm::fixed_16_16 yP,
-                 fpm::fixed_16_16 xQ, fpm::fixed_16_16 yQ, fpm::fixed_16_16 sweep,
-                 fpm::fixed_16_16 flatness) -> QVector<QPointF>
+                 fpm::fixed_16_16 xQ, fpm::fixed_16_16 yQ, fpm::fixed_16_16 sweep, fpm::fixed_16_16 flatness)
+    -> QVector<QPointF>
 {
-    uint k = qMin(static_cast<uint>(AngularInc(xP, yP, xQ, yQ, flatness)), 16U);
-    const uint count = static_cast<std::uint32_t>(sweep.raw_value()) >> (16 - k);
+    uint const k = qMin(static_cast<uint>(AngularInc(xP, yP, xQ, yQ, flatness)), 16U);
+    const auto count = static_cast<std::uint32_t>(sweep.raw_value()) >> (16 - k);
 
     QVector<QPointF> arc;
     arc.reserve(static_cast<int>(count) + 1);
@@ -148,11 +148,11 @@ auto EllipseCore(fpm::fixed_16_16 xC, fpm::fixed_16_16 yC, fpm::fixed_16_16 xP,
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-auto EllipticArcPoints(QPointF c, qreal radius1, qreal radius2, qreal astart, qreal asweep,
-                       qreal approximationScale) -> QVector<QPointF>
+auto EllipticArcPoints(QPointF c, qreal radius1, qreal radius2, qreal astart, qreal asweep, qreal approximationScale)
+    -> QVector<QPointF>
 {
-    fpm::fixed_16_16 xC{c.x()};
-    fpm::fixed_16_16 yC{c.y()};
+    fpm::fixed_16_16 const xC{c.x()};
+    fpm::fixed_16_16 const yC{c.y()};
 
     fpm::fixed_16_16 xP{c.x() + radius1};
     fpm::fixed_16_16 yP{c.y()};
@@ -168,10 +168,10 @@ auto EllipticArcPoints(QPointF c, qreal radius1, qreal radius2, qreal astart, qr
     if (not qFuzzyIsNull(astart))
     {
         // Set new conjugate diameter end points P’ and Q’
-        fpm::fixed_16_16 cosa {cos(astart)};
-        fpm::fixed_16_16 sina {sin(astart)};
-        fpm::fixed_16_16 x {xP * cosa + xQ * sina};
-        fpm::fixed_16_16 y {yP * cosa + yQ * sina};
+        fpm::fixed_16_16 const cosa{cos(astart)};
+        fpm::fixed_16_16 const sina{sin(astart)};
+        fpm::fixed_16_16 const x{xP * cosa + xQ * sina};
+        fpm::fixed_16_16 const y{yP * cosa + yQ * sina};
 
         xQ = xQ * cosa - xP * sina;
         yQ = yQ * cosa - yP * sina;
@@ -187,21 +187,21 @@ auto EllipticArcPoints(QPointF c, qreal radius1, qreal radius2, qreal astart, qr
         asweep = -asweep;
     }
 
-    if(approximationScale < minCurveApproximationScale || approximationScale > maxCurveApproximationScale)
+    if (approximationScale < minCurveApproximationScale || approximationScale > maxCurveApproximationScale)
     {
         approximationScale = VAbstractApplication::VApp()->Settings()->GetCurveApproximationScale();
     }
 
-    fpm::fixed_16_16 flatness {maxCurveApproximationScale / approximationScale * tolerance};
-    fpm::fixed_16_16 swangle{asweep};
+    fpm::fixed_16_16 const flatness{maxCurveApproximationScale / approximationScale * tolerance};
+    fpm::fixed_16_16 const swangle{asweep};
     QVector<QPointF> arc = EllipseCore(xC, yC, xP, yP, xQ, yQ, swangle, flatness);
 
     // Arc end point
-    fpm::fixed_16_16 cosb {qCos(asweep)};
-    fpm::fixed_16_16 sinb {qSin(asweep)};
-    xP = xP*cosb + xQ*sinb;
-    yP = yP*cosb + yQ*sinb;
-    arc.append({static_cast<qreal>(xP+xC), static_cast<qreal>(yP+yC)});
+    fpm::fixed_16_16 const cosb{qCos(asweep)};
+    fpm::fixed_16_16 const sinb{qSin(asweep)};
+    xP = xP * cosb + xQ * sinb;
+    yP = yP * cosb + yQ * sinb;
+    arc.append({static_cast<qreal>(xP + xC), static_cast<qreal>(yP + yC)});
 
     return arc;
 }
@@ -218,7 +218,7 @@ auto JoinVectors(const QVector<QPointF> &v1, const QVector<QPointF> &v2) -> QVec
 
     for (auto p : v2)
     {
-        if (not VFuzzyComparePoints(ConstLast(v), p, accuracy))
+        if (not VFuzzyComparePoints(v.constLast(), p, accuracy))
         {
             v.append(p);
         }
@@ -226,15 +226,26 @@ auto JoinVectors(const QVector<QPointF> &v1, const QVector<QPointF> &v2) -> QVec
 
     return v;
 }
-}  // namespace
+
+//---------------------------------------------------------------------------------------------------------------------
+auto IsBoundedIntersection(QLineF::IntersectType type, QPointF p, const QLineF &segment1, const QLineF &segment2)
+    -> bool
+{
+    return type == QLineF::BoundedIntersection ||
+           (type == QLineF::UnboundedIntersection && VGObject::IsPointOnLineSegment(p, segment1.p1(), segment2.p1()) &&
+            VGObject::IsPointOnLineSegment(p, segment2.p1(), segment2.p2()));
+}
+} // namespace
 
 //---------------------------------------------------------------------------------------------------------------------
 /**
  * @brief VEllipticalArc default constructor.
  */
 VEllipticalArc::VEllipticalArc()
-    : VAbstractArc(GOType::EllipticalArc), d (new VEllipticalArcData)
-{}
+  : VAbstractArc(GOType::EllipticalArc),
+    d(new VEllipticalArcData)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
 /**
@@ -245,23 +256,25 @@ VEllipticalArc::VEllipticalArc()
  * @param f1 start angle (degree).
  * @param f2 end angle (degree).
  */
-VEllipticalArc::VEllipticalArc (const VPointF &center, qreal radius1, qreal radius2, const QString &formulaRadius1,
+VEllipticalArc::VEllipticalArc(const VPointF &center, qreal radius1, qreal radius2, const QString &formulaRadius1,
                                const QString &formulaRadius2, qreal f1, const QString &formulaF1, qreal f2,
                                const QString &formulaF2, qreal rotationAngle, const QString &formulaRotationAngle,
                                quint32 idObject, Draw mode)
-    : VAbstractArc(GOType::EllipticalArc, center, f1, formulaF1, f2, formulaF2, idObject, mode),
-    d (new VEllipticalArcData(radius1, radius2, formulaRadius1, formulaRadius2, rotationAngle, formulaRotationAngle))
+  : VAbstractArc(GOType::EllipticalArc, center, f1, formulaF1, f2, formulaF2, idObject, mode),
+    d(new VEllipticalArcData(radius1, radius2, formulaRadius1, formulaRadius2, rotationAngle, formulaRotationAngle))
 {
     CreateName();
+    SetFlipped(radius1 < 0 || radius2 < 0);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 VEllipticalArc::VEllipticalArc(const VPointF &center, qreal radius1, qreal radius2, qreal f1, qreal f2,
                                qreal rotationAngle)
-    : VAbstractArc(GOType::EllipticalArc, center, f1, f2, NULL_ID, Draw::Calculation),
-    d (new VEllipticalArcData(radius1, radius2, rotationAngle))
+  : VAbstractArc(GOType::EllipticalArc, center, f1, f2, NULL_ID, Draw::Calculation),
+    d(new VEllipticalArcData(radius1, radius2, rotationAngle))
 {
     CreateName();
+    SetFlipped(radius1 < 0 || radius2 < 0);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -269,8 +282,8 @@ VEllipticalArc::VEllipticalArc(qreal length, const QString &formulaLength, const
                                qreal radius2, const QString &formulaRadius1, const QString &formulaRadius2, qreal f1,
                                const QString &formulaF1, qreal rotationAngle, const QString &formulaRotationAngle,
                                quint32 idObject, Draw mode)
-    : VAbstractArc(GOType::EllipticalArc, formulaLength, center, f1, formulaF1, idObject, mode),
-    d (new VEllipticalArcData(radius1, radius2, formulaRadius1, formulaRadius2, rotationAngle, formulaRotationAngle))
+  : VAbstractArc(GOType::EllipticalArc, formulaLength, center, f1, formulaF1, idObject, mode),
+    d(new VEllipticalArcData(radius1, radius2, formulaRadius1, formulaRadius2, rotationAngle, formulaRotationAngle))
 {
     CreateName();
     FindF2(length);
@@ -279,21 +292,16 @@ VEllipticalArc::VEllipticalArc(qreal length, const QString &formulaLength, const
 //---------------------------------------------------------------------------------------------------------------------
 VEllipticalArc::VEllipticalArc(qreal length, const VPointF &center, qreal radius1, qreal radius2, qreal f1,
                                qreal rotationAngle)
-    : VAbstractArc(GOType::EllipticalArc, center, f1, NULL_ID, Draw::Calculation),
-    d (new VEllipticalArcData(radius1, radius2, rotationAngle))
+  : VAbstractArc(GOType::EllipticalArc, center, f1, NULL_ID, Draw::Calculation),
+    d(new VEllipticalArcData(radius1, radius2, rotationAngle))
 {
     CreateName();
     FindF2(length);
+    SetFormulaLength(QString::number(length));
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-/**
- * @brief VEllipticalArc copy constructor
- * @param arc arc
- */
-VEllipticalArc::VEllipticalArc(const VEllipticalArc &arc)
-    : VAbstractArc(arc), d (arc.d)
-{}
+COPY_CONSTRUCTOR_IMPL_2(VEllipticalArc, VAbstractArc)
 
 //---------------------------------------------------------------------------------------------------------------------
 /**
@@ -301,9 +309,9 @@ VEllipticalArc::VEllipticalArc(const VEllipticalArc &arc)
  * @param arc arc
  * @return arc
  */
-auto VEllipticalArc::operator =(const VEllipticalArc &arc) -> VEllipticalArc &
+auto VEllipticalArc::operator=(const VEllipticalArc &arc) -> VEllipticalArc &
 {
-    if ( &arc == this )
+    if (&arc == this)
     {
         return *this;
     }
@@ -312,21 +320,20 @@ auto VEllipticalArc::operator =(const VEllipticalArc &arc) -> VEllipticalArc &
     return *this;
 }
 
-#ifdef Q_COMPILER_RVALUE_REFS
 //---------------------------------------------------------------------------------------------------------------------
-VEllipticalArc::VEllipticalArc(VEllipticalArc &&arc) Q_DECL_NOTHROW
-    : VAbstractArc(std::move(arc)),
-      d(std::move(arc.d))
-{}
+VEllipticalArc::VEllipticalArc(VEllipticalArc &&arc) noexcept
+  : VAbstractArc(std::move(arc)),
+    d(std::move(arc.d)) // NOLINT(bugprone-use-after-move)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-auto VEllipticalArc::operator=(VEllipticalArc &&arc) Q_DECL_NOTHROW -> VEllipticalArc &
+auto VEllipticalArc::operator=(VEllipticalArc &&arc) noexcept -> VEllipticalArc &
 {
     VAbstractArc::operator=(arc);
     std::swap(d, arc.d);
     return *this;
 }
-#endif
 
 //---------------------------------------------------------------------------------------------------------------------
 auto VEllipticalArc::Rotate(QPointF originPoint, qreal degrees, const QString &prefix) const -> VEllipticalArc
@@ -335,11 +342,11 @@ auto VEllipticalArc::Rotate(QPointF originPoint, qreal degrees, const QString &p
 
     QTransform t = d->m_transform;
     t.translate(originPoint.x(), originPoint.y());
-    t.rotate(IsFlipped() ? degrees : -degrees);
+    t.rotate(-degrees);
     t.translate(-originPoint.x(), -originPoint.y());
 
-    VEllipticalArc elArc(VAbstractArc::GetCenter(), GetRadius1(), GetRadius2(), VAbstractArc::GetStartAngle(),
-                         VAbstractArc::GetEndAngle(), GetRotationAngle());
+    VEllipticalArc elArc(VAbstractArc::GetCenter(), d->radius1, d->radius2, VAbstractArc::GetStartAngle(),
+                         VAbstractArc::GetEndAngle(), d->rotationAngle);
     elArc.setName(name() + prefix);
 
     if (not GetAliasSuffix().isEmpty())
@@ -358,8 +365,8 @@ auto VEllipticalArc::Rotate(QPointF originPoint, qreal degrees, const QString &p
 //---------------------------------------------------------------------------------------------------------------------
 auto VEllipticalArc::Flip(const QLineF &axis, const QString &prefix) const -> VEllipticalArc
 {
-    VEllipticalArc elArc(VAbstractArc::GetCenter(), GetRadius1(), GetRadius2(), VAbstractArc::GetStartAngle(),
-                         VAbstractArc::GetEndAngle(), GetRotationAngle());
+    VEllipticalArc elArc(VAbstractArc::GetCenter(), d->radius1, d->radius2, VAbstractArc::GetStartAngle(),
+                         VAbstractArc::GetEndAngle(), d->rotationAngle);
     elArc.setName(name() + prefix);
 
     if (not GetAliasSuffix().isEmpty())
@@ -381,14 +388,14 @@ auto VEllipticalArc::Move(qreal length, qreal angle, const QString &prefix) cons
     const VPointF oldCenter = VAbstractArc::GetCenter();
     const VPointF center = oldCenter.Move(length, angle);
 
-    const QPointF position = d->m_transform.inverted().map(center.toQPointF()) -
-                             d->m_transform.inverted().map(oldCenter.toQPointF());
+    const QPointF position =
+        d->m_transform.inverted().map(center.toQPointF()) - d->m_transform.inverted().map(oldCenter.toQPointF());
 
     QTransform t = d->m_transform;
     t.translate(position.x(), position.y());
 
-    VEllipticalArc elArc(oldCenter, GetRadius1(), GetRadius2(), VAbstractArc::GetStartAngle(),
-                         VAbstractArc::GetEndAngle(), GetRotationAngle());
+    VEllipticalArc elArc(oldCenter, d->radius1, d->radius2, VAbstractArc::GetStartAngle(), VAbstractArc::GetEndAngle(),
+                         d->rotationAngle);
     elArc.setName(name() + prefix);
 
     if (not GetAliasSuffix().isEmpty())
@@ -405,8 +412,7 @@ auto VEllipticalArc::Move(qreal length, qreal angle, const QString &prefix) cons
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VEllipticalArc::~VEllipticalArc() // NOLINT(hicpp-use-equals-default, modernize-use-equals-default)
-{}
+VEllipticalArc::~VEllipticalArc() = default;
 
 //---------------------------------------------------------------------------------------------------------------------
 /**
@@ -419,7 +425,7 @@ auto VEllipticalArc::GetLength() const -> qreal
 
     if (IsFlipped())
     {
-        length = length * -1;
+        length *= -1;
     }
 
     return length;
@@ -440,7 +446,7 @@ auto VEllipticalArc::GetP1() const -> QPointF
  * @brief GetP2 return point associated with end angle.
  * @return point.
  */
-auto VEllipticalArc::GetP2 () const -> QPointF
+auto VEllipticalArc::GetP2() const -> QPointF
 {
     return GetTransform().map(GetP(VAbstractArc::GetEndAngle()));
 }
@@ -476,11 +482,16 @@ auto VEllipticalArc::GetPoints() const -> QVector<QPointF>
 {
     const QPointF center = VAbstractArc::GetCenter().toQPointF();
 
+    if (qFuzzyIsNull(d->radius1) && qFuzzyIsNull(d->radius2))
+    {
+        return {center};
+    }
+
     // Don't work with 0 radius. Always make it bigger than 0.
     Q_RELAXED_CONSTEXPR qreal threshold = ToPixel(0.001, Unit::Mm);
-    qreal radius1 = qMax(d->radius1, threshold);
-    qreal radius2 = qMax(d->radius2, threshold);
-    qreal max = qMax(d->radius1, d->radius2);
+    qreal radius1 = qMax(qAbs(d->radius1), threshold);
+    qreal radius2 = qMax(qAbs(d->radius2), threshold);
+    qreal const max = qMax(qAbs(d->radius1), qAbs(d->radius2));
     qreal scale = 1;
 
     if (max > maxRadius)
@@ -502,24 +513,24 @@ auto VEllipticalArc::GetPoints() const -> QVector<QPointF>
         // To avoid this we calculate an arc for scaled radiuses and then scale up to original size.
         t.scale(scale, scale);
     }
-    t.rotate(-GetRotationAngle());
+    t.rotate(-d->rotationAngle);
     t.translate(-center.x(), -center.y());
 
-    std::transform(points.begin(), points.end(), points.begin(), [t](const QPointF &point) { return t.map(point); });
+    std::transform(points.begin(), points.end(), points.begin(), [&t](const QPointF &point) { return t.map(point); });
 
-    return points;
+    return IsFlipped() ? Reverse(points) : points;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 auto VEllipticalArc::GetStartAngle() const -> qreal
 {
-    return QLineF(GetCenter().toQPointF(), GetP1()).angle() - GetRotationAngle();
+    return QLineF(GetCenter().toQPointF(), GetP1()).angle() - d->rotationAngle;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 auto VEllipticalArc::GetEndAngle() const -> qreal
 {
-    return QLineF(GetCenter().toQPointF(), GetP2()).angle() - GetRotationAngle();
+    return QLineF(GetCenter().toQPointF(), GetP2()).angle() - d->rotationAngle;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -530,94 +541,79 @@ auto VEllipticalArc::GetEndAngle() const -> qreal
  * @param arc2 second arc.
  * @return point cutting
  */
-auto VEllipticalArc::CutArc(const qreal &length, VEllipticalArc &arc1, VEllipticalArc &arc2,
-                            const QString &pointName) const -> QPointF
+auto VEllipticalArc::CutArc(qreal length, VEllipticalArc &arc1, VEllipticalArc &arc2, const QString &pointName) const
+    -> QPointF
 {
-    //Always need return two arcs, so we must correct wrong length.
-    qreal len = 0;
     const qreal fullLength = GetLength();
 
-    if (fullLength <= minLength)
+    if (qFuzzyIsNull(fullLength) || (qFuzzyIsNull(d->radius1) && qFuzzyIsNull(d->radius2)))
     {
-        arc1 = VEllipticalArc();
-        arc2 = VEllipticalArc();
-
-        const QString errorMsg = QObject::tr("Unable to cut curve '%1'. The curve is too short.").arg(name());
-        VAbstractApplication::VApp()->IsPedantic() ? throw VException(errorMsg) :
-            qWarning() << VAbstractApplication::warningMessageSignature + errorMsg;
-
-        return {};
+        arc1 = *this;
+        arc2 = *this;
+        return GetCenter().toQPointF();
     }
 
-    const qreal maxLength = fullLength - minLength;
-
-    if (length < minLength)
+    if (qFuzzyIsNull(length) || qFuzzyIsNull(length + fullLength))
     {
-        len = minLength;
+        arc1 = VEllipticalArc(GetCenter(), d->radius1, d->radius2, d->formulaRadius1, d->formulaRadius2,
+                              GetStartAngle(), GetFormulaF1(), GetStartAngle(), GetFormulaF1(), d->rotationAngle,
+                              GetFormulaRotationAngle(), getIdObject(), getMode());
+        arc1.SetApproximationScale(GetApproximationScale());
+        arc1.SetFlipped(IsFlipped());
+        arc1.SetAllowEmpty(true);
 
-        QString errorMsg;
-        if (not pointName.isEmpty())
-        {
-            errorMsg = QObject::tr("Curve '%1'. Length of a cut segment (%2) is too small. Optimize it to minimal "
-                                   "value.").arg(name(), pointName);
-        }
-        else
-        {
-            errorMsg = QObject::tr("Curve '%1'. Length of a cut segment is too small. Optimize it to minimal value.")
-                           .arg(name());
-        }
-        VAbstractApplication::VApp()->IsPedantic() ? throw VException(errorMsg) :
-            qWarning() << VAbstractApplication::warningMessageSignature + errorMsg;
-    }
-    else if (length > maxLength)
-    {
-        len = maxLength;
+        arc2 = *this;
 
-        QString errorMsg;
-        if (not pointName.isEmpty())
-        {
-            errorMsg = QObject::tr("Curve '%1'. Length of a cut segment (%2) is too big. Optimize it to maximal value.")
-                           .arg(name(), pointName);
-        }
-        else
-        {
-            errorMsg = QObject::tr("Curve '%1'. Length of a cut segment is too big. Optimize it to maximal value.")
-                           .arg(name());
-        }
-        VAbstractApplication::VApp()->IsPedantic() ? throw VException(errorMsg) :
-            qWarning() << VAbstractApplication::warningMessageSignature + errorMsg;
+        return GetP1();
     }
-    else
+
+    if (VFuzzyComparePossibleNulls(length, fullLength))
     {
-        len = length;
+        arc1 = *this;
+
+        arc2 = VEllipticalArc(GetCenter(), d->radius1, d->radius2, d->formulaRadius1, d->formulaRadius2, GetEndAngle(),
+                              GetFormulaF2(), GetEndAngle(), GetFormulaF2(), d->rotationAngle,
+                              GetFormulaRotationAngle(), getIdObject(), getMode());
+        arc2.SetApproximationScale(GetApproximationScale());
+        arc2.SetFlipped(IsFlipped());
+        arc2.SetAllowEmpty(true);
+
+        return GetP2();
     }
 
+    qreal const len = CorrectCutLength(length, fullLength, pointName);
+
     // the first arc has given length and startAngle just like in the origin arc
-    arc1 = VEllipticalArc (len, QString().setNum(length), GetCenter(), d->radius1, d->radius2,
-                          d->formulaRadius1, d->formulaRadius2, GetStartAngle(), GetFormulaF1(), d->rotationAngle,
+    arc1 = VEllipticalArc(len, QString().setNum(length), GetCenter(), d->radius1, d->radius2, d->formulaRadius1,
+                          d->formulaRadius2, GetStartAngle(), GetFormulaF1(), d->rotationAngle,
                           GetFormulaRotationAngle(), getIdObject(), getMode());
+    arc1.SetApproximationScale(GetApproximationScale());
+    arc1.SetFlipped(IsFlipped());
+
     // the second arc has startAngle just like endAngle of the first arc
     // and it has endAngle just like endAngle of the origin arc
-    arc2 = VEllipticalArc (GetCenter(), d->radius1, d->radius2, d->formulaRadius1, d->formulaRadius2,
-                          arc1.GetEndAngle(), arc1.GetFormulaF2(), GetEndAngle(), GetFormulaF2(), d->rotationAngle,
+    arc2 = VEllipticalArc(GetCenter(), d->radius1, d->radius2, d->formulaRadius1, d->formulaRadius2, arc1.GetEndAngle(),
+                          arc1.GetFormulaF2(), GetEndAngle(), GetFormulaF2(), d->rotationAngle,
                           GetFormulaRotationAngle(), getIdObject(), getMode());
-    return arc1.GetP1();
+    arc2.SetApproximationScale(GetApproximationScale());
+    arc2.SetFlipped(IsFlipped());
+
+    return arc1.GetP2();
 }
 
-
 //---------------------------------------------------------------------------------------------------------------------
-auto VEllipticalArc::CutArc(const qreal &length, const QString &pointName) const -> QPointF
+auto VEllipticalArc::CutArc(qreal length, const QString &pointName) const -> QPointF
 {
     VEllipticalArc arc1;
     VEllipticalArc arc2;
-    return this->CutArc(length, arc1, arc2, pointName);
+    return CutArc(length, arc1, arc2, pointName);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void VEllipticalArc::CreateName()
 {
-    QString name = ELARC_ + QStringLiteral("%1").arg(this->GetCenter().name());
-    const QString nameStr = QStringLiteral("_%1");
+    QString name = ELARC_ + this->GetCenter().name();
+    const auto nameStr = QStringLiteral("_%1");
 
     if (getMode() == Draw::Modeling && getIdObject() != NULL_ID)
     {
@@ -653,12 +649,12 @@ void VEllipticalArc::CreateAlias()
 void VEllipticalArc::FindF2(qreal length)
 {
     qreal gap = 180;
-    if (length < 0)
+    if (length < 0 || d->radius1 < 0 || d->radius2 < 0)
     {
         SetFlipped(true);
         gap = -gap;
     }
-    while (length > MaxLength())
+    else if (qAbs(length) > qAbs(MaxLength()))
     {
         length = MaxLength();
     }
@@ -666,7 +662,8 @@ void VEllipticalArc::FindF2(qreal length)
     // We need to calculate the second angle
     // first approximation of angle between start and end angles
 
-    QLineF radius1(GetCenter().x(), GetCenter().y(), GetCenter().x() + d->radius1, GetCenter().y());
+    VPointF const center = GetCenter();
+    QLineF radius1(center.x(), center.y(), center.x() + qAbs(d->radius1), center.y());
     radius1.setAngle(GetStartAngle());
     radius1.setAngle(radius1.angle() + gap);
     qreal endAngle = radius1.angle();
@@ -676,16 +673,17 @@ void VEllipticalArc::FindF2(qreal length)
 
     qreal lenBez = GetLength(); // first approximation of length
 
-    const qreal eps = ToPixel(0.001, Unit::Mm);
+    Q_RELAXED_CONSTEXPR qreal eps = ToPixel(0.001, Unit::Mm);
 
     while (qAbs(lenBez - length) > eps)
     {
-        gap = gap/2;
-        if (gap < 0.0001)
+        gap = gap / 2;
+        if (qAbs(gap) < 0.0001)
         {
             break;
         }
-        if (lenBez > length)
+
+        if (qAbs(lenBez) > qAbs(length))
         { // we selected too big end angle
             radius1.setAngle(endAngle - qAbs(gap));
         }
@@ -698,21 +696,26 @@ void VEllipticalArc::FindF2(qreal length)
         SetFormulaF2(QString::number(endAngle), endAngle);
         lenBez = GetLength();
     }
-    SetFormulaLength(QString::number(VAbstractValApplication::VApp()->fromPixel(lenBez)));
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 auto VEllipticalArc::MaxLength() const -> qreal
 {
-    const qreal h = qPow(d->radius1 - d->radius2, 2) / qPow(d->radius1 + d->radius2, 2);
-    const qreal ellipseLength = M_PI * (d->radius1 + d->radius2) * (1+3*h/(10+qSqrt(4-3*h)));
+    const qreal h = qPow(qAbs(d->radius1) - qAbs(d->radius2), 2) / qPow(qAbs(d->radius1) + qAbs(d->radius2), 2);
+    qreal ellipseLength = M_PI * (qAbs(d->radius1) + qAbs(d->radius2)) * (1 + 3 * h / (10 + qSqrt(4 - 3 * h)));
+
+    if (d->radius1 < 0 || d->radius2 < 0)
+    {
+        ellipseLength *= -1;
+    }
+
     return ellipseLength;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 auto VEllipticalArc::GetP(qreal angle) const -> QPointF
 {
-    if (qFuzzyIsNull(GetRadius1()) && qFuzzyIsNull(GetRadius2()))
+    if (qFuzzyIsNull(d->radius1) && qFuzzyIsNull(d->radius2))
     {
         return GetCenter().toQPointF();
     }
@@ -720,21 +723,21 @@ auto VEllipticalArc::GetP(qreal angle) const -> QPointF
     QLineF line(0, 0, 100, 0);
     line.setAngle(angle);
 
-    const qreal a = not qFuzzyIsNull(GetRadius1()) ? line.p2().x() / GetRadius1() : 0;
-    const qreal b = not qFuzzyIsNull(GetRadius2()) ? line.p2().y() / GetRadius2() : 0;
-    const qreal k = qSqrt(a*a + b*b);
+    const qreal a = not qFuzzyIsNull(d->radius1) ? line.p2().x() / qAbs(d->radius1) : 0;
+    const qreal b = not qFuzzyIsNull(d->radius2) ? line.p2().y() / qAbs(d->radius2) : 0;
+    const qreal k = qSqrt(a * a + b * b);
 
     if (qFuzzyIsNull(k))
     {
         return GetCenter().toQPointF();
     }
 
-    QPointF p(line.p2().x() / k, line.p2().y() / k);
+    QPointF const p(line.p2().x() / k, line.p2().y() / k);
 
     QLineF line2(QPointF(), p);
     SCASSERT(VFuzzyComparePossibleNulls(line2.angle(), line.angle()))
 
-    line2.setAngle(line2.angle() + GetRotationAngle());
+    line2.setAngle(line2.angle() + d->rotationAngle);
     return line2.p2() + VAbstractArc::GetCenter().toQPointF();
 }
 
@@ -746,8 +749,8 @@ auto VEllipticalArc::ArcPoints(QVector<QPointF> points) const -> QVector<QPointF
         return points;
     }
 
-    QPointF center = VAbstractArc::GetCenter().toQPointF();
-    qreal radius = qMax(d->radius1, d->radius2) * 2;
+    QPointF const center = VAbstractArc::GetCenter().toQPointF();
+    qreal const radius = qMax(qAbs(d->radius1), qAbs(d->radius2)) * 2;
 
     QLineF start(center.x(), center.y(), center.x() + radius, center.y());
     start.setAngle(VAbstractArc::GetStartAngle());
@@ -755,31 +758,22 @@ auto VEllipticalArc::ArcPoints(QVector<QPointF> points) const -> QVector<QPointF
     QLineF end(center.x(), center.y(), center.x() + radius, center.y());
     end.setAngle(VAbstractArc::GetEndAngle());
 
-    auto IsBoundedIntersection = [](QLineF::IntersectType type, QPointF p, const QLineF &segment1,
-                                    const QLineF &segment2)
-    {
-        return type == QLineF::BoundedIntersection ||
-               (type == QLineF::UnboundedIntersection &&
-                VGObject::IsPointOnLineSegment (p, segment1.p1(), segment2.p1()) &&
-                VGObject::IsPointOnLineSegment (p, segment2.p1(), segment2.p2()));
-    };
-
     bool begin = true;
 
     if (start.angle() >= end.angle())
     {
-        for (int i=0; i < points.size()-1; ++i)
+        for (int i = 0; i < points.size() - 1; ++i)
         {
-            QLineF edge(points.at(i), points.at(i+1));
+            QLineF const edge(points.at(i), points.at(i + 1));
 
             QPointF p;
-            QLineF::IntersectType type = Intersects(start, edge, &p);
+            QLineF::IntersectType const type = start.intersects(edge, &p);
 
             // QLineF::intersects not always accurate on edge cases
             if (IsBoundedIntersection(type, p, edge, start))
             {
-                QVector<QPointF> head = points.mid(0, i+1);
-                QVector<QPointF> tail = points.mid(i+1, -1);
+                QVector<QPointF> const head = points.mid(0, i + 1);
+                QVector<QPointF> tail = points.mid(i + 1, -1);
 
                 tail = JoinVectors({p}, tail);
                 points = JoinVectors(tail, head);
@@ -799,14 +793,14 @@ auto VEllipticalArc::ArcPoints(QVector<QPointF> points) const -> QVector<QPointF
     QVector<QPointF> arc;
     arc.reserve(points.size());
 
-    for (int i=0; i < points.size()-1; ++i)
+    for (int i = 0; i < points.size() - 1; ++i)
     {
-        QLineF edge(points.at(i), points.at(i+1));
+        QLineF const edge(points.at(i), points.at(i + 1));
 
         if (begin)
         {
             QPointF p;
-            QLineF::IntersectType type = Intersects(start, edge, &p);
+            QLineF::IntersectType const type = start.intersects(edge, &p);
 
             // QLineF::intersects not always accurate on edge cases
             if (IsBoundedIntersection(type, p, edge, start))
@@ -818,7 +812,7 @@ auto VEllipticalArc::ArcPoints(QVector<QPointF> points) const -> QVector<QPointF
         else
         {
             QPointF p;
-            QLineF::IntersectType type = Intersects(end, edge, &p);
+            QLineF::IntersectType const type = end.intersects(edge, &p);
 
             // QLineF::intersects not always accurate on edge cases
             if (IsBoundedIntersection(type, p, edge, end))
@@ -840,6 +834,78 @@ auto VEllipticalArc::ArcPoints(QVector<QPointF> points) const -> QVector<QPointF
     return arc;
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+auto VEllipticalArc::CorrectCutLength(qreal length, qreal fullLength, const QString &pointName) const -> qreal
+{
+    qreal len = length;
+
+    auto TooSmallWarning = [this, pointName]()
+    {
+        QString errorMsg;
+        if (not pointName.isEmpty())
+        {
+            errorMsg = QObject::tr("Curve '%1'. Length of a cut segment (%2) is too small. Optimize it to minimal "
+                                   "value.")
+                           .arg(name(), pointName);
+        }
+        else
+        {
+            errorMsg = QObject::tr("Curve '%1'. Length of a cut segment is too small. Optimize it to minimal value.")
+                           .arg(name());
+        }
+        VAbstractApplication::VApp()->IsPedantic()
+            ? throw VException(errorMsg)
+            : qWarning() << VAbstractApplication::warningMessageSignature + errorMsg;
+    };
+
+    auto TooBigWarning = [this, pointName]()
+    {
+        QString errorMsg;
+        if (not pointName.isEmpty())
+        {
+            errorMsg = QObject::tr("Curve '%1'. Length of a cut segment (%2) is too big. Optimize it to maximal value.")
+                           .arg(name(), pointName);
+        }
+        else
+        {
+            errorMsg = QObject::tr("Curve '%1'. Length of a cut segment is too big. Optimize it to maximal value.")
+                           .arg(name());
+        }
+        VAbstractApplication::VApp()->IsPedantic()
+            ? throw VException(errorMsg)
+            : qWarning() << VAbstractApplication::warningMessageSignature + errorMsg;
+    };
+
+    if (!IsFlipped())
+    {
+        if (length < 0)
+        {
+            len = 0;
+            TooSmallWarning();
+        }
+        else if (length > fullLength)
+        {
+            len = fullLength;
+            TooBigWarning();
+        }
+    }
+    else
+    {
+        if (length < fullLength)
+        {
+            len = fullLength;
+            TooSmallWarning();
+        }
+        else if (length > 0)
+        {
+            len = 0;
+            TooBigWarning();
+        }
+    }
+
+    return len;
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 /**
  * @brief GetFormulaRadius1 return formula for major radius.
