@@ -29,11 +29,11 @@
 #ifndef VGEOMETRYDEF_H
 #define VGEOMETRYDEF_H
 
-#include <QVector>
 #include <QPolygonF>
 #include <QTransform>
+#include <QVector>
 
-#include "../ifc/ifcdef.h"
+#include "../vmisc/def.h"
 
 enum class GOType : qint8
 {
@@ -47,12 +47,16 @@ enum class GOType : qint8
     PlaceLabel,
     Unknown
 };
-enum class SplinePointPosition : qint8 { FirstPoint, LastPoint };
+enum class SplinePointPosition : qint8
+{
+    FirstPoint,
+    LastPoint
+};
 
 // Keep synchronized with XSD schema
-enum class PlaceLabelType :  quint8
+enum class PlaceLabelType : quint8
 {
-    Segment= 0,
+    Segment = 0,
     Rectangle = 1,
     Cross = 2,
     Tshaped = 3,
@@ -64,52 +68,45 @@ enum class PlaceLabelType :  quint8
     Circle = 9
 };
 
-typedef QVector<QPolygonF> PlaceLabelImg;
-
-struct VLayoutPlaceLabel
-{
-    QPointF        center{};
-    PlaceLabelType type{PlaceLabelType::Button};
-    PlaceLabelImg  shape{};
-    QTransform     rotationMatrix{};
-    QRectF         box{};
-
-    friend QDataStream& operator<<(QDataStream& dataStream, const VLayoutPlaceLabel& data);
-    friend QDataStream& operator>>(QDataStream& dataStream, VLayoutPlaceLabel& data);
-private:
-    static const quint32 streamHeader;
-    static const quint16 classVersion;
-};
-Q_DECLARE_METATYPE(VLayoutPlaceLabel)
-
 struct VLayoutPassmark
 {
-    QVector<QLineF>  lines{};
+    QVector<QLineF> lines{};
     PassmarkLineType type{PassmarkLineType::OneLine};
-    QLineF           baseLine{};
-    bool             isBuiltIn{false};
+    QLineF baseLine{};
+    bool isBuiltIn{false};
+    bool isClockwiseOpening{false};
+    QString label{};
+
+    friend auto operator<<(QDataStream &dataStream, const VLayoutPassmark &data) -> QDataStream &;
+    friend auto operator>>(QDataStream &dataStream, VLayoutPassmark &data) -> QDataStream &;
 
-    friend QDataStream& operator<<(QDataStream& dataStream, const VLayoutPassmark& data);
-    friend QDataStream& operator>>(QDataStream& dataStream, VLayoutPassmark& data);
 private:
     static const quint32 streamHeader;
     static const quint16 classVersion;
 };
-Q_DECLARE_METATYPE(VLayoutPassmark)
+Q_DECLARE_METATYPE(VLayoutPassmark) // NOLINT
 
 constexpr qreal accuracyPointOnLine = MmToPixel(0.1555);
 
-Q_REQUIRED_RESULT static inline bool VFuzzyComparePoints(const QPointF &p1, const QPointF &p2,
-                                                         qreal accuracy = accuracyPointOnLine);
-static inline bool VFuzzyComparePoints(const QPointF &p1, const QPointF &p2, qreal accuracy)
+Q_REQUIRED_RESULT inline auto VFuzzyComparePoints(const QPointF &p1, const QPointF &p2,
+                                                  qreal accuracy = accuracyPointOnLine) -> bool;
+inline auto VFuzzyComparePoints(const QPointF &p1, const QPointF &p2, qreal accuracy) -> bool
 {
     return QLineF(p1, p2).length() <= accuracy;
 }
 
-Q_REQUIRED_RESULT static inline bool VFuzzyOnAxis(qreal v1, qreal v2, qreal accuracy = accuracyPointOnLine);
-static inline bool VFuzzyOnAxis(qreal v1, qreal v2, qreal accuracy)
+Q_REQUIRED_RESULT inline auto VFuzzyOnAxis(qreal v1, qreal v2, qreal accuracy = accuracyPointOnLine) -> bool;
+inline auto VFuzzyOnAxis(qreal v1, qreal v2, qreal accuracy) -> bool
 {
     return qAbs(v1 - v2) <= accuracy;
 }
 
+template <class T> inline void Swap(T &line)
+{
+    line = T(line.p2(), line.p1());
+}
+
+auto SingleParallelPoint(const QPointF &p1, const QPointF &p2, qreal angle, qreal width) -> QPointF;
+auto SimpleParallelLine(const QPointF &p1, const QPointF &p2, qreal width) -> QLineF;
+
 #endif // VGEOMETRYDEF_H
