@@ -35,13 +35,13 @@
 #include <QPointF>
 #include <QRectF>
 #include <QTransform>
+#include <QtMath>
 
-#include "../vmisc/def.h"
-#include "../vmisc/vmath.h"
 #include "../vmisc/compatibility.h"
-#include "../ifc/ifcdef.h"
-#include "vgobject_p.h"
+#include "../vmisc/def.h"
 #include "../vmisc/vabstractapplication.h"
+#include "vgeometrydef.h"
+#include "vgobject_p.h"
 
 namespace
 {
@@ -51,7 +51,7 @@ namespace
  * This is actually the same as the area of the triangle defined by the three points, multiplied by 2.
  * @return 2 * triangleArea(a,b,c)
  */
-double PerpDotProduct(const QPointF &p1, const QPointF &p2, const QPointF &t)
+auto PerpDotProduct(const QPointF &p1, const QPointF &p2, const QPointF &t) -> double
 {
     return (p1.x() - t.x()) * (p2.y() - t.y()) - (p1.y() - t.y()) * (p2.x() - t.x());
 }
@@ -66,10 +66,10 @@ double PerpDotProduct(const QPointF &p1, const QPointF &p2, const QPointF &t)
  * line e1=(p1, p2), e.g. the minimal area calucalted with PerpDotProduc() if point still not on the line. This distance
  * is controled by variable accuracyPointOnLine
  */
-double GetEpsilon(const QPointF &t, QPointF p1, QPointF p2, qreal accuracy)
+auto GetEpsilon(const QPointF &t, QPointF p1, QPointF p2, qreal accuracy) -> double
 {
     QLineF edge1(p1, p2);
-    QLineF edge2(p1, t);
+    QLineF const edge2(p1, t);
     if (edge2.length() > edge1.length())
     {
         edge1.setLength(edge2.length());
@@ -83,15 +83,16 @@ double GetEpsilon(const QPointF &t, QPointF p1, QPointF p2, qreal accuracy)
 
     return qAbs(PerpDotProduct(p1, p2, line.p2()));
 }
-}
+} // namespace
 
 //---------------------------------------------------------------------------------------------------------------------
 /**
  * @brief VGObject default constructor.
  */
 VGObject::VGObject()
-    :d(new VGObjectData)
-{}
+  : d(new VGObjectData)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
 /**
@@ -101,17 +102,12 @@ VGObject::VGObject()
  * @param mode mode creation. Used in modeling mode.
  */
 VGObject::VGObject(const GOType &type, const quint32 &idObject, const Draw &mode)
-    :d(new VGObjectData(type, idObject, mode))
-{}
+  : d(new VGObjectData(type, idObject, mode))
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-/**
- * @brief VGObject copy constructor.
- * @param obj object.
- */
-VGObject::VGObject(const VGObject &obj)
-    :d (obj.d)
-{}
+COPY_CONSTRUCTOR_IMPL(VGObject)
 
 //---------------------------------------------------------------------------------------------------------------------
 /**
@@ -119,9 +115,9 @@ VGObject::VGObject(const VGObject &obj)
  * @param obj object
  * @return object
  */
-VGObject &VGObject::operator=(const VGObject &obj)
+auto VGObject::operator=(const VGObject &obj) -> VGObject &
 {
-    if ( &obj == this )
+    if (&obj == this)
     {
         return *this;
     }
@@ -129,30 +125,28 @@ VGObject &VGObject::operator=(const VGObject &obj)
     return *this;
 }
 
-#ifdef Q_COMPILER_RVALUE_REFS
 //---------------------------------------------------------------------------------------------------------------------
-VGObject::VGObject(VGObject &&obj) Q_DECL_NOTHROW
-    :d (std::move(obj.d))
-{}
+VGObject::VGObject(VGObject &&obj) noexcept
+  : d(std::move(obj.d))
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-VGObject &VGObject::operator=(VGObject &&obj) Q_DECL_NOTHROW
+auto VGObject::operator=(VGObject &&obj) noexcept -> VGObject &
 {
     std::swap(d, obj.d);
     return *this;
 }
-#endif
 
 //---------------------------------------------------------------------------------------------------------------------
-VGObject::~VGObject()
-{}
+VGObject::~VGObject() = default;
 
 //---------------------------------------------------------------------------------------------------------------------
 /**
  * @brief getIdObject return parent id.
  * @return parent id or 0 if object don't have parent.
  */
-quint32 VGObject::getIdObject() const
+auto VGObject::getIdObject() const -> quint32
 {
     return d->idObject;
 }
@@ -172,7 +166,7 @@ void VGObject::setIdObject(const quint32 &value)
  * @brief name return name graphical object.
  * @return name
  */
-QString VGObject::name() const
+auto VGObject::name() const -> QString
 {
     return d->_name;
 }
@@ -192,7 +186,7 @@ void VGObject::setName(const QString &name)
  * @brief getMode return mode creation.
  * @return mode.
  */
-Draw VGObject::getMode() const
+auto VGObject::getMode() const -> Draw
 {
     return d->mode;
 }
@@ -212,7 +206,7 @@ void VGObject::setMode(const Draw &value)
  * @brief getType return object type.
  * @return type.
  */
-GOType VGObject::getType() const
+auto VGObject::getType() const -> GOType
 {
     return d->type;
 }
@@ -229,7 +223,7 @@ void VGObject::setType(const GOType &type)
  * @brief id return id object.
  * @return id
  */
-quint32 VGObject::id() const
+auto VGObject::id() const -> quint32
 {
     return d->_id;
 }
@@ -251,7 +245,7 @@ void VGObject::SetAlias(const QString &alias)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VGObject::GetAlias() const
+auto VGObject::GetAlias() const -> QString
 {
     return d->m_alias;
 }
@@ -263,21 +257,21 @@ void VGObject::SetAliasSuffix(const QString &aliasSuffix)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VGObject::GetAliasSuffix() const
+auto VGObject::GetAliasSuffix() const -> QString
 {
     return d->m_aliasSuffix;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VGObject::ObjectName() const
+auto VGObject::ObjectName() const -> QString
 {
     const QString alias = VAbstractApplication::VApp()->TrVars()->VarToUser(d->m_alias);
     const QString name = VAbstractApplication::VApp()->TrVars()->VarToUser(d->_name);
-    return not d->m_alias.isEmpty() ? QString("%1 (%2)").arg(alias, name) : name;
+    return not d->m_alias.isEmpty() ? QStringLiteral("%1 (%2)").arg(alias, name) : name;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-quint32 VGObject::getIdTool() const
+auto VGObject::getIdTool() const -> quint32
 {
     if (d->mode == Draw::Calculation)
     {
@@ -285,22 +279,16 @@ quint32 VGObject::getIdTool() const
         {
             return d->idObject;
         }
-        else
-        {
-            return d->_id;
-        }
-    }
-    else
-    {
         return d->_id;
     }
+
+    return d->_id;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QJsonObject VGObject::ToJson() const
+auto VGObject::ToJson() const -> QJsonObject
 {
-    QJsonObject object
-    {
+    QJsonObject object{
         {"id", static_cast<qint64>(id())},
         {"type", static_cast<int>(getType())},
     };
@@ -309,27 +297,29 @@ QJsonObject VGObject::ToJson() const
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QLineF VGObject::BuildLine(const QPointF &p1, const qreal &length, const qreal &angle)
+auto VGObject::BuildLine(const QPointF &p1, const qreal &length, const qreal &angle) -> QLineF
 {
-    QLineF line = QLineF();
+    QLineF line;
     line.setP1(p1);
-    line.setAngle(angle);// First set angle then length. Length can have negative value.
+    line.setAngle(angle); // First set angle then length. Length can have negative value.
     line.setLength(length);
     return line;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QPointF VGObject::BuildRay(const QPointF &firstPoint, const qreal &angle, const QRectF &scRect)
+auto VGObject::BuildRay(const QPointF &firstPoint, const qreal &angle, const QRectF &scRect) -> QPointF
 {
     QRectF rect = scRect;
-    if (rect.isValid() == false)
+    if (not rect.isValid())
     {
         rect = QRectF(0, 0, 1200, 700);
     }
-    if (rect.contains(firstPoint) == false)
+
+    if (not rect.contains(firstPoint))
     {
         // If point outside of scene rect create one around point and unite two rects.
-        QRectF rectangle(firstPoint.x()-rect.width()/2, firstPoint.y()-rect.height()/2, rect.width(), rect.height());
+        QRectF const rectangle(firstPoint.x() - rect.width() / 2, firstPoint.y() - rect.height() / 2, rect.width(),
+                               rect.height());
         rect = rect.united(rectangle);
     }
     const qreal diagonal = qSqrt(pow(rect.height(), 2) + pow(rect.width(), 2));
@@ -339,22 +329,21 @@ QPointF VGObject::BuildRay(const QPointF &firstPoint, const qreal &angle, const
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QLineF VGObject::BuildAxis(const QPointF &p, const qreal &angle, const QRectF &scRect)
+auto VGObject::BuildAxis(const QPointF &p, const qreal &angle, const QRectF &scRect) -> QLineF
 {
-    const QPointF endP1 = BuildRay(p, angle+180, scRect);
+    const QPointF endP1 = BuildRay(p, angle + 180, scRect);
     const QPointF endP2 = BuildRay(p, angle, scRect);
-    return QLineF(endP1, endP2);
+    return {endP1, endP2};
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QLineF VGObject::BuildAxis(const QPointF &p1, const QPointF &p2, const QRectF &scRect)
+auto VGObject::BuildAxis(const QPointF &p1, const QPointF &p2, const QRectF &scRect) -> QLineF
 {
-    QLineF line(p1, p2);
-    return BuildAxis(p1, line.angle(), scRect);
+    return BuildAxis(p1, QLineF(p1, p2).angle(), scRect);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-int VGObject::ContactPoints(const QPointF &p, const QPointF &center, qreal radius, QPointF &p1, QPointF &p2)
+auto VGObject::ContactPoints(const QPointF &p, const QPointF &center, qreal radius, QPointF &p1, QPointF &p2) -> int
 {
     const int flag = PointInCircle(p, center, radius);
 
@@ -369,8 +358,8 @@ int VGObject::ContactPoints(const QPointF &p, const QPointF &center, qreal radiu
         return 1;
     }
 
-    const double d = QLineF (p, center).length();
-    const double k = sqrt (d * d - radius * radius);
+    const double d = QLineF(p, center).length();
+    const double k = sqrt(d * d - radius * radius);
     return IntersectionCircles(p, k, center, radius, p1, p2);
 }
 
@@ -381,79 +370,71 @@ int VGObject::ContactPoints(const QPointF &p, const QPointF &center, qreal radiu
  * @param line line.
  * @return point intersection.
  */
-QPointF VGObject::LineIntersectRect(const QRectF &rec, const QLineF &line)
+auto VGObject::LineIntersectRect(const QRectF &rec, const QLineF &line) -> QPointF
 {
-    qreal x1, y1, x2, y2;
+    qreal x1 = 0;
+    qreal y1 = 0;
+    qreal x2 = 0;
+    qreal y2 = 0;
     rec.getCoords(&x1, &y1, &x2, &y2);
-    QPointF point;
-    QLineF::IntersectType type = Intersects(line, QLineF(QPointF(x1, y1), QPointF(x1, y2)), &point);
 
-    if ( type == QLineF::BoundedIntersection )
+    // Define lines representing each side of the rectangle
+    QLineF const topLine(QPointF(x1, y1), QPointF(x2, y1));
+    QLineF const bottomLine(QPointF(x1, y2), QPointF(x2, y2));
+    QLineF const leftLine(QPointF(x1, y1), QPointF(x1, y2));
+    QLineF const rightLine(QPointF(x2, y1), QPointF(x2, y2));
+
+    // Check intersections with each side of the rectangle
+    if (QPointF point; line.intersects(topLine, &point) == QLineF::BoundedIntersection ||
+                       line.intersects(bottomLine, &point) == QLineF::BoundedIntersection ||
+                       line.intersects(leftLine, &point) == QLineF::BoundedIntersection ||
+                       line.intersects(rightLine, &point) == QLineF::BoundedIntersection)
     {
         return point;
     }
 
-    type = Intersects(line, QLineF(QPointF(x1, y1), QPointF(x2, y1)), &point);
-
-    if ( type == QLineF::BoundedIntersection )
-    {
-        return point;
-    }
-
-    type = Intersects(line, QLineF(QPointF(x1, y2), QPointF(x2, y2)), &point);
-
-    if ( type == QLineF::BoundedIntersection )
-    {
-        return point;
-    }
-
-    type = Intersects(line, QLineF(QPointF(x2, y1), QPointF(x2, y2)), &point);
-
-    if ( type == QLineF::BoundedIntersection )
-    {
-        return point;
-    }
-    return point;
+    // Return the point (which would be (0,0) if no intersection is found)
+    return {};
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-int VGObject::IntersectionCircles(const QPointF &c1, double r1, const QPointF &c2, double r2, QPointF &p1, QPointF &p2)
+auto VGObject::IntersectionCircles(const QPointF &c1, double r1, const QPointF &c2, double r2, QPointF &p1, QPointF &p2)
+    -> int
 {
-    if (VFuzzyComparePossibleNulls(c1.x(), c2.x()) && VFuzzyComparePossibleNulls(c1.y(), c2.y())
-            && VFuzzyComparePossibleNulls(r1, r2))
+    if (VFuzzyComparePossibleNulls(c1.x(), c2.x()) && VFuzzyComparePossibleNulls(c1.y(), c2.y()) &&
+        VFuzzyComparePossibleNulls(r1, r2))
     {
-        return 3;// Circles are equal
+        return 3; // Circles are equal
     }
-    const double a = - 2.0 * (c2.x() - c1.x());
-    const double b = - 2.0 * (c2.y() - c1.y());
-    const double c = (c2.x() - c1.x())* (c2.x() - c1.x()) + (c2.y() - c1.y()) * (c2.y() - c1.y()) + r1 * r1 - r2 * r2;
+    const double a = -2.0 * (c2.x() - c1.x());
+    const double b = -2.0 * (c2.y() - c1.y());
+    const double c = (c2.x() - c1.x()) * (c2.x() - c1.x()) + (c2.y() - c1.y()) * (c2.y() - c1.y()) + r1 * r1 - r2 * r2;
 
-    const double x0 = -a*c/(a*a+b*b);
-    const double y0 = -b*c/(a*a+b*b);
+    const double x0 = -a * c / (a * a + b * b);
+    const double y0 = -b * c / (a * a + b * b);
 
-    if (c*c > r1*r1*(a*a+b*b))
+    if (c * c > r1 * r1 * (a * a + b * b))
     {
         return 0;
     }
-    else if (VFuzzyComparePossibleNulls(c*c, r1*r1*(a*a+b*b)))
+
+    if (VFuzzyComparePossibleNulls(c * c, r1 * r1 * (a * a + b * b)))
     {
-        p1 = QPointF(x0 + c1.x(), y0  + c1.y());
+        p1 = QPointF(x0 + c1.x(), y0 + c1.y());
         return 1;
     }
-    else
-    {
-        const double d = r1*r1 - c*c/(a*a+b*b);
-        const double mult = sqrt (d / (a*a+b*b));
 
-        const double ax = x0 + b * mult;
-        const double bx = x0 - b * mult;
-        const double ay = y0 - a * mult;
-        const double by = y0 + a * mult;
+    const double d = r1 * r1 - c * c / (a * a + b * b);
+    const double mult = sqrt(d / (a * a + b * b));
 
-        p1 = QPointF(ax + c1.x(), ay + c1.y());
-        p2 = QPointF(bx + c1.x(), by + c1.y());
-        return 2;
-    }
+    const double ax = x0 + b * mult;
+    const double bx = x0 - b * mult;
+    const double ay = y0 - a * mult;
+    const double by = y0 + a * mult;
+
+    p1 = QPointF(ax + c1.x(), ay + c1.y());
+    p2 = QPointF(bx + c1.x(), by + c1.y());
+    return 2;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -466,7 +447,8 @@ int VGObject::IntersectionCircles(const QPointF &c1, double r1, const QPointF &c
  * @param p2 second intersection point.
  * @return 0 - intersection doesn't exist, 1 - one intersection point, 2 - two intersection points.
  */
-qint32 VGObject::LineIntersectCircle(const QPointF &center, qreal radius, const QLineF &line, QPointF &p1, QPointF &p2)
+auto VGObject::LineIntersectCircle(const QPointF &center, qreal radius, const QLineF &line, QPointF &p1, QPointF &p2)
+    -> qint32
 {
     // Fix for issue #485. https://bitbucket.org/dismine/valentina/issues/485/error-when-drawing-a-curved-path
     if (qFuzzyIsNull(line.length()))
@@ -474,14 +456,16 @@ qint32 VGObject::LineIntersectCircle(const QPointF &center, qreal radius, const
         return 0;
     }
 
-    //coefficient for equation of segment
-    qreal a = 0, b = 0, c = 0;
+    // coefficient for equation of segment
+    qreal a = 0;
+    qreal b = 0;
+    qreal c = 0;
     LineCoefficients(line, &a, &b, &c);
     // projection center of circle on to line
-    const QPointF p = ClosestPoint (line, center);
+    const QPointF p = ClosestPoint(line, center);
     // how many solutions?
     qint32 flag = 0;
-    const qreal d = QLineF (center, p).length();
+    const qreal d = QLineF(center, p).length();
     if (VFuzzyComparePossibleNulls(d, radius))
     {
         flag = 1;
@@ -498,11 +482,11 @@ qint32 VGObject::LineIntersectCircle(const QPointF &center, qreal radius, const
         }
     }
     // find distance from projection to points of intersection
-    const qreal k = qSqrt (qAbs(radius * radius - d * d));
-    const qreal t = QLineF (QPointF (0, 0), QPointF (b, - a)).length();
+    const qreal k = qSqrt(qAbs(radius * radius - d * d));
+    const qreal t = QLineF(QPointF(0, 0), QPointF(b, -a)).length();
     // add to projection a vectors aimed to points of intersection
-    p1 = addVector (p, QPointF (0, 0), QPointF (- b, a), k / t);
-    p2 = addVector (p, QPointF (0, 0), QPointF (b, - a), k / t);
+    p1 = addVector(p, QPointF(0, 0), QPointF(-b, a), k / t);
+    p2 = addVector(p, QPointF(0, 0), QPointF(b, -a), k / t);
     return flag;
 }
 
@@ -512,30 +496,30 @@ qint32 VGObject::LineIntersectCircle(const QPointF &center, qreal radius, const
  * @param line line.
  * @return point on line or extended line if origin size too small.
  */
-QPointF VGObject::ClosestPoint(const QLineF &line, const QPointF &point)
+auto VGObject::ClosestPoint(const QLineF &line, const QPointF &point) -> QPointF
 {
-    qreal a = 0, b = 0, c = 0;
+    qreal a = 0;
+    qreal b = 0;
+    qreal c = 0;
     LineCoefficients(line, &a, &b, &c);
-    qreal x = point.x() + a;
-    qreal y = b + point.y();
-    QLineF lin (point, QPointF(x, y));
+    qreal const x = point.x() + a;
+    qreal const y = b + point.y();
+    QLineF const lin(point, QPointF(x, y));
     QPointF p;
-    QLineF::IntersectType intersect = Intersects(line, lin, &p);
+    QLineF::IntersectType const intersect = line.intersects(lin, &p);
 
     if (intersect == QLineF::UnboundedIntersection || intersect == QLineF::BoundedIntersection)
     {
         return p;
     }
-    else
-    {
-        return point;
-    }
+
+    return point;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QPointF VGObject::addVector(const QPointF &p, const QPointF &p1, const QPointF &p2, qreal k)
+auto VGObject::addVector(const QPointF &p, const QPointF &p1, const QPointF &p2, qreal k) -> QPointF
 {
-    return QPointF (p.x() + (p2.x() - p1.x()) * k, p.y() + (p2.y() - p1.y()) * k);
+    return {p.x() + (p2.x() - p1.x()) * k, p.y() + (p2.y() - p1.y()) * k};
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -548,11 +532,11 @@ QPointF VGObject::addVector(const QPointF &p, const QPointF &p1, const QPointF &
  */
 void VGObject::LineCoefficients(const QLineF &line, qreal *a, qreal *b, qreal *c)
 {
-    //coefficient for equation of segment
-    QPointF p1 = line.p1();
+    // coefficient for equation of segment
+    QPointF const p1 = line.p1();
     *a = line.p2().y() - p1.y();
     *b = p1.x() - line.p2().x();
-    *c = - *a * p1.x() - *b * p1.y();
+    *c = -*a * p1.x() - *b * p1.y();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -565,13 +549,13 @@ auto VGObject::IsPointOnLineSegment(const QPointF &t, const QPointF &p1, const Q
     // Here we deal with more like cigar shape.
 
     // Front and rear easy to check
-    if (VFuzzyComparePoints(p1, t) || VFuzzyComparePoints(p2, t))
+    if (VFuzzyComparePoints(p1, t, accuracy) || VFuzzyComparePoints(p2, t, accuracy))
     {
         return true;
     }
 
     // Check if we have a segment. On previous step we already confirmed that we don't have intersection
-    if (VFuzzyComparePoints(p1, p2))
+    if (VFuzzyComparePoints(p1, p2, accuracy))
     {
         return false;
     }
@@ -580,33 +564,33 @@ auto VGObject::IsPointOnLineSegment(const QPointF &t, const QPointF &p1, const Q
     // should be good enough for us.
     const qreal degrees = 90;
     QLineF edge(p1, p2);
-    edge.setAngle(edge.angle()+degrees);
+    edge.setAngle(edge.angle() + degrees);
     edge.setLength(accuracy);
-    QPointF sP1 = edge.p2();
+    QPointF const sP1 = edge.p2();
 
     edge = QLineF(p2, p1);
-    edge.setAngle(edge.angle()-degrees);
+    edge.setAngle(edge.angle() - degrees);
     edge.setLength(accuracy);
-    QPointF sP2 = edge.p2();
+    QPointF const sP2 = edge.p2();
 
     edge = QLineF(p2, p1);
-    edge.setAngle(edge.angle()+degrees);
+    edge.setAngle(edge.angle() + degrees);
     edge.setLength(accuracy);
-    QPointF sP3 = edge.p2();
+    QPointF const sP3 = edge.p2();
 
     edge = QLineF(p1, p2);
-    edge.setAngle(edge.angle()-degrees);
+    edge.setAngle(edge.angle() - degrees);
     edge.setLength(accuracy);
-    QPointF sP4 = edge.p2();
+    QPointF const sP4 = edge.p2();
 
-    QVector<QPointF> shape{sP1, sP2, sP3, sP4, sP1};
+    QVector<QPointF> const shape{sP1, sP2, sP3, sP4, sP1};
 
-    for (int i=0; i < shape.size()-1; ++i)
+    for (int i = 0; i < shape.size() - 1; ++i)
     {
         const QPointF &sp1 = shape.at(i);
-        const QPointF &sp2 = shape.at(i+1);
+        const QPointF &sp2 = shape.at(i + 1);
         // This formula helps to determine on which side of a vector lies a point.
-        qreal position = (sp2.x()-sp1.x())*(t.y()-sp1.y())-(sp2.y()-sp1.y())*(t.x()-sp1.x());
+        qreal const position = (sp2.x() - sp1.x()) * (t.y() - sp1.y()) - (sp2.y() - sp1.y()) * (t.x() - sp1.x());
         if (position < 0)
         {
             return false;
@@ -617,34 +601,30 @@ auto VGObject::IsPointOnLineSegment(const QPointF &t, const QPointF &p1, const Q
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VGObject::IsLineSegmentOnLineSegment(const QLineF &seg1, const QLineF &seg2, qreal accuracy)
+auto VGObject::IsLineSegmentOnLineSegment(const QLineF &seg1, const QLineF &seg2, qreal accuracy) -> bool
 {
     const bool onLine = IsPointOnLineviaPDP(seg1.p1(), seg2.p1(), seg2.p2(), accuracy) &&
-            IsPointOnLineviaPDP(seg1.p2(), seg2.p1(), seg2.p2(), accuracy);
+                        IsPointOnLineviaPDP(seg1.p2(), seg2.p1(), seg2.p2(), accuracy);
     if (onLine)
     {
         return IsPointOnLineSegment(seg1.p1(), seg2.p1(), seg2.p2(), accuracy) ||
-                IsPointOnLineSegment(seg1.p2(), seg2.p1(), seg2.p2(), accuracy) ||
-                IsPointOnLineSegment(seg2.p1(), seg1.p1(), seg1.p2(), accuracy) ||
-                IsPointOnLineSegment(seg2.p2(), seg1.p1(), seg1.p2(), accuracy);
-    }
-    else
-    {
-        return onLine;
+               IsPointOnLineSegment(seg1.p2(), seg2.p1(), seg2.p2(), accuracy) ||
+               IsPointOnLineSegment(seg2.p1(), seg1.p1(), seg1.p2(), accuracy) ||
+               IsPointOnLineSegment(seg2.p2(), seg1.p1(), seg1.p2(), accuracy);
     }
+
+    return onLine;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QPointF VGObject::CorrectDistortion(const QPointF &t, const QPointF &p1, const QPointF &p2)
+auto VGObject::CorrectDistortion(const QPointF &t, const QPointF &p1, const QPointF &p2) -> QPointF
 {
     if (not VFuzzyComparePoints(p1, p2))
     {
         return VGObject::ClosestPoint(QLineF(p1, p2), t);
     }
-    else
-    {
-        return t;
-    }
+
+    return t;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -654,8 +634,13 @@ QPointF VGObject::CorrectDistortion(const QPointF &t, const QPointF &p1, const Q
  *  The pdp is zero only if the t lies on the line e1 = vector from p1 to p2.
  * @return true if point is on line
  */
-bool VGObject::IsPointOnLineviaPDP(const QPointF &t, const QPointF &p1, const QPointF &p2, qreal accuracy)
+auto VGObject::IsPointOnLineviaPDP(const QPointF &t, const QPointF &p1, const QPointF &p2, qreal accuracy) -> bool
 {
+    if (p1 == p2)
+    {
+        return VFuzzyComparePoints(p1, t, accuracy);
+    }
+
     const double p = qAbs(PerpDotProduct(p1, p2, t));
     const double e = GetEpsilon(t, p1, p2, accuracy);
 
@@ -664,17 +649,19 @@ bool VGObject::IsPointOnLineviaPDP(const QPointF &t, const QPointF &p1, const QP
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-int VGObject::PointInCircle(const QPointF &p, const QPointF &center, qreal radius)
+auto VGObject::PointInCircle(const QPointF &p, const QPointF &center, qreal radius) -> int
 {
-    const double d = QLineF (p, center).length();
+    const double d = QLineF(p, center).length();
     if (VFuzzyComparePossibleNulls(radius, d))
     {
         return 1; // on circle
     }
+
     if (radius > d)
     {
         return 0; // outside circle
     }
+
     return 2; // inside circle
 }
 
@@ -686,21 +673,21 @@ int VGObject::PointInCircle(const QPointF &p, const QPointF &center, qreal radiu
  * @return length length of contour.
  */
 // cppcheck-suppress unusedFunction
-int VGObject::GetLengthContour(const QVector<QPointF> &contour, const QVector<QPointF> &newPoints)
+auto VGObject::GetLengthContour(const QVector<QPointF> &contour, const QVector<QPointF> &newPoints) -> int
 {
     qreal length = 0;
     QVector<QPointF> points;
     points << contour << newPoints;
-    for (qint32 i = 0; i < points.size()-1; ++i)
+    for (qint32 i = 0; i < points.size() - 1; ++i)
     {
-        QLineF line(points.at(i), points.at(i+1));
+        QLineF const line(points.at(i), points.at(i + 1));
         length += line.length();
     }
     return qFloor(length);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QTransform VGObject::FlippingMatrix(const QLineF &axis)
+auto VGObject::FlippingMatrix(const QLineF &axis) -> QTransform
 {
     QTransform matrix;
 
@@ -709,7 +696,7 @@ QTransform VGObject::FlippingMatrix(const QLineF &axis)
         return matrix;
     }
 
-    const QLineF axisOX = QLineF(axis.x2(), axis.y2(), axis.x2() + 100, axis.y2()); // Ox axis
+    const auto axisOX = QLineF(axis.x2(), axis.y2(), axis.x2() + 100, axis.y2()); // Ox axis
 
     const qreal angle = axis.angleTo(axisOX);
     const QPointF p2 = axis.p2();
@@ -722,13 +709,13 @@ QTransform VGObject::FlippingMatrix(const QLineF &axis)
 
     m.reset();
     m.translate(p2.x(), p2.y());
-    m.scale(m.m11(), m.m22()*-1);
+    m.scale(m.m11(), m.m22() * -1);
     m.translate(-p2.x(), -p2.y());
     matrix *= m;
 
     m.reset();
     m.translate(p2.x(), p2.y());
-    m.rotate(-(360-angle));
+    m.rotate(-(360 - angle));
     m.translate(-p2.x(), -p2.y());
     matrix *= m;
 
