@@ -36,26 +36,35 @@
 #include <QMessageBox>
 #include <QStyle>
 #include <QtConcurrent>
+#include <memory>
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
-#include "../vmisc/backport/qoverload.h"
-#endif // QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
-
-#include "../vmisc/def.h"
-#include "../vmisc/vabstractapplication.h"
-#include "../vpropertyexplorer/checkablemessagebox.h"
 #include "../ifc/exception/vexception.h"
 #include "../ifc/xml/vwatermarkconverter.h"
 #include "../vformat/vwatermark.h"
+#include "../vmisc/def.h"
+#include "../vmisc/vabstractapplication.h"
+#include "../vpropertyexplorer/checkablemessagebox.h"
+#include "../vwidgets/vmousewheelwidgetadjustmentguard.h"
+
+#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
+#include "../vmisc/compatibility.h"
+#endif
+
+using namespace Qt::Literals::StringLiterals;
 
 //---------------------------------------------------------------------------------------------------------------------
-WatermarkWindow::WatermarkWindow(const QString &patternPath, QWidget *parent) :
-    QMainWindow(parent),
+WatermarkWindow::WatermarkWindow(const QString &patternPath, QWidget *parent)
+  : QMainWindow(parent),
     ui(new Ui::WatermarkWindow),
-    m_patternPath(patternPath),
-    m_okPathColor()
+    m_patternPath(patternPath)
 {
     ui->setupUi(this);
+
+    // Prevent stealing focus when scrolling
+    VMouseWheelWidgetAdjustmentGuard::InstallEventFilter(ui->spinBoxOpacity);
+    VMouseWheelWidgetAdjustmentGuard::InstallEventFilter(ui->spinBoxTextRotation);
+    VMouseWheelWidgetAdjustmentGuard::InstallEventFilter(ui->spinBoxImageRotation);
+
     m_okPathColor = ui->lineEditPath->palette().color(ui->lineEditPath->foregroundRole());
 
     VAbstractApplication::VApp()->Settings()->GetOsSeparator() ? setLocale(QLocale()) : setLocale(QLocale::c());
@@ -66,54 +75,54 @@ WatermarkWindow::WatermarkWindow(const QString &patternPath, QWidget *parent) :
 
     ToolBarStyle(ui->toolBar);
 
-    connect(ui->spinBoxOpacity, QOverload<int>::of(&QSpinBox::valueChanged),this,
-            [this](){WatermarkChangesWereSaved(false);});
+    connect(ui->spinBoxOpacity, QOverload<int>::of(&QSpinBox::valueChanged), this,
+            [this]() { WatermarkChangesWereSaved(false); });
 
-    connect(ui->lineEditText, &QLineEdit::textChanged, this, [this]()
-    {
-        WatermarkChangesWereSaved(false);
-    });
+    connect(ui->lineEditText, &QLineEdit::textChanged, this, [this]() { WatermarkChangesWereSaved(false); });
 
     connect(ui->spinBoxTextRotation, QOverload<int>::of(&QSpinBox::valueChanged), this,
-            [this](){WatermarkChangesWereSaved(false);});
+            [this]() { WatermarkChangesWereSaved(false); });
 
-    connect(ui->toolButtonFont, &QToolButton::clicked, this, [this]()
-    {
-        bool ok;
-        QFont font = QFontDialog::getFont(&ok, m_data.font, this);
-        if (ok)
-        {
-            WatermarkChangesWereSaved(false);
-            m_data.font = font;
-            ui->lineEditFontSample->setFont(font);
-        }
-    });
+    connect(ui->toolButtonFont, &QToolButton::clicked, this,
+            [this]()
+            {
+                bool ok;
+                QFont const font = QFontDialog::getFont(&ok, m_data.font, this);
+                if (ok)
+                {
+                    WatermarkChangesWereSaved(false);
+                    m_data.font = font;
+                    ui->lineEditFontSample->setFont(font);
+                }
+            });
 
-    connect(ui->lineEditPath, &QLineEdit::textChanged, this, [this]()
-    {
-        WatermarkChangesWereSaved(false);
-        ValidatePath();
-    });
+    connect(ui->lineEditPath, &QLineEdit::textChanged, this,
+            [this]()
+            {
+                WatermarkChangesWereSaved(false);
+                ValidatePath();
+            });
 
-    connect(ui->pushButtonBrowse, &QPushButton::clicked, this, [this]()
-    {
-        const QString filter = tr("Images") + QLatin1String(" (*.png *.jpg *.jpeg *.bmp)");
-        const QString fileName = QFileDialog::getOpenFileName(this, tr("Watermark image"), QString(), filter,
-                                                              nullptr,
-                                                              VAbstractApplication::VApp()->NativeFileDialog());
-        if (not fileName.isEmpty())
-        {
-            ui->lineEditPath->setText(fileName);
-        }
-    });
+    connect(ui->pushButtonBrowse, &QPushButton::clicked, this,
+            [this]()
+            {
+                const QString filter = tr("Images") + " (*.png *.jpg *.jpeg *.bmp)"_L1;
+                const QString fileName =
+                    QFileDialog::getOpenFileName(this, tr("Watermark image"), QString(), filter, nullptr,
+                                                 VAbstractApplication::VApp()->NativeFileDialog());
+                if (not fileName.isEmpty())
+                {
+                    ui->lineEditPath->setText(fileName);
+                }
+            });
 
-    connect(ui->spinBoxImageRotation, QOverload<int>::of(&QSpinBox::valueChanged),this,
-            [this](){WatermarkChangesWereSaved(false);});
+    connect(ui->spinBoxImageRotation, QOverload<int>::of(&QSpinBox::valueChanged), this,
+            [this]() { WatermarkChangesWereSaved(false); });
 
-    connect(ui->checkBoxGrayColor, &QCheckBox::stateChanged, this, [this](){WatermarkChangesWereSaved(false);});
+    connect(ui->checkBoxGrayColor, &QCheckBox::stateChanged, this, [this]() { WatermarkChangesWereSaved(false); });
 
-    connect(ui->groupBoxWatermarkText, &QGroupBox::toggled, this, [this](){WatermarkChangesWereSaved(false);});
-    connect(ui->groupBoxWatermarkImage, &QGroupBox::toggled, this, [this](){WatermarkChangesWereSaved(false);});
+    connect(ui->groupBoxWatermarkText, &QGroupBox::toggled, this, [this]() { WatermarkChangesWereSaved(false); });
+    connect(ui->groupBoxWatermarkImage, &QGroupBox::toggled, this, [this]() { WatermarkChangesWereSaved(false); });
 
     ui->pushButtonColorPicker->insertColor(Qt::black, tr("Black", "color"));
     ui->pushButtonColorPicker->insertColor(Qt::red, tr("Red", "color"));
@@ -132,13 +141,14 @@ WatermarkWindow::WatermarkWindow(const QString &patternPath, QWidget *parent) :
     ui->pushButtonColorPicker->insertColor(Qt::darkGray, tr("Dark gray", "color"));
     ui->pushButtonColorPicker->insertColor(Qt::lightGray, tr("Light gray", "color"));
 
-    QVector<QColor> colors = VAbstractApplication::VApp()->Settings()->GetWatermarkCustomColors();
-    for (const auto& color : colors)
+    QVector<QColor> const colors = VAbstractApplication::VApp()->Settings()->GetWatermarkCustomColors();
+    for (const auto &color : colors)
     {
         ui->pushButtonColorPicker->insertColor(color);
     }
 
-    connect(ui->pushButtonColorPicker, &QtColorPicker::colorChanged, this, [this](){WatermarkChangesWereSaved(false);});
+    connect(ui->pushButtonColorPicker, &QtColorPicker::colorChanged, this,
+            [this]() { WatermarkChangesWereSaved(false); });
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -148,13 +158,13 @@ WatermarkWindow::~WatermarkWindow()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString WatermarkWindow::CurrentFile() const
+auto WatermarkWindow::CurrentFile() const -> QString
 {
     return m_curFile;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool WatermarkWindow::Open(QString path)
+auto WatermarkWindow::Open(QString path) -> bool
 {
     qDebug("Loading new watermark file %s.", qUtf8Printable(path));
 
@@ -168,13 +178,14 @@ bool WatermarkWindow::Open(QString path)
     // Convert to absolute path if need
     path = AbsoluteMPath(m_patternPath, path);
 
-    QFuture<VWatermarkConverter *> futureConverter = QtConcurrent::run([path]()
-    {
-        QScopedPointer<VWatermarkConverter> converter(new VWatermarkConverter(path));
-        return converter.take();
-    });
+    QFuture<VWatermarkConverter *> const futureConverter = QtConcurrent::run(
+        [path]()
+        {
+            std::unique_ptr<VWatermarkConverter> converter(new VWatermarkConverter(path));
+            return converter.release();
+        });
 
-    //We have unsaved changes or load more then one file per time
+    // We have unsaved changes or load more then one file per time
     if (OpenNewEditor(path))
     {
         return false;
@@ -199,15 +210,15 @@ bool WatermarkWindow::Open(QString path)
 
     try
     {
-        QScopedPointer<VWatermarkConverter> converter(futureConverter.result());
+        QScopedPointer<VWatermarkConverter> const converter(futureConverter.result());
         m_curFileFormatVersion = converter->GetCurrentFormatVersion();
         m_curFileFormatVersionStr = converter->GetFormatVersionStr();
         doc.setXMLContent(converter->Convert());
     }
     catch (VException &e)
     {
-        qCritical("%s\n\n%s\n\n%s", qUtf8Printable(tr("File error.")),
-                   qUtf8Printable(e.ErrorMessage()), qUtf8Printable(e.DetailedInformation()));
+        qCritical("%s\n\n%s\n\n%s", qUtf8Printable(tr("File error.")), qUtf8Printable(e.ErrorMessage()),
+                  qUtf8Printable(e.DetailedInformation()));
         Clear();
         return false;
     }
@@ -223,15 +234,6 @@ bool WatermarkWindow::Open(QString path)
 //---------------------------------------------------------------------------------------------------------------------
 void WatermarkWindow::closeEvent(QCloseEvent *event)
 {
-#if defined(Q_OS_MAC) && QT_VERSION < QT_VERSION_CHECK(5, 11, 1)
-    // Workaround for Qt bug https://bugreports.qt.io/browse/QTBUG-43344
-    static int numCalled = 0;
-    if (numCalled++ >= 1)
-    {
-        return;
-    }
-#endif
-
     if (MaybeSave())
     {
         event->accept();
@@ -260,8 +262,8 @@ void WatermarkWindow::changeEvent(QEvent *event)
 //---------------------------------------------------------------------------------------------------------------------
 void WatermarkWindow::showEvent(QShowEvent *event)
 {
-    QMainWindow::showEvent( event );
-    if ( event->spontaneous() )
+    QMainWindow::showEvent(event);
+    if (event->spontaneous())
     {
         return;
     }
@@ -272,13 +274,13 @@ void WatermarkWindow::showEvent(QShowEvent *event)
     }
     // do your init stuff here
 
-    QSize sz = VAbstractApplication::VApp()->Settings()->GetWatermarkEditorSize();
-    if (sz.isEmpty() == false)
+    QSize const sz = VAbstractApplication::VApp()->Settings()->GetWatermarkEditorSize();
+    if (not sz.isEmpty())
     {
         resize(sz);
     }
 
-    m_isInitialized = true;//first show windows are held
+    m_isInitialized = true; // first show windows are held
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -301,9 +303,9 @@ void WatermarkWindow::on_actionNew_triggered()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool WatermarkWindow::on_actionSaveAs_triggered()
+auto WatermarkWindow::on_actionSaveAs_triggered() -> bool
 {
-    QString filters(tr("Watermark files") + QLatin1String("(*.vwm)"));
+    QString const filters(tr("Watermark files") + "(*.vwm)"_L1);
     QString dir;
     if (m_curFile.isEmpty())
     {
@@ -314,8 +316,7 @@ bool WatermarkWindow::on_actionSaveAs_triggered()
         dir = QFileInfo(m_curFile).absolutePath();
     }
 
-    QString fileName = QFileDialog::getSaveFileName(this, tr("Save as"),
-                                                    dir + QLatin1String("/") + tr("watermark") + QLatin1String(".vwm"),
+    QString fileName = QFileDialog::getSaveFileName(this, tr("Save as"), dir + '/'_L1 + tr("watermark") + ".vwm"_L1,
                                                     filters, nullptr, VAbstractApplication::VApp()->NativeFileDialog());
 
     if (fileName.isEmpty())
@@ -323,16 +324,16 @@ bool WatermarkWindow::on_actionSaveAs_triggered()
         return false;
     }
 
-    QFileInfo f( fileName );
-    if (f.suffix().isEmpty() && f.suffix() != QLatin1String("vwm"))
+    QFileInfo const f(fileName);
+    if (f.suffix().isEmpty() && f.suffix() != "vwm"_L1)
     {
-        fileName += QLatin1String(".vwm");
+        fileName += ".vwm"_L1;
     }
 
     if (f.exists() && m_curFile != fileName)
     {
         // Temporary try to lock the file before saving
-        VLockGuard<char> tmp(fileName);
+        VLockGuard<char> const tmp(fileName);
         if (not tmp.IsLocked())
         {
             qCritical("%s", qUtf8Printable(tr("Failed to lock. This file already opened in another window.")));
@@ -377,92 +378,90 @@ bool WatermarkWindow::on_actionSaveAs_triggered()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool WatermarkWindow::on_actionSave_triggered()
+auto WatermarkWindow::on_actionSave_triggered() -> bool
 {
     if (m_curFile.isEmpty())
     {
         return on_actionSaveAs_triggered();
     }
-    else
+
+    if (m_curFileFormatVersion < VWatermarkConverter::WatermarkMaxVer &&
+        not ContinueFormatRewrite(m_curFileFormatVersionStr, VWatermarkConverter::WatermarkMaxVerStr))
     {
-        if (m_curFileFormatVersion < VWatermarkConverter::WatermarkMaxVer
-                && not ContinueFormatRewrite(m_curFileFormatVersionStr, VWatermarkConverter::WatermarkMaxVerStr))
+        return false;
+    }
+
+    // #ifdef Q_OS_WIN32
+    //         qt_ntfs_permission_lookup++; // turn checking on
+    // #endif /*Q_OS_WIN32*/
+    const bool isFileWritable = QFileInfo(m_curFile).isWritable();
+    // #ifdef Q_OS_WIN32
+    //         qt_ntfs_permission_lookup--; // turn it off again
+    // #endif /*Q_OS_WIN32*/
+    if (not isFileWritable)
+    {
+        QMessageBox messageBox(this);
+        messageBox.setIcon(QMessageBox::Question);
+        messageBox.setText(tr("The document has no write permissions."));
+        messageBox.setInformativeText(tr("Do you want to change the permissions?"));
+        messageBox.setStandardButtons(QMessageBox::Yes | QMessageBox::Cancel);
+        messageBox.setDefaultButton(QMessageBox::Yes);
+
+        if (messageBox.exec() == QMessageBox::Yes)
         {
-            return false;
-        }
+            // #ifdef Q_OS_WIN32
+            //                 qt_ntfs_permission_lookup++; // turn checking on
+            // #endif /*Q_OS_WIN32*/
+            bool const changed =
+                QFile::setPermissions(m_curFile, QFileInfo(m_curFile).permissions() | QFileDevice::WriteUser);
+            // #ifdef Q_OS_WIN32
+            //                 qt_ntfs_permission_lookup--; // turn it off again
+            // #endif /*Q_OS_WIN32*/
 
-//#ifdef Q_OS_WIN32
-//        qt_ntfs_permission_lookup++; // turn checking on
-//#endif /*Q_OS_WIN32*/
-        const bool isFileWritable = QFileInfo(m_curFile).isWritable();
-//#ifdef Q_OS_WIN32
-//        qt_ntfs_permission_lookup--; // turn it off again
-//#endif /*Q_OS_WIN32*/
-        if (not isFileWritable)
-        {
-            QMessageBox messageBox(this);
-            messageBox.setIcon(QMessageBox::Question);
-            messageBox.setText(tr("The document has no write permissions."));
-            messageBox.setInformativeText(tr("Do you want to change the permissions?"));
-            messageBox.setStandardButtons(QMessageBox::Yes | QMessageBox::Cancel);
-            messageBox.setDefaultButton(QMessageBox::Yes);
-
-            if (messageBox.exec() == QMessageBox::Yes)
-            {
-//#ifdef Q_OS_WIN32
-//                qt_ntfs_permission_lookup++; // turn checking on
-//#endif /*Q_OS_WIN32*/
-                bool changed = QFile::setPermissions(m_curFile,
-                                                     QFileInfo(m_curFile).permissions() | QFileDevice::WriteUser);
-//#ifdef Q_OS_WIN32
-//                qt_ntfs_permission_lookup--; // turn it off again
-//#endif /*Q_OS_WIN32*/
-
-                if (not changed)
-                {
-                    QMessageBox messageBoxWarning(this);
-                    messageBoxWarning.setIcon(QMessageBox::Warning);
-                    messageBoxWarning.setText(tr("Cannot set permissions for %1 to writable.").arg(m_curFile));
-                    messageBoxWarning.setInformativeText(tr("Could not save the file."));
-                    messageBoxWarning.setDefaultButton(QMessageBox::Ok);
-                    messageBoxWarning.setStandardButtons(QMessageBox::Ok);
-                    messageBoxWarning.exec();
-                    return false;
-                }
-            }
-            else
+            if (not changed)
             {
+                QMessageBox messageBoxWarning(this);
+                messageBoxWarning.setIcon(QMessageBox::Warning);
+                messageBoxWarning.setText(tr("Cannot set permissions for %1 to writable.").arg(m_curFile));
+                messageBoxWarning.setInformativeText(tr("Could not save the file."));
+                messageBoxWarning.setDefaultButton(QMessageBox::Ok);
+                messageBoxWarning.setStandardButtons(QMessageBox::Ok);
+                messageBoxWarning.exec();
                 return false;
             }
         }
-
-        QString error;
-        bool result = SaveWatermark(m_curFile, error);
-        if (result)
-        {
-            m_curFileFormatVersion = VWatermarkConverter::WatermarkMaxVer;
-            m_curFileFormatVersionStr = VWatermarkConverter::WatermarkMaxVerStr;
-        }
         else
         {
-            QMessageBox messageBox(this);
-            messageBox.setIcon(QMessageBox::Warning);
-            messageBox.setText(tr("Could not save the file"));
-            messageBox.setDefaultButton(QMessageBox::Ok);
-            messageBox.setDetailedText(error);
-            messageBox.setStandardButtons(QMessageBox::Ok);
-            messageBox.exec();
+            return false;
         }
-        return result;
     }
+
+    QString error;
+    bool const result = SaveWatermark(m_curFile, error);
+    if (result)
+    {
+        m_curFileFormatVersion = VWatermarkConverter::WatermarkMaxVer;
+        m_curFileFormatVersionStr = VWatermarkConverter::WatermarkMaxVerStr;
+    }
+    else
+    {
+        QMessageBox messageBox(this);
+        messageBox.setIcon(QMessageBox::Warning);
+        messageBox.setText(tr("Could not save the file"));
+        messageBox.setDefaultButton(QMessageBox::Ok);
+        messageBox.setDetailedText(error);
+        messageBox.setStandardButtons(QMessageBox::Ok);
+        messageBox.exec();
+    }
+    return result;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void WatermarkWindow::on_actionOpen_triggered()
 {
     qDebug("Openning new watermark file.");
-    const QString filter(tr("Watermark files") + QLatin1String(" (*.vwm)"));
-    QString dir = QDir::homePath();
+    const QString filter(tr("Watermark files") + " (*.vwm)"_L1);
+    QString const dir = QDir::homePath();
     qDebug("Run QFileDialog::getOpenFileName: dir = %s.", qUtf8Printable(dir));
     const QString filePath = QFileDialog::getOpenFileName(this, tr("Open file"), dir, filter, nullptr,
                                                           VAbstractApplication::VApp()->NativeFileDialog());
@@ -487,26 +486,32 @@ void WatermarkWindow::WatermarkChangesWereSaved(bool saved)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool WatermarkWindow::MaybeSave()
+auto WatermarkWindow::MaybeSave() -> bool
 {
     if (this->isWindowModified())
     {
-        QScopedPointer<QMessageBox> messageBox(new QMessageBox(tr("Unsaved changes"),
-                                                               tr("The watermark has been modified.\n"
-                                                                  "Do you want to save your changes?"),
-                                                               QMessageBox::Warning, QMessageBox::Yes, QMessageBox::No,
-                                                               QMessageBox::Cancel, this, Qt::Sheet));
+        QScopedPointer<QMessageBox> const messageBox(
+            new QMessageBox(QMessageBox::Warning, tr("Unsaved changes"),
+                            tr("The watermark has been modified. Do you want to save your changes?"),
+                            QMessageBox::Yes | QMessageBox::No | QMessageBox::Cancel, this, Qt::Sheet));
 
         messageBox->setDefaultButton(QMessageBox::Yes);
         messageBox->setEscapeButton(QMessageBox::Cancel);
 
-        messageBox->setButtonText(QMessageBox::Yes, m_curFile.isEmpty() ? tr("Save") : tr("Save as"));
-        messageBox->setButtonText(QMessageBox::No, tr("Don't Save"));
+        if (QAbstractButton *button = messageBox->button(QMessageBox::Yes))
+        {
+            button->setText(m_curFile.isEmpty() ? tr("Save") : tr("Save as"));
+        }
+
+        if (QAbstractButton *button = messageBox->button(QMessageBox::No))
+        {
+            button->setText(tr("Don't Save"));
+        }
 
         messageBox->setWindowModality(Qt::ApplicationModal);
-        const auto ret = static_cast<QMessageBox::StandardButton>(messageBox->exec());
+        messageBox->setFixedSize(300, 85);
 
-        switch (ret)
+        switch (static_cast<QMessageBox::StandardButton>(messageBox->exec()))
         {
             case QMessageBox::Yes:
                 return m_curFile.isEmpty() ? on_actionSaveAs_triggered() : on_actionSave_triggered();
@@ -527,13 +532,13 @@ void WatermarkWindow::UpdateWindowTitle()
     bool isFileWritable = true;
     if (not m_curFile.isEmpty())
     {
-//#ifdef Q_OS_WIN32
-//        qt_ntfs_permission_lookup++; // turn checking on
-//#endif /*Q_OS_WIN32*/
+        // #ifdef Q_OS_WIN32
+        //         qt_ntfs_permission_lookup++; // turn checking on
+        // #endif /*Q_OS_WIN32*/
         isFileWritable = QFileInfo(m_curFile).isWritable();
-//#ifdef Q_OS_WIN32
-//        qt_ntfs_permission_lookup--; // turn it off again
-//#endif /*Q_OS_WIN32*/
+        // #ifdef Q_OS_WIN32
+        //         qt_ntfs_permission_lookup--; // turn it off again
+        // #endif /*Q_OS_WIN32*/
     }
 
     if (isFileWritable)
@@ -542,13 +547,12 @@ void WatermarkWindow::UpdateWindowTitle()
     }
     else
     {
-        setWindowTitle(GetWatermarkFileName() + QLatin1String(" (") + tr("read only") + QLatin1String(")"));
+        setWindowTitle(GetWatermarkFileName() + " ("_L1 + tr("read only") + ')'_L1);
     }
     setWindowFilePath(m_curFile);
 
 #if defined(Q_OS_MAC)
-    static QIcon fileIcon = QIcon(QCoreApplication::applicationDirPath() +
-                                  QLatin1String("/../Resources/Valentina.icns"));
+    static auto fileIcon = QIcon(QCoreApplication::applicationDirPath() + "/../Resources/Valentina.icns"_L1);
     QIcon icon;
     if (not m_curFile.isEmpty())
     {
@@ -568,23 +572,24 @@ void WatermarkWindow::UpdateWindowTitle()
         }
     }
     setWindowIcon(icon);
-#endif //defined(Q_OS_MAC)
+#endif // defined(Q_OS_MAC)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString WatermarkWindow::GetWatermarkFileName()
+auto WatermarkWindow::GetWatermarkFileName() -> QString
 {
     QString shownName = tr("untitled.vwm");
-    if(not m_curFile.isEmpty())
+    if (not m_curFile.isEmpty())
     {
-        shownName = StrippedName(m_curFile);
+        shownName = QFileInfo(m_curFile).fileName();
     }
-    shownName += QLatin1String("[*]");
+    shownName += "[*]"_L1;
     return shownName;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool WatermarkWindow::ContinueFormatRewrite(const QString &currentFormatVersion, const QString &maxFormatVersion)
+auto WatermarkWindow::ContinueFormatRewrite(const QString &currentFormatVersion, const QString &maxFormatVersion)
+    -> bool
 {
     if (VAbstractApplication::VApp()->Settings()->GetConfirmFormatRewriting())
     {
@@ -593,22 +598,20 @@ bool WatermarkWindow::ContinueFormatRewrite(const QString &currentFormatVersion,
         msgBox.setText(tr("This file is using previous format version v%1. The current is v%2. "
                           "Saving the file with this app version will update the format version for this "
                           "file. This may prevent you from be able to open the file with older app versions. "
-                          "Do you really want to continue?").arg(currentFormatVersion, maxFormatVersion));
+                          "Do you really want to continue?")
+                           .arg(currentFormatVersion, maxFormatVersion));
         msgBox.setStandardButtons(QDialogButtonBox::Yes | QDialogButtonBox::No);
         msgBox.setDefaultButton(QDialogButtonBox::No);
         msgBox.setIconPixmap(QApplication::style()->standardIcon(QStyle::SP_MessageBoxQuestion).pixmap(32, 32));
 
-        int dialogResult = msgBox.exec();
+        int const dialogResult = msgBox.exec();
 
         if (dialogResult == QDialog::Accepted)
         {
             VAbstractApplication::VApp()->Settings()->SetConfirmFormatRewriting(not msgBox.isChecked());
             return true;
         }
-        else
-        {
-            return false;
-        }
+        return false;
     }
     return true;
 }
@@ -650,7 +653,7 @@ void WatermarkWindow::SetCurrentFile(const QString &fileName)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool WatermarkWindow::OpenNewEditor(const QString &fileName) const
+auto WatermarkWindow::OpenNewEditor(const QString &fileName) -> bool
 {
     if (this->isWindowModified() || not m_curFile.isEmpty())
     {
@@ -671,30 +674,30 @@ void WatermarkWindow::Clear()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool WatermarkWindow::IgnoreLocking(int error, const QString &path)
+auto WatermarkWindow::IgnoreLocking(int error, const QString &path) -> bool
 {
     QMessageBox::StandardButton answer = QMessageBox::Abort;
-    switch(error)
+    switch (error)
     {
         case QLockFile::LockFailedError:
             answer = QMessageBox::warning(this, tr("Locking file"),
-                                           tr("This file already opened in another window. Ignore if you want "
-                                              "to continue (not recommended, can cause a data corruption)."),
-                                           QMessageBox::Abort|QMessageBox::Ignore, QMessageBox::Abort);
+                                          tr("This file already opened in another window. Ignore if you want "
+                                             "to continue (not recommended, can cause a data corruption)."),
+                                          QMessageBox::Abort | QMessageBox::Ignore, QMessageBox::Abort);
             break;
         case QLockFile::PermissionError:
             answer = QMessageBox::question(this, tr("Locking file"),
                                            tr("The lock file could not be created, for lack of permissions. "
                                               "Ignore if you want to continue (not recommended, can cause "
                                               "a data corruption)."),
-                                           QMessageBox::Abort|QMessageBox::Ignore, QMessageBox::Abort);
+                                           QMessageBox::Abort | QMessageBox::Ignore, QMessageBox::Abort);
             break;
         case QLockFile::UnknownError:
             answer = QMessageBox::question(this, tr("Locking file"),
                                            tr("Unknown error happened, for instance a full partition prevented "
                                               "writing out the lock file. Ignore if you want to continue (not "
                                               "recommended, can cause a data corruption)."),
-                                           QMessageBox::Abort|QMessageBox::Ignore, QMessageBox::Abort);
+                                           QMessageBox::Abort | QMessageBox::Ignore, QMessageBox::Abort);
             break;
         default:
             answer = QMessageBox::Abort;
