@@ -44,26 +44,26 @@ class WatermarkWindow : public QMainWindow
 
 public:
     explicit WatermarkWindow(const QString &patternPath, QWidget *parent = nullptr);
-    ~WatermarkWindow();
+    ~WatermarkWindow() override;
 
-    QString CurrentFile() const;
+    auto CurrentFile() const -> QString;
 
-    bool Open(QString path);
+    auto Open(QString path) -> bool;
 
 signals:
     void New();
-    void OpenAnother(const QString &fileName) const;
+    void OpenAnother(const QString &fileName);
 
 protected:
-    virtual void closeEvent(QCloseEvent *event) override;
-    virtual void changeEvent(QEvent* event) override;
-    virtual void showEvent(QShowEvent *event) override;
-    virtual void resizeEvent(QResizeEvent *event) override;
+    void closeEvent(QCloseEvent *event) override;
+    void changeEvent(QEvent *event) override;
+    void showEvent(QShowEvent *event) override;
+    void resizeEvent(QResizeEvent *event) override;
 
 private slots:
     void on_actionNew_triggered();
-    bool on_actionSaveAs_triggered();
-    bool on_actionSave_triggered();
+    bool on_actionSaveAs_triggered(); // NOLINT(modernize-use-trailing-return-type)
+    bool on_actionSave_triggered();   // NOLINT(modernize-use-trailing-return-type)
     void on_actionOpen_triggered();
     void on_actionExit_triggered();
 
@@ -76,7 +76,7 @@ private:
     QString m_patternPath;
     QString m_curFile{};
     VWatermarkData m_data{};
-    QColor m_okPathColor;
+    QColor m_okPathColor{};
     bool m_isInitialized{false};
 
     unsigned m_curFileFormatVersion{0x0};
@@ -84,17 +84,17 @@ private:
 
     QSharedPointer<VLockGuard<char>> lock{};
 
-    bool MaybeSave();
+    auto MaybeSave() -> bool;
     void UpdateWindowTitle();
 
-    QString GetWatermarkFileName();
+    auto GetWatermarkFileName() -> QString;
 
-    bool ContinueFormatRewrite(const QString &currentFormatVersion, const QString &maxFormatVersion);
-    bool SaveWatermark(const QString &fileName, QString &error);
+    auto ContinueFormatRewrite(const QString &currentFormatVersion, const QString &maxFormatVersion) -> bool;
+    auto SaveWatermark(const QString &fileName, QString &error) -> bool;
     void SetCurrentFile(const QString &fileName);
-    bool OpenNewEditor(const QString &fileName = QString()) const;
+    auto OpenNewEditor(const QString &fileName = QString()) -> bool;
     void Clear();
-    bool IgnoreLocking(int error, const QString &path);
+    auto IgnoreLocking(int error, const QString &path) -> bool;
     void ShowWatermark();
     void ValidatePath();
     void ToolBarStyle(QToolBar *bar);
