@@ -28,13 +28,13 @@
 
 #include "vbank.h"
 
-#include <climits>
 #include <QLoggingCategory>
+#include <climits>
 
-#include "../vmisc/vabstractvalapplication.h"
-#include "../vmisc/compatibility.h"
-#include "vlayoutdef.h"
 #include "../ifc/exception/vexception.h"
+#include "../vmisc/compatibility.h"
+#include "../vmisc/vabstractvalapplication.h"
+#include "vlayoutdef.h"
 
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_CLANG("-Wmissing-prototypes")
@@ -47,7 +47,7 @@ QT_WARNING_POP
 // An annoying char define, from the Windows team in <rpcndr.h>
 // #define small char
 // http://stuartjames.info/Journal/c--visual-studio-2012-vs2012--win8--converting-projects-up-some-conflicts-i-found.aspx
-#if defined (Q_OS_WIN) && defined (Q_CC_MSVC)
+#if defined(Q_OS_WIN) && defined(Q_CC_MSVC)
 #pragma push_macro("small")
 #undef small
 #endif
@@ -55,11 +55,11 @@ QT_WARNING_POP
 namespace
 {
 //---------------------------------------------------------------------------------------------------------------------
-QVector<VLayoutPiece> PrepareQuantity(const QVector<VLayoutPiece> &details)
+auto PrepareQuantity(const QVector<VLayoutPiece> &details) -> QVector<VLayoutPiece>
 {
     QVector<VLayoutPiece> withQuantity;
     withQuantity.reserve(details.size());
-    for(auto &piece : details)
+    for (const auto &piece : details)
     {
         for (int i = 0; i < piece.GetQuantity(); ++i)
         {
@@ -79,10 +79,9 @@ void Insert(QMap<uint, QHash<int, qint64>> &container, uint key, int valKey, qin
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-template <typename T>
-int CountDetails(const T &container)
+template <typename T> auto CountDetails(const T &container) -> vsizetype
 {
-    int count = 0;
+    vsizetype count = 0;
     auto i = container.constBegin();
     while (i != container.constEnd())
     {
@@ -94,8 +93,8 @@ int CountDetails(const T &container)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool NotArrangedDetail(QMap<uint, QHash<int, qint64>> &container, QMap<uint, QHash<int, qint64>> &unsorted,
-                       int i)
+auto NotArrangedDetail(QMap<uint, QHash<int, qint64>> &container, QMap<uint, QHash<int, qint64>> &unsorted, int i)
+    -> bool
 {
     QMutableMapIterator<uint, QHash<int, qint64>> iterator(container);
     while (iterator.hasNext())
@@ -122,8 +121,8 @@ bool NotArrangedDetail(QMap<uint, QHash<int, qint64>> &container, QMap<uint, QHa
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool NotArrangedDetail(QMap<uint, QMultiMap<qint64, int>> &container, QMap<uint, QHash<int, qint64>> &unsorted,
-                       int i)
+auto NotArrangedDetail(QMap<uint, QMultiMap<qint64, int>> &container, QMap<uint, QHash<int, qint64>> &unsorted, int i)
+    -> bool
 {
     QMutableMapIterator<uint, QMultiMap<qint64, int>> iterator(container);
     while (iterator.hasNext())
@@ -151,7 +150,7 @@ bool NotArrangedDetail(QMap<uint, QMultiMap<qint64, int>> &container, QMap<uint,
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-int TakeFirstForPriority(const QMap<uint, QHash<int, qint64>> &container, uint priority)
+auto TakeFirstForPriority(const QMap<uint, QHash<int, qint64>> &container, uint priority) -> int
 {
     const QHash<int, qint64> priorityGroup = container.value(priority);
     if (not priorityGroup.isEmpty())
@@ -161,14 +160,15 @@ int TakeFirstForPriority(const QMap<uint, QHash<int, qint64>> &container, uint p
 
     return -1;
 }
-}
+} // namespace
 
 //---------------------------------------------------------------------------------------------------------------------
 VBank::VBank()
-{}
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-qreal VBank::GetLayoutWidth() const
+auto VBank::GetLayoutWidth() const -> qreal
 {
     return layoutWidth;
 }
@@ -181,7 +181,7 @@ void VBank::SetLayoutWidth(qreal value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VBank::GetManualPriority() const
+auto VBank::GetManualPriority() const -> bool
 {
     return m_manualPriority;
 }
@@ -193,7 +193,7 @@ void VBank::SetManualPriority(bool value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VBank::IsNestQuantity() const
+auto VBank::IsNestQuantity() const -> bool
 {
     return m_nestQuantity;
 }
@@ -212,7 +212,7 @@ void VBank::SetDetails(const QVector<VLayoutPiece> &details)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-int VBank::GetNext()
+auto VBank::GetNext() -> int
 {
     if (not prepare)
     {
@@ -246,7 +246,7 @@ int VBank::GetNext()
         }
     };
 
-    for (auto &group: groups)
+    for (auto &group : groups)
     {
         int next = -1;
         if (group != 0) // Group 0 must go last
@@ -269,7 +269,7 @@ int VBank::GetNext()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VLayoutPiece VBank::GetDetail(int i) const
+auto VBank::GetDetail(int i) const -> VLayoutPiece
 {
     if (i >= 0 && i < details.size())
     {
@@ -324,18 +324,18 @@ void VBank::NotArranged(int i)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VBank::PrepareUnsorted()
+auto VBank::PrepareUnsorted() -> bool
 {
     QSet<uint> uniqueGroup;
 
-    for (int i=0; i < details.size(); ++i)
+    for (int i = 0; i < details.size(); ++i)
     {
         const qint64 square = details.at(i).Square();
         if (square <= 0)
         {
-            qCCritical(lBank) << VAbstractValApplication::warningMessageSignature +
-                                     tr("Error of preparing data for layout: Detail '%1' square <= 0")
-                                         .arg(details.at(i).GetName());
+            qCCritical(lBank)
+                << VAbstractValApplication::warningMessageSignature +
+                       tr("Error of preparing data for layout: Detail '%1' square <= 0").arg(details.at(i).GetName());
             prepare = false;
             return prepare;
         }
@@ -354,7 +354,7 @@ bool VBank::PrepareUnsorted()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VBank::PrepareDetails()
+auto VBank::PrepareDetails(bool togetherWithNotches) -> bool
 {
     if (layoutWidth <= 0)
     {
@@ -379,20 +379,22 @@ bool VBank::PrepareDetails()
 
     diagonal = 0;
 
-    for (int i=0; i < details.size(); ++i)
+    for (auto &detail : details)
     {
-        details[i].SetLayoutWidth(layoutWidth);
-        details[i].SetLayoutAllowancePoints();
+        detail.SetLayoutWidth(layoutWidth);
+        detail.SetLayoutAllowancePoints(togetherWithNotches);
 
-        if (not details.at(i).IsLayoutAllowanceValid())
+        if (not detail.IsLayoutAllowanceValid(togetherWithNotches))
         {
             const QString errorMsg = QObject::tr("Piece '%1' has invalid layout allowance. Please, check seam allowance"
-                                                 " to check how seam allowance behave.").arg(details.at(i).GetName());
-            VAbstractApplication::VApp()->IsPedantic() ? throw VException(errorMsg) :
-                                              qWarning() << VAbstractValApplication::warningMessageSignature + errorMsg;
+                                                 " to check how seam allowance behave.")
+                                         .arg(detail.GetName());
+            VAbstractApplication::VApp()->IsPedantic()
+                ? throw VException(errorMsg)
+                : qWarning() << VAbstractValApplication::warningMessageSignature + errorMsg;
         }
 
-        const qreal d = details.at(i).Diagonal();
+        const qreal d = detail.Diagonal();
         if (d > diagonal)
         {
             diagonal = d;
@@ -424,25 +426,25 @@ void VBank::SetCaseType(Cases caseType)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-int VBank::AllDetailsCount() const
+auto VBank::AllDetailsCount() const -> vsizetype
 {
     return CountDetails(unsorted) + CountDetails(big) + CountDetails(middle) + CountDetails(small) + CountDetails(desc);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-int VBank::LeftToArrange() const
+auto VBank::LeftToArrange() const -> vsizetype
 {
     return CountDetails(big) + CountDetails(middle) + CountDetails(small) + CountDetails(desc);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-int VBank::FailedToArrange() const
+auto VBank::FailedToArrange() const -> vsizetype
 {
     return CountDetails(unsorted);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-qreal VBank::GetBiggestDiagonal() const
+auto VBank::GetBiggestDiagonal() const -> qreal
 {
     return diagonal;
 }
@@ -479,8 +481,8 @@ void VBank::PrepareThreeGroups(uint priority)
 
     SqMaxMin(sMax, sMin, priority);
 
-    const qint64 s1 = sMax - (sMax - sMin)/3;
-    const qint64 s2 = sMin + (sMax - sMin)/3;
+    const qint64 s1 = sMax - (sMax - sMin) / 3;
+    const qint64 s2 = sMin + (sMax - sMin) / 3;
 
     const QHash<int, qint64> usortedGroup = unsorted.value(priority);
     QHash<int, qint64>::const_iterator i = usortedGroup.constBegin();
@@ -511,7 +513,7 @@ void VBank::PrepareTwoGroups(uint priority)
 
     SqMaxMin(sMax, sMin, priority);
 
-    const qint64 s = (sMax + sMin)/2;
+    const qint64 s = (sMax + sMin) / 2;
     const QHash<int, qint64> usortedGroup = unsorted.value(priority);
     QHash<int, qint64>::const_iterator i = usortedGroup.constBegin();
     while (i != usortedGroup.constEnd())
@@ -545,7 +547,7 @@ void VBank::PrepareDescGroup(uint priority)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-int VBank::GetNextThreeGroups(uint priority) const
+auto VBank::GetNextThreeGroups(uint priority) const -> int
 {
     int next = TakeFirstForPriority(big, priority);
     if (next != -1)
@@ -564,7 +566,7 @@ int VBank::GetNextThreeGroups(uint priority) const
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-int VBank::GetNextTwoGroups(uint priority) const
+auto VBank::GetNextTwoGroups(uint priority) const -> int
 {
     int next = TakeFirstForPriority(big, priority);
     if (next != -1)
@@ -577,10 +579,14 @@ int VBank::GetNextTwoGroups(uint priority) const
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-int VBank::GetNextDescGroup(uint priority) const
+auto VBank::GetNextDescGroup(uint priority) const -> int
 {
     auto descGroup = desc.value(priority);
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    QMultiMapIterator<qint64, int> i(descGroup);
+#else
     QMapIterator<qint64, int> i(descGroup);
+#endif
     i.toBack();
     if (i.hasPrevious())
     {
@@ -614,7 +620,7 @@ void VBank::SqMaxMin(qint64 &sMax, qint64 &sMin, uint priority) const
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VBank::ArrangedDetail(QMap<uint, QHash<int, qint64> > &container, int i)
+auto VBank::ArrangedDetail(QMap<uint, QHash<int, qint64>> &container, int i) -> bool
 {
     QMutableMapIterator<uint, QHash<int, qint64>> iterator(container);
     while (iterator.hasNext())
@@ -640,7 +646,7 @@ bool VBank::ArrangedDetail(QMap<uint, QHash<int, qint64> > &container, int i)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VBank::ArrangedDetail(QMap<uint, QMultiMap<qint64, int>> &container, int i)
+auto VBank::ArrangedDetail(QMap<uint, QMultiMap<qint64, int>> &container, int i) -> bool
 {
     QMutableMapIterator<uint, QMultiMap<qint64, int>> iterator(container);
     while (iterator.hasNext())
@@ -668,9 +674,9 @@ bool VBank::ArrangedDetail(QMap<uint, QMultiMap<qint64, int>> &container, int i)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VBank::IsRotationNeeded() const
+auto VBank::IsRotationNeeded() const -> bool
 {
-    for(auto &piece : details)
+    for (const auto &piece : details)
     {
         if (not piece.IsGrainlineEnabled())
         {
@@ -680,7 +686,6 @@ bool VBank::IsRotationNeeded() const
     return false;
 }
 
-
-#if defined (Q_OS_WIN) && defined (Q_CC_MSVC)
+#if defined(Q_OS_WIN) && defined(Q_CC_MSVC)
 #pragma pop_macro("small")
 #endif
