@@ -29,20 +29,23 @@
 #ifndef VLAYOUTDEF_H
 #define VLAYOUTDEF_H
 
+#include <QPainterPath>
 #include <QSize>
 #include <QTransform>
-#include <QPainterPath>
-#include <ciso646>
+#include <climits>
 
-#include "../vmisc/typedef.h"
+// Header <ciso646> is removed in C++20.
+#if __cplusplus <= 201703L
+#include <ciso646> // and, not, or
+#endif
 
 enum class LayoutExportFormats : qint8
 {
     SVG = 0,
     PDF = 1,
     PNG = 2,
-    OBJ = 3,              /* Wavefront OBJ*/
-    PS  = 4,
+    OBJ = 3, /* Wavefront OBJ*/
+    PS = 4,
     EPS = 5,
     DXF_AC1006_Flat = 6,  /* R10. */
     DXF_AC1009_Flat = 7,  /* R11 & R12. */
@@ -53,29 +56,15 @@ enum class LayoutExportFormats : qint8
     DXF_AC1021_Flat = 12, /* ACAD 2007. */
     DXF_AC1024_Flat = 13, /* ACAD 2010. */
     DXF_AC1027_Flat = 14, /* ACAD 2013. */
-    DXF_AC1006_AAMA = 15, /* R10. */
-    DXF_AC1009_AAMA = 16, /* R11 & R12. */
-    DXF_AC1012_AAMA = 17, /* R13. */
-    DXF_AC1014_AAMA = 18, /* R14. */
-    DXF_AC1015_AAMA = 19, /* ACAD 2000. */
-    DXF_AC1018_AAMA = 20, /* ACAD 2004. */
-    DXF_AC1021_AAMA = 21, /* ACAD 2007. */
-    DXF_AC1024_AAMA = 22, /* ACAD 2010. */
-    DXF_AC1027_AAMA = 23, /* ACAD 2013. */
-    DXF_AC1006_ASTM = 24, /* R10. */
-    DXF_AC1009_ASTM = 25, /* R11 & R12. */
-    DXF_AC1012_ASTM = 26, /* R13. */
-    DXF_AC1014_ASTM = 27, /* R14. */
-    DXF_AC1015_ASTM = 28, /* ACAD 2000. */
-    DXF_AC1018_ASTM = 29, /* ACAD 2004. */
-    DXF_AC1021_ASTM = 30, /* ACAD 2007. */
-    DXF_AC1024_ASTM = 31, /* ACAD 2010. */
-    DXF_AC1027_ASTM = 32, /* ACAD 2013. */
+    DXF_AAMA = 16,        /* R11 & R12. */
+    DXF_ASTM = 25,        /* R11 & R12. */
     PDFTiled = 33,
-    NC = 34,              /*G-code. Reserved for future*/
-    RLD = 35,             /*Raw Layout Data*/
+    NC = 34,  /*G-code. Reserved for future*/
+    RLD = 35, /*Raw Layout Data*/
     TIF = 36,
-    COUNT                 /*Use only for validation*/
+    HPGL = 37,
+    HPGL2 = 38,
+    COUNT /*Use only for validation*/
 };
 
 enum class LayoutErrors : qint8
@@ -96,49 +85,62 @@ enum class BestFrom : qint8
 
 struct VBestSquareResData
 {
-    QSizeF        bestSize{INT_MAX, INT_MAX};
+    QSizeF bestSize{INT_MAX, INT_MAX};
     // cppcheck-suppress unusedStructMember
-    int           globalI{0}; // Edge of global contour
+    int globalI{0}; // Edge of global contour
     // cppcheck-suppress unusedStructMember
-    int           detJ{0}; // Edge of detail
-    QTransform    resMatrix{}; // Matrix for rotation and translation detail
+    int detJ{0};            // Edge of detail
+    QTransform resMatrix{}; // Matrix for rotation and translation detail
     // cppcheck-suppress unusedStructMember
-    bool          resMirror{false};
-    BestFrom      type{BestFrom::Rotation};
+    bool resMirror{false};
+    BestFrom type{BestFrom::Rotation};
     // cppcheck-suppress unusedStructMember
-    qreal         depthPosition{INT_MAX};
+    qreal depthPosition{INT_MAX};
     // cppcheck-suppress unusedStructMember
-    qreal         sidePosition{0};
+    qreal sidePosition{0};
 };
 
 struct VCachedPositions
 {
-    QRectF boundingRect{};
-    QPainterPath layoutAllowancePath{};
+    QRectF boundingRect{};              // NOLINT(misc-non-private-member-variables-in-classes)
+    QPainterPath layoutAllowancePath{}; // NOLINT(misc-non-private-member-variables-in-classes)
+
+    VCachedPositions() = default;
+    VCachedPositions(VCachedPositions &&) noexcept = default;
+    auto operator=(VCachedPositions &&) noexcept -> VCachedPositions & = default;
+    VCachedPositions(const VCachedPositions &) = default;
+    auto operator=(const VCachedPositions &) -> VCachedPositions & = default;
+    ~VCachedPositions() = default;
 };
 
-enum class Cases : qint8 { CaseThreeGroup = 0, CaseTwoGroup, CaseDesc, UnknownCase};
+enum class Cases : qint8
+{
+    CaseThreeGroup = 0,
+    CaseTwoGroup,
+    CaseDesc,
+    UnknownCase
+};
 
 /* Warning! Debugging doesn't work stable in debug mode. If you need big allocation use release mode. Or disable
  * Address Sanitizer. See page https://bitbucket.org/dismine/valentina/wiki/developers/Address_Sanitizer
  */
-//#define LAYOUT_DEBUG // Enable debug mode
+// #define LAYOUT_DEBUG // Enable debug mode
 
 // This block help rule debug mode. Don't turn all options at the same time!
 #ifdef LAYOUT_DEBUG
 // Nice looking
-#   define SHOW_VERTICES         // Show contour vertices
-#   define SHOW_DIRECTION        // Show contour direction
-#   define ARRANGED_DETAILS      // Show already arranged details
-#   define SHOW_SHEET            // Show sheet rect
-#   define SHOW_CANDIDATE        // Show each position
+#define SHOW_VERTICES    // Show contour vertices
+#define SHOW_DIRECTION   // Show contour direction
+#define ARRANGED_DETAILS // Show already arranged details
+#define SHOW_SHEET       // Show sheet rect
+#define SHOW_CANDIDATE   // Show each position
 
 // Debugging
-//#   define SHOW_ROTATION         // For each position show rotation part
-//#   define SHOW_COMBINE          // For each position show edge combine part
-//#   define SHOW_MIRROR           // For each position show mirror part
-//#   define SHOW_CANDIDATE_BEST   // For only correct positions that pass checks
-#   define SHOW_BEST             // Show only best position for workpiece
-#endif//LAYOUT_DEBUG
+// #   define SHOW_ROTATION         // For each position show rotation part
+// #   define SHOW_COMBINE          // For each position show edge combine part
+// #   define SHOW_MIRROR           // For each position show mirror part
+// #   define SHOW_CANDIDATE_BEST   // For only correct positions that pass checks
+#define SHOW_BEST // Show only best position for workpiece
+#endif            // LAYOUT_DEBUG
 
 #endif // VLAYOUTDEF_H
