@@ -27,37 +27,50 @@
  *************************************************************************/
 #include "vlayoutexporter.h"
 
+#include <QCursor>
 #include <QFileInfo>
+#include <QGraphicsItem>
 #include <QGraphicsScene>
 #include <QGuiApplication>
+#include <QImageWriter>
 #include <QPainter>
 #include <QPrinter>
 #include <QProcess>
 #include <QSvgGenerator>
 #include <QTemporaryFile>
 #include <QtDebug>
-#include <QCursor>
-#include <QGraphicsItem>
-#include <QImageWriter>
+#include <QtMath>
 
-#include "../vmisc/vmath.h"
-#include "../vmisc/defglobal.h"
-#include "../vmisc/def.h"
-#include "../vobj/vobjpaintdevice.h"
-#include "../vdxf/vdxfpaintdevice.h"
-#include "vrawlayout.h"
-#include "../vmisc/vabstractvalapplication.h"
 #include "../ifc/exception/vexception.h"
+#include "../vdxf/vdxfpaintdevice.h"
+#include "../vhpgl/vhpglpaintdevice.h"
+#include "../vmisc/def.h"
+#include "../vmisc/defglobal.h"
+#include "../vmisc/vabstractapplication.h"
+#include "../vobj/vobjpaintdevice.h"
+#include "vgraphicsfillitem.h"
 #include "vprintlayout.h"
+#include "vrawlayout.h"
+
+#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
+#include "../vmisc/compatibility.h"
+#endif
+
+using namespace Qt::Literals::StringLiterals;
 
 namespace
 {
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_CLANG("-Wunused-member-function")
+
 #ifdef Q_OS_WIN
-Q_GLOBAL_STATIC_WITH_ARGS(const QString, PDFTOPS, (QLatin1String("pdftops.exe"))) // NOLINT
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, PDFTOPS, ("pdftops.exe"_L1)) // NOLINT
 #else
-Q_GLOBAL_STATIC_WITH_ARGS(const QString, PDFTOPS, (QLatin1String("pdftops"))) // NOLINT
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, PDFTOPS, ("pdftops"_L1)) // NOLINT
 #endif
 
+QT_WARNING_POP
+
 //---------------------------------------------------------------------------------------------------------------------
 /**
  * @brief PrepareTextForDXF prepare QGraphicsSimpleTextItem items for export to flat dxf.
@@ -67,7 +80,7 @@ Q_GLOBAL_STATIC_WITH_ARGS(const QString, PDFTOPS, (QLatin1String("pdftops"))) //
  *
  * @param placeholder placeholder that will be appended to each QGraphicsSimpleTextItem item's text string.
  */
-void PrepareTextForDXF(const QString &placeholder, const QList<QGraphicsItem *> &paperItems)
+void PrepareDetailsForDXF(const QString &placeholder, const QList<QGraphicsItem *> &paperItems)
 {
     for (auto *item : paperItems)
     {
@@ -76,7 +89,7 @@ void PrepareTextForDXF(const QString &placeholder, const QList<QGraphicsItem *>
         {
             if (child->type() == QGraphicsSimpleTextItem::Type)
             {
-                if(auto *textItem = qgraphicsitem_cast<QGraphicsSimpleTextItem *>(child))
+                if (auto *textItem = qgraphicsitem_cast<QGraphicsSimpleTextItem *>(child))
                 {
                     textItem->setText(textItem->text() + placeholder);
                 }
@@ -94,7 +107,7 @@ void PrepareTextForDXF(const QString &placeholder, const QList<QGraphicsItem *>
  *
  * @param placeholder placeholder that will be removed from each QGraphicsSimpleTextItem item's text string.
  */
-void RestoreTextAfterDXF(const QString &placeholder, const QList<QGraphicsItem *> &paperItems)
+void RestoreDetailsAfterDXF(const QString &placeholder, const QList<QGraphicsItem *> &paperItems)
 {
     for (auto *item : paperItems)
     {
@@ -103,7 +116,7 @@ void RestoreTextAfterDXF(const QString &placeholder, const QList<QGraphicsItem *
         {
             if (child->type() == QGraphicsSimpleTextItem::Type)
             {
-                if(auto *textItem = qgraphicsitem_cast<QGraphicsSimpleTextItem *>(child))
+                if (auto *textItem = qgraphicsitem_cast<QGraphicsSimpleTextItem *>(child))
                 {
                     QString text = textItem->text();
                     text.replace(placeholder, QString());
@@ -113,11 +126,37 @@ void RestoreTextAfterDXF(const QString &placeholder, const QList<QGraphicsItem *
         }
     }
 }
-}  // namespace
+} // namespace
 
 //---------------------------------------------------------------------------------------------------------------------
-void VLayoutExporter::ExportToSVG(QGraphicsScene *scene) const
+auto VLayoutExporter::DxfApparelCompatibility() const -> DXFApparelCompatibility
 {
+    return m_dxfCompatibility;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VLayoutExporter::SetDxfApparelCompatibility(DXFApparelCompatibility mode)
+{
+    m_dxfCompatibility = mode;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VLayoutExporter::IsShowGrainline() const -> bool
+{
+    return m_showGrainline;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VLayoutExporter::SetShowGrainline(bool show)
+{
+    m_showGrainline = show;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VLayoutExporter::ExportToSVG(QGraphicsScene *scene, const QList<QGraphicsItem *> &details) const
+{
+    PrepareGrainlineForExport(details, m_showGrainline);
+
     QSvgGenerator generator;
     generator.setFileName(m_fileName);
 
@@ -145,11 +184,15 @@ void VLayoutExporter::ExportToSVG(QGraphicsScene *scene) const
     painter.scale(m_xScale, m_yScale);
     scene->render(&painter, m_imageRect, m_imageRect, Qt::IgnoreAspectRatio);
     painter.end();
+
+    RestoreGrainlineAfterExport(details);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VLayoutExporter::ExportToPNG(QGraphicsScene *scene) const
+void VLayoutExporter::ExportToPNG(QGraphicsScene *scene, const QList<QGraphicsItem *> &details) const
 {
+    PrepareGrainlineForExport(details, m_showGrainline);
+
     // Create the image with the exact size of the shrunk scene
     QSize drawingSize;
     drawingSize.setWidth(qFloor(m_imageRect.width() * m_xScale + m_margins.left() + m_margins.right()));
@@ -167,11 +210,15 @@ void VLayoutExporter::ExportToPNG(QGraphicsScene *scene) const
 
     scene->render(&painter, m_imageRect, m_imageRect, Qt::IgnoreAspectRatio);
     image.save(m_fileName);
+
+    RestoreGrainlineAfterExport(details);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VLayoutExporter::ExportToTIF(QGraphicsScene *scene) const
+void VLayoutExporter::ExportToTIF(QGraphicsScene *scene, const QList<QGraphicsItem *> &details) const
 {
+    PrepareGrainlineForExport(details, m_showGrainline);
+
     // Create the image with the exact size of the shrunk scene
     QSize drawingSize;
     drawingSize.setWidth(qFloor(m_imageRect.width() * m_xScale + m_margins.left() + m_margins.right()));
@@ -197,14 +244,17 @@ void VLayoutExporter::ExportToTIF(QGraphicsScene *scene) const
     if (not writer.write(image))
     { // failed to save file
         qCritical() << qUtf8Printable(tr("Can't save file '%1'. Error: %2.").arg(m_fileName, writer.errorString()));
+        RestoreGrainlineAfterExport(details);
         return;
     }
+
+    RestoreGrainlineAfterExport(details);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VLayoutExporter::ExportToPDF(QGraphicsScene *scene) const
+void VLayoutExporter::ExportToPDF(QGraphicsScene *scene, const QList<QGraphicsItem *> &details) const
 {
-    ExportToPDF(scene, m_fileName);
+    ExportToPDF(scene, details, m_fileName);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -222,25 +272,25 @@ void VLayoutExporter::ExportToOBJ(QGraphicsScene *scene) const
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VLayoutExporter::ExportToPS(QGraphicsScene *scene) const
+void VLayoutExporter::ExportToPS(QGraphicsScene *scene, const QList<QGraphicsItem *> &details) const
 {
     QTemporaryFile tmp;
     if (tmp.open())
     {
         const QString fileName = m_fileName;
-        ExportToPDF(scene, tmp.fileName());
+        ExportToPDF(scene, details, tmp.fileName());
         PdfToPs(QStringList{tmp.fileName(), fileName});
     }
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VLayoutExporter::ExportToEPS(QGraphicsScene *scene) const
+void VLayoutExporter::ExportToEPS(QGraphicsScene *scene, const QList<QGraphicsItem *> &details) const
 {
     QTemporaryFile tmp;
     if (tmp.open())
     {
         const QString fileName = m_fileName;
-        ExportToPDF(scene, tmp.fileName());
+        ExportToPDF(scene, details, tmp.fileName());
         PdfToPs(QStringList{QStringLiteral("-eps"), tmp.fileName(), fileName});
     }
 }
@@ -248,15 +298,16 @@ void VLayoutExporter::ExportToEPS(QGraphicsScene *scene) const
 //---------------------------------------------------------------------------------------------------------------------
 void VLayoutExporter::ExportToFlatDXF(QGraphicsScene *scene, const QList<QGraphicsItem *> &details) const
 {
-    PrepareTextForDXF(endStringPlaceholder, details);
+    PrepareDetailsForDXF(endStringPlaceholder, details);
+    PrepareGrainlineForExport(details, m_showGrainline);
 
     VDxfPaintDevice generator;
-    generator.setFileName(m_fileName);
-    generator.setSize(QSize(qFloor(m_imageRect.width() * m_xScale), qFloor(m_imageRect.height() * m_yScale)));
-    generator.setResolution(PrintDPI);
+    generator.SetFileName(m_fileName);
+    generator.SetSize(QSize(qFloor(m_imageRect.width() * m_xScale), qFloor(m_imageRect.height() * m_yScale)));
+    generator.SetResolution(PrintDPI);
     generator.SetVersion(static_cast<DRW::Version>(m_dxfVersion));
     generator.SetBinaryFormat(m_binaryDxfFormat);
-    generator.setInsunits(VarInsunits::Millimeters);// Decided to always use mm. See issue #745
+    generator.SetInsunits(VarInsunits::Millimeters); // Decided to always use mm. See issue #745
 
     QPainter painter;
     if (painter.begin(&generator))
@@ -265,30 +316,31 @@ void VLayoutExporter::ExportToFlatDXF(QGraphicsScene *scene, const QList<QGraphi
         scene->render(&painter, m_imageRect, m_imageRect, Qt::IgnoreAspectRatio);
         if (not painter.end())
         {
-            qCritical() << tr("Can't create a flat dxf file.")
-                        << generator.ErrorString();
+            qCritical() << tr("Can't create a flat dxf file.") << generator.ErrorString();
         }
     }
 
-    RestoreTextAfterDXF(endStringPlaceholder, details);
+    RestoreDetailsAfterDXF(endStringPlaceholder, details);
+    RestoreGrainlineAfterExport(details);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void VLayoutExporter::ExportToAAMADXF(const QVector<VLayoutPiece> &details) const
 {
     VDxfPaintDevice generator;
-    generator.setFileName(m_fileName);
-    generator.setSize(QSize(qCeil(m_imageRect.width() * m_xScale), qCeil(m_imageRect.height() * m_yScale)));
-    generator.setResolution(PrintDPI);
+    generator.SetFileName(m_fileName);
+    generator.SetSize(QSize(qCeil(m_imageRect.width() * m_xScale), qCeil(m_imageRect.height() * m_yScale)));
+    generator.SetResolution(PrintDPI);
     generator.SetVersion(static_cast<DRW::Version>(m_dxfVersion));
     generator.SetBinaryFormat(m_binaryDxfFormat);
-    generator.setInsunits(VarInsunits::Millimeters);// Decided to always use mm. See issue #745
+    generator.SetInsunits(VarInsunits::Millimeters); // Decided to always use mm. See issue #745
     generator.SetXScale(m_xScale);
     generator.SetYScale(m_yScale);
+    generator.SetBoundaryTogetherWithNotches(m_togetherWithNotches);
+    generator.SetDxfApparelCompatibility(m_dxfCompatibility);
     if (not generator.ExportToAAMA(details))
     {
-        qCritical() << tr("Can't create an AAMA dxf file.")
-                    << generator.ErrorString();
+        qCritical() << tr("Can't create an AAMA dxf file.") << generator.ErrorString();
     }
 }
 
@@ -296,18 +348,19 @@ void VLayoutExporter::ExportToAAMADXF(const QVector<VLayoutPiece> &details) cons
 void VLayoutExporter::ExportToASTMDXF(const QVector<VLayoutPiece> &details) const
 {
     VDxfPaintDevice generator;
-    generator.setFileName(m_fileName);
-    generator.setSize(QSize(qCeil(m_imageRect.width() * m_xScale), qCeil(m_imageRect.height() * m_yScale)));
-    generator.setResolution(PrintDPI);
+    generator.SetFileName(m_fileName);
+    generator.SetSize(QSize(qCeil(m_imageRect.width() * m_xScale), qCeil(m_imageRect.height() * m_yScale)));
+    generator.SetResolution(PrintDPI);
     generator.SetVersion(static_cast<DRW::Version>(m_dxfVersion));
     generator.SetBinaryFormat(m_binaryDxfFormat);
-    generator.setInsunits(VarInsunits::Millimeters);// Decided to always use mm. See issue #745
+    generator.SetInsunits(VarInsunits::Millimeters); // Decided to always use mm. See issue #745
     generator.SetXScale(m_xScale);
     generator.SetYScale(m_yScale);
+    generator.SetBoundaryTogetherWithNotches(m_togetherWithNotches);
+    generator.SetDxfApparelCompatibility(m_dxfCompatibility);
     if (not generator.ExportToASTM(details))
     {
-        qCritical() << tr("Can't create an ASTM dxf file.")
-                    << generator.ErrorString();
+        qCritical() << tr("Can't create an ASTM dxf file.") << generator.ErrorString();
     }
 }
 
@@ -317,7 +370,7 @@ void VLayoutExporter::ExportToRLD(const QVector<VLayoutPiece> &details) const
     QVector<VLayoutPiece> scaledPieces;
     scaledPieces.reserve(details.size());
 
-    for(auto detail : details)
+    for (auto detail : details)
     {
         detail.Scale(m_xScale, m_yScale);
         scaledPieces.append(detail);
@@ -334,41 +387,79 @@ void VLayoutExporter::ExportToRLD(const QVector<VLayoutPiece> &details) const
     }
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void VLayoutExporter::ExportToHPGL(const QVector<VLayoutPiece> &details) const
+{
+    VHPGLPaintDevice generator;
+    generator.SetFileName(m_fileName);
+    generator.SetSize(QSize(qCeil(m_imageRect.width() * m_xScale), qCeil(m_imageRect.height() * m_yScale)));
+    generator.SetXScale(m_xScale);
+    generator.SetYScale(m_yScale);
+    generator.SetShowGrainline(m_showGrainline);
+    generator.SetSingleLineFont(m_singleLineFont);
+    generator.SetSingleStrokeOutlineFont(m_singleStrokeOutlineFont);
+    generator.SetPenWidth(m_penWidth);
+    generator.SetBoundaryTogetherWithNotches(m_togetherWithNotches);
+    if (not generator.ExportToHPGL(details))
+    {
+        qCritical() << tr("Can't create an HP-GL file.");
+    }
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VLayoutExporter::ExportToHPGL2(const QVector<VLayoutPiece> &details) const
+{
+    VHPGLPaintDevice generator;
+    generator.SetFileName(m_fileName);
+    generator.SetSize(QSize(qCeil(m_imageRect.width() * m_xScale), qCeil(m_imageRect.height() * m_yScale)));
+    generator.SetXScale(m_xScale);
+    generator.SetYScale(m_yScale);
+    generator.SetShowGrainline(m_showGrainline);
+    generator.SetSingleLineFont(m_singleLineFont);
+    generator.SetSingleStrokeOutlineFont(m_singleStrokeOutlineFont);
+    generator.SetPenWidth(m_penWidth);
+    generator.SetBoundaryTogetherWithNotches(m_togetherWithNotches);
+    if (not generator.ExportToHPGL2(details))
+    {
+        qCritical() << tr("Can't create an HP-GL file.");
+    }
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 auto VLayoutExporter::SupportPDFConversion() -> bool
 {
-    bool res = false;
-
-    QProcess proc;
-#if defined(Q_OS_WIN) || defined(Q_OS_OSX)
-    // Seek pdftops in app bundle or near valentina.exe
-    proc.start(qApp->applicationDirPath() + QLatin1String("/")+ *PDFTOPS, QStringList());
+    auto Test = [](const QString &program)
+    {
+        QProcess proc;
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+        proc.start(program);
 #else
-    proc.start(*PDFTOPS, QStringList()); // Seek pdftops in standard path
+        proc.start(program, QStringList());
 #endif
 
-    const int timeout = 15000;
-    if (proc.waitForStarted(timeout) && (proc.waitForFinished(timeout) || proc.state() == QProcess::NotRunning))
-    {
-        res = true;
-    }
-    else
-    {
-        qDebug() << *PDFTOPS << "error" << proc.error() << proc.errorString();
-    }
-    return res;
-}
+        const int timeout = 15000;
+        if (proc.waitForStarted(timeout) && (proc.waitForFinished(timeout) || proc.state() == QProcess::NotRunning))
+        {
+            return true;
+        }
 
-//---------------------------------------------------------------------------------------------------------------------
-QPointF VLayoutExporter::offset() const
-{
-    return m_offset;
-}
+        qDebug() << program << "error" << proc.error() << proc.errorString();
+        return false;
+    };
 
-//---------------------------------------------------------------------------------------------------------------------
-void VLayoutExporter::SetOffset(const QPointF &newOffset)
-{
-    m_offset = newOffset;
+#if defined(Q_OS_OSX)
+    // Seek pdftops in app bundle
+    bool found = Test(qApp->applicationDirPath() + '/'_L1 + *PDFTOPS);
+    if (not found)
+    {
+        found = Test(*PDFTOPS);
+    }
+    return found;
+#elif defined(Q_OS_WIN)
+    return Test(qApp->applicationDirPath() + '/'_L1 + *PDFTOPS);
+#else
+    return Test(*PDFTOPS);
+#endif
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -385,9 +476,14 @@ void VLayoutExporter::PdfToPs(const QStringList &params)
 
     QProcess proc;
 #if defined(Q_OS_MAC)
-    // Fix issue #594. Broken export on Mac.
-    proc.setWorkingDirectory(qApp->applicationDirPath());
-    proc.start(QLatin1String("./") + *PDFTOPS, params);
+    if (QFileInfo::exists(qApp->applicationDirPath() + '/'_L1 + *PDFTOPS))
+    {
+        proc.start(qApp->applicationDirPath() + '/'_L1 + *PDFTOPS, params);
+    }
+    else
+    {
+        proc.start(*PDFTOPS, params);
+    }
 #else
     proc.start(*PDFTOPS, params);
 #endif
@@ -402,17 +498,19 @@ void VLayoutExporter::PdfToPs(const QStringList &params)
     QGuiApplication::restoreOverrideCursor();
 #endif
 
-    QFile f(ConstLast<QString>(params));
+    QFile const f(params.constLast());
     if (not f.exists())
     {
-        qCritical() << qUtf8Printable(tr("Creating file '%1' failed! %2")
-                                      .arg(ConstLast<QString>(params), proc.errorString()));
+        qCritical() << qUtf8Printable(tr("Creating file '%1' failed! %2").arg(params.constLast(), proc.errorString()));
     }
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VLayoutExporter::ExportToPDF(QGraphicsScene *scene, const QString &filename) const
+void VLayoutExporter::ExportToPDF(QGraphicsScene *scene, const QList<QGraphicsItem *> &details,
+                                  const QString &filename) const
 {
+    PrepareGrainlineForExport(details, m_showGrainline);
+
     QPrinter printer;
     printer.setCreator(QGuiApplication::applicationDisplayName() + QChar(QChar::Space) +
                        QCoreApplication::applicationVersion());
@@ -422,13 +520,13 @@ void VLayoutExporter::ExportToPDF(QGraphicsScene *scene, const QString &filename
     printer.setResolution(static_cast<int>(PrintDPI));
     printer.setFullPage(m_ignorePrinterMargins);
 
-    QPageLayout::Orientation imageOrientation = m_imageRect.height() >= m_imageRect.width() ? QPageLayout::Portrait
-                                                                                            : QPageLayout::Landscape;
+    QPageLayout::Orientation const imageOrientation =
+        m_imageRect.height() >= m_imageRect.width() ? QPageLayout::Portrait : QPageLayout::Landscape;
 
-    qreal width = FromPixel(m_imageRect.width() * m_xScale + m_margins.left() + m_margins.right(), Unit::Mm);
-    qreal height = FromPixel(m_imageRect.height() * m_yScale + m_margins.top() + m_margins.bottom(), Unit::Mm);
+    qreal const width = FromPixel(m_imageRect.width() * m_xScale + m_margins.left() + m_margins.right(), Unit::Mm);
+    qreal const height = FromPixel(m_imageRect.height() * m_yScale + m_margins.top() + m_margins.bottom(), Unit::Mm);
 
-    QSizeF pageSize = imageOrientation == QPageLayout::Portrait ? QSizeF(width, height) : QSizeF(height, width);
+    QSizeF const pageSize = imageOrientation == QPageLayout::Portrait ? QSizeF(width, height) : QSizeF(height, width);
     if (not printer.setPageSize(QPageSize(pageSize, QPageSize::Millimeter)))
     {
         qWarning() << tr("Cannot set printer page size");
@@ -453,6 +551,7 @@ void VLayoutExporter::ExportToPDF(QGraphicsScene *scene, const QString &filename
     if (not painter.begin(&printer))
     { // failed to open file
         qCritical() << qUtf8Printable(tr("Can't open file '%1'").arg(m_fileName));
+        RestoreGrainlineAfterExport(details);
         return;
     }
     painter.setRenderHint(QPainter::Antialiasing, true);
@@ -461,16 +560,17 @@ void VLayoutExporter::ExportToPDF(QGraphicsScene *scene, const QString &filename
     painter.scale(m_xScale, m_yScale);
     scene->render(&painter, VPrintLayout::SceneTargetRect(&printer, m_imageRect), m_imageRect, Qt::IgnoreAspectRatio);
     painter.end();
+
+    RestoreGrainlineAfterExport(details);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VLayoutExporter::ExportFormatDescription(LayoutExportFormats format)
+auto VLayoutExporter::ExportFormatDescription(LayoutExportFormats format) -> QString
 {
-    const QString dxfSuffix = QStringLiteral("(*.dxf)");
     const QString dxfFlatFilesStr = tr("(flat) files");
     const QString filesStr = tr("files");
 
-    switch(format)
+    switch (format)
     {
         case LayoutExportFormats::SVG:
             return QStringLiteral("Svg %1 (*.svg)").arg(filesStr);
@@ -485,59 +585,27 @@ QString VLayoutExporter::ExportFormatDescription(LayoutExportFormats format)
         case LayoutExportFormats::EPS:
             return QStringLiteral("EPS %1 (*.eps)").arg(filesStr);
         case LayoutExportFormats::DXF_AC1006_Flat:
-            return QStringLiteral("AutoCAD DXF R10 %1 %2").arg(dxfFlatFilesStr, dxfSuffix);
+            return QStringLiteral("AutoCAD DXF R10 %1 (*.dxf)").arg(dxfFlatFilesStr);
         case LayoutExportFormats::DXF_AC1009_Flat:
-            return QStringLiteral("AutoCAD DXF R11/12 %1 %2").arg(dxfFlatFilesStr, dxfSuffix);
+            return QStringLiteral("AutoCAD DXF R11/12 %1 (*.dxf)").arg(dxfFlatFilesStr);
         case LayoutExportFormats::DXF_AC1012_Flat:
-            return QStringLiteral("AutoCAD DXF R13 %1 %2").arg(dxfFlatFilesStr, dxfSuffix);
+            return QStringLiteral("AutoCAD DXF R13 %1 (*.dxf)").arg(dxfFlatFilesStr);
         case LayoutExportFormats::DXF_AC1014_Flat:
-            return QStringLiteral("AutoCAD DXF R14 %1 %2").arg(dxfFlatFilesStr, dxfSuffix);
+            return QStringLiteral("AutoCAD DXF R14 %1 (*.dxf)").arg(dxfFlatFilesStr);
         case LayoutExportFormats::DXF_AC1015_Flat:
-            return QStringLiteral("AutoCAD DXF 2000 %1 %2").arg(dxfFlatFilesStr, dxfSuffix);
+            return QStringLiteral("AutoCAD DXF 2000 %1 (*.dxf)").arg(dxfFlatFilesStr);
         case LayoutExportFormats::DXF_AC1018_Flat:
-            return QStringLiteral("AutoCAD DXF 2004 %1 %2").arg(dxfFlatFilesStr, dxfSuffix);
+            return QStringLiteral("AutoCAD DXF 2004 %1 (*.dxf)").arg(dxfFlatFilesStr);
         case LayoutExportFormats::DXF_AC1021_Flat:
-            return QStringLiteral("AutoCAD DXF 2007 %1 %2").arg(dxfFlatFilesStr, dxfSuffix);
+            return QStringLiteral("AutoCAD DXF 2007 %1 (*.dxf)").arg(dxfFlatFilesStr);
         case LayoutExportFormats::DXF_AC1024_Flat:
-            return QStringLiteral("AutoCAD DXF 2010 %1 %2").arg(dxfFlatFilesStr, dxfSuffix);
+            return QStringLiteral("AutoCAD DXF 2010 %1 (*.dxf)").arg(dxfFlatFilesStr);
         case LayoutExportFormats::DXF_AC1027_Flat:
-            return QStringLiteral("AutoCAD DXF 2013 %1 %2").arg(dxfFlatFilesStr, dxfSuffix);
-        case LayoutExportFormats::DXF_AC1006_AAMA:
-            return QStringLiteral("AutoCAD DXF R10 AAMA %1 %2").arg(filesStr, dxfSuffix);
-        case LayoutExportFormats::DXF_AC1009_AAMA:
-            return QStringLiteral("AutoCAD DXF R11/12 AAMA %1 %2").arg(filesStr, dxfSuffix);
-        case LayoutExportFormats::DXF_AC1012_AAMA:
-            return QStringLiteral("AutoCAD DXF R13 AAMA %1 %2").arg(filesStr, dxfSuffix);
-        case LayoutExportFormats::DXF_AC1014_AAMA:
-            return QStringLiteral("AutoCAD DXF R14 AAMA %1 %2").arg(filesStr, dxfSuffix);
-        case LayoutExportFormats::DXF_AC1015_AAMA:
-            return QStringLiteral("AutoCAD DXF 2000 AAMA %1 %2").arg(filesStr, dxfSuffix);
-        case LayoutExportFormats::DXF_AC1018_AAMA:
-            return QStringLiteral("AutoCAD DXF 2004 AAMA %1 %2").arg(filesStr, dxfSuffix);
-        case LayoutExportFormats::DXF_AC1021_AAMA:
-            return QStringLiteral("AutoCAD DXF 2007 AAMA %1 %2").arg(filesStr, dxfSuffix);
-        case LayoutExportFormats::DXF_AC1024_AAMA:
-            return QStringLiteral("AutoCAD DXF 2010 AAMA %1 %2").arg(filesStr, dxfSuffix);
-        case LayoutExportFormats::DXF_AC1027_AAMA:
-            return QStringLiteral("AutoCAD DXF 2013 AAMA %1 %2").arg(filesStr, dxfSuffix);
-        case LayoutExportFormats::DXF_AC1006_ASTM:
-            return QStringLiteral("AutoCAD DXF R10 ASTM %1 %2").arg(filesStr, dxfSuffix);
-        case LayoutExportFormats::DXF_AC1009_ASTM:
-            return QStringLiteral("AutoCAD DXF R11/12 ASTM %1 %2").arg(filesStr, dxfSuffix);
-        case LayoutExportFormats::DXF_AC1012_ASTM:
-            return QStringLiteral("AutoCAD DXF R13 ASTM %1 %2").arg(filesStr, dxfSuffix);
-        case LayoutExportFormats::DXF_AC1014_ASTM:
-            return QStringLiteral("AutoCAD DXF R14 ASTM %1 %2").arg(filesStr, dxfSuffix);
-        case LayoutExportFormats::DXF_AC1015_ASTM:
-            return QStringLiteral("AutoCAD DXF 2000 ASTM %1 %2").arg(filesStr, dxfSuffix);
-        case LayoutExportFormats::DXF_AC1018_ASTM:
-            return QStringLiteral("AutoCAD DXF 2004 ASTM %1 %2").arg(filesStr, dxfSuffix);
-        case LayoutExportFormats::DXF_AC1021_ASTM:
-            return QStringLiteral("AutoCAD DXF 2007 ASTM %1 %2").arg(filesStr, dxfSuffix);
-        case LayoutExportFormats::DXF_AC1024_ASTM:
-            return QStringLiteral("AutoCAD DXF 2010 ASTM %1 %2").arg(filesStr, dxfSuffix);
-        case LayoutExportFormats::DXF_AC1027_ASTM:
-            return QStringLiteral("AutoCAD DXF 2013 ASTM %1 %2").arg(filesStr, dxfSuffix);
+            return QStringLiteral("AutoCAD DXF 2013 %1 (*.dxf)").arg(dxfFlatFilesStr);
+        case LayoutExportFormats::DXF_AAMA:
+            return QStringLiteral("AutoCAD DXF AAMA %1 (*.dxf)").arg(filesStr);
+        case LayoutExportFormats::DXF_ASTM:
+            return QStringLiteral("AutoCAD DXF ASTM %1 (*.dxf)").arg(filesStr);
         case LayoutExportFormats::PDFTiled:
             return QStringLiteral("PDF %1 %2 (*.pdf)").arg(tr("tiled"), filesStr);
         case LayoutExportFormats::NC:
@@ -546,15 +614,19 @@ QString VLayoutExporter::ExportFormatDescription(LayoutExportFormats format)
             return QStringLiteral("%1 %2 (*.rld)").arg(tr("Raw Layout Data"), filesStr);
         case LayoutExportFormats::TIF:
             return QStringLiteral("TIFF %1 (*.tif)").arg(filesStr);
+        case LayoutExportFormats::HPGL:
+            return QStringLiteral("HP-GL %1 (*.hpgl)").arg(filesStr);
+        case LayoutExportFormats::HPGL2:
+            return QStringLiteral("HP-GL/2 %1 (*.hpgl)").arg(filesStr);
         default:
-            return QString();
+            return {};
     }
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VLayoutExporter::ExportFormatSuffix(LayoutExportFormats format)
+auto VLayoutExporter::ExportFormatSuffix(LayoutExportFormats format) -> QString
 {
-    switch(format)
+    switch (format)
     {
         case LayoutExportFormats::SVG:
             return QStringLiteral(".svg");
@@ -578,24 +650,8 @@ QString VLayoutExporter::ExportFormatSuffix(LayoutExportFormats format)
         case LayoutExportFormats::DXF_AC1021_Flat:
         case LayoutExportFormats::DXF_AC1024_Flat:
         case LayoutExportFormats::DXF_AC1027_Flat:
-        case LayoutExportFormats::DXF_AC1006_AAMA:
-        case LayoutExportFormats::DXF_AC1009_AAMA:
-        case LayoutExportFormats::DXF_AC1012_AAMA:
-        case LayoutExportFormats::DXF_AC1014_AAMA:
-        case LayoutExportFormats::DXF_AC1015_AAMA:
-        case LayoutExportFormats::DXF_AC1018_AAMA:
-        case LayoutExportFormats::DXF_AC1021_AAMA:
-        case LayoutExportFormats::DXF_AC1024_AAMA:
-        case LayoutExportFormats::DXF_AC1027_AAMA:
-        case LayoutExportFormats::DXF_AC1006_ASTM:
-        case LayoutExportFormats::DXF_AC1009_ASTM:
-        case LayoutExportFormats::DXF_AC1012_ASTM:
-        case LayoutExportFormats::DXF_AC1014_ASTM:
-        case LayoutExportFormats::DXF_AC1015_ASTM:
-        case LayoutExportFormats::DXF_AC1018_ASTM:
-        case LayoutExportFormats::DXF_AC1021_ASTM:
-        case LayoutExportFormats::DXF_AC1024_ASTM:
-        case LayoutExportFormats::DXF_AC1027_ASTM:
+        case LayoutExportFormats::DXF_AAMA:
+        case LayoutExportFormats::DXF_ASTM:
             return QStringLiteral(".dxf");
         case LayoutExportFormats::NC:
             return QStringLiteral(".nc");
@@ -603,7 +659,42 @@ QString VLayoutExporter::ExportFormatSuffix(LayoutExportFormats format)
             return QStringLiteral(".rld");
         case LayoutExportFormats::TIF:
             return QStringLiteral(".tif");
+        case LayoutExportFormats::HPGL:
+        case LayoutExportFormats::HPGL2:
+            return QStringLiteral(".hpgl");
         default:
-            return QString();
+            return {};
+    }
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VLayoutExporter::PrepareGrainlineForExport(const QList<QGraphicsItem *> &items, bool showGrainline)
+{
+    for (auto *item : items)
+    {
+        QList<QGraphicsItem *> pieceChildren = item->childItems();
+        for (auto *child : qAsConst(pieceChildren))
+        {
+            if (child->type() == VGraphicsFillItem::Type)
+            {
+                child->setVisible(showGrainline);
+            }
+        }
+    }
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VLayoutExporter::RestoreGrainlineAfterExport(const QList<QGraphicsItem *> &items)
+{
+    for (auto *item : items)
+    {
+        QList<QGraphicsItem *> pieceChildren = item->childItems();
+        for (auto *child : qAsConst(pieceChildren))
+        {
+            if (child->type() == VGraphicsFillItem::Type)
+            {
+                child->setVisible(true);
+            }
+        }
     }
 }
