@@ -29,9 +29,10 @@
 #ifndef VLAYOUTPIECEPATH_H
 #define VLAYOUTPIECEPATH_H
 
+#include "vlayoutpoint.h"
+#include <QMetaType>
 #include <QPointF>
 #include <QSharedDataPointer>
-#include <QMetaType>
 
 class VLayoutPiecePathData;
 class QPainterPath;
@@ -40,36 +41,38 @@ class VLayoutPiecePath
 {
 public:
     VLayoutPiecePath();
-    explicit VLayoutPiecePath(const QVector<QPointF> &points);
+    explicit VLayoutPiecePath(const QVector<VLayoutPoint> &points);
     VLayoutPiecePath(const VLayoutPiecePath &path);
 
     virtual ~VLayoutPiecePath();
 
-    VLayoutPiecePath &operator=(const VLayoutPiecePath &path);
-#ifdef Q_COMPILER_RVALUE_REFS
-    VLayoutPiecePath(VLayoutPiecePath &&path) Q_DECL_NOTHROW;
-    VLayoutPiecePath &operator=(VLayoutPiecePath &&path) Q_DECL_NOTHROW;
-#endif
+    auto operator=(const VLayoutPiecePath &path) -> VLayoutPiecePath &;
 
-    QPainterPath GetPainterPath() const;
+    VLayoutPiecePath(VLayoutPiecePath &&path) noexcept;
+    auto operator=(VLayoutPiecePath &&path) noexcept -> VLayoutPiecePath &;
 
-    QVector<QPointF> Points() const;
-    void             SetPoints(const QVector<QPointF> &points);
+    auto GetPainterPath() const -> QPainterPath;
 
-    Qt::PenStyle PenStyle() const;
-    void         SetPenStyle(const Qt::PenStyle &penStyle);
+    auto Points() const -> QVector<VLayoutPoint>;
+    void SetPoints(const QVector<VLayoutPoint> &points);
 
-    bool IsCutPath() const;
+    auto PenStyle() const -> Qt::PenStyle;
+    void SetPenStyle(const Qt::PenStyle &penStyle);
+
+    auto IsCutPath() const -> bool;
     void SetCutPath(bool cut);
 
-    friend QDataStream& operator<< (QDataStream& dataStream, const VLayoutPiecePath& path);
-    friend QDataStream& operator>> (QDataStream& dataStream, VLayoutPiecePath& path);
+    auto IsNotMirrored() const -> bool;
+    void SetNotMirrored(bool value);
+
+    friend auto operator<<(QDataStream &dataStream, const VLayoutPiecePath &path) -> QDataStream &;
+    friend auto operator>>(QDataStream &dataStream, VLayoutPiecePath &path) -> QDataStream &;
 
 private:
     QSharedDataPointer<VLayoutPiecePathData> d;
 };
 
-Q_DECLARE_METATYPE(VLayoutPiecePath)
+Q_DECLARE_METATYPE(VLayoutPiecePath)                  // NOLINT
 Q_DECLARE_TYPEINFO(VLayoutPiecePath, Q_MOVABLE_TYPE); // NOLINT
 
 #endif // VLAYOUTPIECEPATH_H
