@@ -29,7 +29,6 @@
 #include "vposition.h"
 
 #include <QDir>
-#include <QtConcurrent>
 #include <QFutureWatcher>
 #include <QImage>
 #include <QLineF>
@@ -42,44 +41,42 @@
 #include <QRect>
 #include <QRectF>
 #include <QSizeF>
-#include <QStaticStringData>
 #include <QString>
-#include <QStringData>
-#include <QStringDataPtr>
 #include <QThreadPool>
-#include <Qt>
+#include <QtConcurrent>
 #include <functional>
 
-#include "../vmisc/def.h"
 #include "../ifc/exception/vexception.h"
-#include "../vpatterndb/floatItemData/floatitemdef.h"
+#include "../vlayout/vlayoutpoint.h"
+#include "../vmisc/def.h"
+#include "vpiecegrainline.h"
 
+#ifdef LAYOUT_DEBUG
 namespace
 {
-#ifdef LAYOUT_DEBUG
 //---------------------------------------------------------------------------------------------------------------------
 QPainterPath ShowDirection(const QLineF &edge)
 {
     const int arrowLength = 14;
     QPainterPath path;
-    if (edge.length()/arrowLength < 5)
+    if (edge.length() / arrowLength < 5)
     {
-        return  path;
+        return path;
     }
 
     QLineF arrow = edge;
-    arrow.setLength(edge.length()/2.0);
+    arrow.setLength(edge.length() / 2.0);
 
-    //Reverse line because we want start arrow from this point
-    arrow = QLineF(arrow.p2(), arrow.p1());
-    const qreal angle = arrow.angle();//we each time change line angle, better save original angle value
-    arrow.setLength(arrowLength);//arrow length in pixels
+    // Reverse line because we want start arrow from this point
+    Swap(arrow);
+    const qreal angle = arrow.angle(); // we each time change line angle, better save original angle value
+    arrow.setLength(arrowLength);      // arrow length in pixels
 
-    arrow.setAngle(angle-35);
+    arrow.setAngle(angle - 35);
     path.moveTo(arrow.p1());
     path.lineTo(arrow.p2());
 
-    arrow.setAngle(angle+35);
+    arrow.setAngle(angle + 35);
     path.moveTo(arrow.p1());
     path.lineTo(arrow.p2());
     return path;
@@ -92,24 +89,24 @@ QPainterPath DumpContour(const QVector<QPointF> &points)
     path.setFillRule(Qt::WindingFill);
     if (points.count() >= 2)
     {
-        for (qint32 i = 0; i < points.count()-1; ++i)
+        for (qint32 i = 0; i < points.count() - 1; ++i)
         {
             path.moveTo(points.at(i));
-            path.lineTo(points.at(i+1));
+            path.lineTo(points.at(i + 1));
         }
         path.lineTo(points.at(0));
 
 #ifdef SHOW_DIRECTION
-        for (qint32 i = 0; i < points.count()-1; ++i)
+        for (qint32 i = 0; i < points.count() - 1; ++i)
         {
-            path.addPath(ShowDirection(QLineF(points.at(i), points.at(i+1))));
+            path.addPath(ShowDirection(QLineF(points.at(i), points.at(i + 1))));
         }
 #endif
 
 #ifdef SHOW_VERTICES
         for (qint32 i = 0; i < points.count(); ++i)
         {
-            path.addRect(points.at(i).x()-3, points.at(i).y()-3, 6, 6);
+            path.addRect(points.at(i).x() - 3, points.at(i).y() - 3, 6, 6);
         }
 #endif
     }
@@ -121,7 +118,7 @@ QPainterPath DumpDetails(const QVector<VLayoutPiece> &details)
 {
     QPainterPath path;
     path.setFillRule(Qt::WindingFill);
-    if (details.count() > 0)
+    if (!details.isEmpty())
     {
         for (auto &detail : details)
         {
@@ -130,15 +127,15 @@ QPainterPath DumpDetails(const QVector<VLayoutPiece> &details)
     }
     return path;
 }
+} // anonymous namespace
 #endif
-} //anonymous namespace
 
 //---------------------------------------------------------------------------------------------------------------------
 VPosition::VPosition(const VPositionData &data, std::atomic_bool *stop, bool saveLength)
-    : m_isValid(true),
-      m_bestResult(VBestSquare(data.gContour.GetSize(), saveLength, data.isOriginPaperOrientationPortrait)),
-      m_data(data),
-      stop(stop)
+  : m_isValid(true),
+    m_bestResult(VBestSquare(data.gContour.GetSize(), saveLength, data.isOriginPaperOrientationPortrait)),
+    m_data(data),
+    stop(stop)
 {
     if (m_data.rotationNumber > 360 || m_data.rotationNumber < 1)
     {
@@ -161,7 +158,7 @@ void VPosition::run()
 
     try
     {
-        for (int i=1; i<= m_data.detail.LayoutEdgesCount(); ++i)
+        for (int i = 1; i <= m_data.detail.LayoutEdgesCount(); ++i)
         {
             if (stop->load())
             {
@@ -182,7 +179,7 @@ void VPosition::run()
         m_bestResult.TerminatedByException(QStringLiteral("%1\n\n%2").arg(e.ErrorMessage(), e.DetailedInformation()));
         return;
     }
-    catch (std::exception& e)
+    catch (std::exception &e)
     {
         m_bestResult.TerminatedByException(QString::fromLatin1(e.what()));
         return;
@@ -212,17 +209,17 @@ auto VPosition::ArrangeDetail(const VPositionData &data, std::atomic_bool *stop,
     }
 
     const VLayoutPiece detail = data.detail;
-    const int detailEdgesCount = detail.LayoutEdgesCount();
+    const auto detailEdgesCount = detail.LayoutEdgesCount();
     if (detailEdgesCount < 3 || detail.DetailEdgesCount() < 3)
     {
-        return bestResult;//Not enough edges
+        return bestResult; // Not enough edges
     }
 
     QFutureWatcher<VBestSquare> watcher;
     QVector<VPosition> jobs;
     jobs.reserve(data.gContour.GlobalEdgesCount());
 
-    for (int j=1; j <= data.gContour.GlobalEdgesCount(); ++j)
+    for (int j = 1; j <= data.gContour.GlobalEdgesCount(); ++j)
     {
         VPositionData linkedData = data;
         linkedData.j = j;
@@ -232,42 +229,25 @@ auto VPosition::ArrangeDetail(const VPositionData &data, std::atomic_bool *stop,
 
     Q_ASSERT(not jobs.isEmpty());
 
-    std::function<VBestSquare (VPosition position)> Nest = [](VPosition position)
+    std::function<VBestSquare(VPosition position)> const Nest = [](VPosition position)
     {
         position.run();
         return position.getBestResult();
     };
 
+    QEventLoop wait;
+    QObject::connect(&watcher, &QFutureWatcher<VBestSquare>::finished, &wait, &QEventLoop::quit);
+
     watcher.setFuture(QtConcurrent::mapped(jobs, Nest));
-
-    while(not watcher.isStarted())
-    {
-        QCoreApplication::processEvents();
-        QThread::msleep(250);
-    }
-
-    // Wait for done
-    do
-    {
-        QCoreApplication::processEvents();
-        QThread::msleep(250);
-    }
-    while(watcher.isRunning() && not stop->load());
+    wait.exec();
 
     if (stop->load())
     {
-        do
-        {
-            QCoreApplication::processEvents();
-            QThread::msleep(250);
-        }
-        while(watcher.isRunning());
-
         return bestResult;
     }
 
-    QList<VBestSquare> results = watcher.future().results();
-    for (auto &result : results)
+    QList<VBestSquare> const results = watcher.future().results();
+    for (const auto &result : results)
     {
         bestResult.NewResult(result);
     }
@@ -276,8 +256,7 @@ auto VPosition::ArrangeDetail(const VPositionData &data, std::atomic_bool *stop,
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VPosition::SaveCandidate(VBestSquare &bestResult, const VLayoutPiece &detail, int globalI, int detJ,
-                              BestFrom type)
+void VPosition::SaveCandidate(VBestSquare &bestResult, const VLayoutPiece &detail, int globalI, int detJ, BestFrom type)
 {
     if (bestResult.IsSaveLength())
     {
@@ -285,18 +264,24 @@ void VPosition::SaveCandidate(VBestSquare &bestResult, const VLayoutPiece &detai
     }
 
     QVector<QPointF> newGContour = m_data.gContour.UniteWithContour(detail, globalI, detJ, type);
-    newGContour.append(ConstFirst(newGContour));
+    newGContour.append(newGContour.constFirst());
     const QSizeF size = QPolygonF(newGContour).boundingRect().size();
     const QRectF boundingRect = detail.MappedDetailBoundingRect();
     const qreal depthPosition = m_data.isOriginPaperOrientationPortrait ? boundingRect.y() : boundingRect.x();
     const qreal sidePosition = m_data.isOriginPaperOrientationPortrait ? boundingRect.x() : boundingRect.y();
 
+    QT_WARNING_PUSH
+    QT_WARNING_DISABLE_GCC("-Wnoexcept")
+
     VBestSquareResData data;
+
+    QT_WARNING_POP
+
     data.bestSize = size;
-    data.globalI = globalI; // Edge of global contour
-    data.detJ = detJ; // Edge of detail
+    data.globalI = globalI;              // Edge of global contour
+    data.detJ = detJ;                    // Edge of detail
     data.resMatrix = detail.GetMatrix(); // Matrix for rotation and translation detail
-    data.resMirror = detail.IsMirror();
+    data.resMirror = detail.IsVerticallyFlipped();
     data.type = type;
     data.depthPosition = depthPosition;
     data.sidePosition = sidePosition;
@@ -314,9 +299,9 @@ auto VPosition::CheckCombineEdges(VLayoutPiece &detail, int j, int &dEdge) -> bo
     CombineEdges(detail, globalEdge, dEdge);
 
 #ifdef LAYOUT_DEBUG
-#   ifdef SHOW_COMBINE
+#ifdef SHOW_COMBINE
     DumpFrame(m_data.gContour, detail, m_data.mutex, m_data.details);
-#   endif
+#endif
 #endif
 
     CrossingType type = CrossingType::Intersection;
@@ -350,18 +335,18 @@ auto VPosition::CheckCombineEdges(VLayoutPiece &detail, int j, int &dEdge) -> bo
     if (flagMirror && not detail.IsForbidFlipping())
     {
 #ifdef LAYOUT_DEBUG
-#   ifdef SHOW_MIRROR
+#ifdef SHOW_MIRROR
         DumpFrame(m_data.gContour, detail, m_data.mutex, m_data.details);
-#   endif
+#endif
 #endif
 
-        dEdge = detail.LayoutEdgeByPoint(globalEdge.p2());
-
-        if (dEdge <= 0)
+        EdgeIndex layoutEdge = detail.LayoutEdgeByPoint(globalEdge.p2());
+        if (not layoutEdge.has_value())
         {
             return false;
         }
 
+        dEdge = *layoutEdge;
         CrossingType type = CrossingType::Intersection;
         if (SheetContains(detail.MappedDetailBoundingRect()))
         {
@@ -393,15 +378,15 @@ auto VPosition::CheckRotationEdges(VLayoutPiece &detail, int j, int dEdge, qreal
 
     if (detail.IsForceFlipping())
     {
-        detail.Mirror(not m_data.followGrainline ? globalEdge : QLineF(10, 10, 10, 100));
+        detail.Mirror(m_data.followGrainline || detail.IsFollowGrainline() ? QLineF(10, 10, 10, 100) : globalEdge);
     }
 
     RotateEdges(detail, globalEdge, dEdge, angle);
 
 #ifdef LAYOUT_DEBUG
-#   ifdef SHOW_ROTATION
+#ifdef SHOW_ROTATION
     DumpFrame(m_data.gContour, detail, m_data.mutex, m_data.details);
-#   endif
+#endif
 #endif
 
     CrossingType type = CrossingType::Intersection;
@@ -440,9 +425,9 @@ void VPosition::RotateOnAngle(qreal angle)
         }
 
 #ifdef LAYOUT_DEBUG
-#   ifdef SHOW_CANDIDATE_BEST
+#ifdef SHOW_CANDIDATE_BEST
         DumpFrame(m_data.gContour, workDetail, m_data.mutex, m_data.details);
-#   endif
+#endif
 #endif
 
         SaveCandidate(m_bestResult, workDetail, m_data.j, m_data.i, BestFrom::Rotation);
@@ -459,23 +444,24 @@ auto VPosition::Crossing(const VLayoutPiece &detail) const -> VPosition::Crossin
 
     const QVector<QPointF> layoutPoints = detail.GetMappedLayoutAllowancePoints();
     const QRectF layoutBoundingRect = VLayoutPiece::BoundingRect(layoutPoints);
-    const QPainterPath layoutAllowancePath = VAbstractPiece::PainterPath(layoutPoints);
+    const QPainterPath layoutAllowancePath = VGObject::PainterPath(layoutPoints);
 
-    const QVector<QPointF> contourPoints = detail.IsSeamAllowance() && not detail.IsSeamAllowanceBuiltIn() ?
-                detail.GetMappedSeamAllowancePoints() : detail.GetMappedContourPoints();
+    QVector<QPointF> contourPoints;
+    CastTo(detail.IsSeamAllowance() && not detail.IsSeamAllowanceBuiltIn() ? detail.GetMappedSeamAllowancePoints()
+                                                                           : detail.GetMappedContourPoints(),
+           contourPoints);
     const QRectF detailBoundingRect = VLayoutPiece::BoundingRect(contourPoints);
-    const QPainterPath contourPath = VAbstractPiece::PainterPath(contourPoints);
+    const QPainterPath contourPath = VGObject::PainterPath(contourPoints);
 
-    for(const auto &position : m_data.positionsCache)
+    for (const auto &position : m_data.positionsCache)
     {
-        if (position.boundingRect.intersects(layoutBoundingRect) || position.boundingRect.contains(detailBoundingRect)
-            || detailBoundingRect.contains(position.boundingRect))
+        if ((position.boundingRect.intersects(layoutBoundingRect) ||
+             position.boundingRect.contains(detailBoundingRect) ||
+             detailBoundingRect.contains(position.boundingRect)) &&
+            (position.layoutAllowancePath.contains(contourPath) || contourPath.contains(position.layoutAllowancePath) ||
+             position.layoutAllowancePath.intersects(layoutAllowancePath)))
         {
-            if (position.layoutAllowancePath.contains(contourPath) || contourPath.contains(position.layoutAllowancePath)
-                || position.layoutAllowancePath.intersects(layoutAllowancePath))
-            {
-                return CrossingType::Intersection;
-            }
+            return CrossingType::Intersection;
         }
     }
 
@@ -485,8 +471,8 @@ auto VPosition::Crossing(const VLayoutPiece &detail) const -> VPosition::Crossin
 //---------------------------------------------------------------------------------------------------------------------
 auto VPosition::SheetContains(const QRectF &rect) const -> bool
 {
-    const QRectF bRect(-accuracyPointOnLine, -accuracyPointOnLine, m_data.gContour.GetWidth()+accuracyPointOnLine,
-                       m_data.gContour.GetHeight()+accuracyPointOnLine);
+    const QRectF bRect(-accuracyPointOnLine, -accuracyPointOnLine, m_data.gContour.GetWidth() + accuracyPointOnLine,
+                       m_data.gContour.GetHeight() + accuracyPointOnLine);
     return bRect.contains(rect);
 }
 
@@ -514,7 +500,7 @@ void VPosition::CombineEdges(VLayoutPiece &detail, const QLineF &globalEdge, int
 //---------------------------------------------------------------------------------------------------------------------
 void VPosition::RotateEdges(VLayoutPiece &detail, const QLineF &globalEdge, int dEdge, qreal angle)
 {
-    QLineF detailEdge = detail.LayoutEdge(dEdge);
+    QLineF const detailEdge = detail.LayoutEdge(dEdge);
     // Now we move detail to position near to global contour edge.
     detail.Translate(globalEdge.x2() - detailEdge.x2(), globalEdge.y2() - detailEdge.y2());
     detail.Rotate(globalEdge.p2(), angle);
@@ -523,7 +509,7 @@ void VPosition::RotateEdges(VLayoutPiece &detail, const QLineF &globalEdge, int
 //---------------------------------------------------------------------------------------------------------------------
 void VPosition::Rotate(int number)
 {
-    const qreal step = 360.0/number;
+    const qreal step = 360.0 / number;
     qreal startAngle = 0;
     if (VFuzzyComparePossibleNulls(angle_between, 360))
     {
@@ -531,7 +517,7 @@ void VPosition::Rotate(int number)
     }
 
     qreal angle = startAngle;
-    while(angle < 360)
+    while (angle < 360)
     {
         if (stop->load())
         {
@@ -540,7 +526,7 @@ void VPosition::Rotate(int number)
 
         RotateOnAngle(angle);
 
-        angle = angle+step;
+        angle = angle + step;
     }
 }
 
@@ -552,13 +538,16 @@ void VPosition::FollowGrainline()
         return;
     }
 
+    VPieceGrainline const pieceGrainline = m_data.detail.GetGrainline();
     QLineF detailGrainline(10, 10, 100, 10);
-    detailGrainline.setAngle(m_data.detail.GrainlineAngle());
+    detailGrainline.setAngle(pieceGrainline.GetMainLine().angle());
 
     if (m_data.detail.IsForceFlipping())
     {
         VLayoutPiece workDetail = m_data.detail; // We need copy for temp change
-        workDetail.Mirror(not m_data.followGrainline ? m_data.gContour.GlobalEdge(m_data.j) : QLineF(10, 10, 10, 100));
+        workDetail.Mirror(m_data.followGrainline || workDetail.IsFollowGrainline()
+                              ? QLineF(10, 10, 10, 100)
+                              : m_data.gContour.GlobalEdge(m_data.j));
         detailGrainline = workDetail.GetMatrix().map(detailGrainline);
     }
 
@@ -569,8 +558,7 @@ void VPosition::FollowGrainline()
 
     const qreal angle = detailGrainline.angleTo(FabricGrainline());
 
-    if (m_data.detail.GrainlineArrowType() == GrainlineArrowDirection::atBoth ||
-            m_data.detail.GrainlineArrowType() == GrainlineArrowDirection::atFront)
+    if (pieceGrainline.IsArrowUpEnabled())
     {
         RotateOnAngle(angle);
     }
@@ -580,10 +568,29 @@ void VPosition::FollowGrainline()
         return;
     }
 
-    if (m_data.detail.GrainlineArrowType() == GrainlineArrowDirection::atBoth ||
-            m_data.detail.GrainlineArrowType() == GrainlineArrowDirection::atRear)
+    if (pieceGrainline.IsArrowDownEnabled())
     {
-        RotateOnAngle(angle+180);
+        RotateOnAngle(angle + 180);
+    }
+
+    if (stop->load())
+    {
+        return;
+    }
+
+    if (pieceGrainline.IsArrowLeftEnabled())
+    {
+        RotateOnAngle(angle + 90);
+    }
+
+    if (stop->load())
+    {
+        return;
+    }
+
+    if (pieceGrainline.IsArrowRightEnabled())
+    {
+        RotateOnAngle(angle - 90);
     }
 }
 
@@ -595,41 +602,40 @@ void VPosition::FindBestPosition()
         return;
     }
 
-    if (not m_data.followGrainline || not m_data.detail.IsGrainlineEnabled())
+    if (m_data.detail.IsGrainlineEnabled() && (m_data.followGrainline || m_data.detail.IsFollowGrainline()))
     {
-        // We should use copy of the detail.
-        VLayoutPiece workDetail = m_data.detail;
+        FollowGrainline();
+        return;
+    }
 
-        int dEdge = m_data.i;// For mirror detail edge will be different
-        if (CheckCombineEdges(workDetail, m_data.j, dEdge))
-        {
-            if (stop->load())
-            {
-                return;
-            }
-
-#ifdef LAYOUT_DEBUG
-#   ifdef SHOW_CANDIDATE_BEST
-            DumpFrame(m_data.gContour, workDetail, m_data.mutex, m_data.details);
-#   endif
-#endif
-
-            SaveCandidate(m_bestResult, workDetail, m_data.j, dEdge, BestFrom::Combine);
-        }
+    // We should use copy of the detail.
+    VLayoutPiece workDetail = m_data.detail;
 
+    int dEdge = m_data.i; // For mirror detail edge will be different
+    if (CheckCombineEdges(workDetail, m_data.j, dEdge))
+    {
         if (stop->load())
         {
             return;
         }
 
-        if (m_data.rotate)
-        {
-            Rotate(m_data.rotationNumber);
-        }
+#ifdef LAYOUT_DEBUG
+#ifdef SHOW_CANDIDATE_BEST
+        DumpFrame(m_data.gContour, workDetail, m_data.mutex, m_data.details);
+#endif
+#endif
+
+        SaveCandidate(m_bestResult, workDetail, m_data.j, dEdge, BestFrom::Combine);
     }
-    else
+
+    if (stop->load())
     {
-        FollowGrainline();
+        return;
+    }
+
+    if (m_data.rotate)
+    {
+        Rotate(m_data.rotationNumber);
     }
 }
 
@@ -639,9 +645,7 @@ void VPosition::DumpFrame(const VContour &contour, const VLayoutPiece &detail, Q
                           const QVector<VLayoutPiece> &details = QVector<VLayoutPiece>())
 {
     auto Bias = [](int length, int maxLength)
-    {
-        return length < maxLength && length*2 < maxLength ? length : maxLength-length;
-    };
+    { return length < maxLength && length * 2 < maxLength ? length : maxLength - length; };
 
     const int biasWidth = Bias(contour.GetWidth(), QIMAGE_MAX);
     const int biasHeight = Bias(contour.GetHeight(), QIMAGE_MAX);
@@ -655,20 +659,20 @@ void VPosition::DumpFrame(const VContour &contour, const VLayoutPiece &detail, Q
     if (contour.GetContour().isEmpty())
     {
         p = DumpContour(contour.CutEmptySheetEdge());
-        p.translate(biasWidth/2, biasHeight/2);
+        p.translate(biasWidth / 2, biasHeight / 2);
         paint.drawPath(p);
     }
     else
     {
         p = DumpContour(contour.GetContour());
-        p.translate(biasWidth/2, biasHeight/2);
+        p.translate(biasWidth / 2, biasHeight / 2);
         paint.drawPath(p);
     }
 
 #ifdef SHOW_CANDIDATE
     paint.setPen(QPen(Qt::darkGreen, 6, Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin));
     p = DumpContour(detail.GetLayoutAllowancePoints());
-    p.translate(biasWidth/2, biasHeight/2);
+    p.translate(biasWidth / 2, biasHeight / 2);
     paint.drawPath(p);
 #else
     Q_UNUSED(detail)
@@ -678,7 +682,7 @@ void VPosition::DumpFrame(const VContour &contour, const VLayoutPiece &detail, Q
 #ifdef ARRANGED_DETAILS
     paint.setPen(QPen(Qt::blue, 2, Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin));
     p = DumpDetails(details);
-    p.translate(biasWidth/2, biasHeight/2);
+    p.translate(biasWidth / 2, biasHeight / 2);
     paint.drawPath(p);
 #else
     Q_UNUSED(details)
@@ -690,7 +694,7 @@ void VPosition::DumpFrame(const VContour &contour, const VLayoutPiece &detail, Q
     // Sheet
 #ifdef SHOW_SHEET
     paint.setPen(QPen(Qt::darkRed, 15, Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin));
-    paint.drawRect(QRectF(biasWidth/2, biasHeight/2, contour.GetWidth(), contour.GetHeight()));
+    paint.drawRect(QRectF(biasWidth / 2, biasHeight / 2, contour.GetWidth(), contour.GetHeight()));
 #endif
 
     paint.end();
@@ -698,7 +702,7 @@ void VPosition::DumpFrame(const VContour &contour, const VLayoutPiece &detail, Q
     // Dump frame to image
     // Note. If program was build with Address Sanitizer possible crashes. Address Sanitizer doesn't support big
     // allocations. See page https://bitbucket.org/dismine/valentina/wiki/developers/Address_Sanitizer
-    QImage frameImage(pictureRect.width()+biasWidth, pictureRect.height()+biasHeight, QImage::Format_RGB32);
+    QImage frameImage(pictureRect.width() + biasWidth, pictureRect.height() + biasHeight, QImage::Format_RGB32);
 
     if (frameImage.isNull())
     {
@@ -717,7 +721,7 @@ void VPosition::DumpFrame(const VContour &contour, const VLayoutPiece &detail, Q
     static int frame = 0;
     ++frame;
 
-    const QString path = QDir::homePath()+QStringLiteral("/LayoutDebug/%1.png").arg(frame);
-    frameImage.save (path);
+    const QString path = QDir::homePath() + QStringLiteral("/LayoutDebug/%1.png").arg(frame);
+    frameImage.save(path);
 }
 #endif
