@@ -28,48 +28,49 @@
 
 #include "vposter.h"
 
+#include <QDebug>
+#include <QFileInfo>
+#include <QFont>
+#include <QFontMetrics>
 #include <QGraphicsLineItem>
 #include <QGraphicsTextItem>
+#include <QImageReader>
+#include <QPainter>
 #include <QPen>
 #include <QPixmap>
+#include <QPixmapCache>
 #include <QPrinter>
 #include <QRectF>
 #include <QString>
 #include <QVector>
-#include <Qt>
-#include <QDebug>
-#include <QFont>
-#include <QFontMetrics>
-#include <QImageReader>
-#include <QPixmapCache>
-#include <QPainter>
-#include <QFileInfo>
+#include <QtMath>
 
-#include "../vmisc/vmath.h"
+#include "../ifc/exception/vexception.h"
+#include "../vmisc/compatibility.h"
 #include "../vmisc/def.h"
 #include "../vmisc/vabstractvalapplication.h"
-#include "../vmisc/compatibility.h"
-#include "../ifc/exception/vexception.h"
+
+using namespace Qt::Literals::StringLiterals;
 
 namespace
 {
 //---------------------------------------------------------------------------------------------------------------------
-qreal ToPixel(qreal val)
+auto ToPixel(qreal val) -> qreal
 {
     return val / 25.4 * PrintDPI; // Mm to pixels with current dpi.
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QImage Grayscale(QImage image)
+auto Grayscale(QImage image) -> QImage
 {
     for (int ii = 0; ii < image.height(); ii++)
     {
-        uchar* scan = image.scanLine(ii);
-        int depth = 4;
+        uchar *scan = image.scanLine(ii);
+        int const depth = 4;
         for (int jj = 0; jj < image.width(); jj++)
         {
-            QRgb* rgbpixel = reinterpret_cast<QRgb*>(scan + jj * depth);
-            int gray = qGray(*rgbpixel);
+            auto *rgbpixel = reinterpret_cast<QRgb *>(scan + jj * depth);
+            int const gray = qGray(*rgbpixel);
             *rgbpixel = QColor(gray, gray, gray, qAlpha(*rgbpixel)).rgba();
         }
     }
@@ -78,10 +79,11 @@ QImage Grayscale(QImage image)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QPixmap WatermarkImageFromCache(const VWatermarkData &watermarkData, const QString &watermarkPath, QString &error)
+auto WatermarkImageFromCache(const VWatermarkData &watermarkData, const QString &watermarkPath, QString &error)
+    -> QPixmap
 {
     QPixmap pixmap;
-    QString imagePath = AbsoluteMPath(watermarkPath, watermarkData.path);
+    QString const imagePath = AbsoluteMPath(watermarkPath, watermarkData.path);
 
     if (not QPixmapCache::find(imagePath, &pixmap))
     {
@@ -106,7 +108,7 @@ QPixmap WatermarkImageFromCache(const VWatermarkData &watermarkData, const QStri
         tmp.fill(Qt::transparent);
         QPainter p;
         p.begin(&tmp);
-        p.setOpacity(watermarkData.opacity/100.);
+        p.setOpacity(watermarkData.opacity / 100.);
         p.drawImage(QPointF(), watermark);
         p.end();
 
@@ -116,16 +118,17 @@ QPixmap WatermarkImageFromCache(const VWatermarkData &watermarkData, const QStri
     }
     return pixmap;
 }
-}
+} // namespace
 
 //---------------------------------------------------------------------------------------------------------------------
 VPoster::VPoster(const QPrinter *printer)
-    :printer(printer), allowance(static_cast<quint32>(qRound(CmToPixel(1.))))
+  : printer(printer),
+    allowance(static_cast<quint32>(qRound(CmToPixel(1.))))
 {
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QVector<PosterData> VPoster::Calc(const QSize &imageRect, int page, PageOrientation orientation) const
+auto VPoster::Calc(const QSize &imageRect, int page, PageOrientation orientation) const -> QVector<PosterData>
 {
     QVector<PosterData> poster;
 
@@ -137,9 +140,9 @@ QVector<PosterData> VPoster::Calc(const QSize &imageRect, int page, PageOrientat
     const int rows = CountRows(imageRect.height(), orientation);
     const int columns = CountColumns(imageRect.width(), orientation);
 
-    for (int i=0; i < rows; i++)
+    for (int i = 0; i < rows; i++)
     {
-        for (int j=0; j< columns; j++)
+        for (int j = 0; j < columns; j++)
         {
             PosterData data = Cut(i, j, imageRect, orientation);
             data.index = static_cast<quint32>(page);
@@ -153,15 +156,11 @@ QVector<PosterData> VPoster::Calc(const QSize &imageRect, int page, PageOrientat
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QVector<QGraphicsItem *> VPoster::Tile(QGraphicsItem *parent, const PosterData &img, int sheets,
-                                       const VWatermarkData &watermarkData, const QString &watermarkPath) const
+auto VPoster::Tile(QGraphicsItem *parent, const PosterData &img, vsizetype sheets, const VWatermarkData &watermarkData,
+                   const QString &watermarkPath) const -> QVector<QGraphicsItem *>
 {
     QVector<QGraphicsItem *> data;
-#if QT_VERSION >= QT_VERSION_CHECK(5, 5, 0)
     data.append(Borders(parent, img, sheets));
-#else
-    data += Borders(parent, img, sheets);
-#endif
 
     if (watermarkData.opacity > 0)
     {
@@ -180,7 +179,7 @@ QVector<QGraphicsItem *> VPoster::Tile(QGraphicsItem *parent, const PosterData &
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QVector<QGraphicsItem *> VPoster::Borders(QGraphicsItem *parent, const PosterData &img, int sheets) const
+auto VPoster::Borders(QGraphicsItem *parent, const PosterData &img, vsizetype sheets) const -> QVector<QGraphicsItem *>
 {
     SCASSERT(parent != nullptr)
 
@@ -195,43 +194,43 @@ QVector<QGraphicsItem *> VPoster::Borders(QGraphicsItem *parent, const PosterDat
 
     const QRect rec = img.rect;
     if (img.column != 0)
-    {// Left border
+    { // Left border
         auto *line = new QGraphicsLineItem(parent);
         line->setPen(pen);
         line->setLine(rec.x(), rec.y(), rec.x(), rec.y() + rec.height());
         data.append(line);
 
         auto *scissors = new QGraphicsPixmapItem(QPixmap(QStringLiteral("://scissors_vertical.png")), parent);
-        scissors->setPos(rec.x(), rec.y() + rec.height()-static_cast<int>(allowance));
+        scissors->setPos(rec.x(), rec.y() + rec.height() - static_cast<int>(allowance));
         data.append(scissors);
     }
 
-    if (img.column != img.columns-1)
-    {// Right border
+    if (img.column != img.columns - 1)
+    { // Right border
         auto *line = new QGraphicsLineItem(parent);
         line->setPen(pen);
-        line->setLine(rec.x() + rec.width()-static_cast<int>(allowance), rec.y(),
-                      rec.x() + rec.width()-static_cast<int>(allowance), rec.y() + rec.height());
+        line->setLine(rec.x() + rec.width() - static_cast<int>(allowance), rec.y(),
+                      rec.x() + rec.width() - static_cast<int>(allowance), rec.y() + rec.height());
         data.append(line);
     }
 
     if (img.row != 0)
-    {// Top border
+    { // Top border
         auto *line = new QGraphicsLineItem(parent);
         line->setPen(pen);
         line->setLine(rec.x(), rec.y(), rec.x() + rec.width(), rec.y());
         data.append(line);
 
         auto *scissors = new QGraphicsPixmapItem(QPixmap(QStringLiteral("://scissors_horizontal.png")), parent);
-        scissors->setPos(rec.x() + rec.width()-static_cast<int>(allowance), rec.y());
+        scissors->setPos(rec.x() + rec.width() - static_cast<int>(allowance), rec.y());
         data.append(scissors);
     }
 
     // Bottom border (mandatory)
     auto *line = new QGraphicsLineItem(parent);
     line->setPen(pen);
-    line->setLine(rec.x(), rec.y() + rec.height()-static_cast<int>(allowance),
-                  rec.x() + rec.width(), rec.y() + rec.height()-static_cast<int>(allowance));
+    line->setLine(rec.x(), rec.y() + rec.height() - static_cast<int>(allowance), rec.x() + rec.width(),
+                  rec.y() + rec.height() - static_cast<int>(allowance));
     data.append(line);
 
     // Ruler
@@ -242,24 +241,26 @@ QVector<QGraphicsItem *> VPoster::Borders(QGraphicsItem *parent, const PosterDat
 
     const int layoutX = 15;
     const int layoutY = 5;
-    labels->setPos(rec.x() + layoutX, rec.y() + rec.height()-static_cast<int>(allowance)+layoutY);
-    labels->setTextWidth(rec.width()-(static_cast<int>(allowance)+layoutX));
+    labels->setPos(rec.x() + layoutX, rec.y() + rec.height() - static_cast<int>(allowance) + layoutY);
+    labels->setTextWidth(rec.width() - (static_cast<int>(allowance) + layoutX));
 
-    const QString grid = tr("Grid ( %1 , %2 )").arg(img.row+1).arg(img.column+1);
-    const QString page = tr("Page %1 of %2").arg(img.row*(img.columns)+img.column+1).arg(img.rows*img.columns);
+    const QString grid =
+        QCoreApplication::translate("VPoster", "Grid ( %1 , %2 )").arg(img.row + 1).arg(img.column + 1);
+    const QString page = QCoreApplication::translate("VPoster", "Page %1 of %2")
+                             .arg(img.row * (img.columns) + img.column + 1)
+                             .arg(img.rows * img.columns);
 
     QString sheet;
     if (sheets > 1)
     {
-        sheet = tr("Sheet %1 of %2").arg(img.index+1).arg(sheets);
+        sheet = QCoreApplication::translate("VPoster", "Sheet %1 of %2").arg(img.index + 1).arg(sheets);
     }
 
-    labels->setHtml(QString("<table width='100%'>"
-                            "<tr>"
-                            "<td>%1</td><td align='center'>%2</td><td align='right'>%3</td>"
-                            "</tr>"
-                            "</table>")
-                    .arg(grid, page, sheet));
+    labels->setHtml(u"<table width='100%'>"
+                    u"<tr>"
+                    u"<td>%1</td><td align='center'>%2</td><td align='right'>%3</td>"
+                    u"</tr>"
+                    u"</table>"_s.arg(grid, page, sheet));
 
     data.append(labels);
 
@@ -267,27 +268,27 @@ QVector<QGraphicsItem *> VPoster::Borders(QGraphicsItem *parent, const PosterDat
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QVector<QGraphicsItem *> VPoster::TextWatermark(QGraphicsItem *parent, const PosterData &img,
-                                                const VWatermarkData &watermarkData) const
+auto VPoster::TextWatermark(QGraphicsItem *parent, const PosterData &img, const VWatermarkData &watermarkData) const
+    -> QVector<QGraphicsItem *>
 {
     SCASSERT(parent != nullptr)
 
     QVector<QGraphicsItem *> data;
 
-    QGraphicsSimpleTextItem *text = new QGraphicsSimpleTextItem(watermarkData.text, parent);
+    auto *text = new QGraphicsSimpleTextItem(watermarkData.text, parent);
     text->setFont(watermarkData.font);
 
     QPen pen = text->pen();
     pen.setColor(watermarkData.textColor);
     text->setPen(pen);
 
-    text->setOpacity(watermarkData.opacity/100.);
+    text->setOpacity(watermarkData.opacity / 100.);
     text->setTransformOriginPoint(text->boundingRect().center());
     text->setRotation(-watermarkData.textRotation);
 
     const QRect boundingRect = text->boundingRect().toRect();
-    int x = img.rect.x() + (img.rect.width() - boundingRect.width()) / 2;
-    int y = img.rect.y() + (img.rect.height() - boundingRect.height()) / 2;
+    int const x = img.rect.x() + (img.rect.width() - boundingRect.width()) / 2;
+    int const y = img.rect.y() + (img.rect.height() - boundingRect.height()) / 2;
 
     text->setX(x);
     text->setY(y);
@@ -299,9 +300,8 @@ QVector<QGraphicsItem *> VPoster::TextWatermark(QGraphicsItem *parent, const Pos
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QVector<QGraphicsItem *> VPoster::ImageWatermark(QGraphicsItem *parent, const PosterData &img,
-                                                 const VWatermarkData &watermarkData,
-                                                 const QString &watermarkPath) const
+auto VPoster::ImageWatermark(QGraphicsItem *parent, const PosterData &img, const VWatermarkData &watermarkData,
+                             const QString &watermarkPath) const -> QVector<QGraphicsItem *>
 {
     SCASSERT(parent != nullptr)
 
@@ -309,17 +309,19 @@ QVector<QGraphicsItem *> VPoster::ImageWatermark(QGraphicsItem *parent, const Po
 
     QGraphicsItem *image = nullptr;
 
-    QFileInfo f(watermarkData.path);
+    QFileInfo const f(watermarkData.path);
     if (f.suffix() == "png" || f.suffix() == "jpg" || f.suffix() == "jpeg" || f.suffix() == "bmp")
     {
         QString error;
-        QPixmap watermark = WatermarkImageFromCache(watermarkData, watermarkPath, error);
+        QPixmap const watermark = WatermarkImageFromCache(watermarkData, watermarkPath, error);
 
         if (watermark.isNull())
         {
-            const QString errorMsg = tr("Cannot open the watermark image.") + QChar(' ') + error;
-            VAbstractApplication::VApp()->IsPedantic() ? throw VException(errorMsg) :
-                                              qWarning() << VAbstractValApplication::warningMessageSignature + errorMsg;
+            const QString errorMsg =
+                QCoreApplication::translate("VPoster", "Cannot open the watermark image.") + ' '_L1 + error;
+            VAbstractApplication::VApp()->IsPedantic()
+                ? throw VException(errorMsg)
+                : qWarning() << VAbstractValApplication::warningMessageSignature + errorMsg;
             return data;
         }
 
@@ -327,9 +329,11 @@ QVector<QGraphicsItem *> VPoster::ImageWatermark(QGraphicsItem *parent, const Po
     }
     else
     {
-        const QString errorMsg = tr("Not supported file suffix '%1'").arg(f.suffix());
-        VAbstractApplication::VApp()->IsPedantic() ? throw VException(errorMsg) :
-                                              qWarning() << VAbstractValApplication::warningMessageSignature + errorMsg;
+        const QString errorMsg =
+            QCoreApplication::translate("VPoster", "Not supported file suffix '%1'").arg(f.suffix());
+        VAbstractApplication::VApp()->IsPedantic()
+            ? throw VException(errorMsg)
+            : qWarning() << VAbstractValApplication::warningMessageSignature + errorMsg;
         return data;
     }
 
@@ -338,8 +342,8 @@ QVector<QGraphicsItem *> VPoster::ImageWatermark(QGraphicsItem *parent, const Po
     image->setRotation(-watermarkData.imageRotation);
 
     const QRect boundingRect = image->boundingRect().toRect();
-    int x = img.rect.x() + (img.rect.width() - boundingRect.width()) / 2;
-    int y = img.rect.y() + (img.rect.height() - boundingRect.height()) / 2;
+    int const x = img.rect.x() + (img.rect.width() - boundingRect.width()) / 2;
+    int const y = img.rect.y() + (img.rect.height() - boundingRect.height()) / 2;
 
     image->setX(x);
     image->setY(y);
@@ -350,12 +354,12 @@ QVector<QGraphicsItem *> VPoster::ImageWatermark(QGraphicsItem *parent, const Po
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-int VPoster::CountRows(int height, PageOrientation orientation) const
+auto VPoster::CountRows(int height, PageOrientation orientation) const -> int
 {
     const qreal imgLength = height;
     qreal pageLength = 0;
 
-    if(orientation == PageOrientation::Landscape)
+    if (orientation == PageOrientation::Landscape)
     {
         pageLength = PageRect().width();
     }
@@ -368,19 +372,17 @@ int VPoster::CountRows(int height, PageOrientation orientation) const
     {
         return 1;
     }
-    else
-    {
-        return qCeil(imgLength/(pageLength - static_cast<int>(allowance)));
-    }
+
+    return qCeil(imgLength / (pageLength - static_cast<int>(allowance)));
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-int VPoster::CountColumns(int width, PageOrientation orientation) const
+auto VPoster::CountColumns(int width, PageOrientation orientation) const -> int
 {
     const qreal imgLength = width;
     qreal pageLength = 0;
 
-    if(orientation == PageOrientation::Landscape)
+    if (orientation == PageOrientation::Landscape)
     {
         pageLength = PageRect().height();
     }
@@ -393,20 +395,18 @@ int VPoster::CountColumns(int width, PageOrientation orientation) const
     {
         return 1;
     }
-    else
-    {
-        return qCeil(imgLength/(pageLength-static_cast<int>(allowance)));
-    }
+
+    return qCeil(imgLength / (pageLength - static_cast<int>(allowance)));
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-PosterData VPoster::Cut(int i, int j, const QSize &imageRect, PageOrientation orientation) const
+auto VPoster::Cut(int i, int j, const QSize &imageRect, PageOrientation orientation) const -> PosterData
 {
     Q_UNUSED(imageRect)
 
     int pageLengthX, pageLengthY;
 
-    if(orientation == PageOrientation::Landscape)
+    if (orientation == PageOrientation::Landscape)
     {
         pageLengthX = PageRect().height();
         pageLengthY = PageRect().width();
@@ -417,8 +417,8 @@ PosterData VPoster::Cut(int i, int j, const QSize &imageRect, PageOrientation or
         pageLengthY = PageRect().height();
     }
 
-    const int x = j*pageLengthX - j*static_cast<int>(allowance);
-    const int y = i*pageLengthY - i*static_cast<int>(allowance);
+    const int x = j * pageLengthX - j * static_cast<int>(allowance);
+    const int y = i * pageLengthY - i * static_cast<int>(allowance);
 
     SCASSERT(x <= imageRect.width())
     SCASSERT(y <= imageRect.height())
@@ -432,19 +432,19 @@ PosterData VPoster::Cut(int i, int j, const QSize &imageRect, PageOrientation or
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QRect VPoster::PageRect() const
+auto VPoster::PageRect() const -> QRect
 {
     // Because the Point unit is defined to be 1/72th of an inch
     // we can't use method pageRect(QPrinter::Point). Our dpi value can be different.
     // We convert value yourself to pixels.
     const QRectF rect = printer->pageRect(QPrinter::Millimeter);
 
-    if(printer->fullPage())
+    if (printer->fullPage())
     {
         QPageLayout layout = printer->pageLayout();
         layout.setUnits(QPageLayout::Millimeter);
-        QMarginsF pMargins = layout.margins();
-        QRectF newRect = rect.marginsRemoved(pMargins);
+        QMarginsF const pMargins = layout.margins();
+        QRectF const newRect = rect.marginsRemoved(pMargins);
         const QRect pageRectFP(0, 0, qFloor(ToPixel(newRect.width())), qFloor(ToPixel(newRect.height())));
         return pageRectFP;
     }
@@ -463,11 +463,11 @@ void VPoster::Ruler(QVector<QGraphicsItem *> &data, QGraphicsItem *parent, QRect
     QPen rulePen(Qt::NoBrush, 1, Qt::SolidLine);
     rulePen.setColor(Qt::black);
 
-    const qreal notchHeight = ToPixel(3); // mm
+    const qreal notchHeight = ToPixel(3);        // mm
     const qreal shortNotchHeight = ToPixel(1.1); // mm
-    Unit patternUnits = VAbstractValApplication::VApp()->patternUnits();
+    Unit const patternUnits = VAbstractValApplication::VApp()->patternUnits();
     const qreal step = UnitConvertor(1, patternUnits, Unit::Px);
-    double marksCount = rec.width() / step;
+    double const marksCount = rec.width() / step;
     int i = 0;
     while (i < marksCount)
     {
@@ -476,32 +476,30 @@ void VPoster::Ruler(QVector<QGraphicsItem *> &data, QGraphicsItem *parent, QRect
             auto *middleRuleLine = new QGraphicsLineItem(parent);
             middleRuleLine->setPen(rulePen);
             middleRuleLine->setLine(rec.x() + step * i - step / 2.,
-                          rec.y() + rec.height()-static_cast<int>(allowance),
-                          rec.x() + step * i - step / 2.,
-                          rec.y() + rec.height()-static_cast<int>(allowance) + shortNotchHeight);
+                                    rec.y() + rec.height() - static_cast<int>(allowance),
+                                    rec.x() + step * i - step / 2.,
+                                    rec.y() + rec.height() - static_cast<int>(allowance) + shortNotchHeight);
             data.append(middleRuleLine);
 
             auto *ruleLine = new QGraphicsLineItem(parent);
             ruleLine->setPen(rulePen);
-            ruleLine->setLine(rec.x() + step * i,
-                          rec.y() + rec.height()-static_cast<int>(allowance),
-                          rec.x() + step * i,
-                          rec.y() + rec.height()-static_cast<int>(allowance) + notchHeight);
+            ruleLine->setLine(rec.x() + step * i, rec.y() + rec.height() - static_cast<int>(allowance),
+                              rec.x() + step * i, rec.y() + rec.height() - static_cast<int>(allowance) + notchHeight);
             data.append(ruleLine);
         }
         else
         {
             auto *units = new QGraphicsTextItem(parent);
-            units->setPlainText(patternUnits == Unit::Cm || patternUnits == Unit::Mm ? tr("cm", "unit") :
-                                                                                       tr("in", "unit"));
+            units->setPlainText(patternUnits == Unit::Cm || patternUnits == Unit::Mm ? tr("cm", "unit")
+                                                                                     : tr("in", "unit"));
             QFont fnt = units->font();
             fnt.setPointSize(10);
 
             qreal unitsWidth = 0;
-            QFontMetrics fm(fnt);
-            unitsWidth = TextWidth(fm, units->toPlainText());
-            units->setPos(rec.x() + step*0.5-unitsWidth*0.7,
-                          rec.y() + rec.height()-static_cast<int>(allowance)-shortNotchHeight);
+            QFontMetrics const fm(fnt);
+            unitsWidth = fm.horizontalAdvance(units->toPlainText());
+            units->setPos(rec.x() + step * 0.5 - unitsWidth * 0.7,
+                          rec.y() + rec.height() - static_cast<int>(allowance) - shortNotchHeight);
             units->setFont(fnt);
             data.append(units);
         }
