@@ -28,69 +28,101 @@
 #ifndef VRAWSAPOINT_H
 #define VRAWSAPOINT_H
 
-#include <QPointF>
+#include <QtGlobal>
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
-#include "../vmisc/diagnostic.h"
-#endif // QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
-#include "../vmisc/def.h"
+#include "vlayoutpoint.h"
 
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_GCC("-Weffc++")
+// cppcheck-suppress unknownMacro
 QT_WARNING_DISABLE_GCC("-Wnon-virtual-dtor")
+QT_WARNING_DISABLE_CLANG("-Wnon-virtual-dtor")
 
-class VRawSAPoint : public QPointF
+class VRawSAPoint final : public VLayoutPoint
 {
 public:
-    Q_DECL_CONSTEXPR VRawSAPoint();
-    Q_DECL_CONSTEXPR VRawSAPoint(qreal xpos, qreal ypos);
-    Q_DECL_CONSTEXPR VRawSAPoint(QPointF p);
-    Q_DECL_CONSTEXPR VRawSAPoint(QPointF p, bool loopPoint);
+    constexpr VRawSAPoint() = default;
+    constexpr VRawSAPoint(qreal xpos, qreal ypos);
+    constexpr explicit VRawSAPoint(QPointF p);
+    constexpr explicit VRawSAPoint(const VLayoutPoint &p);
+    constexpr VRawSAPoint(QPointF p, bool curvePoint, bool turnPoint);
+    constexpr VRawSAPoint(QPointF p, bool curvePoint, bool turnPoint, bool loopPoint);
 
-    Q_DECL_CONSTEXPR bool LoopPoint() const;
-    Q_DECL_RELAXED_CONSTEXPR void SetLoopPoint(bool loopPoint);
+    constexpr auto LoopPoint() const -> bool;
+    constexpr void SetLoopPoint(bool loopPoint);
 
-    QJsonObject toJson() const;
+    constexpr auto Primary() const -> bool;
+    constexpr void SetPrimary(bool primary);
+
+    auto toJson() const -> QJsonObject;
 
 private:
     bool m_loopPoint{false};
+    bool m_primary{false};
 };
 
-Q_DECLARE_METATYPE(VRawSAPoint)
+Q_DECLARE_METATYPE(VRawSAPoint)                  // NOLINT
 Q_DECLARE_TYPEINFO(VRawSAPoint, Q_MOVABLE_TYPE); // NOLINT
 
 //---------------------------------------------------------------------------------------------------------------------
-Q_DECL_CONSTEXPR inline VRawSAPoint::VRawSAPoint()
-{}
+constexpr VRawSAPoint::VRawSAPoint(qreal xpos, qreal ypos)
+  : VLayoutPoint(xpos, ypos)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-Q_DECL_CONSTEXPR inline VRawSAPoint::VRawSAPoint(qreal xpos, qreal ypos)
-    : QPointF(xpos, ypos)
-{}
+constexpr VRawSAPoint::VRawSAPoint(QPointF p)
+  : VLayoutPoint(p)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-Q_DECL_CONSTEXPR inline VRawSAPoint::VRawSAPoint(QPointF p)
-    : QPointF(p)
-{}
+constexpr VRawSAPoint::VRawSAPoint(const VLayoutPoint &p)
+  : VLayoutPoint(p)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-Q_DECL_CONSTEXPR inline VRawSAPoint::VRawSAPoint(QPointF p, bool loopPoint)
-    : QPointF(p),
-      m_loopPoint(loopPoint)
-{}
+constexpr VRawSAPoint::VRawSAPoint(QPointF p, bool curvePoint, bool turnPoint)
+  : VLayoutPoint(p)
+{
+    SetCurvePoint(curvePoint);
+    SetTurnPoint(turnPoint);
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-Q_DECL_CONSTEXPR inline bool VRawSAPoint::LoopPoint() const
+constexpr VRawSAPoint::VRawSAPoint(QPointF p, bool curvePoint, bool turnPoint, bool loopPoint)
+  : VLayoutPoint(p),
+    m_loopPoint(loopPoint)
+{
+    SetCurvePoint(curvePoint);
+    SetTurnPoint(turnPoint);
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+constexpr auto VRawSAPoint::LoopPoint() const -> bool
 {
     return m_loopPoint;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-Q_DECL_RELAXED_CONSTEXPR inline void VRawSAPoint::SetLoopPoint(bool loopPoint)
+constexpr void VRawSAPoint::SetLoopPoint(bool loopPoint)
 {
     m_loopPoint = loopPoint;
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+constexpr auto VRawSAPoint::Primary() const -> bool
+{
+    return m_primary;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+constexpr void VRawSAPoint::SetPrimary(bool primary)
+{
+    m_primary = primary;
+}
+
 QT_WARNING_POP
 
 #endif // VRAWSAPOINT_H
