@@ -33,9 +33,12 @@
 #include <QColor>
 #include <QComboBox>
 #include <QCursor>
+#include <QDesktopServices>
 #include <QDir>
 #include <QDirIterator>
 #include <QFileInfo>
+#include <QGlobalStatic>
+#include <QGraphicsItem>
 #include <QGuiApplication>
 #include <QImage>
 #include <QLatin1Char>
@@ -44,32 +47,86 @@
 #include <QMessageLogger>
 #include <QObject>
 #include <QPixmap>
+#include <QPixmapCache>
 #include <QPrinterInfo>
 #include <QProcess>
 #include <QRgb>
-#include <QStaticStringData>
-#include <QStringData>
-#include <QStringDataPtr>
-#include <QtDebug>
-#include <QPixmapCache>
-#include <QGraphicsItem>
-#include <QGlobalStatic>
-#include <QDesktopServices>
 #include <QUrl>
+#include <QtDebug>
 
-#include "vabstractapplication.h"
-#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
-#   include "vdatastreamenum.h"
-#endif
 #include "../ifc/exception/vexception.h"
+#include "compatibility.h"
 #include "literals.h"
+#include "vabstractapplication.h"
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
-#include "../vmisc/diagnostic.h"
-#endif // QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
+using namespace Qt::Literals::StringLiterals;
+
+namespace
+{
+//---------------------------------------------------------------------------------------------------------------------
+auto LocalList() -> QStringList
+{
+    static QStringList fileNames;
+
+    // Check if file names have already been cached
+    if (!fileNames.isEmpty())
+    {
+        return fileNames;
+    }
+
+    QDirIterator it(VAbstractApplication::translationsPath(), QStringList("valentina_*.qm"), QDir::Files,
+                    QDirIterator::Subdirectories);
+    while (it.hasNext())
+    {
+        it.next();
+        fileNames.append(it.fileName());
+    }
+    return fileNames;
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-QPixmap QPixmapFromCache(const QString &pixmapPath)
+void InitLanguageList(QComboBox *combobox)
+{
+    SCASSERT(combobox != nullptr)
+    combobox->clear();
+
+    const QStringList fileNames = LocalList();
+    const QStringList supportedLocales = SupportedLocales();
+
+    for (auto locale : fileNames)
+    {
+        // get locale extracted by filename           "valentina_de_De.qm"
+        locale.truncate(locale.lastIndexOf('.'_L1));  // "valentina_de_De"
+        locale.remove(0, locale.indexOf('_'_L1) + 1); // "de_De"
+
+        if (locale.startsWith("ru"_L1) || !supportedLocales.contains(locale))
+        {
+            continue;
+        }
+
+        auto const loc = QLocale(locale);
+        QString const lang = loc.nativeLanguageName();
+        QString country = TerritoryToString(loc);
+        if (country == "Czechia"_L1)
+        {
+            country = "CzechRepublic"_L1;
+        }
+        QIcon const ico(u"://flags/%1.png"_s.arg(country));
+
+        combobox->addItem(ico, lang, locale);
+    }
+
+    // English language is internal and doesn't have own *.qm file.
+    // Since Qt 5.12 country names have spaces
+    QIcon const ico(u"://flags/%1.png"_s.arg(TerritoryToString(QLocale::UnitedStates)));
+    const auto en_US = QStringLiteral("en_US");
+    QString const lang = QLocale(en_US).nativeLanguageName();
+    combobox->addItem(ico, lang, en_US);
+}
+} // namespace
+
+//---------------------------------------------------------------------------------------------------------------------
+auto QPixmapFromCache(const QString &pixmapPath) -> QPixmap
 {
     QPixmap pixmap;
 
@@ -96,44 +153,14 @@ void SetItemOverrideCursor(QGraphicsItem *item, const QString &pixmapPath, int h
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QStringList SupportedLocales()
+auto SupportedLocales() -> QStringList
 {
-    return QStringList
-    {
-        "uk_UA",
-        "de_DE",
-        "cs_CZ",
-        "he_IL",
-        "fr_FR",
-        "it_IT",
-        "nl_NL",
-        "id_ID",
-        "es_ES",
-        "fi_FI",
-        "en_US",
-        "en_CA",
-        "en_IN",
-        "ro_RO",
-        "zh_CN",
-        "pt_BR",
-        "el_GR",
-        "pl_PL"
-    };
+    return QStringList{"uk_UA", "de_DE", "cs_CZ", "he_IL", "fr_FR", "it_IT", "nl_NL", "id_ID",
+                       "es_ES", "fi_FI", "ro_RO", "zh_CN", "pt_BR", "el_GR", "pl_PL"};
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-/**
- * @brief strippedName the function call around curFile to exclude the path to the file.
- * @param fullFileName full path to the file.
- * @return file name.
- */
-QString StrippedName(const QString &fullFileName)
-{
-    return QFileInfo(fullFileName).fileName();
-}
-
-//---------------------------------------------------------------------------------------------------------------------
-QString RelativeMPath(const QString &patternPath, const QString &absoluteMPath)
+auto RelativeMPath(const QString &patternPath, const QString &absoluteMPath) -> QString
 {
     if (patternPath.isEmpty() || absoluteMPath.isEmpty())
     {
@@ -149,7 +176,7 @@ QString RelativeMPath(const QString &patternPath, const QString &absoluteMPath)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString AbsoluteMPath(const QString &patternPath, const QString &relativeMPath)
+auto AbsoluteMPath(const QString &patternPath, const QString &relativeMPath) -> QString
 {
     if (patternPath.isEmpty() || relativeMPath.isEmpty())
     {
@@ -165,7 +192,7 @@ QString AbsoluteMPath(const QString &patternPath, const QString &relativeMPath)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QMarginsF GetMinPrinterFields(const QSharedPointer<QPrinter> &printer)
+auto GetMinPrinterFields(const QSharedPointer<QPrinter> &printer) -> QMarginsF
 {
     QPageLayout layout = printer->pageLayout();
     layout.setUnits(QPageLayout::Millimeter);
@@ -199,7 +226,7 @@ auto GetPrinterFields(const QSharedPointer<QPrinter> &printer) -> QMarginsF
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QPixmap darkenPixmap(const QPixmap &pixmap)
+auto darkenPixmap(const QPixmap &pixmap) -> QPixmap
 {
     QImage img = pixmap.toImage().convertToFormat(QImage::Format_ARGB32);
     const int imgh = img.height();
@@ -208,7 +235,9 @@ QPixmap darkenPixmap(const QPixmap &pixmap)
     {
         for (int x = 0; x < imgw; ++x)
         {
-            int h, s, v;
+            int h;
+            int s;
+            int v;
             QRgb pixel = img.pixel(x, y);
             const int a = qAlpha(pixel);
             QColor hsvColor(pixel);
@@ -227,32 +256,26 @@ QPixmap darkenPixmap(const QPixmap &pixmap)
 void ShowInGraphicalShell(const QString &filePath)
 {
 #ifdef Q_OS_MAC
-    QStringList args{
-        "-e", "tell application \"Finder\"",
-        "-e", "activate",
-        "-e", "select POSIX file \""+filePath+"\"",
-        "-e", "end tell"
-    };
+    QStringList args{"-e", "tell application \"Finder\"",
+                     "-e", "activate",
+                     "-e", "select POSIX file \"" + filePath + "\"",
+                     "-e", "end tell"};
     QProcess::startDetached(QStringLiteral("osascript"), args);
 #elif defined(Q_OS_WIN)
     QProcess::startDetached(QStringLiteral("explorer"), QStringList{"/select", QDir::toNativeSeparators(filePath)});
 #else
     const int timeout = 1000; // ms
-    QString command = QStringLiteral("dbus-send --reply-timeout=%1 --session --dest=org.freedesktop.FileManager1 "
-                                     "--type=method_call /org/freedesktop/FileManager1 "
-                                     "org.freedesktop.FileManager1.ShowItems array:string:\"%2\" string:\"\"")
-                          .arg(timeout).arg(QUrl::fromLocalFile(filePath).toString());
+    auto const command = QStringLiteral("dbus-send --reply-timeout=%1 --session --dest=org.freedesktop.FileManager1 "
+                                        "--type=method_call /org/freedesktop/FileManager1 "
+                                        "org.freedesktop.FileManager1.ShowItems array:string:\"%2\" string:\"\"")
+                             .arg(timeout)
+                             .arg(QUrl::fromLocalFile(filePath).toString());
 
     // Sending message through dbus will highlighting file
     QProcess dbus;
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QT_WARNING_PUSH
-    QT_WARNING_DISABLE_CLANG("-Wdeprecated-declarations")
-    QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")
-
-    dbus.start(command); // clazy:exclude=qt6-deprecated-api-fixes
-
-    QT_WARNING_POP
+    // This approach works too.
+    dbus.start(command, QStringList()); // clazy:exclude=qt6-deprecated-api-fixes
 #else
     dbus.startCommand(command);
 #endif
@@ -273,51 +296,37 @@ void ShowInGraphicalShell(const QString &filePath)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool IsOptionSet(int argc, char *argv[], const char *option)
+#ifdef Q_OS_MAC
+#if MACOS_LAYER_BACKING_AFFECTED
+void MacosEnableLayerBacking()
 {
-    for (int i = 1; i < argc; ++i)
+    QOperatingSystemVersion osVer = QOperatingSystemVersion::current();
+    const int majorVer = osVer.majorVersion();
+    const int minorVer = osVer.minorVersion();
+    if (((majorVer == 10 && minorVer >= 16) || majorVer >= 11) && qEnvironmentVariableIsEmpty("QT_MAC_WANTS_LAYER"))
     {
-        if (!qstrcmp(argv[i], option))
-        {
-            return true;
-        }
-    }
-    return false;
-}
-
-//---------------------------------------------------------------------------------------------------------------------
-// See issue #624. https://bitbucket.org/dismine/valentina/issues/624
-void InitHighDpiScaling(int argc, char *argv[])
-{
-    /* For more info see: http://doc.qt.io/qt-5/highdpi.html */
-    if (IsOptionSet(argc, argv, qPrintable(QLatin1String("--") + LONG_OPTION_NO_HDPI_SCALING)))
-    {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)
-        QCoreApplication::setAttribute(Qt::AA_DisableHighDpiScaling);
-#else
-        qputenv("QT_DEVICE_PIXEL_RATIO", QByteArray("1"));
-#endif
-    }
-    else
-    {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)
-        QApplication::setAttribute(Qt::AA_EnableHighDpiScaling); // DPI support
-#else
-        qputenv("QT_AUTO_SCREEN_SCALE_FACTOR", QByteArray("1"));
-#endif
+        qputenv("QT_MAC_WANTS_LAYER", "1");
     }
 }
+#endif // MACOS_LAYER_BACKING_AFFECTED
+#endif // Q_OS_MAC
 
-Q_GLOBAL_STATIC_WITH_ARGS(const QString, strTMark, (QLatin1String("tMark"))) // NOLINT
-Q_GLOBAL_STATIC_WITH_ARGS(const QString, strVMark, (QLatin1String("vMark"))) // NOLINT
-Q_GLOBAL_STATIC_WITH_ARGS(const QString, strVMark2, (QLatin1String("vMark2"))) // NOLINT
-Q_GLOBAL_STATIC_WITH_ARGS(const QString, strUMark, (QLatin1String("uMark"))) // NOLINT
-Q_GLOBAL_STATIC_WITH_ARGS(const QString, strBoxMark, (QLatin1String("boxMark"))) // NOLINT
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_CLANG("-Wunused-member-function")
+
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, strTMark, ("tMark"_L1))         // NOLINT
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, strVMark, ("vMark"_L1))         // NOLINT
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, strVMark2, ("vMark2"_L1))       // NOLINT
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, strUMark, ("uMark"_L1))         // NOLINT
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, strBoxMark, ("boxMark"_L1))     // NOLINT
+Q_GLOBAL_STATIC_WITH_ARGS(const QString, strCheckMark, ("checkMark"_L1)) // NOLINT
+
+QT_WARNING_POP
 
 //---------------------------------------------------------------------------------------------------------------------
-QString PassmarkLineTypeToString(PassmarkLineType type)
+auto PassmarkLineTypeToString(PassmarkLineType type) -> QString
 {
-    switch(type)
+    switch (type)
     {
         case PassmarkLineType::OneLine:
             return strOne;
@@ -327,14 +336,16 @@ QString PassmarkLineTypeToString(PassmarkLineType type)
             return strThree;
         case PassmarkLineType::TMark:
             return *strTMark;
-        case PassmarkLineType::VMark:
+        case PassmarkLineType::ExternalVMark:
             return *strVMark;
-        case PassmarkLineType::VMark2:
+        case PassmarkLineType::InternalVMark:
             return *strVMark2;
         case PassmarkLineType::UMark:
             return *strUMark;
         case PassmarkLineType::BoxMark:
             return *strBoxMark;
+        case PassmarkLineType::CheckMark:
+            return *strCheckMark;
         default:
             break;
     }
@@ -343,11 +354,12 @@ QString PassmarkLineTypeToString(PassmarkLineType type)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-PassmarkLineType StringToPassmarkLineType(const QString &value)
+auto StringToPassmarkLineType(const QString &value) -> PassmarkLineType
 {
-    const QStringList values{strOne, strTwo, strThree, *strTMark, *strVMark, *strVMark2, *strUMark, *strBoxMark};
+    const QStringList values{strOne,     strTwo,    strThree,    *strTMark,    *strVMark,
+                             *strVMark2, *strUMark, *strBoxMark, *strCheckMark};
 
-    switch(values.indexOf(value))
+    switch (values.indexOf(value))
     {
         case 0: // strOne
             return PassmarkLineType::OneLine;
@@ -358,13 +370,15 @@ PassmarkLineType StringToPassmarkLineType(const QString &value)
         case 3: // strTMark
             return PassmarkLineType::TMark;
         case 4: // strVMark
-            return PassmarkLineType::VMark;
+            return PassmarkLineType::ExternalVMark;
         case 5: // strVMark2
-            return PassmarkLineType::VMark2;
+            return PassmarkLineType::InternalVMark;
         case 6: // strUMark
             return PassmarkLineType::UMark;
         case 7: // strBoxMark
             return PassmarkLineType::BoxMark;
+        case 8: // strCheckMark
+            return PassmarkLineType::CheckMark;
         default:
             break;
     }
@@ -372,9 +386,9 @@ PassmarkLineType StringToPassmarkLineType(const QString &value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString PassmarkAngleTypeToString(PassmarkAngleType type)
+auto PassmarkAngleTypeToString(PassmarkAngleType type) -> QString
 {
-    switch(type)
+    switch (type)
     {
         case PassmarkAngleType::Straightforward:
             return strStraightforward;
@@ -393,25 +407,18 @@ QString PassmarkAngleTypeToString(PassmarkAngleType type)
         case PassmarkAngleType::Intersection2OnlyRight:
             return strIntersection2OnlyRight;
         default:
-            break;
+            return strStraightforward;
     }
-
-    return strStraightforward;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-PassmarkAngleType StringToPassmarkAngleType(const QString &value)
+auto StringToPassmarkAngleType(const QString &value) -> PassmarkAngleType
 {
-    const QStringList values = QStringList() << strStraightforward
-                                             << strBisector
-                                             << strIntersection
-                                             << strIntersectionOnlyLeft
-                                             << strIntersectionOnlyRight
-                                             << strIntersection2
-                                             << strIntersection2OnlyLeft
-                                             << strIntersection2OnlyRight;
+    const QStringList values{
+        strStraightforward,       strBisector,      strIntersection,          strIntersectionOnlyLeft,
+        strIntersectionOnlyRight, strIntersection2, strIntersection2OnlyLeft, strIntersection2OnlyRight};
 
-    switch(values.indexOf(value))
+    switch (values.indexOf(value))
     {
         case 0:
             return PassmarkAngleType::Straightforward;
@@ -430,34 +437,80 @@ PassmarkAngleType StringToPassmarkAngleType(const QString &value)
         case 7:
             return PassmarkAngleType::Intersection2OnlyRight;
         default:
-            break;
+            return PassmarkAngleType::Straightforward;
     }
-    return PassmarkAngleType::Straightforward;
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+auto FoldLineTypeToString(FoldLineType type) -> QString
+{
+    switch (type)
+    {
+        case FoldLineType::TwoArrowsTextUnder:
+            return strFoldTypeTwoArrowsTextUnder;
+        case FoldLineType::TwoArrows:
+            return strFoldTypeTwoArrows;
+        case FoldLineType::Text:
+            return strFoldTypeText;
+        case FoldLineType::ThreeDots:
+            return strFoldTypeThreeDots;
+        case FoldLineType::ThreeX:
+            return strFoldTypeThreeX;
+        case FoldLineType::None:
+            return strFoldTypeNone;
+        case FoldLineType::TwoArrowsTextAbove:
+        default:
+            return strFoldTypeTwoArrowsTextAbove;
+    }
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-Unit StrToUnits(const QString &unit)
+auto StringToFoldLineType(const QString &value) -> FoldLineType
 {
-    const QStringList units = QStringList() << unitMM << unitCM << unitINCH << unitPX;
-    Unit result = Unit::Cm;
+    const QStringList values{strFoldTypeTwoArrowsTextAbove, // 0
+                             strFoldTypeTwoArrowsTextUnder, // 1
+                             strFoldTypeTwoArrows,          // 2
+                             strFoldTypeText,               // 3
+                             strFoldTypeThreeDots,          // 4
+                             strFoldTypeThreeX,             // 5
+                             strFoldTypeNone};              // 6
+
+    switch (values.indexOf(value))
+    {
+        case 1:
+            return FoldLineType::TwoArrowsTextUnder;
+        case 2:
+            return FoldLineType::TwoArrows;
+        case 3:
+            return FoldLineType::Text;
+        case 4:
+            return FoldLineType::ThreeDots;
+        case 5:
+            return FoldLineType::ThreeX;
+        case 6:
+            return FoldLineType::None;
+        case 0:
+        default:
+            return FoldLineType::TwoArrowsTextAbove;
+    };
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto StrToUnits(const QString &unit) -> Unit
+{
+    const QStringList units{unitMM, unitCM, unitINCH, unitPX};
     switch (units.indexOf(unit))
     {
-        case 0:// mm
-            result = Unit::Mm;
-            break;
-        case 2:// inch
-            result = Unit::Inch;
-            break;
-        case 3:// px
-            result = Unit::Px;
-            break;
-        case 1:// cm
+        case 0: // mm
+            return Unit::Mm;
+        case 2: // inch
+            return Unit::Inch;
+        case 3: // px
+            return Unit::Px;
+        case 1: // cm
         default:
-            result = Unit::Cm;
-            break;
+            return Unit::Cm;
     }
-    return result;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -469,83 +522,46 @@ Unit StrToUnits(const QString &unit)
  * @param translate true if need show translated name. Default value false.
  * @return string reprezantation for unit.
  */
-QString UnitsToStr(const Unit &unit, const bool translate)
+auto UnitsToStr(const Unit &unit, const bool translate) -> QString
 {
-    QString result;
     switch (unit)
     {
         case Unit::Mm:
-            translate ? result = QObject::tr("mm") : result = unitMM;
-            break;
+            return translate ? QObject::tr("mm") : unitMM;
         case Unit::Inch:
-            translate ? result = QObject::tr("inch") : result = unitINCH;
-            break;
+            return translate ? QObject::tr("inch") : unitINCH;
         case Unit::Px:
-            translate ? result = QObject::tr("px") : result = unitPX;
-            break;
+            return translate ? QObject::tr("px") : unitPX;
         case Unit::LAST_UNIT_DO_NOT_USE:
-            break;
+            return {};
         case Unit::Cm:
         default:
-            translate ? result = QObject::tr("cm") : result = unitCM;
-            break;
+            return translate ? QObject::tr("cm") : unitCM;
     }
-    return result;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void InitLanguages(QComboBox *combobox)
 {
-    SCASSERT(combobox != nullptr)
-    combobox->clear();
-
-    QStringList fileNames;
-    QDirIterator it(VAbstractApplication::translationsPath(), QStringList("valentina_*.qm"), QDir::Files,
-                    QDirIterator::Subdirectories);
-    while (it.hasNext())
-    {
-        it.next();
-        fileNames.append(it.fileName());
-    }
-
-    bool englishUS = false;
-    const QString en_US = QStringLiteral("en_US");
-
-    for (auto locale : fileNames)
-    {
-        // get locale extracted by filename           "valentina_de_De.qm"
-        locale.truncate(locale.lastIndexOf('.'));  // "valentina_de_De"
-        locale.remove(0, locale.indexOf('_') + 1); // "de_De"
-
-        if (locale.startsWith(QLatin1String("ru")))
-        {
-            continue;
-        }
-
-        if (not englishUS)
-        {
-            englishUS = (en_US == locale);
-        }
-
-        QLocale loc = QLocale(locale);
-        QString lang = loc.nativeLanguageName();
-        // Since Qt 5.12 country names have spaces
-        QIcon ico(QString("://flags/%1.png").arg(QLocale::countryToString(loc.country()).remove(' ')));
-
-        combobox->addItem(ico, lang, locale);
-    }
-
-    if (combobox->count() == 0 || not englishUS)
-    {
-        // English language is internal and doens't have own *.qm file.
-        // Since Qt 5.12 country names have spaces
-        QIcon ico(QString("://flags/%1.png").arg(QLocale::countryToString(QLocale::UnitedStates).remove(' ')));
-        QString lang = QLocale(en_US).nativeLanguageName();
-        combobox->addItem(ico, lang, en_US);
-    }
+    InitLanguageList(combobox);
 
     // set default translators and language checked
-    qint32 index = combobox->findData(VAbstractApplication::VApp()->Settings()->GetLocale());
+    qint32 const index = combobox->findData(VAbstractApplication::VApp()->Settings()->GetLocale());
+    if (index != -1)
+    {
+        combobox->setCurrentIndex(index);
+    }
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void InitPieceLabelLanguages(QComboBox *combobox)
+{
+    InitLanguageList(combobox);
+
+    combobox->addItem(QApplication::translate("InitPieceLabelLanguages", "Default"),
+                      VCommonSettings::defaultPieceLabelLocale);
+
+    qint32 const index = combobox->findData(VAbstractApplication::VApp()->Settings()->GetPieceLabelLocale());
     if (index != -1)
     {
         combobox->setCurrentIndex(index);
@@ -557,7 +573,7 @@ const quint16 CustomSARecord::classVersion = 1;
 
 // Friend functions
 //---------------------------------------------------------------------------------------------------------------------
-QDataStream &operator<<(QDataStream &out, const CustomSARecord &record)
+auto operator<<(QDataStream &out, const CustomSARecord &record) -> QDataStream &
 {
     out << CustomSARecord::streamHeader << CustomSARecord::classVersion;
 
@@ -574,17 +590,17 @@ QDataStream &operator<<(QDataStream &out, const CustomSARecord &record)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QDataStream &operator>>(QDataStream &in, CustomSARecord &record)
+auto operator>>(QDataStream &in, CustomSARecord &record) -> QDataStream &
 {
     quint32 actualStreamHeader = 0;
     in >> actualStreamHeader;
 
     if (actualStreamHeader != CustomSARecord::streamHeader)
     {
-        QString message = QCoreApplication::tr("CustomSARecord prefix mismatch error: actualStreamHeader = 0x%1 "
-                                               "and streamHeader = 0x%2")
-                .arg(actualStreamHeader, 8, 0x10, QChar('0'))
-                .arg(CustomSARecord::streamHeader, 8, 0x10, QChar('0'));
+        QString const message = QCoreApplication::tr("CustomSARecord prefix mismatch error: actualStreamHeader = 0x%1 "
+                                                     "and streamHeader = 0x%2")
+                                    .arg(actualStreamHeader, 8, 0x10, '0'_L1)
+                                    .arg(CustomSARecord::streamHeader, 8, 0x10, '0'_L1);
         throw VException(message);
     }
 
@@ -593,9 +609,10 @@ QDataStream &operator>>(QDataStream &in, CustomSARecord &record)
 
     if (actualClassVersion > CustomSARecord::classVersion)
     {
-        QString message = QCoreApplication::tr("CustomSARecord compatibility error: actualClassVersion = %1 and "
-                                               "classVersion = %2")
-                .arg(actualClassVersion).arg(CustomSARecord::classVersion);
+        QString const message = QCoreApplication::tr("CustomSARecord compatibility error: actualClassVersion = %1 and "
+                                                     "classVersion = %2")
+                                    .arg(actualClassVersion)
+                                    .arg(CustomSARecord::classVersion);
         throw VException(message);
     }
 
@@ -605,18 +622,18 @@ QDataStream &operator>>(QDataStream &in, CustomSARecord &record)
     in >> record.reverse;
     in >> record.includeType;
 
-//    if (actualClassVersion >= 2)
-//    {
+    //    if (actualClassVersion >= 2)
+    //    {
 
-//    }
+    //    }
 
     return in;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString IncrementTypeToString(IncrementType type)
+auto IncrementTypeToString(IncrementType type) -> QString
 {
-    switch(type)
+    switch (type)
     {
         case IncrementType::Increment:
             return strTypeIncrement;
@@ -630,11 +647,11 @@ QString IncrementTypeToString(IncrementType type)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-IncrementType StringToIncrementType(const QString &value)
+auto StringToIncrementType(const QString &value) -> IncrementType
 {
-    const QStringList values { strTypeIncrement, strTypeSeparator };
+    const QStringList values{strTypeIncrement, strTypeSeparator};
 
-    switch(values.indexOf(value))
+    switch (values.indexOf(value))
     {
         case 0:
             return IncrementType::Increment;
@@ -647,9 +664,9 @@ IncrementType StringToIncrementType(const QString &value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString MeasurementTypeToString(MeasurementType type)
+auto MeasurementTypeToString(MeasurementType type) -> QString
 {
-    switch(type)
+    switch (type)
     {
         case MeasurementType::Measurement:
             return strTypeMeasurement;
@@ -663,11 +680,11 @@ QString MeasurementTypeToString(MeasurementType type)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-MeasurementType StringToMeasurementType(const QString &value)
+auto StringToMeasurementType(const QString &value) -> MeasurementType
 {
-    const QStringList values { strTypeMeasurement, strTypeSeparator };
+    const QStringList values{strTypeMeasurement, strTypeSeparator};
 
-    switch(values.indexOf(value))
+    switch (values.indexOf(value))
     {
         case 0:
             return MeasurementType::Measurement;
@@ -680,7 +697,7 @@ MeasurementType StringToMeasurementType(const QString &value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QStringList SplitFilePaths(const QString &path)
+auto SplitFilePaths(const QString &path) -> QStringList
 {
     QStringList result;
     QString subPath = QDir::cleanPath(path);
@@ -688,15 +705,14 @@ QStringList SplitFilePaths(const QString &path)
 
     do
     {
-        QFileInfo fileInfo(subPath);
+        QFileInfo const fileInfo(subPath);
         lastFileName = fileInfo.fileName();
         if (not lastFileName.isEmpty())
         {
             result.prepend(lastFileName);
             subPath = fileInfo.path();
         }
-    }
-    while(not lastFileName.isEmpty());
+    } while (not lastFileName.isEmpty());
 
     return result;
 }
