@@ -31,42 +31,41 @@
 
 #include <QtGlobal>
 #ifdef Q_OS_WIN
-#  include <qt_windows.h>
+#include <qt_windows.h>
 #endif /*Q_OS_WIN*/
 
-#include <qcompilerdetection.h>
+#include <QLineF>
+#include <QMargins>
 #include <QPrinter>
 #include <QString>
 #include <QStringList>
-#include <Qt>
 #include <csignal>
-#include <QMargins>
-#include <QLineF>
 
 #include "debugbreak.h"
 #include "defglobal.h"
-#if QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
-#include "diagnostic.h"
-#endif // QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
 
 template <class T> class QSharedPointer;
 
-#include <ciso646>
-
-// Backport of relaxed constexpr
-#if QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
-#if defined Q_COMPILER_CONSTEXPR
-# if defined(__cpp_constexpr) && __cpp_constexpr-0 >= 201304
-#  define Q_DECL_RELAXED_CONSTEXPR constexpr
-#  define Q_RELAXED_CONSTEXPR constexpr
-# else
-#  define Q_DECL_RELAXED_CONSTEXPR
-#  define Q_RELAXED_CONSTEXPR const
-# endif
-#else
-# define Q_DECL_RELAXED_CONSTEXPR
-# define Q_RELAXED_CONSTEXPR const
+// Header <ciso646> is removed in C++20.
+#if __cplusplus <= 201703L
+#include <ciso646> // and, not, or
 #endif
+
+// NOLINTNEXTLINE(cppcoreguidelines-macro-usage)
+#define COPY_CONSTRUCTOR_IMPL(className) className::className(const className &) = default;
+// NOLINTNEXTLINE(cppcoreguidelines-macro-usage)
+#define COPY_CONSTRUCTOR_IMPL_2(className, baseClassName) className::className(const className &) = default;
+
+// https://stackoverflow.com/questions/75008386/constructor-is-implicitly-deleted-because-its-exception-specification-does-not-m
+#if (defined(Q_CC_GNU) && Q_CC_GNU < 1001) && !defined(Q_CC_CLANG)
+// NOLINTNEXTLINE(cppcoreguidelines-macro-usage)
+#define DEF_CONSTRUCTOR(className)                                                                                     \
+    className() noexcept                                                                                               \
+    {                                                                                                                  \
+    }
+#else
+// NOLINTNEXTLINE(cppcoreguidelines-macro-usage)
+#define DEF_CONSTRUCTOR(className) className() noexcept = default;
 #endif
 
 class QComboBox;
@@ -83,15 +82,63 @@ constexpr qreal maxCurveApproximationScale = 10.0;
 constexpr int minLabelFontSize = 5;
 constexpr int maxLabelFontSize = 100;
 
-enum class NodeDetail : qint8 { Contour, Modeling };
-enum class SceneObject : qint8 { Point, Line, Spline, Arc, ElArc, SplinePath, Detail, Unknown };
-enum class MeasurementsType : qint8 { Multisize, Individual, Unknown};
-enum class Unit : qint8 { Mm = 0, Cm, Inch, Px, LAST_UNIT_DO_NOT_USE};
-enum class Source : qint8 { FromGui, FromFile, FromTool };
-enum class NodeUsage : bool {NotInUse = false, InUse = true};
-enum class SelectionType : bool {ByMousePress, ByMouseRelease};
-enum class PageOrientation : bool {Portrait = true, Landscape = false};
-enum class Draw : qint8 { Calculation, Modeling, Layout };
+enum class NodeDetail : qint8
+{
+    Contour,
+    Modeling
+};
+enum class SceneObject : qint8
+{
+    Point,
+    Line,
+    Spline,
+    Arc,
+    ElArc,
+    SplinePath,
+    Detail,
+    Unknown
+};
+enum class MeasurementsType : qint8
+{
+    Multisize,
+    Individual,
+    Unknown
+};
+enum class Unit : qint8
+{
+    Mm = 0,
+    Cm,
+    Inch,
+    Px,
+    LAST_UNIT_DO_NOT_USE
+};
+enum class Source : qint8
+{
+    FromGui,
+    FromFile,
+    FromTool
+};
+enum class NodeUsage : bool
+{
+    NotInUse = false,
+    InUse = true
+};
+enum class SelectionType : bool
+{
+    ByMousePress,
+    ByMouseRelease
+};
+enum class PageOrientation : bool
+{
+    Portrait = true,
+    Landscape = false
+};
+enum class Draw : qint8
+{
+    Calculation,
+    Modeling,
+    Layout
+};
 
 enum class PieceNodeAngle : quint8
 {
@@ -108,18 +155,19 @@ enum class PieceNodeAngle : quint8
 enum class PassmarkLineType : quint8
 {
     OneLine = 0, // Default
-    TwoLines,
-    ThreeLines,
-    TMark,
-    VMark,
-    VMark2,
-    UMark,
-    BoxMark,
+    TwoLines = 1,
+    ThreeLines = 2,
+    TMark = 3,
+    ExternalVMark = 4,
+    InternalVMark = 5,
+    UMark = 6,
+    BoxMark = 7,
+    CheckMark = 8,
     LAST_ONE_DO_NOT_USE
 };
 
-QString          PassmarkLineTypeToString(PassmarkLineType type);
-PassmarkLineType StringToPassmarkLineType(const QString &value);
+auto PassmarkLineTypeToString(PassmarkLineType type) -> QString;
+auto StringToPassmarkLineType(const QString &value) -> PassmarkLineType;
 
 enum class PassmarkAngleType : quint8
 {
@@ -134,13 +182,11 @@ enum class PassmarkAngleType : quint8
     LAST_ONE_DO_NOT_USE
 };
 
-QString           PassmarkAngleTypeToString(PassmarkAngleType type);
-PassmarkAngleType StringToPassmarkAngleType(const QString &value);
-
-
-Unit    StrToUnits(const QString &unit);
-QString UnitsToStr(const Unit &unit, const bool translate = false);
+auto PassmarkAngleTypeToString(PassmarkAngleType type) -> QString;
+auto StringToPassmarkAngleType(const QString &value) -> PassmarkAngleType;
 
+auto StrToUnits(const QString &unit) -> Unit;
+auto UnitsToStr(const Unit &unit, const bool translate = false) -> QString;
 
 enum class PiecePathIncludeType : quint8
 {
@@ -148,9 +194,32 @@ enum class PiecePathIncludeType : quint8
     AsCustomSA = 1
 };
 
-enum class PiecePathType :  quint8 {PiecePath = 0, CustomSeamAllowance = 1, InternalPath = 2, Unknown = 3};
+constexpr unsigned int defFoldLineFontSize{12};
 
-typedef int ToolVisHolderType;
+enum class FoldLineType : quint8
+{
+    TwoArrowsTextAbove = 0, // Default
+    TwoArrowsTextUnder,
+    TwoArrows,
+    Text,
+    ThreeDots,
+    ThreeX,
+    None,
+    LAST_ONE_DO_NOT_USE
+};
+
+auto FoldLineTypeToString(FoldLineType type) -> QString;
+auto StringToFoldLineType(const QString &value) -> FoldLineType;
+
+enum class PiecePathType : quint8
+{
+    PiecePath = 0,
+    CustomSeamAllowance = 1,
+    InternalPath = 2,
+    Unknown = 3
+};
+
+using ToolVisHolderType = int;
 enum class Tool : ToolVisHolderType
 {
     Arrow,
@@ -212,7 +281,9 @@ enum class Tool : ToolVisHolderType
     BackgroundImageControls,
     BackgroundPixmapImage,
     BackgroundSVGImage,
-    LAST_ONE_DO_NOT_USE //add new stuffs above this, this constant must be last and never used
+    ArcStart,
+    ArcEnd,
+    LAST_ONE_DO_NOT_USE // add new stuffs above this, this constant must be last and never used
 };
 
 enum class Vis : ToolVisHolderType
@@ -271,23 +342,52 @@ enum class Vis : ToolVisHolderType
     PieceItem,
     TextGraphicsItem,
     ScenePoint,
-    LAST_ONE_DO_NOT_USE //add new stuffs above this, this constant must be last and never used
+    LAST_ONE_DO_NOT_USE // add new stuffs above this, this constant must be last and never used
 };
 
-enum class VarType : qint8 { Measurement, MeasurementSeparator, Increment, IncrementSeparator, LineLength, CurveLength,
-                             CurveCLength, LineAngle, CurveAngle, ArcRadius, Unknown };
+enum class Layout : ToolVisHolderType
+{
+    GrainlineItem = static_cast<ToolVisHolderType>(Vis::LAST_ONE_DO_NOT_USE),
+    FoldLineItem,
+    LAST_ONE_DO_NOT_USE // add new stuffs above this, this constant must be last and never used
+};
 
-enum class IncrementType : qint8 { Increment, Separator };
+enum class VarType : qint8
+{
+    Measurement,
+    MeasurementSeparator,
+    Increment,
+    IncrementSeparator,
+    LineLength,
+    CurveLength,
+    CurveCLength,
+    LineAngle,
+    CurveAngle,
+    ArcRadius,
+    PieceExternalArea,
+    PieceSeamLineArea,
+    Unknown
+};
+
+enum class IncrementType : qint8
+{
+    Increment,
+    Separator
+};
 
 auto IncrementTypeToString(IncrementType type) -> QString;
 auto StringToIncrementType(const QString &value) -> IncrementType;
 
-enum class MeasurementType : qint8 { Measurement, Separator };
+enum class MeasurementType : qint8
+{
+    Measurement,
+    Separator
+};
 
 auto MeasurementTypeToString(MeasurementType type) -> QString;
 auto StringToMeasurementType(const QString &value) -> MeasurementType;
 
-enum class IMD: qint8 // Individual measurement dimension
+enum class IMD : qint8 // Individual measurement dimension
 {
     N, // None
     X, // height
@@ -321,66 +421,75 @@ enum class IMD: qint8 // Individual measurement dimension
  */
 #ifndef V_NO_ASSERT
 
-#define SCASSERT(cond)                                  \
-if (!(cond))                                            \
-{                                                       \
-    qCritical("ASSERT: %s in %s (%s:%u)",               \
-              #cond, Q_FUNC_INFO , __FILE__, __LINE__); \
-    debug_break();                                      \
-    abort();                                            \
-}
+#define SCASSERT(cond)                                                                                                 \
+    if (!(cond))                                                                                                       \
+    {                                                                                                                  \
+        qCritical("ASSERT: %s in %s (%s:%u)", #cond, Q_FUNC_INFO, __FILE__, __LINE__);                                 \
+        debug_break();                                                                                                 \
+        abort();                                                                                                       \
+    }
 
 #else // define but disable this function if debugging is not set
 #define SCASSERT(cond) qt_noop();
 #endif /* V_NO_ASSERT */
 
 #ifndef __has_cpp_attribute
-# define __has_cpp_attribute(x) 0
+#define __has_cpp_attribute(x) 0
 #endif
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 8, 0)
+#ifdef Q_OS_MAC
+// Fix QT issue on MacOS version 11.0 "Big Sur"
+//     https://bugreports.qt.io/browse/QTBUG-87014
+// Enables layer backing for Big Sur
+// Prevents 100% CPU & RAM utilization
+//
+// The fix at
+//
+//     https://codereview.qt-project.org/c/qt/qtbase/+/322228/3/src/plugins/platforms/cocoa/qnsview_drawing.mm
+//
+// enables layer backing if we're running on Big Sur OR we're running on
+// Catalina AND we were built with the Catalina SDK. Enable layer backing
+// here by setting QT_MAC_WANTS_LAYER=1, but only if we're running on Big
+// Sur and our version of Qt doesn't have a fix for QTBUG-87014.
 
-#ifndef QT_HAS_CPP_ATTRIBUTE
-#ifdef __has_cpp_attribute
-#  define QT_HAS_CPP_ATTRIBUTE(x) __has_cpp_attribute(x)
-#else
-#  define QT_HAS_CPP_ATTRIBUTE(x) 0
-#endif
-#endif // QT_HAS_CPP_ATTRIBUTE
+// We'll assume that it will be fixed in 5.12.11, 5.15.3, and 6.0.1.
+// Feel free to add other versions if needed.
+#define MACOS_LAYER_BACKING_AFFECTED                                                                                   \
+    ((QT_VERSION >= QT_VERSION_CHECK(5, 15, 0) && QT_VERSION < QT_VERSION_CHECK(5, 15, 3)) ||                          \
+     (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0) && QT_VERSION < QT_VERSION_CHECK(6, 0, 1)))
 
-#if defined(__cplusplus)
-#if QT_HAS_CPP_ATTRIBUTE(clang::fallthrough)
-#    define Q_FALLTHROUGH() [[clang::fallthrough]]
-#elif QT_HAS_CPP_ATTRIBUTE(gnu::fallthrough)
-#    define Q_FALLTHROUGH() [[gnu::fallthrough]]
-#elif QT_HAS_CPP_ATTRIBUTE(fallthrough)
-#  define Q_FALLTHROUGH() [[fallthrough]]
-#endif
-#endif
-#ifndef Q_FALLTHROUGH
-#  if (defined(Q_CC_GNU) && Q_CC_GNU >= 700) && !defined(Q_CC_INTEL)
-#    define Q_FALLTHROUGH() __attribute__((fallthrough))
-#  else
-#    define Q_FALLTHROUGH() (void)0
-#endif
-#endif // defined(__cplusplus)
-#endif // QT_VERSION < QT_VERSION_CHECK(5, 8, 0)
-
-bool IsOptionSet(int argc, char *argv[], const char *option);
-void InitHighDpiScaling(int argc, char *argv[]);
+#if MACOS_LAYER_BACKING_AFFECTED
+#include <QOperatingSystemVersion>
+void MacosEnableLayerBacking();
+#endif // MACOS_LAYER_BACKING_AFFECTED
+#endif // Q_OS_MAC
 
 // Don't forget to syncronize with XSD schema.
 const int userMaterialPlaceholdersQuantity = 20;
 
-QPixmap QPixmapFromCache(const QString &pixmapPath);
-void SetItemOverrideCursor(QGraphicsItem *item, const QString & pixmapPath, int hotX = -1, int hotY = -1);
-
-template<typename T> constexpr inline auto MmToPixel(T val) -> T { return (val / 25.4) * PrintDPI; }
-template<typename T> constexpr inline auto CmToPixel(T val) -> T { return ((val * 10.0) / 25.4) * PrintDPI; }
-template<typename T> constexpr inline auto InchToPixel(T val) -> T { return val * PrintDPI; }
+auto QPixmapFromCache(const QString &pixmapPath) -> QPixmap;
+void SetItemOverrideCursor(QGraphicsItem *item, const QString &pixmapPath, int hotX = -1, int hotY = -1);
 
 //---------------------------------------------------------------------------------------------------------------------
-Q_DECL_RELAXED_CONSTEXPR inline auto ToPixel(double val, const Unit &unit) -> double
+template <typename T> constexpr auto MmToPixel(T val) noexcept -> T
+{
+    return (val / 25.4) * PrintDPI;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+template <typename T> constexpr auto CmToPixel(T val) noexcept -> T
+{
+    return ((val * 10.0) / 25.4) * PrintDPI;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+template <typename T> constexpr auto InchToPixel(T val) noexcept -> T
+{
+    return val * PrintDPI;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+constexpr auto ToPixel(double val, const Unit &unit) noexcept -> double
 {
     switch (unit)
     {
@@ -398,12 +507,26 @@ Q_DECL_RELAXED_CONSTEXPR inline auto ToPixel(double val, const Unit &unit) -> do
     return 0;
 }
 
-template<typename T> constexpr inline auto PixelToMm(T pix) -> T { return (pix / PrintDPI) * 25.4; }
-template<typename T> constexpr inline auto PixelToCm(T pix) -> T { return ((pix / PrintDPI) * 25.4) / 10.0; }
-template<typename T> constexpr inline auto PixelToInch(T pix) -> T { return pix / PrintDPI; }
+//---------------------------------------------------------------------------------------------------------------------
+template <typename T> constexpr auto PixelToInch(T pix) -> T
+{
+    return pix / PrintDPI;
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-Q_DECL_RELAXED_CONSTEXPR inline auto FromPixel(double pix, const Unit &unit) -> double
+template <typename T> constexpr auto PixelToMm(T pix) -> T
+{
+    return PixelToInch(pix) * 25.4;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+template <typename T> constexpr auto PixelToCm(T pix) -> T
+{
+    return PixelToInch(pix) * 2.54;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+constexpr auto FromPixel(double pix, const Unit &unit) -> double
 {
     switch (unit)
     {
@@ -422,7 +545,85 @@ Q_DECL_RELAXED_CONSTEXPR inline auto FromPixel(double pix, const Unit &unit) ->
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-Q_DECL_RELAXED_CONSTEXPR inline auto UnitConvertor(qreal value, const Unit &from, const Unit &to) -> qreal
+template <typename T> constexpr auto Inch2ToPixel2(T val) -> T
+{
+    return val * (PrintDPI * PrintDPI);
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+template <typename T> constexpr auto Mm2ToPixel2(T val) -> T
+{
+    // There are 0.15500031 square inches in a square centimeter.
+    return Inch2ToPixel2(val * 0.001550031);
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+template <typename T> constexpr auto Cm2ToPixel2(T val) -> T
+{
+    // There are 0.15500031 square inches in a square centimeter.
+    return Inch2ToPixel2(val * 0.15500031);
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+constexpr auto ToPixel2(double val, const Unit &unit) -> double
+{
+    switch (unit)
+    {
+        case Unit::Mm:
+            return Mm2ToPixel2(val);
+        case Unit::Cm:
+            return Cm2ToPixel2(val);
+        case Unit::Inch:
+            return Inch2ToPixel2(val);
+        case Unit::Px:
+            return val;
+        default:
+            break;
+    }
+    return 0;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+template <typename T> constexpr auto Pixel2ToInch2(T pix) -> T
+{
+    return pix / (PrintDPI * PrintDPI);
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+template <typename T> constexpr auto Pixel2ToMm2(T pix) -> T
+{
+    // There are 0.15500031 square inches in a square centimeter.
+    return Pixel2ToInch2(pix) / 0.001550031;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+template <typename T> constexpr auto Pixel2ToCm2(T pix) -> T
+{
+    // There are 0.15500031 square inches in a square centimeter.
+    return Pixel2ToInch2(pix) / 0.15500031;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+constexpr auto FromPixel2(double pix, const Unit &unit) -> double
+{
+    switch (unit)
+    {
+        case Unit::Mm:
+            return Pixel2ToMm2(pix);
+        case Unit::Cm:
+            return Pixel2ToCm2(pix);
+        case Unit::Inch:
+            return Pixel2ToInch2(pix);
+        case Unit::Px:
+            return pix;
+        default:
+            break;
+    }
+    return 0;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+constexpr auto UnitConvertor(qreal value, const Unit &from, const Unit &to) -> qreal
 {
     switch (from)
     {
@@ -497,8 +698,8 @@ Q_DECL_RELAXED_CONSTEXPR inline auto UnitConvertor(qreal value, const Unit &from
  * @brief UnitConvertor Converts the values of the given margin from given unit to the new unit.
  * returns a new instand of QMarginsF.
  */
-Q_DECL_RELAXED_CONSTEXPR inline auto UnitConvertor(const QMarginsF &margins, const Unit &from,
-                                                   const Unit &to) -> QMarginsF
+constexpr auto UnitConvertor(const QMarginsF &margins, const Unit &from, const Unit &to)
+    -> QMarginsF
 {
     const qreal left = UnitConvertor(margins.left(), from, to);
     const qreal top = UnitConvertor(margins.top(), from, to);
@@ -509,36 +710,35 @@ Q_DECL_RELAXED_CONSTEXPR inline auto UnitConvertor(const QMarginsF &margins, con
 }
 
 void InitLanguages(QComboBox *combobox);
-Q_REQUIRED_RESULT QStringList SupportedLocales();
+void InitPieceLabelLanguages(QComboBox *combobox);
+Q_REQUIRED_RESULT auto SupportedLocales() -> QStringList;
 
-Q_REQUIRED_RESULT QString StrippedName(const QString &fullFileName);
-Q_REQUIRED_RESULT QString RelativeMPath(const QString &patternPath, const QString &absoluteMPath);
-Q_REQUIRED_RESULT QString AbsoluteMPath(const QString &patternPath, const QString &relativeMPath);
+Q_REQUIRED_RESULT auto RelativeMPath(const QString &patternPath, const QString &absoluteMPath) -> QString;
+Q_REQUIRED_RESULT auto AbsoluteMPath(const QString &patternPath, const QString &relativeMPath) -> QString;
 
-QStringList SplitFilePaths(const QString &path);
+auto SplitFilePaths(const QString &path) -> QStringList;
 
-QMarginsF GetMinPrinterFields(const QSharedPointer<QPrinter> &printer);
-QMarginsF GetPrinterFields(const QSharedPointer<QPrinter> &printer);
+auto GetMinPrinterFields(const QSharedPointer<QPrinter> &printer) -> QMarginsF;
+auto GetPrinterFields(const QSharedPointer<QPrinter> &printer) -> QMarginsF;
 
-Q_REQUIRED_RESULT QPixmap darkenPixmap(const QPixmap &pixmap);
+Q_REQUIRED_RESULT auto darkenPixmap(const QPixmap &pixmap) -> QPixmap;
 
 void ShowInGraphicalShell(const QString &filePath);
 
-Q_REQUIRED_RESULT Q_DECL_RELAXED_CONSTEXPR static inline bool VFuzzyComparePossibleNulls(double p1, double p2);
-Q_DECL_RELAXED_CONSTEXPR static inline bool VFuzzyComparePossibleNulls(double p1, double p2)
+Q_REQUIRED_RESULT constexpr static inline auto VFuzzyComparePossibleNulls(double p1, double p2) -> bool;
+constexpr static inline auto VFuzzyComparePossibleNulls(double p1, double p2) -> bool
 {
-    if(qFuzzyIsNull(p1))
+    if (qFuzzyIsNull(p1))
     {
         return qFuzzyIsNull(p2);
     }
-    else if(qFuzzyIsNull(p2))
+
+    if (qFuzzyIsNull(p2))
     {
         return false;
     }
-    else
-    {
-        return qFuzzyCompare(p1, p2);
-    }
+
+    return qFuzzyCompare(p1, p2);
 }
 
 /**
@@ -547,15 +747,16 @@ Q_DECL_RELAXED_CONSTEXPR static inline bool VFuzzyComparePossibleNulls(double p1
 struct CustomSARecord
 {
     CustomSARecord()
-        : startPoint(0),
-          path(0),
-          endPoint(0),
-          reverse(false),
-          includeType(PiecePathIncludeType::AsCustomSA)
-    {}
+      : startPoint(0),
+        path(0),
+        endPoint(0),
+        reverse(false),
+        includeType(PiecePathIncludeType::AsCustomSA)
+    {
+    }
 
-    friend QDataStream& operator<<(QDataStream& out, const CustomSARecord& record);
-    friend QDataStream& operator>>(QDataStream& in, CustomSARecord& record);
+    friend auto operator<<(QDataStream &out, const CustomSARecord &record) -> QDataStream &;
+    friend auto operator>>(QDataStream &in, CustomSARecord &record) -> QDataStream &;
 
     quint32 startPoint{0};
     quint32 path{0};
@@ -582,90 +783,62 @@ Q_DECLARE_TYPEINFO(CustomSARecord, Q_MOVABLE_TYPE); // NOLINT
 ** this file shall be copyright (C) 2006-2008 by Adam Higerd.
 ****************************************************************************/
 
-#define QXT_DECLARE_PRIVATE(PUB) friend class PUB##Private; QxtPrivateInterface<PUB, PUB##Private> qxt_d;
+#define QXT_DECLARE_PRIVATE(PUB)                                                                                       \
+    friend class PUB##Private;                                                                                         \
+    QxtPrivateInterface<PUB, PUB##Private> qxt_d;
 #define QXT_DECLARE_PUBLIC(PUB) friend class PUB;
 #define QXT_INIT_PRIVATE(PUB) qxt_d.setPublic(this);
-#define QXT_D(PUB) PUB##Private& d = qxt_d()
-#define QXT_P(PUB) PUB& p = qxt_p()
+#define QXT_D(PUB) PUB##Private &d = qxt_d()
+#define QXT_P(PUB) PUB &p = qxt_p()
 
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_GCC("-Wsuggest-final-types")
 QT_WARNING_DISABLE_GCC("-Wsuggest-final-methods")
 
-template <typename PUB>
-class QxtPrivate
+template <typename PUB> class QxtPrivate
 {
 public:
-    QxtPrivate(): qxt_p_ptr(nullptr)
-    {}
-    virtual ~QxtPrivate()
-    {}
-    inline void QXT_setPublic(PUB* pub)
+    QxtPrivate()
+      : qxt_p_ptr(nullptr)
     {
-        qxt_p_ptr = pub;
     }
+    virtual ~QxtPrivate() {}
+    inline void QXT_setPublic(PUB *pub) { qxt_p_ptr = pub; }
 
 protected:
-    inline PUB& qxt_p()
-    {
-        return *qxt_p_ptr;
-    }
-    inline const PUB& qxt_p() const
-    {
-        return *qxt_p_ptr;
-    }
-    inline PUB* qxt_ptr()
-    {
-        return qxt_p_ptr;
-    }
-    inline const PUB* qxt_ptr() const
-    {
-        return qxt_p_ptr;
-    }
+    inline auto qxt_p() -> PUB & { return *qxt_p_ptr; }
+    inline auto qxt_p() const -> const PUB & { return *qxt_p_ptr; }
+    inline auto qxt_ptr() -> PUB * { return qxt_p_ptr; }
+    inline auto qxt_ptr() const -> const PUB * { return qxt_p_ptr; }
 
 private:
     Q_DISABLE_COPY_MOVE(QxtPrivate) // NOLINT
-    PUB* qxt_p_ptr;
+    PUB *qxt_p_ptr;
 };
 
 // cppcheck-suppress unknownMacro
 QT_WARNING_POP
 
-template <typename PUB, typename PVT>
-class QxtPrivateInterface
+template <typename PUB, typename PVT> class QxtPrivateInterface
 {
     friend class QxtPrivate<PUB>;
-public:
-    QxtPrivateInterface() : pvt(new PVT)
-    {}
-    ~QxtPrivateInterface()
-    {
-        delete pvt;
-    }
 
-    inline void setPublic(PUB* pub)
+public:
+    QxtPrivateInterface()
+      : pvt(new PVT)
     {
-        pvt->QXT_setPublic(pub);
-    }
-    inline PVT& operator()()
-    {
-        return *static_cast<PVT*>(pvt);
-    }
-    inline const PVT& operator()() const
-    {
-        return *static_cast<PVT*>(pvt);
-    }
-    inline PVT * operator->()
-    {
-    return static_cast<PVT*>(pvt);
-    }
-    inline const PVT * operator->() const
-    {
-    return static_cast<PVT*>(pvt);
     }
+    ~QxtPrivateInterface() { delete pvt; }
+
+    inline void setPublic(PUB *pub) { pvt->QXT_setPublic(pub); }
+    inline auto operator()() -> PVT & { return *static_cast<PVT *>(pvt); }
+    inline auto operator()() const -> const PVT & { return *static_cast<PVT *>(pvt); }
+    inline auto operator->() -> PVT * { return static_cast<PVT *>(pvt); }
+    inline auto operator->() const -> const PVT * { return static_cast<PVT *>(pvt); }
+
 private:
     Q_DISABLE_COPY_MOVE(QxtPrivateInterface) // NOLINT
-    QxtPrivate<PUB>* pvt;
+    QxtPrivate<PUB> *pvt;
 };
 
 #endif // DEF_H
