@@ -30,8 +30,6 @@
 
 #include <QDialog>
 
-#include "../vmisc/defglobal.h"
-
 namespace Ui
 {
 class DialogSelectLanguage;
@@ -45,7 +43,7 @@ public:
     explicit DialogSelectLanguage(QWidget *parent = nullptr);
     ~DialogSelectLanguage();
 
-    QString Locale() const;
+    auto Locale() const -> QString;
 
 private:
     // cppcheck-suppress unknownMacro
