@@ -29,25 +29,37 @@
 #ifndef VABSTRACTAPPLICATION_H
 #define VABSTRACTAPPLICATION_H
 
-#include <qcompilerdetection.h>
 #include <QApplication>
 #include <QCoreApplication>
+#include <QElapsedTimer>
+#include <QFileDialog>
 #include <QLocale>
 #include <QMetaObject>
 #include <QObject>
 #include <QPointer>
 #include <QString>
-#include <QtGlobal>
 #include <QTranslator>
-#include <QFileDialog>
+#include <QtGlobal>
 
-#include "../vmisc/def.h"
 #include "../vpatterndb/vtranslatevars.h"
+#include "def.h"
 #include "vcommonsettings.h"
 
 class QUndoStack;
-class VAbstractApplication;// use in define
+class VAbstractApplication; // use in define
 class VCommonSettings;
+class VSvgFontDatabase;
+class QFileSystemWatcher;
+class VAbstractShortcutManager;
+class VKnownMeasurementsDatabase;
+class VTranslator;
+
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+class VTextCodec;
+#else
+class QTextCodec;
+using VTextCodec = QTextCodec;
+#endif
 
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_GCC("-Wsuggest-final-types")
@@ -56,39 +68,68 @@ QT_WARNING_DISABLE_GCC("-Wsuggest-final-methods")
 class VAbstractApplication : public QApplication
 {
     Q_OBJECT // NOLINT
+
 public:
-    VAbstractApplication(int &argc, char ** argv);
-    virtual ~VAbstractApplication() =default;
+    VAbstractApplication(int &argc, char **argv);
+    ~VAbstractApplication() override;
 
-    virtual const VTranslateVars *TrVars()=0;
+    virtual auto TrVars() -> const VTranslateVars * = 0;
 
-    static QString translationsPath(const QString &locale = QString());
+    static auto translationsPath(const QString &locale = QString()) -> QString;
+    static auto QtTranslationsPath(const QString &locale = QString()) -> QString;
 
-    void LoadTranslation(const QString &locale);
+    static auto ReduceLogContextFilePath(QString path) -> QString;
 
-    virtual void     OpenSettings()=0;
-    VCommonSettings *Settings();
+    void LoadTranslation(QString locale);
 
-    template <typename T>
-    QString LocaleToString(const T &value);
+    virtual void OpenSettings() = 0;
+    auto Settings() -> VCommonSettings *;
 
-    QUndoStack *getUndoStack() const;
+    template <typename T> auto LocaleToString(const T &value) -> QString;
 
-    virtual bool IsAppInGUIMode()const =0;
-    virtual bool IsPedantic() const;
+    auto getUndoStack() const -> QUndoStack *;
 
-    static QString ClearMessage(QString msg);
+    virtual auto IsAppInGUIMode() const -> bool = 0;
+    virtual auto IsPedantic() const -> bool;
+
+    static auto ClearMessage(QString msg) -> QString;
 
     static const QString warningMessageSignature;
-    bool IsWarningMessage(const QString &message) const;
+    auto IsWarningMessage(const QString &message) const -> bool;
 
-    QFileDialog::Options NativeFileDialog(QFileDialog::Options options = QFileDialog::Options()) const;
+    auto NativeFileDialog(QFileDialog::Options options = QFileDialog::Options()) const -> QFileDialog::Options;
+
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    auto TextCodecCache(QStringConverter::Encoding encoding) const -> VTextCodec *;
+    void CacheTextCodec(QStringConverter::Encoding encoding, VTextCodec *codec);
+#endif
 
 #if defined(Q_OS_WIN)
     static void WinAttachConsole();
 #endif
 
-    static VAbstractApplication *VApp();
+    static auto VApp() -> VAbstractApplication *;
+
+    auto SVGFontDatabase() -> VSvgFontDatabase *;
+
+    virtual auto KnownMeasurementsDatabase() -> VKnownMeasurementsDatabase *;
+
+    auto AppUptime() const -> qint64;
+
+    auto GetShortcutManager() const -> VAbstractShortcutManager *;
+
+    auto GetPlaceholderTranslator() -> QSharedPointer<VTranslator>;
+
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    // NOLINTNEXTLINE(cppcoreguidelines-avoid-c-arrays, hicpp-avoid-c-arrays, modernize-avoid-c-arrays)
+    static auto IsOptionSet(int argc, char *argv[], const char *option) -> bool;
+    // NOLINTNEXTLINE(cppcoreguidelines-avoid-c-arrays, hicpp-avoid-c-arrays, modernize-avoid-c-arrays)
+    static void InitHighDpiScaling(int argc, char *argv[]);
+#endif
+
+    static auto LogDirPath() -> QString;
+    static auto CreateLogDir() -> bool;
+    static void ClearOldLogs();
 
 protected:
     QUndoStack *undoStack;
@@ -99,29 +140,46 @@ protected:
     VCommonSettings *settings{nullptr};
 
     QPointer<QTranslator> qtTranslator{nullptr};
+#if (defined(Q_OS_WIN) && !defined(QBS_BUILD)) || defined(APPIMAGE)
     QPointer<QTranslator> qtxmlTranslator{nullptr};
     QPointer<QTranslator> qtBaseTranslator{nullptr};
+#endif // defined(Q_OS_WIN) && !defined(QBS_BUILD)
     QPointer<QTranslator> appTranslator{nullptr};
-    QPointer<QTranslator> pmsTranslator{nullptr};
 
-    virtual void InitTrVars()=0;
+    QElapsedTimer m_uptimeTimer{};
+
+    VAbstractShortcutManager *m_shortcutManager{nullptr};
+
+    virtual void InitTrVars() = 0;
 
     static void CheckSystemLocale();
 
 protected slots:
-    virtual void AboutToQuit()=0;
+    virtual void AboutToQuit() = 0;
+    void SVGFontsPathChanged(const QString &oldPath, const QString &newPath);
+
+private slots:
+    void RepopulateFontDatabase(const QString &path);
 
 private:
     Q_DISABLE_COPY_MOVE(VAbstractApplication) // NOLINT
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    QHash<QStringConverter::Encoding, VTextCodec *> m_codecs{};
+#endif
+
+    VSvgFontDatabase *m_svgFontDatabase{nullptr};
+    QFileSystemWatcher *m_svgFontDatabaseWatcher{nullptr};
+
     void ClearTranslation();
+
+    void RestartSVGFontDatabaseWatcher();
 };
 
 QT_WARNING_POP
 
 //---------------------------------------------------------------------------------------------------------------------
-template <typename T>
-inline QString VAbstractApplication::LocaleToString(const T &value)
+template <typename T> inline auto VAbstractApplication::LocaleToString(const T &value) -> QString
 {
     QLocale loc;
     VAbstractApplication::VApp()->Settings()->GetOsSeparator() ? loc = QLocale() : loc = QLocale::c();
@@ -131,7 +189,7 @@ inline QString VAbstractApplication::LocaleToString(const T &value)
 //---------------------------------------------------------------------------------------------------------------------
 inline auto VAbstractApplication::VApp() -> VAbstractApplication *
 {
-    return qobject_cast<VAbstractApplication*>(QCoreApplication::instance());
+    return qobject_cast<VAbstractApplication *>(QCoreApplication::instance());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -139,7 +197,7 @@ inline auto VAbstractApplication::VApp() -> VAbstractApplication *
  * @brief getSettings hide settings constructor.
  * @return pointer to class for acssesing to settings in ini file.
  */
-inline VCommonSettings *VAbstractApplication::Settings()
+inline auto VAbstractApplication::Settings() -> VCommonSettings *
 {
     SCASSERT(settings != nullptr)
     return settings;
