@@ -33,20 +33,18 @@
 
 //---------------------------------------------------------------------------------------------------------------------
 VPieceLabelData::VPieceLabelData()
-    : VPatternLabelData(),
-      d(new VPieceLabelDataPrivate())
-{}
-
-//---------------------------------------------------------------------------------------------------------------------
-VPieceLabelData::VPieceLabelData(const VPieceLabelData &data)
-    : VPatternLabelData(data),
-      d (data.d)
-{}
-
-//---------------------------------------------------------------------------------------------------------------------
-VPieceLabelData &VPieceLabelData::operator=(const VPieceLabelData &data)
+  : VPatternLabelData(),
+    d(new VPieceLabelDataPrivate())
 {
-    if ( &data == this )
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+COPY_CONSTRUCTOR_IMPL_2(VPieceLabelData, VPatternLabelData)
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VPieceLabelData::operator=(const VPieceLabelData &data) -> VPieceLabelData &
+{
+    if (&data == this)
     {
         return *this;
     }
@@ -55,25 +53,23 @@ VPieceLabelData &VPieceLabelData::operator=(const VPieceLabelData &data)
     return *this;
 }
 
-#ifdef Q_COMPILER_RVALUE_REFS
 //---------------------------------------------------------------------------------------------------------------------
-VPieceLabelData::VPieceLabelData(VPieceLabelData &&data) Q_DECL_NOTHROW
-    : VPatternLabelData(std::move(data)),
-      d (std::move(data.d))
-{}
+VPieceLabelData::VPieceLabelData(VPieceLabelData &&data) noexcept
+  : VPatternLabelData(std::move(data)),
+    d(std::move(data.d)) // NOLINT(bugprone-use-after-move)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-VPieceLabelData &VPieceLabelData::operator=(VPieceLabelData &&data) Q_DECL_NOTHROW
+auto VPieceLabelData::operator=(VPieceLabelData &&data) noexcept -> VPieceLabelData &
 {
     VPatternLabelData::operator=(data);
     std::swap(d, data.d);
     return *this;
 }
-#endif
 
 //---------------------------------------------------------------------------------------------------------------------
-VPieceLabelData::~VPieceLabelData()
-{}
+VPieceLabelData::~VPieceLabelData() = default;
 
 //---------------------------------------------------------------------------------------------------------------------
 void VPieceLabelData::Clear()
@@ -82,7 +78,7 @@ void VPieceLabelData::Clear()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VPieceLabelData::GetLetter() const
+auto VPieceLabelData::GetLetter() const -> QString
 {
     return d->m_qsLetter;
 }
@@ -94,7 +90,7 @@ void VPieceLabelData::SetLetter(const QString &qsLetter)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VPieceLabelData::GetAnnotation() const
+auto VPieceLabelData::GetAnnotation() const -> QString
 {
     return d->m_annotation;
 }
@@ -106,7 +102,7 @@ void VPieceLabelData::SetAnnotation(const QString &val)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VPieceLabelData::GetOrientation() const
+auto VPieceLabelData::GetOrientation() const -> QString
 {
     return d->m_orientation;
 }
@@ -118,7 +114,7 @@ void VPieceLabelData::SetOrientation(const QString &val)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VPieceLabelData::GetRotationWay() const
+auto VPieceLabelData::GetRotationWay() const -> QString
 {
     return d->m_rotationWay;
 }
@@ -130,7 +126,7 @@ void VPieceLabelData::SetRotationWay(const QString &val)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VPieceLabelData::GetTilt() const
+auto VPieceLabelData::GetTilt() const -> QString
 {
     return d->m_tilt;
 }
@@ -142,7 +138,7 @@ void VPieceLabelData::SetTilt(const QString &val)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VPieceLabelData::GetFoldPosition() const
+auto VPieceLabelData::GetFoldPosition() const -> QString
 {
     return d->m_foldPosition;
 }
@@ -154,7 +150,7 @@ void VPieceLabelData::SetFoldPosition(const QString &val)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-quint16 VPieceLabelData::GetQuantity() const
+auto VPieceLabelData::GetQuantity() const -> quint16
 {
     return d->m_quantity;
 }
@@ -166,7 +162,7 @@ void VPieceLabelData::SetQuantity(quint16 val)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VPieceLabelData::IsOnFold() const
+auto VPieceLabelData::IsOnFold() const -> bool
 {
     return d->m_onFold;
 }
@@ -178,7 +174,19 @@ void VPieceLabelData::SetOnFold(bool onFold)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QVector<VLabelTemplateLine> VPieceLabelData::GetLabelTemplate() const
+auto VPieceLabelData::GetAreaShortName() const -> QString
+{
+    return d->m_areaShortName;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void VPieceLabelData::SetAreaShortName(const QString &val)
+{
+    d->m_areaShortName = val;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VPieceLabelData::GetLabelTemplate() const -> QVector<VLabelTemplateLine>
 {
     return d->m_lines;
 }
