@@ -31,15 +31,20 @@
 #include <QLatin1String>
 #include <QMessageLogger>
 
-#include "../vmisc/def.h"
 #include "../ifc/ifcdef.h"
-#include "../vgeometry/vabstractcurve.h"
 #include "../vgeometry/vspline.h"
+#include "../vmisc/def.h"
 #include "vcurvevariable.h"
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
+#include "../vmisc/compatibility.h"
+#endif
+
+using namespace Qt::Literals::StringLiterals;
+
 //---------------------------------------------------------------------------------------------------------------------
 VCurveCLength::VCurveCLength()
-    : VCurveVariable()
+  : VCurveVariable()
 {
     SetType(VarType::CurveCLength);
 }
@@ -47,7 +52,7 @@ VCurveCLength::VCurveCLength()
 //---------------------------------------------------------------------------------------------------------------------
 VCurveCLength::VCurveCLength(const quint32 &id, const quint32 &parentId, const VAbstractBezier *curve,
                              CurveCLength cType, Unit patternUnit)
-    : VCurveVariable(id, parentId)
+  : VCurveVariable(id, parentId)
 {
     SetType(VarType::CurveCLength);
     SCASSERT(curve != nullptr)
@@ -76,7 +81,7 @@ VCurveCLength::VCurveCLength(const quint32 &id, const quint32 &parentId, const V
 //---------------------------------------------------------------------------------------------------------------------
 VCurveCLength::VCurveCLength(const quint32 &id, const quint32 &parentId, const VAbstractBezier *baseCurve,
                              const VSpline &spl, CurveCLength cType, Unit patternUnit, qint32 segment)
-    : VCurveVariable(id, parentId)
+  : VCurveVariable(id, parentId)
 {
     // cppcheck-suppress unknownMacro
     SCASSERT(baseCurve != nullptr)
@@ -85,35 +90,35 @@ VCurveCLength::VCurveCLength(const quint32 &id, const quint32 &parentId, const V
     if (cType == CurveCLength::C1)
     {
         SetValue(FromPixel(spl.GetC1Length(), patternUnit));
-        SetName(c1Length_V + baseCurve->name() + QLatin1String("_") + seg_ + QString().setNum(segment));
+        SetName(c1Length_V + baseCurve->name() + '_'_L1 + seg_ + QString().setNum(segment));
 
         if (not baseCurve->GetAlias().isEmpty())
         {
-            SetAlias(c1Length_V + baseCurve->GetAlias() + QLatin1String("_") + seg_ + QString().setNum(segment));
+            SetAlias(c1Length_V + baseCurve->GetAlias() + '_'_L1 + seg_ + QString().setNum(segment));
         }
     }
     else
     {
         SetValue(FromPixel(spl.GetC2Length(), patternUnit));
-        SetName(c2Length_V + baseCurve->name() + QLatin1String("_") + seg_ + QString().setNum(segment));
+        SetName(c2Length_V + baseCurve->name() + '_'_L1 + seg_ + QString().setNum(segment));
 
         if (not baseCurve->GetAlias().isEmpty())
         {
-            SetAlias(c2Length_V + baseCurve->GetAlias() + QLatin1String("_") + seg_ + QString().setNum(segment));
+            SetAlias(c2Length_V + baseCurve->GetAlias() + '_'_L1 + seg_ + QString().setNum(segment));
         }
     }
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 VCurveCLength::VCurveCLength(const VCurveCLength &var)
-    : VCurveVariable(var)
+  : VCurveVariable(var)
 {
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VCurveCLength &VCurveCLength::operator=(const VCurveCLength &var)
+auto VCurveCLength::operator=(const VCurveCLength &var) -> VCurveCLength &
 {
-    if ( &var == this )
+    if (&var == this)
     {
         return *this;
     }
@@ -125,4 +130,3 @@ VCurveCLength &VCurveCLength::operator=(const VCurveCLength &var)
 VCurveCLength::~VCurveCLength()
 {
 }
-
