@@ -29,15 +29,16 @@
 #include "vincrement.h"
 
 #include "../vmisc/def.h"
-#include "vvariable.h"
 #include "vincrement_p.h"
+#include "vvariable.h"
 
 //---------------------------------------------------------------------------------------------------------------------
 /**
  * @brief VIncrement create enpty increment
  */
 VIncrement::VIncrement()
-    :VVariable(), d(new VIncrementData)
+  : VVariable(),
+    d(new VIncrementData)
 {
     SetType(VarType::Increment);
 }
@@ -48,20 +49,19 @@ VIncrement::VIncrement()
  * @param name increment's name
  */
 VIncrement::VIncrement(VContainer *data, const QString &name, IncrementType incrType)
-    :VVariable(name, QString()), d(new VIncrementData(data, incrType))
+  : VVariable(name, QString()),
+    d(new VIncrementData(data, incrType))
 {
     incrType == IncrementType::Separator ? SetType(VarType::IncrementSeparator) : SetType(VarType::Increment);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VIncrement::VIncrement(const VIncrement &incr)
-    :VVariable(incr), d(incr.d)
-{}
+COPY_CONSTRUCTOR_IMPL_2(VIncrement, VVariable)
 
 //---------------------------------------------------------------------------------------------------------------------
-VIncrement &VIncrement::operator=(const VIncrement &incr)
+auto VIncrement::operator=(const VIncrement &incr) -> VIncrement &
 {
-    if ( &incr == this )
+    if (&incr == this)
     {
         return *this;
     }
@@ -70,24 +70,23 @@ VIncrement &VIncrement::operator=(const VIncrement &incr)
     return *this;
 }
 
-#ifdef Q_COMPILER_RVALUE_REFS
 //---------------------------------------------------------------------------------------------------------------------
-VIncrement::VIncrement(VIncrement &&incr) Q_DECL_NOTHROW
-    :VVariable(std::move(incr)), d(std::move(incr.d))
-{}
+VIncrement::VIncrement(VIncrement &&incr) noexcept
+  : VVariable(std::move(incr)),
+    d(std::move(incr.d)) // NOLINT(bugprone-use-after-move)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-VIncrement &VIncrement::operator=(VIncrement &&incr) Q_DECL_NOTHROW
+auto VIncrement::operator=(VIncrement &&incr) noexcept -> VIncrement &
 {
     VVariable::operator=(incr);
     std::swap(d, incr.d);
     return *this;
 }
-#endif
 
 //---------------------------------------------------------------------------------------------------------------------
-VIncrement::~VIncrement()
-{}
+VIncrement::~VIncrement() = default;
 
 //---------------------------------------------------------------------------------------------------------------------
 /**
@@ -95,7 +94,7 @@ VIncrement::~VIncrement()
  * using.
  * @return index
  */
-quint32 VIncrement::GetIndex() const
+auto VIncrement::GetIndex() const -> quint32
 {
     return d->index;
 }
@@ -109,13 +108,13 @@ void VIncrement::SetFormula(qreal base, const QString &formula, bool ok)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VIncrement::GetFormula() const
+auto VIncrement::GetFormula() const -> QString
 {
     return d->formula;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VIncrement::IsFormulaOk() const
+auto VIncrement::IsFormulaOk() const -> bool
 {
     return d->formulaOk;
 }
@@ -127,19 +126,19 @@ void VIncrement::SetIndex(quint32 index)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VContainer *VIncrement::GetData()
+auto VIncrement::GetData() -> VContainer *
 {
     return d->data.data();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-IncrementType VIncrement::GetIncrementType() const
+auto VIncrement::GetIncrementType() const -> IncrementType
 {
     return d->incrType;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VIncrement::IsPreviewCalculation() const
+auto VIncrement::IsPreviewCalculation() const -> bool
 {
     return d->previewCalculation;
 }
@@ -151,7 +150,7 @@ void VIncrement::SetPreviewCalculation(bool value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VIncrement::IsSpecialUnits() const
+auto VIncrement::IsSpecialUnits() const -> bool
 {
     return d->specialUnits;
 }
