@@ -31,18 +31,17 @@
 
 //---------------------------------------------------------------------------------------------------------------------
 VInternalVariable::VInternalVariable()
-    :d(new VInternalVariableData)
-{}
-
-//---------------------------------------------------------------------------------------------------------------------
-VInternalVariable::VInternalVariable(const VInternalVariable &var)
-    :d(var.d)
-{}
-
-//---------------------------------------------------------------------------------------------------------------------
-VInternalVariable &VInternalVariable::operator=(const VInternalVariable &var)
+  : d(new VInternalVariableData)
 {
-    if ( &var == this )
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+COPY_CONSTRUCTOR_IMPL(VInternalVariable)
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VInternalVariable::operator=(const VInternalVariable &var) -> VInternalVariable &
+{
+    if (&var == this)
     {
         return *this;
     }
@@ -51,44 +50,42 @@ VInternalVariable &VInternalVariable::operator=(const VInternalVariable &var)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VInternalVariable::VInternalVariable(VInternalVariable &&var) Q_DECL_NOTHROW
-    :d(std::move(var.d))
-{}
+VInternalVariable::VInternalVariable(VInternalVariable &&var) noexcept
+  : d(std::move(var.d))
+{
+}
 
-#ifdef Q_COMPILER_RVALUE_REFS
 //---------------------------------------------------------------------------------------------------------------------
-VInternalVariable &VInternalVariable::operator=(VInternalVariable &&var) Q_DECL_NOTHROW
+auto VInternalVariable::operator=(VInternalVariable &&var) noexcept -> VInternalVariable &
 {
     std::swap(d, var.d);
     return *this;
 }
-#endif
 
 //---------------------------------------------------------------------------------------------------------------------
-VInternalVariable::~VInternalVariable()
-{}
+VInternalVariable::~VInternalVariable() = default;
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VInternalVariable::Filter(quint32 id)
+auto VInternalVariable::Filter(quint32 id) -> bool
 {
     Q_UNUSED(id)
     return false;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VInternalVariable::IsNotUsed() const
+auto VInternalVariable::IsNotUsed() const -> bool
 {
     return false;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-qreal VInternalVariable::GetValue() const
+auto VInternalVariable::GetValue() const -> qreal
 {
     return d->value;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-qreal *VInternalVariable::GetValue()
+auto VInternalVariable::GetValue() -> qreal *
 {
     return &d->value;
 }
@@ -100,7 +97,7 @@ void VInternalVariable::SetValue(const qreal &value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VInternalVariable::GetName() const
+auto VInternalVariable::GetName() const -> QString
 {
     return d->name;
 }
@@ -112,12 +109,11 @@ void VInternalVariable::SetName(const QString &name)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VarType VInternalVariable::GetType() const
+auto VInternalVariable::GetType() const -> VarType
 {
     return d->type;
 }
 
-
 //---------------------------------------------------------------------------------------------------------------------
 void VInternalVariable::SetType(const VarType &type)
 {
@@ -131,7 +127,7 @@ void VInternalVariable::SetAlias(const QString &alias)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VInternalVariable::GetAlias() const
+auto VInternalVariable::GetAlias() const -> QString
 {
     return d->alias;
 }
