@@ -40,7 +40,8 @@
 
 //---------------------------------------------------------------------------------------------------------------------
 VLengthLine::VLengthLine()
-    :VInternalVariable(), d(new VLengthLineData)
+  : VInternalVariable(),
+    d(new VLengthLineData)
 {
     SetType(VarType::LineLength);
 }
@@ -48,26 +49,25 @@ VLengthLine::VLengthLine()
 //---------------------------------------------------------------------------------------------------------------------
 VLengthLine::VLengthLine(const VPointF *p1, const quint32 &p1Id, const VPointF *p2, const quint32 &p2Id,
                          Unit patternUnit)
-    :VInternalVariable(), d(new VLengthLineData(p1Id, p2Id, patternUnit))
+  : VInternalVariable(),
+    d(new VLengthLineData(p1Id, p2Id, patternUnit))
 {
     // cppcheck-suppress unknownMacro
     SCASSERT(p1 != nullptr)
     SCASSERT(p2 != nullptr)
 
     SetType(VarType::LineLength);
-    SetName(QString(line_+"%1_%2").arg(p1->name(), p2->name()));
+    SetName(QString(line_ + "%1_%2").arg(p1->name(), p2->name()));
     SetValue(p1, p2);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VLengthLine::VLengthLine(const VLengthLine &var)
-    :VInternalVariable(var), d(var.d)
-{}
+COPY_CONSTRUCTOR_IMPL_2(VLengthLine, VInternalVariable)
 
 //---------------------------------------------------------------------------------------------------------------------
-VLengthLine &VLengthLine::operator=(const VLengthLine &var)
+auto VLengthLine::operator=(const VLengthLine &var) -> VLengthLine &
 {
-    if ( &var == this )
+    if (&var == this)
     {
         return *this;
     }
@@ -77,26 +77,25 @@ VLengthLine &VLengthLine::operator=(const VLengthLine &var)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VLengthLine::VLengthLine(VLengthLine &&var) Q_DECL_NOTHROW
-    :VInternalVariable(std::move(var)), d(std::move(var.d))
-{}
+VLengthLine::VLengthLine(VLengthLine &&var) noexcept
+  : VInternalVariable(std::move(var)),
+    d(std::move(var.d)) // NOLINT(bugprone-use-after-move)
+{
+}
 
-#ifdef Q_COMPILER_RVALUE_REFS
 //---------------------------------------------------------------------------------------------------------------------
-VLengthLine &VLengthLine::operator=(VLengthLine &&var) Q_DECL_NOTHROW
+auto VLengthLine::operator=(VLengthLine &&var) noexcept -> VLengthLine &
 {
     VInternalVariable::operator=(var);
     std::swap(d, var.d);
     return *this;
 }
-#endif
 
 //---------------------------------------------------------------------------------------------------------------------
-VLengthLine::~VLengthLine()
-{}
+VLengthLine::~VLengthLine() = default;
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VLengthLine::Filter(quint32 id)
+auto VLengthLine::Filter(quint32 id) -> bool
 {
     return id == d->p1Id || id == d->p2Id;
 }
@@ -107,18 +106,18 @@ void VLengthLine::SetValue(const VPointF *p1, const VPointF *p2)
     SCASSERT(p1 != nullptr)
     SCASSERT(p2 != nullptr)
 
-    VInternalVariable::SetValue(FromPixel(QLineF(static_cast<QPointF>(*p1), static_cast<QPointF>(*p2)).length(),
-                                          d->patternUnit));
+    VInternalVariable::SetValue(
+        FromPixel(QLineF(static_cast<QPointF>(*p1), static_cast<QPointF>(*p2)).length(), d->patternUnit));
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-quint32 VLengthLine::GetP1Id() const
+auto VLengthLine::GetP1Id() const -> quint32
 {
     return d->p1Id;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-quint32 VLengthLine::GetP2Id() const
+auto VLengthLine::GetP2Id() const -> quint32
 {
     return d->p2Id;
 }
