@@ -28,30 +28,31 @@
 
 #include "vcontainer.h"
 
-#include <climits>
+#include <QLoggingCategory>
+#include <QUuid>
 #include <QVector>
 #include <QtDebug>
-#include <QUuid>
-#include <QLoggingCategory>
+#include <climits>
 
 #include "../ifc/exception/vexception.h"
 #include "../vgeometry/vabstractcubicbezierpath.h"
 #include "../vgeometry/vabstractcurve.h"
+#include "../vgeometry/varc.h"
+#include "../vgeometry/vellipticalarc.h"
 #include "../vgeometry/vgeometrydef.h"
 #include "../vgeometry/vgobject.h"
 #include "../vgeometry/vpointf.h"
 #include "../vgeometry/vspline.h"
-#include "../vgeometry/varc.h"
-#include "../vgeometry/vellipticalarc.h"
 #include "../vmisc/literals.h"
 #include "variables/varcradius.h"
 #include "variables/vcurveangle.h"
-#include "variables/vcurvelength.h"
 #include "variables/vcurveclength.h"
+#include "variables/vcurvelength.h"
 #include "variables/vincrement.h"
 #include "variables/vlineangle.h"
 #include "variables/vlinelength.h"
 #include "variables/vmeasurement.h"
+#include "variables/vpiecearea.h"
 #include "vtranslatevars.h"
 
 QT_WARNING_PUSH
@@ -71,7 +72,7 @@ QMap<QString, quint32> VContainer::copyCounter = QMap<QString, quint32>();
  * @brief VContainer create empty container
  */
 VContainer::VContainer(const VTranslateVars *trVars, const Unit *patternUnit, const QString &nspace)
-    :d(new VContainerData(trVars, patternUnit, nspace))
+  : d(new VContainerData(trVars, patternUnit, nspace))
 {
     if (nspace.isEmpty())
     {
@@ -105,9 +106,9 @@ VContainer::VContainer(const VTranslateVars *trVars, const Unit *patternUnit, co
  * @param data container
  * @return copy container
  */
-VContainer &VContainer::operator =(const VContainer &data)
+auto VContainer::operator=(const VContainer &data) -> VContainer &
 {
-    if ( &data == this )
+    if (&data == this)
     {
         return *this;
     }
@@ -116,19 +117,18 @@ VContainer &VContainer::operator =(const VContainer &data)
     return *this;
 }
 
-#ifdef Q_COMPILER_RVALUE_REFS
 //---------------------------------------------------------------------------------------------------------------------
-VContainer::VContainer(VContainer &&data) Q_DECL_NOTHROW
-    :d(std::move(data.d))
-{}
+VContainer::VContainer(VContainer &&data) noexcept
+  : d(std::move(data.d))
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-VContainer &VContainer::operator=(VContainer &&data) Q_DECL_NOTHROW
+auto VContainer::operator=(VContainer &&data) noexcept -> VContainer &
 {
     std::swap(d, data.d);
     return *this;
 }
-#endif
 
 //---------------------------------------------------------------------------------------------------------------------
 /**
@@ -136,24 +136,22 @@ VContainer &VContainer::operator=(VContainer &&data) Q_DECL_NOTHROW
  * @param data container
  */
 VContainer::VContainer(const VContainer &data)
-    :d(data.d)
+  : d(data.d)
 {
     ++copyCounter[d->nspace];
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VContainer::~VContainer()
-{}
+VContainer::~VContainer() = default;
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VContainer::UniqueNamespace()
+auto VContainer::UniqueNamespace() -> QString
 {
     QString candidate;
     do
     {
         candidate = QUuid::createUuid().toString();
-    }
-    while(_id.contains(candidate));
+    } while (_id.contains(candidate));
 
     return candidate;
 }
@@ -172,24 +170,23 @@ void VContainer::ClearNamespace(const QString &nspace)
  * @return point
  */
 // cppcheck-suppress unusedFunction
-const QSharedPointer<VGObject> VContainer::GetGObject(quint32 id) const
+auto VContainer::GetGObject(quint32 id) const -> QSharedPointer<VGObject>
 {
     if (d->calculationObjects.contains(id))
     {
         return d->calculationObjects.value(id);
     }
-    else if (d->modelingObjects->contains(id))
+
+    if (d->modelingObjects->contains(id))
     {
         return d->modelingObjects->value(id);
     }
-    else
-    {
-        throw VExceptionBadId(tr("Can't find object"), id);
-    }
+
+    throw VExceptionBadId(QCoreApplication::translate("VContainer", "Can't find object"), id);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-const QSharedPointer<VGObject> VContainer::GetFakeGObject(quint32 id)
+auto VContainer::GetFakeGObject(quint32 id) -> QSharedPointer<VGObject>
 {
     auto *obj = new VGObject();
     obj->setId(id);
@@ -198,20 +195,18 @@ const QSharedPointer<VGObject> VContainer::GetFakeGObject(quint32 id)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VPiece VContainer::GetPiece(quint32 id) const
+auto VContainer::GetPiece(quint32 id) const -> VPiece
 {
     if (d->pieces->contains(id))
     {
         return d->pieces->value(id);
     }
-    else
-    {
-        throw VExceptionBadId(tr("Can't find object"), id);
-    }
+
+    throw VExceptionBadId(tr("Can't find object"), id);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VPiecePath VContainer::GetPiecePath(quint32 id) const
+auto VContainer::GetPiecePath(quint32 id) const -> VPiecePath
 {
     if (d->piecePaths->contains(id))
     {
@@ -224,7 +219,7 @@ VPiecePath VContainer::GetPiecePath(quint32 id) const
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-quint32 VContainer::GetPieceForPiecePath(quint32 id) const
+auto VContainer::GetPieceForPiecePath(quint32 id) const -> quint32
 {
     auto i = d->pieces->constBegin();
     while (i != d->pieces->constEnd())
@@ -243,7 +238,7 @@ quint32 VContainer::GetPieceForPiecePath(quint32 id) const
 void VContainer::RegisterUniqueName(VGObject *obj) const
 {
     SCASSERT(obj != nullptr)
-    QSharedPointer<VGObject> pointer(obj);
+    QSharedPointer<VGObject> const pointer(obj);
     RegisterUniqueName(pointer);
 }
 
@@ -266,15 +261,15 @@ void VContainer::RegisterUniqueName(const QSharedPointer<VGObject> &obj) const
  * @param obj new object
  * @return return id of new object in container
  */
-quint32 VContainer::AddGObject(VGObject *obj)
+auto VContainer::AddGObject(VGObject *obj) -> quint32
 {
     SCASSERT(obj != nullptr)
-    QSharedPointer<VGObject> pointer(obj);
+    QSharedPointer<VGObject> const pointer(obj);
     return AddGObject(pointer);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-quint32 VContainer::AddGObject(const QSharedPointer<VGObject> &obj)
+auto VContainer::AddGObject(const QSharedPointer<VGObject> &obj) -> quint32
 {
     SCASSERT(not obj.isNull())
 
@@ -302,7 +297,7 @@ quint32 VContainer::AddGObject(const QSharedPointer<VGObject> &obj)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-quint32 VContainer::AddPiece(const VPiece &detail)
+auto VContainer::AddPiece(const VPiece &detail) -> quint32
 {
     const quint32 id = getNextId();
     d->pieces->insert(id, detail);
@@ -310,7 +305,7 @@ quint32 VContainer::AddPiece(const VPiece &detail)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-quint32 VContainer::AddPiecePath(const VPiecePath &path)
+auto VContainer::AddPiecePath(const VPiecePath &path) -> quint32
 {
     const quint32 id = getNextId();
     d->piecePaths->insert(id, path);
@@ -318,7 +313,7 @@ quint32 VContainer::AddPiecePath(const VPiecePath &path)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-quint32 VContainer::getId() const
+auto VContainer::getId() const -> quint32
 {
     return _id.value(d->nspace);
 }
@@ -328,14 +323,14 @@ quint32 VContainer::getId() const
  * @brief getNextId generate next unique id
  * @return next unique id
  */
-quint32 VContainer::getNextId() const
+auto VContainer::getNextId() const -> quint32
 {
-    //TODO. Current count of ids are very big and allow us save time before someone will reach its max value.
-    //Better way, of cource, is to seek free ids inside the set of values and reuse them.
-    //But for now better to keep it as it is now.
+    // TODO. Current count of ids are very big and allow us save time before someone will reach its max value.
+    // Better way, of cource, is to seek free ids inside the set of values and reuse them.
+    // But for now better to keep it as it is now.
     if (_id.value(d->nspace) == UINT_MAX)
     {
-        qCritical()<<(tr("Number of free id exhausted."));
+        qCritical() << (tr("Number of free id exhausted."));
     }
     _id[d->nspace]++;
     return _id.value(d->nspace);
@@ -348,7 +343,7 @@ void VContainer::UpdateId(quint32 newId, const QString &nspace)
     {
         if (newId > _id.value(nspace))
         {
-           _id[nspace] = newId;
+            _id[nspace] = newId;
         }
     }
     else
@@ -391,15 +386,11 @@ void VContainer::ClearForFullParse()
 
     d->pieces->clear();
     d->piecePaths->clear();
-    Q_STATIC_ASSERT_X(static_cast<int>(VarType::Unknown) == 10, "Check that you used all types");
-    ClearVariables(QVector<VarType>({VarType::Increment,
-                                     VarType::IncrementSeparator,
-                                     VarType::LineAngle,
-                                     VarType::LineLength,
-                                     VarType::CurveLength,
-                                     VarType::CurveCLength,
-                                     VarType::ArcRadius,
-                                     VarType::CurveAngle}));
+    Q_STATIC_ASSERT_X(static_cast<int>(VarType::Unknown) == 12, "Check that you used all types");
+    ClearVariables(QVector<VarType>{VarType::Increment, VarType::IncrementSeparator, VarType::LineAngle,
+                                    VarType::LineLength, VarType::CurveLength, VarType::CurveCLength,
+                                    VarType::ArcRadius, VarType::CurveAngle, VarType::PieceExternalArea,
+                                    VarType::PieceSeamLineArea});
     ClearGObjects();
     ClearUniqueNames();
 }
@@ -437,7 +428,7 @@ void VContainer::ClearVariables(const QVector<VarType> &types)
         }
         else
         {
-            QHash<QString, QSharedPointer<VInternalVariable> >::iterator i;
+            QHash<QString, QSharedPointer<VInternalVariable>>::iterator i;
             for (i = d->variables.begin(); i != d->variables.end();)
             {
                 if (types.contains(i.value()->GetType()))
@@ -493,9 +484,8 @@ void VContainer::AddArc(const QSharedPointer<VAbstractCurve> &arc, const quint32
 void VContainer::AddCurve(const QSharedPointer<VAbstractCurve> &curve, const quint32 &id, quint32 parentId)
 {
     const GOType curveType = curve->getType();
-    if (curveType != GOType::Spline      && curveType != GOType::SplinePath &&
-        curveType != GOType::CubicBezier && curveType != GOType::CubicBezierPath &&
-        curveType != GOType::Arc         && curveType != GOType::EllipticalArc)
+    if (curveType != GOType::Spline && curveType != GOType::SplinePath && curveType != GOType::CubicBezier &&
+        curveType != GOType::CubicBezierPath && curveType != GOType::Arc && curveType != GOType::EllipticalArc)
     {
         throw VException(tr("Can't create a curve with type '%1'").arg(static_cast<int>(curveType)));
     }
@@ -571,97 +561,112 @@ void VContainer::RemoveIncrement(const QString &name)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-const QMap<QString, QSharedPointer<VMeasurement> > VContainer::DataMeasurements() const
+void VContainer::FillPiecesAreas(Unit unit)
+{
+    QHash<quint32, VPiece> *pieces = d->pieces.data();
+
+    auto i = pieces->constBegin();
+    while (i != pieces->constEnd())
+    {
+        AddVariable(QSharedPointer<VPieceArea>::create(PieceAreaType::External, i.key(), i.value(), this, unit));
+        AddVariable(QSharedPointer<VPieceArea>::create(PieceAreaType::SeamLine, i.key(), i.value(), this, unit));
+        ++i;
+    }
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VContainer::DataMeasurements() const -> QMap<QString, QSharedPointer<VMeasurement>>
 {
     return DataVar<VMeasurement>(VarType::Measurement);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-const QMap<QString, QSharedPointer<VMeasurement> > VContainer::DataMeasurementsWithSeparators() const
+auto VContainer::DataMeasurementsWithSeparators() const -> QMap<QString, QSharedPointer<VMeasurement>>
 {
-    QMap<QString, QSharedPointer<VMeasurement> > measurements = DataVar<VMeasurement>(VarType::Measurement);
-    QMap<QString, QSharedPointer<VMeasurement> > separators = DataVar<VMeasurement>(VarType::MeasurementSeparator);
+    QMap<QString, QSharedPointer<VMeasurement>> measurements = DataVar<VMeasurement>(VarType::Measurement);
+    QMap<QString, QSharedPointer<VMeasurement>> const separators = DataVar<VMeasurement>(VarType::MeasurementSeparator);
 
-    QMap<QString, QSharedPointer<VMeasurement>>::const_iterator i = separators.constBegin();
-    while (i != separators.constEnd())
-    {
-        measurements.insert(i.key(), i.value());
-        ++i;
-    }
+    measurements.insert(separators);
 
     return measurements;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-const QMap<QString, QSharedPointer<VIncrement> > VContainer::DataIncrements() const
+auto VContainer::DataIncrements() const -> QMap<QString, QSharedPointer<VIncrement>>
 {
     return DataVar<VIncrement>(VarType::Increment);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-const QMap<QString, QSharedPointer<VIncrement> > VContainer::DataIncrementsWithSeparators() const
+auto VContainer::DataIncrementsWithSeparators() const -> QMap<QString, QSharedPointer<VIncrement>>
 {
-    QMap<QString, QSharedPointer<VIncrement> > increments = DataVar<VIncrement>(VarType::Increment);
-    QMap<QString, QSharedPointer<VIncrement> > separators = DataVar<VIncrement>(VarType::IncrementSeparator);
+    QMap<QString, QSharedPointer<VIncrement>> increments = DataVar<VIncrement>(VarType::Increment);
+    QMap<QString, QSharedPointer<VIncrement>> const separators = DataVar<VIncrement>(VarType::IncrementSeparator);
 
-    QMap<QString, QSharedPointer<VIncrement>>::const_iterator i = separators.constBegin();
-    while (i != separators.constEnd())
-    {
-        increments.insert(i.key(), i.value());
-        ++i;
-    }
+    increments.insert(separators);
 
     return increments;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-const QMap<QString, QSharedPointer<VLengthLine> > VContainer::DataLengthLines() const
+auto VContainer::DataLengthLines() const -> QMap<QString, QSharedPointer<VLengthLine>>
 {
     return DataVar<VLengthLine>(VarType::LineLength);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-const QMap<QString, QSharedPointer<VCurveLength> > VContainer::DataLengthCurves() const
+auto VContainer::DataLengthCurves() const -> QMap<QString, QSharedPointer<VCurveLength>>
 {
     return DataVar<VCurveLength>(VarType::CurveLength);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-const QMap<QString, QSharedPointer<VCurveCLength> > VContainer::DataCurvesCLength() const
+auto VContainer::DataCurvesCLength() const -> QMap<QString, QSharedPointer<VCurveCLength>>
 {
     return DataVar<VCurveCLength>(VarType::CurveCLength);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-const QMap<QString, QSharedPointer<VLineAngle> > VContainer::DataAngleLines() const
+auto VContainer::DataAngleLines() const -> QMap<QString, QSharedPointer<VLineAngle>>
 {
     return DataVar<VLineAngle>(VarType::LineAngle);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-const QMap<QString, QSharedPointer<VArcRadius> > VContainer::DataRadiusesArcs() const
+auto VContainer::DataRadiusesArcs() const -> QMap<QString, QSharedPointer<VArcRadius>>
 {
     return DataVar<VArcRadius>(VarType::ArcRadius);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-const QMap<QString, QSharedPointer<VCurveAngle> > VContainer::DataAnglesCurves() const
+auto VContainer::DataAnglesCurves() const -> QMap<QString, QSharedPointer<VCurveAngle>>
 {
     return DataVar<VCurveAngle>(VarType::CurveAngle);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VContainer::IsUnique(const QString &name) const
+auto VContainer::DataPieceArea() const -> QMap<QString, QSharedPointer<VPieceArea>>
+{
+    QMap<QString, QSharedPointer<VPieceArea>> externalAreas = DataVar<VPieceArea>(VarType::PieceExternalArea);
+    QMap<QString, QSharedPointer<VPieceArea>> const seamLineAreas = DataVar<VPieceArea>(VarType::PieceSeamLineArea);
+
+    externalAreas.insert(seamLineAreas);
+
+    return externalAreas;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto VContainer::IsUnique(const QString &name) const -> bool
 {
     return VContainer::IsUnique(name, d->nspace);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VContainer::IsUnique(const QString &name, const QString &nspace)
+auto VContainer::IsUnique(const QString &name, const QString &nspace) -> bool
 {
     if (uniqueNames.contains(nspace))
     {
-        return (!uniqueNames.value(nspace).contains(name) && !builInFunctions.contains(name));
+        return (!uniqueNames.value(nspace).contains(name) && !BuilInFunctions().contains(name));
     }
     else
     {
@@ -670,17 +675,17 @@ bool VContainer::IsUnique(const QString &name, const QString &nspace)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QStringList VContainer::AllUniqueNames() const
+auto VContainer::AllUniqueNames() const -> QStringList
 {
     return AllUniqueNames(d->nspace);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QStringList VContainer::AllUniqueNames(const QString &nspace)
+auto VContainer::AllUniqueNames(const QString &nspace) -> QStringList
 {
     if (uniqueNames.contains(nspace))
     {
-        QStringList names = builInFunctions;
+        QStringList names = BuilInFunctions();
         names.append(uniqueNames.value(nspace).values());
         return names;
     }
@@ -691,29 +696,28 @@ QStringList VContainer::AllUniqueNames(const QString &nspace)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-const Unit *VContainer::GetPatternUnit() const
+auto VContainer::GetPatternUnit() const -> const Unit *
 {
     return d->patternUnit;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-const VTranslateVars *VContainer::GetTrVars() const
+auto VContainer::GetTrVars() const -> const VTranslateVars *
 {
     return d->trVars;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-template <typename T>
-const QMap<QString, QSharedPointer<T> > VContainer::DataVar(const VarType &type) const
+template <typename T> auto VContainer::DataVar(const VarType &type) const -> QMap<QString, QSharedPointer<T>>
 {
-    QMap<QString, QSharedPointer<T> > map;
-    //Sorting QHash by id
-    QHash<QString, QSharedPointer<VInternalVariable> >::const_iterator i;
+    QMap<QString, QSharedPointer<T>> map;
+    // Sorting QHash by id
+    QHash<QString, QSharedPointer<VInternalVariable>>::const_iterator i;
     for (i = d->variables.constBegin(); i != d->variables.constEnd(); ++i)
     {
         if (i.value()->GetType() == type)
         {
-            QSharedPointer<T> var = GetVariable<T>(i.key());
+            QSharedPointer<T> const var = GetVariable<T>(i.key());
             map.insert(d->trVars->VarToUser(i.key()), var);
         }
     }
@@ -732,7 +736,7 @@ void VContainer::ClearUniqueIncrementNames() const
     const QList<QString> list = uniqueNames.value(d->nspace).values();
     ClearUniqueNames();
 
-    for(auto &name : list)
+    for (const auto &name : list)
     {
         if (not name.startsWith('#'))
         {
@@ -747,7 +751,7 @@ void VContainer::ClearExceptUniqueIncrementNames() const
     const QList<QString> list = uniqueNames.value(d->nspace).values();
     ClearUniqueNames();
 
-    for(auto &name : list)
+    for (const auto &name : list)
     {
         if (name.startsWith('#'))
         {
@@ -761,31 +765,35 @@ void VContainer::ClearExceptUniqueIncrementNames() const
  * @brief data container with datagObjects return container of gObjects
  * @return pointer on container of gObjects
  */
-const QHash<quint32, QSharedPointer<VGObject> > *VContainer::CalculationGObjects() const
+auto VContainer::CalculationGObjects() const -> const QHash<quint32, QSharedPointer<VGObject>> *
 {
     return &d->calculationObjects;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-const QHash<quint32, VPiece> *VContainer::DataPieces() const
+auto VContainer::DataPieces() const -> QHash<quint32, VPiece> *
 {
     return d->pieces.data();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-const QHash<QString, QSharedPointer<VInternalVariable> > *VContainer::DataVariables() const
+auto VContainer::DataVariables() const -> const QHash<QString, QSharedPointer<VInternalVariable>> *
 {
     return &d->variables;
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+VContainerData::VContainerData(const VTranslateVars *trVars, const Unit *patternUnit, const QString &nspace)
+  : trVars(trVars),
+    patternUnit(patternUnit),
+    nspace(nspace)
+{
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 VContainerData::~VContainerData()
 {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
     if (ref.loadRelaxed() == 0)
-#else
-    if (ref.load() == 0)
-#endif
     {
         --VContainer::copyCounter[nspace];
     }
