@@ -29,7 +29,6 @@
 #ifndef VLINECOLORPROPERTY_H
 #define VLINECOLORPROPERTY_H
 
-#include <qcompilerdetection.h>
 #include <QMap>
 #include <QMetaObject>
 #include <QObject>
@@ -37,7 +36,6 @@
 #include <QStyleOptionViewItem>
 #include <QVariant>
 #include <QVector>
-#include <Qt>
 #include <QtGlobal>
 
 #include "../vproperty.h"
@@ -49,48 +47,49 @@ namespace VPE
 class VPROPERTYEXPLORERSHARED_EXPORT VLineColorProperty : public VProperty
 {
     Q_OBJECT // NOLINT
+
 public:
     //! Constructor
-    explicit VLineColorProperty(const QString& name);
+    explicit VLineColorProperty(const QString &name);
 
     //! Destructor
-    virtual ~VLineColorProperty() override {}
+    ~VLineColorProperty() override {}
 
     //! Get the data how it should be displayed
-    virtual QVariant data (int column = DPC_Name, int role = Qt::DisplayRole) const override;
+    virtual auto data(int column = DPC_Name, int role = Qt::DisplayRole) const -> QVariant override;
 
     //! Returns an editor widget, or NULL if it doesn't supply one
     //! \param parent The widget to which the editor will be added as a child
     //! \options Render options
     //! \delegate A pointer to the QAbstractItemDelegate requesting the editor. This can be used to connect signals and
     //! slots.
-    virtual QWidget *createEditor(QWidget* parent, const QStyleOptionViewItem& options,
-                                  const QAbstractItemDelegate* delegate) override;
+    virtual auto createEditor(QWidget *parent, const QStyleOptionViewItem &options,
+                              const QAbstractItemDelegate *delegate) -> QWidget * override;
 
     //! Gets the data from the widget
-    virtual QVariant getEditorData(const QWidget* editor) const override;
+    virtual auto getEditorData(const QWidget *editor) const -> QVariant override;
 
     //! Sets the colors
     virtual void setColors(const QMap<QString, QString> &colors);
 
     //! Get the settings. This function has to be implemented in a subclass in order to have an effect
-    virtual QMap<QString, QString> getColors() const;
+    virtual auto getColors() const -> QMap<QString, QString>;
 
     //! Sets the value of the property
-    virtual void setValue(const QVariant& value) override;
+    virtual void setValue(const QVariant &value) override;
 
     //! Returns a string containing the type of the property
-    virtual QString type() const override;
+    virtual auto type() const -> QString override;
 
     //! Clones this property
     //! \param include_children Indicates whether to also clone the children
     //! \param container If a property is being passed here, no new VProperty is being created but instead it is tried
     //! to fill all the data into container. This can also be used when subclassing this function.
     //! \return Returns the newly created property (or container, if it was not NULL)
-    Q_REQUIRED_RESULT virtual VProperty* clone(bool include_children = true,
-                                               VProperty* container = nullptr) const override;
+    Q_REQUIRED_RESULT virtual auto clone(bool include_children = true, VProperty *container = nullptr) const
+        -> VProperty * override;
 
-    static int IndexOfColor(const QMap<QString, QString> &colors, const QString &color);
+    static auto IndexOfColor(const QMap<QString, QString> &colors, const QString &color) -> vpesizetype;
 
 public slots:
     void currentIndexChanged(int index);
@@ -100,11 +99,12 @@ protected:
     QMap<QString, QString> colors;
     QVector<QString> indexList;
     // No use of d-pointer in this case, because it is unlikely this will change. If it does, we can still add other
-    //members by reimplementing the VPropertyPrivate class without touching this header file.
+    // members by reimplementing the VPropertyPrivate class without touching this header file.
+
 private:
     Q_DISABLE_COPY_MOVE(VLineColorProperty) // NOLINT
 };
 
-}
+} // namespace VPE
 
 #endif // VLINECOLORPROPERTY_H
