@@ -18,8 +18,8 @@
  **
  *************************************************************************/
 #include "vtextproperty.h"
-#include "../vproperty_p.h"
 #include "../vmisc/compatibility.h"
+#include "../vproperty_p.h"
 
 #include <QPlainTextEdit>
 #include <QTextEdit>
@@ -27,52 +27,59 @@
 namespace
 {
 //---------------------------------------------------------------------------------------------------------------------
-void SetTabStopDistance(QPlainTextEdit *edit, int tabWidthChar=4);
+void SetTabStopDistance(QPlainTextEdit *edit, int tabWidthChar = 4);
 void SetTabStopDistance(QPlainTextEdit *edit, int tabWidthChar)
 {
     const auto fontMetrics = edit->fontMetrics();
 
     const QString testString(" ");
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 10, 0)
-    const int singleCharWidth = fontMetrics.width(testString);
-    edit->setTabStopWidth(tabWidthChar * singleCharWidth);
-#else
     // compute the size of a char in double-precision
     static constexpr int bigNumber = 1000; // arbitrary big number.
-    const int many_char_width = TextWidth(fontMetrics, testString.repeated(bigNumber));
+    const int many_char_width = fontMetrics.horizontalAdvance(testString.repeated(bigNumber));
     const double singleCharWidthDouble = many_char_width / double(bigNumber);
     // set the tab stop with double precision
     edit->setTabStopDistance(tabWidthChar * singleCharWidthDouble);
-#endif
 }
-}
-
+} // namespace
 
 VPE::VTextProperty::VTextProperty(const QString &name, const QMap<QString, QVariant> &settings)
-    : VProperty(name, QVariant::String),
+  : VProperty(name,
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+              QMetaType::QString),
+#else
+              QVariant::String),
+#endif
     readOnly(false)
 {
     VProperty::setSettings(settings);
     d_ptr->VariantValue.setValue(QString());
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    d_ptr->VariantValue.convert(QMetaType(QMetaType::QString));
+#else
     d_ptr->VariantValue.convert(QVariant::String);
+#endif
 }
 
 VPE::VTextProperty::VTextProperty(const QString &name)
-    : VProperty(name),
+  : VProperty(name),
     readOnly(false)
 {
     d_ptr->VariantValue.setValue(QString());
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    d_ptr->VariantValue.convert(QMetaType(QMetaType::QString));
+#else
     d_ptr->VariantValue.convert(QVariant::String);
+#endif
 }
 
-QWidget *VPE::VTextProperty::createEditor(QWidget *parent, const QStyleOptionViewItem &options,
-                                          const QAbstractItemDelegate *delegate)
+auto VPE::VTextProperty::createEditor(QWidget *parent, const QStyleOptionViewItem &options,
+                                      const QAbstractItemDelegate *delegate) -> QWidget *
 {
     Q_UNUSED(options)
     Q_UNUSED(delegate)
 
-    QPlainTextEdit* tmpEditor = new QPlainTextEdit(parent);
+    auto *tmpEditor = new QPlainTextEdit(parent);
     tmpEditor->setLocale(parent->locale());
     tmpEditor->setReadOnly(readOnly);
     tmpEditor->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
@@ -83,9 +90,9 @@ QWidget *VPE::VTextProperty::createEditor(QWidget *parent, const QStyleOptionVie
     return d_ptr->editor;
 }
 
-bool VPE::VTextProperty::setEditorData(QWidget *editor)
+auto VPE::VTextProperty::setEditorData(QWidget *editor) -> bool
 {
-    if (QPlainTextEdit* tmpWidget = qobject_cast<QPlainTextEdit*>(editor))
+    if (auto *tmpWidget = qobject_cast<QPlainTextEdit *>(editor))
     {
         tmpWidget->setPlainText(d_ptr->VariantValue.toString());
         return true;
@@ -94,9 +101,9 @@ bool VPE::VTextProperty::setEditorData(QWidget *editor)
     return false;
 }
 
-QVariant VPE::VTextProperty::getEditorData(const QWidget *editor) const
+auto VPE::VTextProperty::getEditorData(const QWidget *editor) const -> QVariant
 {
-    const QPlainTextEdit* tmpEditor = qobject_cast<const QPlainTextEdit*>(editor);
+    const auto *tmpEditor = qobject_cast<const QPlainTextEdit *>(editor);
     if (tmpEditor)
     {
         return tmpEditor->toPlainText();
@@ -118,7 +125,7 @@ void VPE::VTextProperty::setSetting(const QString &key, const QVariant &value)
     }
 }
 
-QVariant VPE::VTextProperty::getSetting(const QString &key) const
+auto VPE::VTextProperty::getSetting(const QString &key) const -> QVariant
 {
     if (key == QLatin1String("ReadOnly"))
     {
@@ -128,19 +135,19 @@ QVariant VPE::VTextProperty::getSetting(const QString &key) const
         return VProperty::getSetting(key);
 }
 
-QStringList VPE::VTextProperty::getSettingKeys() const
+auto VPE::VTextProperty::getSettingKeys() const -> QStringList
 {
     QStringList settings;
     settings << QStringLiteral("ReadOnly");
     return settings;
 }
 
-QString VPE::VTextProperty::type() const
+auto VPE::VTextProperty::type() const -> QString
 {
     return QStringLiteral("string");
 }
 
-VPE::VProperty *VPE::VTextProperty::clone(bool include_children, VPE::VProperty *container) const
+auto VPE::VTextProperty::clone(bool include_children, VPE::VProperty *container) const -> VPE::VProperty *
 {
     return VProperty::clone(include_children, container ? container : new VTextProperty(getName(), getSettings()));
 }
