@@ -30,15 +30,15 @@
 #include <QStyleOptionViewItem>
 #include <QVariant>
 #include <QWidget>
-#include <Qt>
 
 #include "plugins/vwidgetproperty.h"
 #include "vproperty.h"
 #include "vpropertyformwidget_p.h"
 
 VPE::VPropertyFormWidget::VPropertyFormWidget(const QString &title, const QString &description,
-                                         const QList<VProperty*>& properties, QWidget *parent)
-    : QGroupBox(title, parent), d_ptr(new VPropertyFormWidgetPrivate(properties))
+                                              const QList<VProperty *> &properties, QWidget *parent)
+  : QGroupBox(title, parent),
+    d_ptr(new VPropertyFormWidgetPrivate(properties))
 {
     VPE::VPropertyFormWidget::build();
     setToolTip(description);
@@ -46,7 +46,8 @@ VPE::VPropertyFormWidget::VPropertyFormWidget(const QString &title, const QStrin
 }
 
 VPE::VPropertyFormWidget::VPropertyFormWidget(VProperty *parent_property, QWidget *parent)
-    : QGroupBox(parent), d_ptr(new VPropertyFormWidgetPrivate())
+  : QGroupBox(parent),
+    d_ptr(new VPropertyFormWidgetPrivate())
 {
     if (parent_property)
     {
@@ -60,7 +61,8 @@ VPE::VPropertyFormWidget::VPropertyFormWidget(VProperty *parent_property, QWidge
 
 VPE::VPropertyFormWidget::VPropertyFormWidget(VPropertyFormWidgetPrivate *d_pointer, QWidget *parent,
                                               const QString &title, const QString &description)
-    : QGroupBox(title, parent), d_ptr(d_pointer)
+  : QGroupBox(title, parent),
+    d_ptr(d_pointer)
 {
     VPE::VPropertyFormWidget::build();
     setToolTip(description);
@@ -72,21 +74,20 @@ VPE::VPropertyFormWidget::~VPropertyFormWidget()
     delete d_ptr;
 }
 
-
 void VPE::VPropertyFormWidget::build()
 {
     // Clear the old content, delete old widgets
     d_ptr->EditorWidgets.clear();
-    if (layout())
+    if (layout() != nullptr)
     {
-        QLayoutItem *child;
-        while (layout()->count() > 0 && (child = layout()->takeAt(0)) != nullptr)
+        while (layout()->count() > 0)
         {
-            if (child->widget())
+            QLayoutItem *child = layout()->takeAt(0);
+            if (child != nullptr)
             {
                 delete child->widget();
+                delete child;
             }
-            delete child;
         }
         delete layout();
     }
@@ -97,14 +98,14 @@ void VPE::VPropertyFormWidget::build()
         return; //... only if there are properties
     }
 
-    QFormLayout* tmpFormLayout = new QFormLayout(this);
+    auto *tmpFormLayout = new QFormLayout(this);
     tmpFormLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
     setLayout(tmpFormLayout);
 
     for (int i = 0; i < d_ptr->Properties.count(); ++i)
     {
         // Get the current property
-        VProperty* tmpProperty = d_ptr->Properties.value(i, nullptr);
+        VProperty *tmpProperty = d_ptr->Properties.value(i, nullptr);
         if (!tmpProperty)
         {
             continue;
@@ -115,10 +116,10 @@ void VPE::VPropertyFormWidget::build()
             if (tmpProperty->propertyType() == Property::Complex)
             {
                 buildEditor(tmpProperty, tmpFormLayout, Property::Complex);
-                QWidget *group = new QWidget(this);
+                auto *group = new QWidget(this);
                 tmpFormLayout->addRow(group);
 
-                QFormLayout* subFormLayout = new QFormLayout(group);
+                auto *subFormLayout = new QFormLayout(group);
                 subFormLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
                 QMargins margins = subFormLayout->contentsMargins();
                 margins.setTop(0);
@@ -127,7 +128,7 @@ void VPE::VPropertyFormWidget::build()
                 subFormLayout->setContentsMargins(margins);
 
                 group->setLayout(subFormLayout);
-                QList<VProperty*> children = tmpProperty->getChildren();
+                QList<VProperty *> children = tmpProperty->getChildren();
                 for (int j = 0; j < children.size(); ++j)
                 {
                     buildEditor(children[j], subFormLayout);
@@ -140,7 +141,7 @@ void VPE::VPropertyFormWidget::build()
             else
             {
                 // Child properties, the property itself is not being added
-                VPropertyFormWidget* tmpNewFormWidget = new VPropertyFormWidget(tmpProperty, this);
+                auto *tmpNewFormWidget = new VPropertyFormWidget(tmpProperty, this);
                 tmpFormLayout->addRow(tmpNewFormWidget);
                 d_ptr->EditorWidgets.append(VPropertyFormWidgetPrivate::SEditorWidget(tmpNewFormWidget));
                 tmpNewFormWidget->setCommitBehaviour(d_ptr->UpdateEditors);
@@ -148,7 +149,7 @@ void VPE::VPropertyFormWidget::build()
         }
         else if (tmpProperty->type() == "widget")
         {
-            VWidgetProperty* tmpWidgetProperty = static_cast<VWidgetProperty*>(tmpProperty);
+            auto *tmpWidgetProperty = static_cast<VWidgetProperty *>(tmpProperty);
             tmpFormLayout->addRow(tmpWidgetProperty->getWidget());
             d_ptr->EditorWidgets.append(VPropertyFormWidgetPrivate::SEditorWidget(tmpWidgetProperty->getWidget()));
         }
@@ -159,11 +160,11 @@ void VPE::VPropertyFormWidget::build()
     }
 }
 
-void VPE::VPropertyFormWidget::buildEditor(VProperty* property, QFormLayout* formLayout, Property type)
+void VPE::VPropertyFormWidget::buildEditor(VProperty *property, QFormLayout *formLayout, Property type)
 {
     // Add property (no child properties)
     // Create the editor (if it doesn't work, create empty widget)
-    QWidget* tmpEditor = property->createEditor(this, QStyleOptionViewItem(), nullptr);
+    QWidget *tmpEditor = property->createEditor(this, QStyleOptionViewItem(), nullptr);
     if (!tmpEditor)
     {
         tmpEditor = new QWidget(this);
@@ -182,7 +183,7 @@ void VPE::VPropertyFormWidget::buildEditor(VProperty* property, QFormLayout* for
     // add new row
     if (type == Property::Complex)
     {
-        QString name = "<b>"+property->getName()+"</b>";
+        QString const name = "<b>" + property->getName() + "</b>";
         formLayout->addRow(name, tmpEditor);
     }
     else
@@ -216,16 +217,16 @@ void VPE::VPropertyFormWidget::commitData(int row)
         return;
     }
 
-    VPropertyFormWidgetPrivate::SEditorWidget& tmpEditorWidget = d_ptr->EditorWidgets[row];
-    VProperty* tmpProperty = d_ptr->Properties[row];
+    VPropertyFormWidgetPrivate::SEditorWidget &tmpEditorWidget = d_ptr->EditorWidgets[row];
+    VProperty *tmpProperty = d_ptr->Properties[row];
     if (tmpEditorWidget.FormWidget)
     {
         tmpEditorWidget.FormWidget->commitData();
     }
     else if (tmpEditorWidget.Editor && tmpProperty)
     {
-        QVariant newValue = tmpProperty->getEditorData(tmpEditorWidget.Editor);
-        QVariant oldValue = tmpProperty->data(VProperty::DPC_Data, Qt::EditRole);
+        QVariant const newValue = tmpProperty->getEditorData(tmpEditorWidget.Editor);
+        QVariant const oldValue = tmpProperty->data(VProperty::DPC_Data, Qt::EditRole);
         if (oldValue != newValue)
         {
             VProperty *parent = tmpProperty->getParent();
@@ -250,8 +251,8 @@ void VPE::VPropertyFormWidget::loadData(int row)
         return;
     }
 
-    VPropertyFormWidgetPrivate::SEditorWidget& tmpEditorWidget = d_ptr->EditorWidgets[row];
-    VProperty* tmpProperty = d_ptr->Properties[row];
+    VPropertyFormWidgetPrivate::SEditorWidget &tmpEditorWidget = d_ptr->EditorWidgets[row];
+    VProperty *tmpProperty = d_ptr->Properties[row];
     if (tmpEditorWidget.FormWidget)
     {
         tmpEditorWidget.FormWidget->loadData();
@@ -266,8 +267,8 @@ void VPE::VPropertyFormWidget::setCommitBehaviour(bool auto_commit)
 {
     d_ptr->UpdateEditors = auto_commit;
 
-    const QList<VPropertyFormWidget*> tmpChildFormWidgets = getChildPropertyFormWidgets();
-    for (auto tmpChild : tmpChildFormWidgets)
+    const QList<VPropertyFormWidget *> tmpChildFormWidgets = getChildPropertyFormWidgets();
+    for (auto *tmpChild : tmpChildFormWidgets)
     {
         if (tmpChild)
         {
@@ -276,7 +277,7 @@ void VPE::VPropertyFormWidget::setCommitBehaviour(bool auto_commit)
     }
 }
 
-QList<VPE::VPropertyFormWidget *> VPE::VPropertyFormWidget::getChildPropertyFormWidgets() const
+auto VPE::VPropertyFormWidget::getChildPropertyFormWidgets() const -> QList<VPE::VPropertyFormWidget *>
 {
     QList<VPropertyFormWidget *> tmpResult;
     for (auto &tmpEditorWidget : d_ptr->EditorWidgets)
@@ -290,14 +291,14 @@ QList<VPE::VPropertyFormWidget *> VPE::VPropertyFormWidget::getChildPropertyForm
     return tmpResult;
 }
 
-bool VPE::VPropertyFormWidget::eventFilter(QObject *object, QEvent *event)
+auto VPE::VPropertyFormWidget::eventFilter(QObject *object, QEvent *event) -> bool
 {
     if (!d_ptr->UpdateEditors)
     {
         return false;
     }
 
-    QWidget* editor = qobject_cast<QWidget*>(object);
+    QWidget *editor = qobject_cast<QWidget *>(object);
     if (!editor)
     {
         return false;
@@ -339,14 +340,14 @@ bool VPE::VPropertyFormWidget::eventFilter(QObject *object, QEvent *event)
         }
         return false;
     }
-    else if (event->type() == QEvent::FocusOut || (event->type() == QEvent::Hide && editor->isWindow()))
+    if (event->type() == QEvent::FocusOut || (event->type() == QEvent::Hide && editor->isWindow()))
     {
         commitData(editor);
         return false;
     }
     else if (event->type() == QEvent::ShortcutOverride)
     {
-        if (static_cast<QKeyEvent*>(event)->key() == Qt::Key_Escape)
+        if (static_cast<QKeyEvent *>(event)->key() == Qt::Key_Escape)
         {
             commitData(editor);
             event->accept();
@@ -377,7 +378,7 @@ void VPE::VPropertyFormWidget::commitData(const QWidget *editor)
 
     for (int i = 0; i < d_ptr->EditorWidgets.count(); ++i)
     {
-        VPropertyFormWidgetPrivate::SEditorWidget& tmpEditorWidget = d_ptr->EditorWidgets[i];
+        VPropertyFormWidgetPrivate::SEditorWidget const &tmpEditorWidget = d_ptr->EditorWidgets[i];
         if (tmpEditorWidget.Editor == editor)
         {
             commitData(i);
