@@ -21,7 +21,6 @@
 #ifndef VPROPERTYTREEVIEW_H
 #define VPROPERTYTREEVIEW_H
 
-#include <qcompilerdetection.h>
 #include <QMetaObject>
 #include <QObject>
 #include <QString>
@@ -30,8 +29,6 @@
 
 #include "vpropertyexplorer_global.h"
 
-#include "../vmisc/defglobal.h"
-
 namespace VPE
 {
 
@@ -42,13 +39,14 @@ class VPropertyTreeViewPrivate;
 class VPROPERTYEXPLORERSHARED_EXPORT VPropertyTreeView : public QTreeView
 {
     Q_OBJECT // NOLINT
+
 public:
     //! Default constructor
     explicit VPropertyTreeView(QWidget *parent = nullptr);
 
     //! The destructor, taking a model and setting it to the tree view
     //! \param model The model to set as model for this tree view
-    explicit VPropertyTreeView(VPropertyModel* model, QWidget *parent = nullptr);
+    explicit VPropertyTreeView(VPropertyModel *model, QWidget *parent = nullptr);
 
     //! Destructor
     virtual ~VPropertyTreeView() override;
@@ -56,21 +54,20 @@ public:
     //! Sets the height for each row. Set this to 0 in order to let the standard delegate decide
     void setRowHeight(int height = 0, bool add_to_standard = false);
 
-
 protected:
     //! This method is called by the constructors to initialize the view
     virtual void init();
 
     //! protected constructor
-    VPropertyTreeView(VPropertyTreeViewPrivate* d, bool init_, QWidget *parent = nullptr);
+    VPropertyTreeView(VPropertyTreeViewPrivate *d, bool init_, QWidget *parent = nullptr);
 
     //! The protected data
-    VPropertyTreeViewPrivate* d_ptr;
+    VPropertyTreeViewPrivate *d_ptr;
 
 private:
     Q_DISABLE_COPY_MOVE(VPropertyTreeView) // NOLINT
 };
 
-}  // namespace VPE
+} // namespace VPE
 
 #endif // VPROPERTYTREEVIEWEEVIEW_H
