@@ -24,9 +24,6 @@
 // ONLY INCLUDE THIS IN .CPP FILES
 
 #include "vproperty_p.h"
-#if QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
-#include "../vmisc/diagnostic.h"
-#endif // QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
 
 #include <QPointer>
 #include <QWidget>
@@ -44,12 +41,24 @@ public:
     QPointer<QWidget> Widget;
 
     //! Constructor passing name and type
-    VWidgetPropertyPrivate(const QString& name, QVariant::Type type, QWidget* widget = nullptr)
-        : VPropertyPrivate(name, type), Widget(widget) {}
+    VWidgetPropertyPrivate(const QString &name,
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+                           QMetaType::Type type,
+#else
+                           QVariant::Type type,
+#endif
+                           QWidget *widget = nullptr)
+      : VPropertyPrivate(name, type),
+        Widget(widget)
+    {
+    }
 
     //! Constructor
     VWidgetPropertyPrivate()
-        : VPropertyPrivate(), Widget(nullptr) {}
+      : VPropertyPrivate(),
+        Widget(nullptr)
+    {
+    }
 
     //! Destructor
     virtual ~VWidgetPropertyPrivate() override
@@ -63,6 +72,6 @@ public:
 
 QT_WARNING_POP
 
-}
+} // namespace VPE
 
 #endif // VWIDGETPROPERTY_P_H
