@@ -27,36 +27,44 @@
  *************************************************************************/
 #include "dialogtoolbox.h"
 
-#include "../vmisc/def.h"
-#include "../vmisc/vabstractapplication.h"
-#include "../vpatterndb/calculator.h"
-#include "../vpatterndb/vcontainer.h"
-#include "../vpatterndb/vpiecenode.h"
-#include "../vgeometry/vpointf.h"
-#include "../vpatterndb/variables/vcurvelength.h"
 #include "../ifc/exception/vexceptionbadid.h"
-#include "../vpatterndb/vcontainer.h"
-#include "../vgeometry/vellipticalarc.h"
+#include "../qmuparser/qmudef.h"
 #include "../vgeometry/varc.h"
 #include "../vgeometry/vcubicbezier.h"
 #include "../vgeometry/vcubicbezierpath.h"
+#include "../vgeometry/vellipticalarc.h"
+#include "../vgeometry/vpointf.h"
 #include "../vgeometry/vspline.h"
 #include "../vgeometry/vsplinepath.h"
-#include "../qmuparser/qmudef.h"
+#include "../vmisc/def.h"
+#include "../vmisc/theme/themeDef.h"
+#include "../vmisc/vabstractapplication.h"
+#include "../vpatterndb/calculator.h"
+#include "../vpatterndb/variables/vcurvelength.h"
+#include "../vpatterndb/vcontainer.h"
+#include "../vpatterndb/vpiecenode.h"
+#include "qdialogbuttonbox.h"
 
+#include <QBuffer>
+#include <QDebug>
 #include <QDialog>
 #include <QLabel>
+#include <QLineEdit>
+#include <QListWidget>
 #include <QLocale>
+#include <QPainter>
 #include <QPlainTextEdit>
 #include <QPushButton>
-#include <QTextCursor>
-#include <QDebug>
-#include <QTimer>
-#include <QLineEdit>
 #include <QRegularExpression>
+#include <QTextCursor>
+#include <QTimer>
 #include <qnumeric.h>
-#include <QListWidget>
-#include <QBuffer>
+
+#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
+#include "../vmisc/compatibility.h"
+#endif
+
+using namespace Qt::Literals::StringLiterals;
 
 const QColor errorColor = Qt::red;
 
@@ -65,11 +73,11 @@ namespace
 const int dialogMaxFormulaHeight = 80;
 
 //---------------------------------------------------------------------------------------------------------------------
-auto DoublePoint(const VPieceNode &firstNode, const VPieceNode &secondNode, const VContainer *data,
-                 QString &error) -> bool
+auto DoublePoint(const VPieceNode &firstNode, const VPieceNode &secondNode, const VContainer *data, QString &error)
+    -> bool
 {
-    if (firstNode.GetTypeTool() == Tool::NodePoint && not (firstNode.GetId() == NULL_ID)
-            && secondNode.GetTypeTool() == Tool::NodePoint && not (secondNode.GetId() == NULL_ID))
+    if (firstNode.GetTypeTool() == Tool::NodePoint && not(firstNode.GetId() == NULL_ID) &&
+        secondNode.GetTypeTool() == Tool::NodePoint && not(secondNode.GetId() == NULL_ID))
     {
         QSharedPointer<VPointF> firstPoint;
         QSharedPointer<VPointF> secondPoint;
@@ -79,7 +87,7 @@ auto DoublePoint(const VPieceNode &firstNode, const VPieceNode &secondNode, cons
             firstPoint = data->GeometricObject<VPointF>(firstNode.GetId());
             secondPoint = data->GeometricObject<VPointF>(secondNode.GetId());
         }
-        catch(const VExceptionBadId &)
+        catch (const VExceptionBadId &)
         {
             return false;
         }
@@ -93,8 +101,8 @@ auto DoublePoint(const VPieceNode &firstNode, const VPieceNode &secondNode, cons
 
         // The same point, but different modeling objects
         if (firstPoint->getIdObject() != NULL_ID && secondPoint->getIdObject() != NULL_ID &&
-                firstPoint->getMode() == Draw::Modeling && secondPoint->getMode() == Draw::Modeling &&
-                firstPoint->getIdObject() == secondPoint->getIdObject())
+            firstPoint->getMode() == Draw::Modeling && secondPoint->getMode() == Draw::Modeling &&
+            firstPoint->getIdObject() == secondPoint->getIdObject())
         {
             error = QObject::tr("Point '%1' repeats twice").arg(firstPoint->name());
             return true;
@@ -106,11 +114,11 @@ auto DoublePoint(const VPieceNode &firstNode, const VPieceNode &secondNode, cons
             return false;
         }
 
-        bool sameCoordinates = VFuzzyComparePoints(firstPoint->toQPointF(), secondPoint->toQPointF());
+        bool const sameCoordinates = VFuzzyComparePoints(firstPoint->toQPointF(), secondPoint->toQPointF());
         if (sameCoordinates)
         {
             error = QObject::tr("Points '%1' and '%2' have the same coordinates.")
-                    .arg(firstPoint->name(), secondPoint->name());
+                        .arg(firstPoint->name(), secondPoint->name());
         }
 
         return sameCoordinates;
@@ -120,11 +128,11 @@ auto DoublePoint(const VPieceNode &firstNode, const VPieceNode &secondNode, cons
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-auto DoubleCurve(const VPieceNode &firstNode, const VPieceNode &secondNode, const VContainer *data,
-                 QString &error) -> bool
+auto DoubleCurve(const VPieceNode &firstNode, const VPieceNode &secondNode, const VContainer *data, QString &error)
+    -> bool
 {
-    if (firstNode.GetTypeTool() != Tool::NodePoint && not (firstNode.GetId() == NULL_ID)
-            && secondNode.GetTypeTool() != Tool::NodePoint && not (secondNode.GetId() == NULL_ID))
+    if (firstNode.GetTypeTool() != Tool::NodePoint && not(firstNode.GetId() == NULL_ID) &&
+        secondNode.GetTypeTool() != Tool::NodePoint && not(secondNode.GetId() == NULL_ID))
     {
         QSharedPointer<VGObject> curve1;
         QSharedPointer<VGObject> curve2;
@@ -160,8 +168,7 @@ auto DoubleCurve(const VPieceNode &firstNode, const VPieceNode &secondNode, cons
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-template <class T>
-auto CurveAliases(const QString &alias1, const QString &alias2) -> QPair<QString, QString>
+template <class T> auto CurveAliases(const QString &alias1, const QString &alias2) -> QPair<QString, QString>
 {
     T curve1;
     curve1.SetAliasSuffix(alias1);
@@ -171,16 +178,16 @@ auto CurveAliases(const QString &alias1, const QString &alias2) -> QPair<QString
 
     return qMakePair(curve1.GetAlias(), curve2.GetAlias());
 }
-}  // namespace
+} // namespace
 
 //---------------------------------------------------------------------------------------------------------------------
-VPieceNode RowNode(QListWidget *listWidget, int i)
+auto RowNode(QListWidget *listWidget, int i) -> VPieceNode
 {
     SCASSERT(listWidget != nullptr);
 
     if (i < 0 || i >= listWidget->count())
     {
-        return VPieceNode();
+        return {};
     }
 
     const QListWidgetItem *rowItem = listWidget->item(i);
@@ -207,25 +214,23 @@ void DeployFormula(QDialog *dialog, QPlainTextEdit *formula, QPushButton *button
 
     const QTextCursor cursor = formula->textCursor();
 
-    //Before deploy ned to release dialog size
-    //I don't know why, but don't need to fixate again.
-    //A dialog will be lefted fixated. That's what we need.
+    // Before deploy ned to release dialog size
+    // I don't know why, but don't need to fixate again.
+    // A dialog will be lefted fixated. That's what we need.
     dialog->setMaximumSize(QSize(QWIDGETSIZE_MAX, QWIDGETSIZE_MAX));
     dialog->setMinimumSize(QSize(0, 0));
 
     if (formula->height() < dialogMaxFormulaHeight)
     {
         formula->setFixedHeight(dialogMaxFormulaHeight);
-        //Set icon from theme (internal for Windows system)
-        buttonGrowLength->setIcon(QIcon::fromTheme(QStringLiteral("go-next"),
-                                                   QIcon(":/icons/win.icon.theme/16x16/actions/go-next.png")));
+        // Set icon from theme (internal for Windows system)
+        buttonGrowLength->setIcon(FromTheme(VThemeIcon::GoNext));
     }
     else
     {
-       formula->setFixedHeight(formulaBaseHeight);
-       //Set icon from theme (internal for Windows system)
-       buttonGrowLength->setIcon(QIcon::fromTheme(QStringLiteral("go-down"),
-                                                  QIcon(":/icons/win.icon.theme/16x16/actions/go-down.png")));
+        formula->setFixedHeight(formulaBaseHeight);
+        // Set icon from theme (internal for Windows system)
+        buttonGrowLength->setIcon(FromTheme(VThemeIcon::GoDown));
     }
 
     // I found that after change size of formula field, it was filed for angle formula, field for formula became black.
@@ -239,22 +244,22 @@ void DeployFormula(QDialog *dialog, QPlainTextEdit *formula, QPushButton *button
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool FilterObject(QObject *object, QEvent *event)
+auto FilterObject(QObject *object, QEvent *event) -> bool
 {
-    if (QPlainTextEdit *plainTextEdit = qobject_cast<QPlainTextEdit *>(object))
+    if (auto *plainTextEdit = qobject_cast<QPlainTextEdit *>(object))
     {
         if (event->type() == QEvent::KeyPress)
         {
-            QKeyEvent *keyEvent = static_cast<QKeyEvent *>(event);
+            auto *keyEvent = static_cast<QKeyEvent *>(event);
             if ((keyEvent->key() == Qt::Key_Period) && (keyEvent->modifiers() & Qt::KeypadModifier))
             {
                 if (VAbstractApplication::VApp()->Settings()->GetOsSeparator())
                 {
-                    plainTextEdit->insertPlainText(QLocale().decimalPoint());
+                    plainTextEdit->insertPlainText(LocaleDecimalPoint(QLocale()));
                 }
                 else
                 {
-                    plainTextEdit->insertPlainText(QLocale::c().decimalPoint());
+                    plainTextEdit->insertPlainText(LocaleDecimalPoint(QLocale::c()));
                 }
                 return true;
             }
@@ -265,12 +270,12 @@ bool FilterObject(QObject *object, QEvent *event)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-qreal EvalToolFormula(QDialog *dialog, const FormulaData &data, bool &flag)
+auto EvalToolFormula(QDialog *dialog, const FormulaData &data, bool &flag) -> qreal
 {
     SCASSERT(data.labelResult != nullptr)
     SCASSERT(data.labelEditFormula != nullptr)
 
-    qreal result = INT_MIN;//Value can be 0, so use max imposible value
+    qreal result = INT_MIN; // Value can be 0, so use max imposible value
 
     if (data.formula.isEmpty())
     {
@@ -284,10 +289,9 @@ qreal EvalToolFormula(QDialog *dialog, const FormulaData &data, bool &flag)
         try
         {
             // Translate to internal look.
-            QString formula = VAbstractApplication::VApp()
-                    ->TrVars()->FormulaFromUser(data.formula,
-                                                VAbstractApplication::VApp()->Settings()->GetOsSeparator());
-            QScopedPointer<Calculator> cal(new Calculator());
+            QString const formula = VAbstractApplication::VApp()->TrVars()->FormulaFromUser(
+                data.formula, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+            QScopedPointer<Calculator> const cal(new Calculator());
             result = cal->EvalFormula(data.variables, formula);
 
             if (qIsInf(result) || qIsNaN(result))
@@ -300,7 +304,7 @@ qreal EvalToolFormula(QDialog *dialog, const FormulaData &data, bool &flag)
             }
             else
             {
-                //if result equal 0
+                // if result equal 0
                 if (data.checkZero && qFuzzyIsNull(result))
                 {
                     flag = false;
@@ -317,8 +321,8 @@ qreal EvalToolFormula(QDialog *dialog, const FormulaData &data, bool &flag)
                 }
                 else
                 {
-                    data.labelResult->setText(VAbstractApplication::VApp()
-                                              ->LocaleToString(result) + QChar(QChar::Space) + data.postfix);
+                    data.labelResult->setText(VAbstractApplication::VApp()->LocaleToString(result) +
+                                              QChar(QChar::Space) + data.postfix);
                     flag = true;
                     ChangeColor(data.labelEditFormula, OkColor(dialog));
                     data.labelResult->setToolTip(QObject::tr("Value"));
@@ -333,7 +337,7 @@ qreal EvalToolFormula(QDialog *dialog, const FormulaData &data, bool &flag)
             data.labelResult->setToolTip(QObject::tr("Parser error: %1").arg(e.GetMsg()));
             qDebug() << "\nMath parser error:\n"
                      << "--------------------------------------\n"
-                     << "Message:     " << e.GetMsg()  << "\n"
+                     << "Message:     " << e.GetMsg() << "\n"
                      << "Expression:  " << e.GetExpr() << "\n"
                      << "--------------------------------------";
         }
@@ -352,14 +356,14 @@ void ChangeColor(QWidget *widget, const QColor &color)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QColor OkColor(QWidget *widget)
+auto OkColor(const QWidget *widget) -> QColor
 {
     SCASSERT(widget != nullptr);
     return widget->palette().color(QPalette::Active, QPalette::WindowText);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void CheckPointLabel(QDialog *dialog, QLineEdit* edit, QLabel *labelEditNamePoint, const QString &pointName,
+void CheckPointLabel(QDialog *dialog, QLineEdit *edit, QLabel *labelEditNamePoint, const QString &pointName,
                      const VContainer *data, bool &flag)
 {
     SCASSERT(dialog != nullptr)
@@ -367,8 +371,8 @@ void CheckPointLabel(QDialog *dialog, QLineEdit* edit, QLabel *labelEditNamePoin
     SCASSERT(labelEditNamePoint != nullptr)
 
     const QString name = edit->text();
-    QRegularExpression rx(NameRegExp());
-    if (name.isEmpty() || (pointName != name && not data->IsUnique(name)) || not rx.match(name).hasMatch())
+    if (QRegularExpression const rx(NameRegExp());
+        name.isEmpty() || (pointName != name && not data->IsUnique(name)) || not rx.match(name).hasMatch())
     {
         flag = false;
         ChangeColor(labelEditNamePoint, errorColor);
@@ -381,7 +385,99 @@ void CheckPointLabel(QDialog *dialog, QLineEdit* edit, QLabel *labelEditNamePoin
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-int FindNotExcludedNodeDown(QListWidget *listWidget, int candidate)
+auto FindNotExcludedNeighborNodeDown(QListWidget *listWidget, int candidate) -> int
+{
+    SCASSERT(listWidget != nullptr);
+
+    int index = -1;
+    if (candidate < 0 || candidate >= listWidget->count())
+    {
+        return index;
+    }
+
+    int i = candidate;
+    VPieceNode rowNode;
+    bool foundNeighbor = false;
+
+    do
+    {
+        const QListWidgetItem *rowItem = listWidget->item(i);
+        SCASSERT(rowItem != nullptr);
+        rowNode = qvariant_cast<VPieceNode>(rowItem->data(Qt::UserRole));
+
+        if (not rowNode.IsExcluded())
+        {
+            index = i;
+            foundNeighbor = true;
+            break;
+        }
+
+        --i;
+        if (i < 0)
+        {
+            // Wrap around to the end of the list
+            i = listWidget->count() - 1;
+        }
+
+    } while (i != candidate);
+
+    if (!foundNeighbor)
+    {
+        // No not excluded neighbor found
+        index = -1;
+    }
+
+    return index;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto FindNotExcludedNeighborNodeUp(QListWidget *listWidget, int candidate) -> int
+{
+    SCASSERT(listWidget != nullptr);
+
+    int index = -1;
+    if (candidate < 0 || candidate >= listWidget->count())
+    {
+        return index;
+    }
+
+    int i = candidate;
+    VPieceNode rowNode;
+    bool foundNeighbor = false;
+
+    do
+    {
+        const QListWidgetItem *rowItem = listWidget->item(i);
+        SCASSERT(rowItem != nullptr);
+        rowNode = qvariant_cast<VPieceNode>(rowItem->data(Qt::UserRole));
+
+        if (not rowNode.IsExcluded())
+        {
+            index = i;
+            foundNeighbor = true;
+            break;
+        }
+
+        ++i;
+        if (i >= listWidget->count())
+        {
+            // Wrap around to the beginning of the list
+            i = 0;
+        }
+
+    } while (i != candidate); // Continue until we reach back to the starting point or find a neighbor
+
+    if (!foundNeighbor)
+    {
+        // No not excluded neighbor found
+        index = -1;
+    }
+
+    return index;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto FindNotExcludedNodeDown(QListWidget *listWidget, int candidate) -> int
 {
     SCASSERT(listWidget != nullptr);
 
@@ -405,14 +501,13 @@ int FindNotExcludedNodeDown(QListWidget *listWidget, int candidate)
         }
 
         ++i;
-    }
-    while (rowNode.IsExcluded() && i < listWidget->count());
+    } while (rowNode.IsExcluded() && i < listWidget->count());
 
     return index;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-int FindNotExcludedNodeUp(QListWidget *listWidget, int candidate)
+auto FindNotExcludedNodeUp(QListWidget *listWidget, int candidate) -> int
 {
     SCASSERT(listWidget != nullptr);
 
@@ -436,20 +531,19 @@ int FindNotExcludedNodeUp(QListWidget *listWidget, int candidate)
         }
 
         --i;
-    }
-    while (rowNode.IsExcluded() && i > -1);
+    } while (rowNode.IsExcluded() && i > -1);
 
     return index;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool FirstPointEqualLast(QListWidget *listWidget, const VContainer *data, QString &error)
+auto FirstPointEqualLast(QListWidget *listWidget, const VContainer *data, QString &error) -> bool
 {
     SCASSERT(listWidget != nullptr);
     if (listWidget->count() > 1)
     {
         const VPieceNode topNode = RowNode(listWidget, FindNotExcludedNodeDown(listWidget, 0));
-        const VPieceNode bottomNode = RowNode(listWidget, FindNotExcludedNodeUp(listWidget, listWidget->count()-1));
+        const VPieceNode bottomNode = RowNode(listWidget, FindNotExcludedNodeUp(listWidget, listWidget->count() - 1));
 
         return DoublePoint(topNode, bottomNode, data, error);
     }
@@ -457,14 +551,14 @@ bool FirstPointEqualLast(QListWidget *listWidget, const VContainer *data, QStrin
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool DoublePoints(QListWidget *listWidget, const VContainer *data, QString &error)
+auto DoublePoints(QListWidget *listWidget, const VContainer *data, QString &error) -> bool
 {
     SCASSERT(listWidget != nullptr);
-    for (int i=0, sz = listWidget->count()-1; i<sz; ++i)
+    for (int i = 0, sz = listWidget->count() - 1; i < sz; ++i)
     {
         const int firstIndex = FindNotExcludedNodeDown(listWidget, i);
         const VPieceNode firstNode = RowNode(listWidget, firstIndex);
-        const VPieceNode secondNode = RowNode(listWidget, FindNotExcludedNodeDown(listWidget, firstIndex+1));
+        const VPieceNode secondNode = RowNode(listWidget, FindNotExcludedNodeDown(listWidget, firstIndex + 1));
 
         if (DoublePoint(firstNode, secondNode, data, error))
         {
@@ -478,11 +572,11 @@ bool DoublePoints(QListWidget *listWidget, const VContainer *data, QString &erro
 auto DoubleCurves(QListWidget *listWidget, const VContainer *data, QString &error) -> bool
 {
     SCASSERT(listWidget != nullptr);
-    for (int i=0, sz = listWidget->count()-1; i<sz; ++i)
+    for (int i = 0, sz = listWidget->count() - 1; i < sz; ++i)
     {
         const int firstIndex = FindNotExcludedNodeDown(listWidget, i);
         const VPieceNode firstNode = RowNode(listWidget, firstIndex);
-        const VPieceNode secondNode = RowNode(listWidget, FindNotExcludedNodeDown(listWidget, firstIndex+1));
+        const VPieceNode secondNode = RowNode(listWidget, FindNotExcludedNodeDown(listWidget, firstIndex + 1));
 
         if (DoubleCurve(firstNode, secondNode, data, error))
         {
@@ -498,7 +592,7 @@ auto EachPointLabelIsUnique(QListWidget *listWidget) -> bool
     SCASSERT(listWidget != nullptr);
     QSet<quint32> pointLabels;
     int countPoints = 0;
-    for (int i=0; i < listWidget->count(); ++i)
+    for (int i = 0; i < listWidget->count(); ++i)
     {
         const QListWidgetItem *rowItem = listWidget->item(i);
         SCASSERT(rowItem != nullptr);
@@ -514,20 +608,19 @@ auto EachPointLabelIsUnique(QListWidget *listWidget) -> bool
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogWarningIcon()
+auto DialogWarningIcon() -> QString
 {
-    const QIcon icon = QIcon::fromTheme("dialog-warning",
-                                  QIcon(":/icons/win.icon.theme/16x16/status/dialog-warning.png"));
+    const QIcon icon = FromTheme(VThemeIcon::DialogWarning);
 
     const QPixmap pixmap = icon.pixmap(QSize(16, 16));
     QByteArray byteArray;
     QBuffer buffer(&byteArray);
     pixmap.save(&buffer, "PNG");
-    return QStringLiteral("<img src=\"data:image/png;base64,") + byteArray.toBase64() + QStringLiteral("\"/> ");
+    return QStringLiteral("<img src=\"data:image/png;base64,") + byteArray.toBase64() + "\"/> "_L1;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QFont NodeFont(QFont font, bool nodeExcluded)
+auto NodeFont(QFont font, bool nodeExcluded) -> QFont
 {
     font.setPointSize(12);
     font.setWeight(QFont::Bold);
@@ -564,38 +657,37 @@ void SetTabStopDistance(QPlainTextEdit *edit, int tabWidthChar)
 
     const QString testString(" ");
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 10, 0)
-    const int single_char_width = fontMetrics.width(testString);
-    edit->setTabStopWidth(tabWidthChar * single_char_width);
-#else
     // compute the size of a char in double-precision
     static constexpr int bigNumber = 1000; // arbitrary big number.
-    const int many_char_width = TextWidth(fontMetrics, testString.repeated(bigNumber));
+    const int many_char_width = fontMetrics.horizontalAdvance(testString.repeated(bigNumber));
     const double singleCharWidthDouble = many_char_width / double(bigNumber);
     // set the tab stop with double precision
     edit->setTabStopDistance(tabWidthChar * singleCharWidthDouble);
-#endif
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QIcon LineColor(int size, const QString &color)
+auto LineColor(const QColor &borderColor, int size, const QString &color) -> QIcon
 {
     // On Mac pixmap should be little bit smaller.
 #if defined(Q_OS_MAC)
     size -= 2; // Two pixels should be enough.
-#endif //defined(Q_OS_MAC)
+#endif         // defined(Q_OS_MAC)
 
     QPixmap pix(size, size);
     pix.fill(QColor(color));
-    return QIcon(pix);
+
+    // Draw a white border around the icon
+    QPainter painter(&pix);
+    painter.setPen(borderColor);
+    painter.drawRect(0, 0, size - 1, size - 1);
+
+    return {pix};
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QT_WARNING_PUSH
-QT_WARNING_DISABLE_GCC("-Wswitch-default")
 auto SegmentAliases(GOType curveType, const QString &alias1, const QString &alias2) -> QPair<QString, QString>
 {
-    switch(curveType)
+    switch (curveType)
     {
         case GOType::EllipticalArc:
             return CurveAliases<VEllipticalArc>(alias1, alias2);
@@ -614,14 +706,13 @@ auto SegmentAliases(GOType curveType, const QString &alias1, const QString &alia
         case GOType::Unknown:
             Q_UNREACHABLE();
             break;
+        default:
+            return {};
     }
-
-    return {};
 }
-QT_WARNING_POP
 
 //---------------------------------------------------------------------------------------------------------------------
-QString GetNodeName(const VContainer *data, const VPieceNode &node, bool showPassmarkDetails)
+auto GetNodeName(const VContainer *data, const VPieceNode &node, bool showPassmarkDetails) -> QString
 {
     const QSharedPointer<VGObject> obj = data->GetGObject(node.GetId());
     QString name = obj->ObjectName();
@@ -630,31 +721,31 @@ QString GetNodeName(const VContainer *data, const VPieceNode &node, bool showPas
     {
         if (node.GetReverse())
         {
-            name = QStringLiteral("- ") + name;
+            name = "- "_L1 + name;
         }
     }
     else
     {
         if (showPassmarkDetails && node.IsPassmark())
         {
-            switch(node.GetPassmarkLineType())
+            switch (node.GetPassmarkLineType())
             {
                 case PassmarkLineType::OneLine:
-                    name += QLatin1Char('|');
+                    name += '|'_L1;
                     break;
                 case PassmarkLineType::TwoLines:
-                    name += QLatin1String("||");
+                    name += "||"_L1;
                     break;
                 case PassmarkLineType::ThreeLines:
-                    name += QLatin1String("|||");
+                    name += "|||"_L1;
                     break;
                 case PassmarkLineType::TMark:
                     name += QStringLiteral("┴");
                     break;
-                case PassmarkLineType::VMark:
+                case PassmarkLineType::ExternalVMark:
                     name += QStringLiteral("⊼");
                     break;
-                case PassmarkLineType::VMark2:
+                case PassmarkLineType::InternalVMark:
                     name += QStringLiteral("⊽");
                     break;
                 case PassmarkLineType::UMark:
@@ -663,6 +754,9 @@ QString GetNodeName(const VContainer *data, const VPieceNode &node, bool showPas
                 case PassmarkLineType::BoxMark:
                     name += QStringLiteral("⎕");
                     break;
+                case PassmarkLineType::CheckMark:
+                    name += QStringLiteral("✓");
+                    break;
                 default:
                     break;
             }
@@ -670,7 +764,12 @@ QString GetNodeName(const VContainer *data, const VPieceNode &node, bool showPas
 
         if (not node.IsCheckUniqueness())
         {
-            name = QLatin1Char('[') + name + QLatin1Char(']');
+            name = '['_L1 + name + ']'_L1;
+        }
+
+        if (not node.IsTurnPoint())
+        {
+            name += QStringLiteral(" ⦿");
         }
     }
 
@@ -709,8 +808,7 @@ auto FindNotExcludedPointDown(QListWidget *listWidget, int start) -> int
         }
 
         ++count;
-    }
-    while (count < listWidget->count());
+    } while (count < listWidget->count());
 
     return index;
 }
@@ -747,8 +845,7 @@ auto FindNotExcludedCurveDown(QListWidget *listWidget, int start) -> int
         }
 
         ++count;
-    }
-    while (count < listWidget->count());
+    } while (count < listWidget->count());
 
     return index;
 }
@@ -758,15 +855,15 @@ auto InvalidSegment(QListWidget *listWidget, const VContainer *data, QString &er
 {
     SCASSERT(listWidget != nullptr);
 
-    for (int index=0; index < listWidget->count(); ++index)
+    for (int index = 0; index < listWidget->count(); ++index)
     {
         int firstCurveIndex = -1;
         int pointIndex = -1;
         int secondCurveIndex = -1;
 
-        auto FindPair = [listWidget, &firstCurveIndex, &pointIndex, &secondCurveIndex]( int start)
+        auto FindPair = [listWidget, &firstCurveIndex, &pointIndex, &secondCurveIndex](int start)
         {
-            for (int i=start; i < listWidget->count(); ++i)
+            for (int i = start; i < listWidget->count(); ++i)
             {
                 firstCurveIndex = FindNotExcludedCurveDown(listWidget, i);
                 if (firstCurveIndex == -1)
@@ -774,13 +871,13 @@ auto InvalidSegment(QListWidget *listWidget, const VContainer *data, QString &er
                     continue;
                 }
 
-                pointIndex = FindNotExcludedPointDown(listWidget, firstCurveIndex+1);
+                pointIndex = FindNotExcludedPointDown(listWidget, firstCurveIndex + 1);
                 if (pointIndex == -1)
                 {
                     continue;
                 }
 
-                secondCurveIndex = FindNotExcludedCurveDown(listWidget, pointIndex+1);
+                secondCurveIndex = FindNotExcludedCurveDown(listWidget, pointIndex + 1);
                 if (secondCurveIndex == -1 || firstCurveIndex == secondCurveIndex)
                 {
                     continue;
@@ -819,7 +916,7 @@ auto InvalidSegment(QListWidget *listWidget, const VContainer *data, QString &er
 
             error = QObject::tr("Point '%1' does not lie on a curve '%2'").arg(point->name(), curve1->name());
 
-            bool validSegment = curve1->IsPointOnCurve(point->toQPointF());
+            bool const validSegment = curve1->IsPointOnCurve(point->toQPointF());
             if (not validSegment)
             {
                 return true;
@@ -833,3 +930,81 @@ auto InvalidSegment(QListWidget *listWidget, const VContainer *data, QString &er
 
     return false;
 }
+
+//---------------------------------------------------------------------------------------------------------------------
+void InitDialogButtonBoxIcons(QDialogButtonBox *buttonBox)
+{
+    SCASSERT(buttonBox != nullptr)
+
+    QStyle *style = QApplication::style();
+
+    if (QPushButton *bOk = buttonBox->button(QDialogButtonBox::Ok))
+    {
+        bOk->setIcon(style->standardIcon(QStyle::SP_DialogOkButton));
+    }
+
+    if (QPushButton *bApply = buttonBox->button(QDialogButtonBox::Apply))
+    {
+        bApply->setIcon(style->standardIcon(QStyle::SP_DialogApplyButton));
+    }
+
+    if (QPushButton *bCancel = buttonBox->button(QDialogButtonBox::Cancel))
+    {
+        bCancel->setIcon(style->standardIcon(QStyle::SP_DialogCancelButton));
+    }
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto MirrorLinePointsNeighbors(QListWidget *listWidget, quint32 startPoint, quint32 endPoint) -> bool
+{
+    SCASSERT(listWidget != nullptr)
+
+    if (startPoint == endPoint || startPoint == NULL_ID || endPoint == NULL_ID)
+    {
+        return false;
+    }
+
+    const int startIndex = NodeRowIndex(listWidget, startPoint);
+    if (startIndex == -1)
+    {
+        return false;
+    }
+
+    int nextIndex = startIndex + 1;
+    if (nextIndex >= listWidget->count())
+    {
+        nextIndex = 0;
+    }
+
+    int prevIndex = startIndex - 1;
+    if (prevIndex < 0)
+    {
+        prevIndex = listWidget->count() - 1;
+    }
+
+    const int next = FindNotExcludedNeighborNodeDown(listWidget, prevIndex);
+    const int prev = FindNotExcludedNeighborNodeUp(listWidget, nextIndex);
+
+    return (next >= 0 && endPoint == RowNode(listWidget, next).GetId()) ||
+           (prev >= 0 && endPoint == RowNode(listWidget, prev).GetId());
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto NodeRowIndex(QListWidget *listWidget, quint32 id) -> int
+{
+    SCASSERT(listWidget != nullptr)
+
+    for (int i = 0, sz = listWidget->count(); i < sz; ++i)
+    {
+        const QListWidgetItem *rowItem = listWidget->item(i);
+        SCASSERT(rowItem != nullptr);
+        auto rowNode = qvariant_cast<VPieceNode>(rowItem->data(Qt::UserRole));
+
+        if (id == rowNode.GetId())
+        {
+            return i;
+        }
+    }
+
+    return -1;
+}
