@@ -27,35 +27,66 @@
  *************************************************************************/
 
 #include "dialogeditlabel.h"
-#include "ui_dialogeditlabel.h"
-#include "../vmisc/vabstractapplication.h"
-#if QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
-#include "../vmisc/backport/qoverload.h"
-#endif // QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
-#include "../vformat/vlabeltemplate.h"
-#include "../ifc/xml/vlabeltemplateconverter.h"
-#include "../ifc/xml/vabstractpattern.h"
 #include "../ifc/exception/vexception.h"
+#include "../ifc/xml/vabstractpattern.h"
+#include "../ifc/xml/vlabeltemplateconverter.h"
+#include "../tools/dialogtool.h"
+#include "../vformat/vlabeltemplate.h"
+#include "../vmisc/compatibility.h"
+#include "../vmisc/vabstractapplication.h"
+#include "../vmisc/vtranslator.h"
+#include "../vpatterndb/calculator.h"
+#include "../vpatterndb/floatItemData/vpiecelabeldata.h"
+#include "../vpatterndb/variables/vmeasurement.h"
+#include "../vpatterndb/variables/vpiecearea.h"
 #include "../vpatterndb/vcontainer.h"
 #include "../vpatterndb/vpiece.h"
-#include "../vpatterndb/floatItemData/vpiecelabeldata.h"
-#include "../vpatterndb/calculator.h"
-#include "../tools/dialogtool.h"
+#include "ui_dialogeditlabel.h"
+#include "vabstractvalapplication.h"
+#include "vvalentinasettings.h"
 
+#include <QDate>
 #include <QDir>
-#include <QMessageBox>
 #include <QFileDialog>
 #include <QMenu>
-#include <QDate>
+#include <QMessageBox>
+
+using namespace Qt::Literals::StringLiterals;
+
+namespace
+{
+//---------------------------------------------------------------------------------------------------------------------
+auto FileBaseName(const QString &filePath) -> QString
+{
+    // Known suffixes to check for
+    QStringList const knownSuffixes = {".val", ".vst", ".vit"};
+
+    QFileInfo const fileInfo(filePath);
+
+    // Check if the file has one of the known suffixes
+    for (const QString &suffix : knownSuffixes)
+    {
+        if (fileInfo.completeSuffix().endsWith(suffix, Qt::CaseInsensitive))
+        {
+            // Remove the known suffix and return the modified file name
+            QString modifiedFileName = fileInfo.fileName();
+            modifiedFileName.chop(suffix.length());
+            return modifiedFileName;
+        }
+    }
+
+    // Fallback to QFileInfo::baseName if no known suffix is found
+    return fileInfo.baseName();
+}
+} // namespace
 
 //---------------------------------------------------------------------------------------------------------------------
 DialogEditLabel::DialogEditLabel(const VAbstractPattern *doc, const VContainer *data, QWidget *parent)
-    : QDialog(parent),
-      ui(new Ui::DialogEditLabel),
-      m_placeholdersMenu(new QMenu(this)),
-      m_doc(doc),
-      m_data(data),
-      m_placeholders()
+  : QDialog(parent),
+    ui(new Ui::DialogEditLabel),
+    m_placeholdersMenu(new QMenu(this)),
+    m_doc(doc),
+    m_data(data)
 {
     ui->setupUi(this);
 
@@ -76,17 +107,21 @@ DialogEditLabel::DialogEditLabel(const VAbstractPattern *doc, const VContainer *
     connect(ui->toolButtonImportLabel, &QToolButton::clicked, this, &DialogEditLabel::ImportTemplate);
     connect(ui->spinBoxFontSize, QOverload<int>::of(&QSpinBox::valueChanged), this,
             &DialogEditLabel::SaveAdditionalFontSize);
-    connect(ui->toolButtonTop, &QToolButton::clicked, this, [this](){DialogTool::MoveListRowTop(ui->listWidgetEdit);});
-    connect(ui->toolButtonUp, &QToolButton::clicked, this, [this](){DialogTool::MoveListRowUp(ui->listWidgetEdit);});
+    connect(ui->toolButtonTop, &QToolButton::clicked, this,
+            [this]() { DialogTool::MoveListRowTop(ui->listWidgetEdit); });
+    connect(ui->toolButtonUp, &QToolButton::clicked, this, [this]() { DialogTool::MoveListRowUp(ui->listWidgetEdit); });
     connect(ui->toolButtonDown, &QToolButton::clicked, this,
-            [this](){DialogTool::MoveListRowDown(ui->listWidgetEdit);});
+            [this]() { DialogTool::MoveListRowDown(ui->listWidgetEdit); });
     connect(ui->toolButtonBottom, &QToolButton::clicked, this,
-            [this](){DialogTool::MoveListRowBottom(ui->listWidgetEdit);});
+            [this]() { DialogTool::MoveListRowBottom(ui->listWidgetEdit); });
 
+    QApplication::setOverrideCursor(Qt::WaitCursor);
     InitPlaceholders();
     InitPlaceholdersMenu();
+    QApplication::restoreOverrideCursor();
 
     m_placeholdersMenu->setStyleSheet(QStringLiteral("QMenu { menu-scrollable: 1; }"));
+    m_placeholdersMenu->setToolTipsVisible(true);
     ui->pushButtonInsert->setMenu(m_placeholdersMenu);
 }
 
@@ -169,10 +204,7 @@ void DialogEditLabel::RemoveLine()
 {
     ui->listWidgetEdit->blockSignals(true);
     QListWidgetItem *curLine = ui->listWidgetEdit->takeItem(ui->listWidgetEdit->currentRow());
-    if (curLine)
-    {
-        delete curLine;
-    }
+    delete curLine;
     ui->listWidgetEdit->blockSignals(false);
     ShowLineDetails();
 }
@@ -195,7 +227,7 @@ void DialogEditLabel::SaveFontStyle(bool checked)
     {
         QFont lineFont = curLine->font();
 
-        QToolButton *button = qobject_cast<QToolButton *>(sender());
+        auto *button = qobject_cast<QToolButton *>(sender());
         if (button)
         {
             if (button == ui->toolButtonBold)
@@ -218,7 +250,7 @@ void DialogEditLabel::SaveTextFormating(bool checked)
     QListWidgetItem *curLine = ui->listWidgetEdit->currentItem();
     if (curLine)
     {
-        QToolButton *button = qobject_cast<QToolButton *>(sender());
+        auto *button = qobject_cast<QToolButton *>(sender());
         if (button)
         {
             ui->toolButtonTextLeft->blockSignals(true);
@@ -280,10 +312,11 @@ void DialogEditLabel::NewTemplate()
 {
     if (ui->listWidgetEdit->count() > 0)
     {
-        const QMessageBox::StandardButton answer = QMessageBox::question(this, tr("Create new template"),
-                                                            tr("Creating new template will overwrite the current, do "
-                                                               "you want to continue?"),
-                                                            QMessageBox::Yes | QMessageBox::No, QMessageBox::Yes);
+        const QMessageBox::StandardButton answer =
+            QMessageBox::question(this, tr("Create new template"),
+                                  tr("Creating new template will overwrite the current, do "
+                                     "you want to continue?"),
+                                  QMessageBox::Yes | QMessageBox::No, QMessageBox::Yes);
         if (answer == QMessageBox::No)
         {
             return;
@@ -299,32 +332,35 @@ void DialogEditLabel::NewTemplate()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogEditLabel::ExportTemplate()
 {
-    QString filters(tr("Label template") + QLatin1String("(*.xml)"));
-    const QString path =
-            VCommonSettings::PrepareLabelTemplates(VAbstractApplication::VApp()->Settings()->GetPathLabelTemplate());
+    VValentinaSettings *settings = VAbstractValApplication::VApp()->ValentinaSettings();
 
-    QString fileName = QFileDialog::getSaveFileName(this, tr("Export label template"),
-                                                    path + QLatin1String("/") + tr("template") + QLatin1String(".xml"),
-                                                    filters, nullptr, VAbstractApplication::VApp()->NativeFileDialog());
+    QString const filters(tr("Label template") + "(*.xml)"_L1);
+    const QString path = settings->GetPathLabelTemplate();
+
+    QString fileName =
+        QFileDialog::getSaveFileName(this, tr("Export label template"), path + '/'_L1 + tr("template") + ".xml"_L1,
+                                     filters, nullptr, VAbstractApplication::VApp()->NativeFileDialog());
 
     if (fileName.isEmpty())
     {
         return;
     }
 
-    QFileInfo f( fileName );
-    if (f.suffix().isEmpty() && f.suffix() != QLatin1String("xml"))
+    QFileInfo const f(fileName);
+    if (f.suffix().isEmpty() && f.suffix() != "xml"_L1)
     {
-        fileName += QLatin1String(".xml");
+        fileName += ".xml"_L1;
     }
 
+    settings->SetPathLabelTemplate(QFileInfo(fileName).absolutePath());
+
     VLabelTemplate ltemplate;
     ltemplate.CreateEmptyTemplate();
     ltemplate.AddLines(GetTemplate());
 
     QString error;
     const bool result = ltemplate.SaveDocument(fileName, error);
-    if (result == false)
+    if (not result)
     {
         QMessageBox messageBox(this);
         messageBox.setIcon(QMessageBox::Warning);
@@ -341,20 +377,20 @@ void DialogEditLabel::ImportTemplate()
 {
     if (ui->listWidgetEdit->count() > 0)
     {
-        const QMessageBox::StandardButton answer = QMessageBox::question(this, tr("Import template"),
-                                                            tr("Import template will overwrite the current, do "
-                                                               "you want to continue?"),
-                                                            QMessageBox::Yes | QMessageBox::No, QMessageBox::Yes);
+        const QMessageBox::StandardButton answer =
+            QMessageBox::question(this, tr("Import template"),
+                                  tr("Import template will overwrite the current, do "
+                                     "you want to continue?"),
+                                  QMessageBox::Yes | QMessageBox::No, QMessageBox::Yes);
         if (answer == QMessageBox::No)
         {
             return;
         }
     }
 
-    QString filter(tr("Label template") + QLatin1String(" (*.xml)"));
-    //Use standard path to label templates
-    const QString path =
-            VCommonSettings::PrepareLabelTemplates(VAbstractApplication::VApp()->Settings()->GetPathLabelTemplate());
+    QString const filter(tr("Label template") + " (*.xml)"_L1);
+    // Use standard path to label templates
+    const QString path = VAbstractValApplication::VApp()->ValentinaSettings()->GetPathLabelTemplate();
     const QString fileName = QFileDialog::getOpenFileName(this, tr("Import template"), path, filter, nullptr,
                                                           VAbstractApplication::VApp()->NativeFileDialog());
     if (fileName.isEmpty())
@@ -378,7 +414,7 @@ void DialogEditLabel::ImportTemplate()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogEditLabel::InsertPlaceholder()
 {
-    QAction *action = qobject_cast<QAction *>(sender());
+    auto *action = qobject_cast<QAction *>(sender());
     if (action)
     {
         ui->lineEditLine->insert(action->data().toString());
@@ -409,7 +445,7 @@ void DialogEditLabel::SaveAdditionalFontSize(int i)
     if (curLine)
     {
         QFont lineFont = curLine->font();
-        lineFont.setPointSize(lineFont.pointSize() - curLine->data(Qt::UserRole).toInt() + i);
+        lineFont.setPointSize(qMax(lineFont.pointSize() - curLine->data(Qt::UserRole).toInt() + i, 1));
         curLine->setFont(lineFont);
         curLine->setData(Qt::UserRole, i);
     }
@@ -454,7 +490,7 @@ void DialogEditLabel::SetupControls()
             ui->toolButtonDown->setEnabled(true);
             ui->toolButtonBottom->setEnabled(true);
         }
-        else if (ui->listWidgetEdit->currentRow() == ui->listWidgetEdit->count()-1)
+        else if (ui->listWidgetEdit->currentRow() == ui->listWidgetEdit->count() - 1)
         {
             ui->toolButtonTop->setEnabled(true);
             ui->toolButtonUp->setEnabled(true);
@@ -470,15 +506,29 @@ void DialogEditLabel::SetupControls()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void DialogEditLabel::InitPlaceholdersMenu()
+auto DialogEditLabel::SortedActions() const -> QMap<QString, QString>
 {
-    QChar per('%');
+    QMap<QString, QString> sortedActions;
+    QChar const per('%');
     auto i = m_placeholders.constBegin();
     while (i != m_placeholders.constEnd())
     {
-        auto value = i.value();
-        QAction *action = m_placeholdersMenu->addAction(value.first);
-        action->setData(per + i.key() + per);
+        sortedActions.insert(i.value().first, per + i.key() + per);
+        ++i;
+    }
+    return sortedActions;
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void DialogEditLabel::InitPlaceholdersMenu()
+{
+    QMap<QString, QString> const sortedActions = SortedActions();
+    auto i = sortedActions.constBegin();
+    while (i != sortedActions.constEnd())
+    {
+        QAction *action = m_placeholdersMenu->addAction(i.key());
+        action->setData(i.value());
+        action->setToolTip(i.value());
         connect(action, &QAction::triggered, this, &DialogEditLabel::InsertPlaceholder);
         ++i;
     }
@@ -488,7 +538,7 @@ void DialogEditLabel::InitPlaceholdersMenu()
 void DialogEditLabel::InitPlaceholders()
 {
     // Pattern tags
-    QLocale locale(VAbstractApplication::VApp()->Settings()->GetLocale());
+    QLocale const locale(VAbstractApplication::VApp()->Settings()->GetLocale());
 
     const QString date = locale.toString(QDate::currentDate(), m_doc->GetLabelDateFormat());
     m_placeholders.insert(pl_date, qMakePair(tr("Date"), date));
@@ -502,23 +552,25 @@ void DialogEditLabel::InitPlaceholders()
 
     m_placeholders.insert(pl_mUnits, qMakePair(tr("Measurements units"),
                                                UnitsToStr(VAbstractValApplication::VApp()->MeasurementsUnits(), true)));
-    m_placeholders.insert(pl_pUnits, qMakePair(tr("Pattern units"),
-                                               UnitsToStr(VAbstractValApplication::VApp()->patternUnits(), true)));
-    m_placeholders.insert(pl_mSizeUnits, qMakePair(tr("Size units"),
-                                                   UnitsToStr(VAbstractValApplication::VApp()->DimensionSizeUnits(),
-                                                              true)));
+
+    const QString pUnits = UnitsToStr(VAbstractValApplication::VApp()->patternUnits(), true);
+    m_placeholders.insert(pl_pUnits, qMakePair(tr("Pattern units"), pUnits));
+    m_placeholders.insert(
+        pl_mSizeUnits,
+        qMakePair(tr("Size units"), UnitsToStr(VAbstractValApplication::VApp()->DimensionSizeUnits(), true)));
+    m_placeholders.insert(pl_areaUnits, qMakePair(tr("Area units"), pUnits + QStringLiteral("²")));
 
     if (VAbstractValApplication::VApp()->GetMeasurementsType() == MeasurementsType::Individual)
     {
-        m_placeholders.insert(pl_customer, qMakePair(tr("Customer name"),
-                                                     VAbstractValApplication::VApp()->GetCustomerName()));
+        m_placeholders.insert(pl_customer,
+                              qMakePair(tr("Customer name"), VAbstractValApplication::VApp()->GetCustomerName()));
 
-        const QString birthDate = locale.toString(VAbstractValApplication::VApp()->GetCustomerBirthDate(),
-                                                  m_doc->GetLabelDateFormat());
+        const QString birthDate =
+            locale.toString(VAbstractValApplication::VApp()->GetCustomerBirthDate(), m_doc->GetLabelDateFormat());
         m_placeholders.insert(pl_birthDate, qMakePair(tr("Customer birth date"), birthDate));
 
-        m_placeholders.insert(pl_email, qMakePair(tr("Customer email"),
-                                                  VAbstractValApplication::VApp()->CustomerEmail()));
+        m_placeholders.insert(pl_email,
+                              qMakePair(tr("Customer email"), VAbstractValApplication::VApp()->CustomerEmail()));
     }
     else
     {
@@ -530,67 +582,64 @@ void DialogEditLabel::InitPlaceholders()
         m_placeholders.insert(pl_email, qMakePair(tr("Customer email"), m_doc->GetCustomerEmail()));
     }
 
-    m_placeholders.insert(pl_pExt, qMakePair(tr("Pattern extension"), QString("val")));
+    m_placeholders.insert(pl_pExt, qMakePair(tr("Pattern extension"), QStringLiteral("val")));
+    m_placeholders.insert(pl_pFileName, qMakePair(tr("Pattern file name"),
+                                                  FileBaseName(VAbstractValApplication::VApp()->GetPatternPath())));
+    m_placeholders.insert(pl_mFileName, qMakePair(tr("Measurements file name"), FileBaseName(m_doc->MPath())));
 
-    const QString patternFilePath = QFileInfo(VAbstractValApplication::VApp()->GetPatternPath()).baseName();
-    m_placeholders.insert(pl_pFileName, qMakePair(tr("Pattern file name"), patternFilePath));
-
-    const QString measurementsFilePath = QFileInfo(m_doc->MPath()).baseName();
-    m_placeholders.insert(pl_mFileName, qMakePair(tr("Measurments file name"), measurementsFilePath));
-
-    QString heightValue = QString::number(VAbstractValApplication::VApp()->GetDimensionHeight());
+    QString const heightValue = QString::number(VAbstractValApplication::VApp()->GetDimensionHeight());
     m_placeholders.insert(pl_height, qMakePair(tr("Height", "dimension"), heightValue));
     m_placeholders.insert(pl_dimensionX, qMakePair(tr("Dimension X", "dimension"), heightValue));
 
-    QString sizeValue = QString::number(VAbstractValApplication::VApp()->GetDimensionSize());
+    QString const sizeValue = QString::number(VAbstractValApplication::VApp()->GetDimensionSize());
     m_placeholders.insert(pl_size, qMakePair(tr("Size", "dimension"), sizeValue));
     m_placeholders.insert(pl_dimensionY, qMakePair(tr("Dimension Y", "dimension"), sizeValue));
 
-    QString hipValue = QString::number(VAbstractValApplication::VApp()->GetDimensionHip());
+    QString const hipValue = QString::number(VAbstractValApplication::VApp()->GetDimensionHip());
     m_placeholders.insert(pl_hip, qMakePair(tr("Hip", "dimension"), hipValue));
     m_placeholders.insert(pl_dimensionZ, qMakePair(tr("Dimension Z", "dimension"), hipValue));
 
-    QString waistValue = QString::number(VAbstractValApplication::VApp()->GetDimensionWaist());
+    QString const waistValue = QString::number(VAbstractValApplication::VApp()->GetDimensionWaist());
     m_placeholders.insert(pl_waist, qMakePair(tr("Waist", "dimension"), waistValue));
     m_placeholders.insert(pl_dimensionW, qMakePair(tr("Dimension W", "dimension"), waistValue));
 
     {
         QString label = VAbstractValApplication::VApp()->GetDimensionHeightLabel();
-        m_placeholders.insert(pl_heightLabel, qMakePair(tr("Height label", "dimension"),
-                                                        not label.isEmpty() ? label : heightValue));
-        m_placeholders.insert(pl_dimensionX, qMakePair(tr("Dimension X label", "dimension"),
-                                                        not label.isEmpty() ? label : heightValue));
+        m_placeholders.insert(pl_heightLabel,
+                              qMakePair(tr("Height label", "dimension"), not label.isEmpty() ? label : heightValue));
+        m_placeholders.insert(pl_dimensionXLabel, qMakePair(tr("Dimension X label", "dimension"),
+                                                            not label.isEmpty() ? label : heightValue));
 
         label = VAbstractValApplication::VApp()->GetDimensionSizeLabel();
-        m_placeholders.insert(pl_sizeLabel, qMakePair(tr("Size label", "dimension"),
-                                                      not label.isEmpty() ? label : sizeValue));
-        m_placeholders.insert(pl_dimensionY, qMakePair(tr("Dimension Y label", "dimension"),
-                                                      not label.isEmpty() ? label : sizeValue));
+        m_placeholders.insert(pl_sizeLabel,
+                              qMakePair(tr("Size label", "dimension"), not label.isEmpty() ? label : sizeValue));
+        m_placeholders.insert(pl_dimensionYLabel,
+                              qMakePair(tr("Dimension Y label", "dimension"), not label.isEmpty() ? label : sizeValue));
 
         label = VAbstractValApplication::VApp()->GetDimensionHipLabel();
-        m_placeholders.insert(pl_hipLabel, qMakePair(tr("Hip label", "dimension"),
-                                                     not label.isEmpty() ? label : hipValue));
-        m_placeholders.insert(pl_dimensionZ, qMakePair(tr("Dimension Z label", "dimension"),
-                                                       not label.isEmpty() ? label : hipValue));
+        m_placeholders.insert(pl_hipLabel,
+                              qMakePair(tr("Hip label", "dimension"), not label.isEmpty() ? label : hipValue));
+        m_placeholders.insert(pl_dimensionZLabel,
+                              qMakePair(tr("Dimension Z label", "dimension"), not label.isEmpty() ? label : hipValue));
 
         label = VAbstractValApplication::VApp()->GetDimensionWaistLabel();
-        m_placeholders.insert(pl_waistLabel, qMakePair(tr("Waist label", "dimension"),
-                                                       not label.isEmpty() ? label : waistValue));
-        m_placeholders.insert(pl_dimensionW, qMakePair(tr("Dimension W label", "dimension"),
-                                                       not label.isEmpty() ? label : waistValue));
+        m_placeholders.insert(pl_waistLabel,
+                              qMakePair(tr("Waist label", "dimension"), not label.isEmpty() ? label : waistValue));
+        m_placeholders.insert(pl_dimensionWLabel, qMakePair(tr("Dimension W label", "dimension"),
+                                                            not label.isEmpty() ? label : waistValue));
     }
 
-
-    m_placeholders.insert(pl_mExt,
-                          qMakePair(tr("Measurments extension"),
-                                   VAbstractValApplication::VApp()->GetMeasurementsType() == MeasurementsType::Multisize
-                                    ? QStringLiteral("vst") : QStringLiteral("vit")));
+    m_placeholders.insert(
+        pl_mExt, qMakePair(tr("Measurements extension"),
+                           VAbstractValApplication::VApp()->GetMeasurementsType() == MeasurementsType::Multisize
+                               ? QStringLiteral("vst")
+                               : QStringLiteral("vit")));
 
     const QString userMaterialStr = tr("User material");
     const QMap<int, QString> materials = m_doc->GetPatternMaterials();
     for (int i = 0; i < userMaterialPlaceholdersQuantity; ++i)
     {
-        const QString number = QString::number(i+1);
+        const QString number = QString::number(i + 1);
         QString materialDescription;
 
         QString value;
@@ -608,11 +657,11 @@ void DialogEditLabel::InitPlaceholders()
     }
 
     {
-        const QMap<QString, QSharedPointer<VMeasurement> > measurements = m_data->DataMeasurements();
+        const QMap<QString, QSharedPointer<VMeasurement>> measurements = m_data->DataMeasurements();
         auto i = measurements.constBegin();
         while (i != measurements.constEnd())
         {
-            QString description = i.value()->GetGuiText().isEmpty() ? i.key() : i.value()->GetGuiText();
+            QString const description = i.value()->GetGuiText().isEmpty() ? i.key() : i.value()->GetGuiText();
             m_placeholders.insert(pl_measurement + i.key(), qMakePair(tr("Measurement: %1").arg(description),
                                                                       QString::number(*i.value()->GetValue())));
             ++i;
@@ -621,30 +670,39 @@ void DialogEditLabel::InitPlaceholders()
 
     {
         const QVector<VFinalMeasurement> measurements = m_doc->GetFinalMeasurements();
-        const VContainer completeData = m_doc->GetCompleteData();
+        VContainer completeData = m_doc->GetCompleteData();
+        completeData.FillPiecesAreas(VAbstractValApplication::VApp()->patternUnits());
 
-        for (int i=0; i < measurements.size(); ++i)
+        m_placeholders.insert(pl_currentArea, qMakePair(tr("Piece full area"), QString()));
+        m_placeholders.insert(pl_currentSeamLineArea, qMakePair(tr("Piece seam line area"), QString()));
+
+        for (int i = 0; i < measurements.size(); ++i)
         {
             const VFinalMeasurement &m = measurements.at(i);
 
             try
             {
-                QScopedPointer<Calculator> cal(new Calculator());
+                QScopedPointer<Calculator> const cal(new Calculator());
                 const qreal result = cal->EvalFormula(completeData.DataVariables(), m.formula);
 
-                m_placeholders.insert(pl_finalMeasurement + m.name, qMakePair(tr("Final measurement: %1").arg(m.name),
-                                                                              QString::number(result)));
+                m_placeholders.insert(pl_finalMeasurement + m.name,
+                                      qMakePair(tr("Final measurement: %1").arg(m.name), QString::number(result)));
             }
             catch (qmu::QmuParserError &e)
             {
                 const QString errorMsg = QObject::tr("Failed to prepare final measurement placeholder. Parser error at "
-                                                     "line %1: %2.").arg(i+1).arg(e.GetMsg());
-                VAbstractApplication::VApp()->IsPedantic() ? throw VException(errorMsg) :
-                                              qWarning() << VAbstractValApplication::warningMessageSignature + errorMsg;
+                                                     "line %1: %2.")
+                                             .arg(i + 1)
+                                             .arg(e.GetMsg());
+                VAbstractApplication::VApp()->IsPedantic()
+                    ? throw VException(errorMsg)
+                    : qWarning() << VAbstractValApplication::warningMessageSignature + errorMsg;
             }
         }
     }
 
+    QSharedPointer<VTranslator> const phTr = VAbstractApplication::VApp()->GetPlaceholderTranslator();
+
     // Piece tags
     m_placeholders.insert(pl_pLetter, qMakePair(tr("Piece letter"), QString()));
     m_placeholders.insert(pl_pAnnotation, qMakePair(tr("Piece annotation"), QString()));
@@ -654,25 +712,28 @@ void DialogEditLabel::InitPlaceholders()
     m_placeholders.insert(pl_pFoldPosition, qMakePair(tr("Piece fold position"), QString()));
     m_placeholders.insert(pl_pName, qMakePair(tr("Piece name"), QString()));
     m_placeholders.insert(pl_pQuantity, qMakePair(tr("Quantity"), QString()));
-    m_placeholders.insert(pl_mFabric, qMakePair(tr("Material: Fabric"), tr("Fabric")));
-    m_placeholders.insert(pl_mLining, qMakePair(tr("Material: Lining"), tr("Lining")));
-    m_placeholders.insert(pl_mInterfacing, qMakePair(tr("Material: Interfacing"), tr("Interfacing")));
-    m_placeholders.insert(pl_mInterlining, qMakePair(tr("Material: Interlining"), tr("Interlining")));
-    m_placeholders.insert(pl_wCut, qMakePair(tr("Word: Cut"), tr("Cut")));
-    m_placeholders.insert(pl_wOnFold, qMakePair(tr("Word: on fold"), QString()));// By default should be empty
+    m_placeholders.insert(pl_mFabric, qMakePair(tr("Material: Fabric"), phTr->translate("Placeholder", "Fabric")));
+    m_placeholders.insert(pl_mLining, qMakePair(tr("Material: Lining"), phTr->translate("Placeholder", "Lining")));
+    m_placeholders.insert(pl_mInterfacing,
+                          qMakePair(tr("Material: Interfacing"), phTr->translate("Placeholder", "Interfacing")));
+    m_placeholders.insert(pl_mInterlining,
+                          qMakePair(tr("Material: Interlining"), phTr->translate("Placeholder", "Interlining")));
+    m_placeholders.insert(pl_wCut, qMakePair(tr("Word: Cut"), phTr->translate("Placeholder", "Cut")));
+    m_placeholders.insert(pl_wOnFold, qMakePair(tr("Word: on fold"), QString())); // By default should be empty
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogEditLabel::ReplacePlaceholders(QString line) const
+auto DialogEditLabel::ReplacePlaceholders(QString line) const -> QString
 {
-    QChar per('%');
+    QChar const per('%');
 
     auto TestDimension = [per, this, line](const QString &placeholder, const QString &errorMsg)
     {
-        if (line.contains(per+placeholder+per) && m_placeholders.value(placeholder).second == QChar('0'))
+        if (line.contains(per + placeholder + per) && m_placeholders.value(placeholder).second == '0'_L1)
         {
-            VAbstractApplication::VApp()->IsPedantic() ? throw VException(errorMsg) :
-                                              qWarning() << VAbstractValApplication::warningMessageSignature + errorMsg;
+            VAbstractApplication::VApp()->IsPedantic()
+                ? throw VException(errorMsg)
+                : qWarning() << VAbstractValApplication::warningMessageSignature + errorMsg;
         }
     };
 
@@ -689,21 +750,22 @@ QString DialogEditLabel::ReplacePlaceholders(QString line) const
     auto i = m_placeholders.constBegin();
     while (i != m_placeholders.constEnd())
     {
-        line.replace(per+i.key()+per, i.value().second);
+        line.replace(per + i.key() + per, i.value().second);
         ++i;
     }
     return line;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QVector<VLabelTemplateLine> DialogEditLabel::GetTemplate() const
+auto DialogEditLabel::GetTemplate() const -> QVector<VLabelTemplateLine>
 {
     QVector<VLabelTemplateLine> lines;
+    lines.reserve(ui->listWidgetEdit->count());
 
-    for (int i=0; i<ui->listWidgetEdit->count(); ++i)
+    for (int i = 0; i < ui->listWidgetEdit->count(); ++i)
     {
         const QListWidgetItem *lineItem = ui->listWidgetEdit->item(i);
-        if (lineItem)
+        if (lineItem != nullptr)
         {
             VLabelTemplateLine line;
             line.line = lineItem->text();
@@ -729,16 +791,16 @@ void DialogEditLabel::SetTemplate(const QVector<VLabelTemplateLine> &lines)
 
     int row = -1;
 
-    for (auto &line : lines)
+    for (const auto &line : lines)
     {
-        QListWidgetItem *item = new QListWidgetItem(line.line);
-        item->setTextAlignment(line.alignment);
+        auto *item = new QListWidgetItem(line.line);
+        SetTextAlignment(item, static_cast<Qt::Alignment>(line.alignment));
         item->setData(Qt::UserRole, line.fontSizeIncrement);
 
         QFont font = item->font();
         font.setBold(line.bold);
         font.setItalic(line.italic);
-        font.setPointSize(font.pointSize() + line.fontSizeIncrement);
+        font.setPointSize(qMax(font.pointSize() + line.fontSizeIncrement, 1));
         item->setFont(font);
 
         ui->listWidgetEdit->insertItem(++row, item);
@@ -755,7 +817,9 @@ void DialogEditLabel::SetTemplate(const QVector<VLabelTemplateLine> &lines)
 //---------------------------------------------------------------------------------------------------------------------
 void DialogEditLabel::SetPiece(const VPiece &piece)
 {
-    const VPieceLabelData& pieceData = piece.GetPatternPieceData();
+    QApplication::setOverrideCursor(Qt::WaitCursor);
+
+    const VPieceLabelData &pieceData = piece.GetPieceLabelData();
     m_placeholders[pl_pLetter].second = pieceData.GetLetter();
     m_placeholders[pl_pAnnotation].second = pieceData.GetAnnotation();
     m_placeholders[pl_pOrientation].second = pieceData.GetOrientation();
@@ -766,8 +830,47 @@ void DialogEditLabel::SetPiece(const VPiece &piece)
     m_placeholders[pl_pQuantity].second = QString::number(pieceData.GetQuantity());
     if (pieceData.IsOnFold())
     {
-        m_placeholders[pl_wOnFold].second = tr("on fold");
+        QSharedPointer<VTranslator> const phTr = VAbstractApplication::VApp()->GetPlaceholderTranslator();
+        m_placeholders[pl_wOnFold].second = phTr->translate("Placeholder", "on fold");
     }
+
+    VContainer completeData = m_doc->GetCompleteData();
+    completeData.AddVariable(QSharedPointer<VPieceArea>::create(PieceAreaType::External, 0, piece, &completeData,
+                                                                VAbstractValApplication::VApp()->patternUnits()));
+    completeData.AddVariable(QSharedPointer<VPieceArea>::create(PieceAreaType::SeamLine, 0, piece, &completeData,
+                                                                VAbstractValApplication::VApp()->patternUnits()));
+
+    QScopedPointer<Calculator> const cal(new Calculator());
+
+    try
+    {
+        const QString formula = pieceArea_ + VPieceArea::PieceShortName(piece);
+        const qreal result = cal->EvalFormula(completeData.DataVariables(), formula);
+        m_placeholders[pl_currentArea].second = QString::number(result);
+    }
+    catch (qmu::QmuParserError &e)
+    {
+        const QString errorMsg = QObject::tr("Failed to prepare full piece area placeholder. %1.").arg(e.GetMsg());
+        VAbstractApplication::VApp()->IsPedantic()
+            ? throw VException(errorMsg)
+            : qWarning() << VAbstractValApplication::warningMessageSignature + errorMsg;
+    }
+
+    try
+    {
+        const QString formula = pieceSeamLineArea_ + VPieceArea::PieceShortName(piece);
+        const qreal result = cal->EvalFormula(completeData.DataVariables(), formula);
+        m_placeholders[pl_currentSeamLineArea].second = QString::number(result);
+    }
+    catch (qmu::QmuParserError &e)
+    {
+        const QString errorMsg = QObject::tr("Failed to prepare piece seam line area placeholder. %1.").arg(e.GetMsg());
+        VAbstractApplication::VApp()->IsPedantic()
+            ? throw VException(errorMsg)
+            : qWarning() << VAbstractValApplication::warningMessageSignature + errorMsg;
+    }
+
+    QApplication::restoreOverrideCursor();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -777,16 +880,16 @@ void DialogEditLabel::InitPreviewLines(const QVector<VLabelTemplateLine> &lines)
 
     int row = -1;
 
-    for (auto &line : lines)
+    for (const auto &line : lines)
     {
-        QListWidgetItem *item = new QListWidgetItem(ReplacePlaceholders(line.line));
-        item->setTextAlignment(line.alignment);
+        auto *item = new QListWidgetItem(ReplacePlaceholders(line.line));
+        SetTextAlignment(item, static_cast<Qt::Alignment>(line.alignment));
         item->setData(Qt::UserRole, line.fontSizeIncrement);
 
         QFont font = item->font();
         font.setBold(line.bold);
         font.setItalic(line.italic);
-        font.setPointSize(font.pointSize() + line.fontSizeIncrement);
+        font.setPointSize(qMax(font.pointSize() + line.fontSizeIncrement, 1));
         item->setFont(font);
 
         ui->listWidgetPreview->insertItem(++row, item);
