@@ -28,7 +28,6 @@
 
 #include "dialogeditwrongformula.h"
 
-#include <qiterator.h>
 #include <QAbstractItemView>
 #include <QApplication>
 #include <QCheckBox>
@@ -47,43 +46,54 @@
 #include <QTableWidget>
 #include <QTableWidgetItem>
 #include <QTextCursor>
+#include <QTimer>
 #include <QToolButton>
 #include <QWidget>
-#include <Qt>
 #include <new>
-#include <QTimer>
 
-#include "../vpatterndb/vcontainer.h"
-#include "../vpatterndb/vtranslatevars.h"
+#include "../tools/dialogtool.h"
+#include "../vformat/knownmeasurements/vknownmeasurement.h"
+#include "../vformat/knownmeasurements/vknownmeasurements.h"
+#include "../vformat/knownmeasurements/vknownmeasurementsdatabase.h"
+#include "../vmisc/def.h"
+#include "../vmisc/theme/vtheme.h"
+#include "../vmisc/vabstractapplication.h"
+#include "../vmisc/vcommonsettings.h"
 #include "../vpatterndb/variables/varcradius.h"
 #include "../vpatterndb/variables/vcurveangle.h"
+#include "../vpatterndb/variables/vcurveclength.h"
 #include "../vpatterndb/variables/vcurvelength.h"
 #include "../vpatterndb/variables/vincrement.h"
 #include "../vpatterndb/variables/vlineangle.h"
 #include "../vpatterndb/variables/vlinelength.h"
 #include "../vpatterndb/variables/vmeasurement.h"
-#include "../vmisc/def.h"
-#include "../vmisc/vabstractapplication.h"
-#include "../vmisc/vcommonsettings.h"
-#include "../tools/dialogtool.h"
+#include "../vpatterndb/variables/vpiecearea.h"
+#include "../vpatterndb/vcontainer.h"
+#include "../vpatterndb/vtranslatevars.h"
 #include "ui_dialogeditwrongformula.h"
 
 template <class T> class QSharedPointer;
 
-enum {ColumnName = 0, ColumnFullName};
+enum
+{
+    ColumnName = 0,
+    ColumnFullName
+};
 
 //---------------------------------------------------------------------------------------------------------------------
 DialogEditWrongFormula::DialogEditWrongFormula(const VContainer *data, quint32 toolId, QWidget *parent)
-    : QDialog(parent),
-      ui(new Ui::DialogEditWrongFormula),
-      m_data(data),
-      m_toolId(toolId),
-      timerFormula(new QTimer(this))
+  : QDialog(parent),
+    ui(new Ui::DialogEditWrongFormula),
+    m_data(data),
+    m_toolId(toolId),
+    timerFormula(new QTimer(this))
 {
     SCASSERT(data != nullptr)
 
     ui->setupUi(this);
 
+    ui->radioButtonPieceArea->setVisible(false);
+
     timerFormula->setSingleShot(true);
     connect(timerFormula, &QTimer::timeout, this, &DialogEditWrongFormula::EvalFormula);
 
@@ -111,20 +121,15 @@ DialogEditWrongFormula::DialogEditWrongFormula(const VContainer *data, quint32 t
     connect(ui->toolButtonPutHere, &QPushButton::clicked, this, &DialogEditWrongFormula::PutHere);
     connect(ui->tableWidget, &QTableWidget::itemDoubleClicked, this, &DialogEditWrongFormula::PutVal);
 
-    connect(ui->plainTextEditFormula, &QPlainTextEdit::textChanged, this, [this]()
-    {
-        timerFormula->start(formulaTimerTimeout);
-    });
+    connect(ui->plainTextEditFormula, &QPlainTextEdit::textChanged, this,
+            [this]() { timerFormula->start(formulaTimerTimeout); });
 
-    //Disable Qt::WaitCursor
+    // Disable Qt::WaitCursor
 #ifndef QT_NO_CURSOR
-    if (QGuiApplication::overrideCursor() != nullptr)
+    if (QGuiApplication::overrideCursor() != nullptr && QGuiApplication::overrideCursor()->shape() == Qt::WaitCursor)
     {
-        if (QGuiApplication::overrideCursor()->shape() == Qt::WaitCursor)
-        {
-            restoreCursor = true;
-            QGuiApplication::restoreOverrideCursor();
-        }
+        restoreCursor = true;
+        QGuiApplication::restoreOverrideCursor();
     }
 #endif
     ui->tableWidget->setColumnCount(2);
@@ -162,7 +167,7 @@ void DialogEditWrongFormula::DialogRejected()
 
 //---------------------------------------------------------------------------------------------------------------------
 void DialogEditWrongFormula::EvalFormula()
-{    
+{
     FormulaData formulaData;
     formulaData.formula = ui->plainTextEditFormula->toPlainText();
     formulaData.variables = m_data->DataVariables();
@@ -187,15 +192,14 @@ void DialogEditWrongFormula::ValChanged(int row)
         ui->labelDescription->setText(QString());
         return;
     }
-    QTableWidgetItem *item = ui->tableWidget->item( row, ColumnName );
+    QTableWidgetItem *item = ui->tableWidget->item(row, ColumnName);
     const QString name = VAbstractApplication::VApp()->TrVars()->VarFromUser(item->text());
 
     try
     {
         if (ui->radioButtonStandardTable->isChecked())
         {
-            const QSharedPointer<VMeasurement> stable = m_data->GetVariable<VMeasurement>(name);
-            SetDescription(item->text(), *stable->GetValue(), stable->IsSpecialUnits(), stable->GetGuiText());
+            SetMeasurementDescription(item, name);
         }
         else if (ui->radioButtonIncrements->isChecked() || ui->radioButtonPC->isChecked())
         {
@@ -232,6 +236,16 @@ void DialogEditWrongFormula::ValChanged(int row)
             SetDescription(item->text(), *m_data->GetVariable<VCurveAngle>(name)->GetValue(), specialUnits,
                            tr("Curve angle"));
         }
+        else if (ui->radioButtonCLength->isChecked())
+        {
+            const bool specialUnits = false;
+            SetDescription(item->text(), *m_data->GetVariable<VCurveCLength>(name)->GetValue(), specialUnits,
+                           tr("Length to control point"));
+        }
+        else if (ui->radioButtonPieceArea->isChecked())
+        {
+            SetPieceAreaDescription(item, name);
+        }
         else if (ui->radioButtonFunctions->isChecked())
         {
             ui->labelDescription->setText(item->toolTip());
@@ -269,7 +283,7 @@ void DialogEditWrongFormula::PutVal(QTableWidgetItem *item)
     QTextCursor cursor = ui->plainTextEditFormula->textCursor();
     if (ui->radioButtonFunctions->isChecked())
     {
-        QString function = valItem->data(Qt::UserRole).toString();
+        QString const function = valItem->data(Qt::UserRole).toString();
         const VTranslateVars *trVars = VAbstractApplication::VApp()->TrVars();
         const QMap<QString, QString> functionsArguments = trVars->GetFunctionsArguments();
         cursor.insertText(valItem->text() + functionsArguments.value(function));
@@ -289,7 +303,13 @@ void DialogEditWrongFormula::PutVal(QTableWidgetItem *item)
 void DialogEditWrongFormula::Measurements()
 {
     ui->checkBoxHideEmpty->setEnabled(true);
-    ShowMeasurements(m_data->DataMeasurements());
+
+    QList<QSharedPointer<VMeasurement>> vars = m_data->DataMeasurements().values();
+    std::stable_sort(vars.begin(), vars.end(),
+                     [](const QSharedPointer<VMeasurement> &obj1, const QSharedPointer<VMeasurement> &obj2)
+                     { return obj1->Index() < obj2->Index(); });
+
+    ShowMeasurements(vars);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -299,21 +319,21 @@ void DialogEditWrongFormula::Measurements()
 void DialogEditWrongFormula::LengthLines()
 {
     ui->checkBoxHideEmpty->setEnabled(false);
-    ShowVariable(m_data->DataLengthLines());
+    ShowVariable(m_data->DataLengthLines().values());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void DialogEditWrongFormula::RadiusArcs()
 {
     ui->checkBoxHideEmpty->setEnabled(false);
-    ShowVariable(m_data->DataRadiusesArcs());
+    ShowVariable(m_data->DataRadiusesArcs().values());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void DialogEditWrongFormula::AnglesCurves()
 {
     ui->checkBoxHideEmpty->setEnabled(false);
-    ShowVariable(m_data->DataAnglesCurves());
+    ShowVariable(m_data->DataAnglesCurves().values());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -323,21 +343,21 @@ void DialogEditWrongFormula::AnglesCurves()
 void DialogEditWrongFormula::LengthCurves()
 {
     ui->checkBoxHideEmpty->setEnabled(false);
-    ShowVariable(m_data->DataLengthCurves());
+    ShowVariable(m_data->DataLengthCurves().values());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void DialogEditWrongFormula::CurvesCLength()
 {
     ui->checkBoxHideEmpty->setEnabled(false);
-    ShowVariable(m_data->DataCurvesCLength());
+    ShowVariable(m_data->DataCurvesCLength().values());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void DialogEditWrongFormula::AngleLines()
 {
     ui->checkBoxHideEmpty->setEnabled(false);
-    ShowVariable(m_data->DataAngleLines());
+    ShowVariable(m_data->DataAngleLines().values());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -355,6 +375,13 @@ void DialogEditWrongFormula::PreviewCalculations()
     ShowIncrementsInPreviewCalculation(true);
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void DialogEditWrongFormula::PieceArea()
+{
+    ui->checkBoxHideEmpty->setEnabled(false);
+    ShowVariable(m_data->DataPieceArea().values());
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 /**
  * @brief Functions show in list functions
@@ -375,8 +402,8 @@ void DialogEditWrongFormula::closeEvent(QCloseEvent *event)
 //---------------------------------------------------------------------------------------------------------------------
 void DialogEditWrongFormula::showEvent(QShowEvent *event)
 {
-    QDialog::showEvent( event );
-    if ( event->spontaneous() )
+    QDialog::showEvent(event);
+    if (event->spontaneous())
     {
         return;
     }
@@ -395,7 +422,7 @@ void DialogEditWrongFormula::showEvent(QShowEvent *event)
 
     CheckState();
 
-    m_isInitialized = true;//first show windows are held
+    m_isInitialized = true; // first show windows are held
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -411,6 +438,24 @@ void DialogEditWrongFormula::resizeEvent(QResizeEvent *event)
     QDialog::resizeEvent(event);
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void DialogEditWrongFormula::changeEvent(QEvent *event)
+{
+    if (event->type() == QEvent::LanguageChange)
+    {
+        ui->retranslateUi(this);
+    }
+
+    if (event->type() == QEvent::PaletteChange)
+    {
+        InitIcons();
+        InitDialogButtonBoxIcons(ui->buttonBox);
+    }
+
+    // remember to call base class implementation
+    QDialog::changeEvent(event);
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void DialogEditWrongFormula::CheckState()
 {
@@ -428,8 +473,8 @@ void DialogEditWrongFormula::CheckState()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogEditWrongFormula::SetFormula(const QString &value)
 {
-    formula = VAbstractApplication::VApp()->TrVars()
-            ->FormulaToUser(value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    formula = VAbstractApplication::VApp()->TrVars()->FormulaToUser(
+        value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
     ui->plainTextEditFormula->setPlainText(formula);
     MoveCursorToEnd(ui->plainTextEditFormula);
     ui->plainTextEditFormula->selectAll();
@@ -478,6 +523,12 @@ void DialogEditWrongFormula::SetPreviewCalculationsMode()
     ui->radioButtonCLength->setDisabled(true);
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void DialogEditWrongFormula::ShowPieceArea(bool show) const
+{
+    ui->radioButtonPieceArea->setVisible(show);
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 auto DialogEditWrongFormula::GetFormula() const -> QString
 {
@@ -493,7 +544,7 @@ void DialogEditWrongFormula::InitVariables()
     Measurements();
 
     // clear text filter every time when new radio button selected
-    auto ClearFilterFormulaInputs = [this] () { ui->filterFormulaInputs->clear(); };
+    auto ClearFilterFormulaInputs = [this]() { ui->filterFormulaInputs->clear(); };
 
     connect(ui->radioButtonStandardTable, &QRadioButton::clicked, this, &DialogEditWrongFormula::Measurements);
     connect(ui->radioButtonStandardTable, &QRadioButton::clicked, this, ClearFilterFormulaInputs);
@@ -522,6 +573,9 @@ void DialogEditWrongFormula::InitVariables()
     connect(ui->radioButtonCLength, &QRadioButton::clicked, this, &DialogEditWrongFormula::CurvesCLength);
     connect(ui->radioButtonCLength, &QRadioButton::clicked, this, ClearFilterFormulaInputs);
 
+    connect(ui->radioButtonPieceArea, &QRadioButton::clicked, this, &DialogEditWrongFormula::PieceArea);
+    connect(ui->radioButtonPieceArea, &QRadioButton::clicked, this, ClearFilterFormulaInputs);
+
     connect(ui->radioButtonFunctions, &QRadioButton::clicked, this, &DialogEditWrongFormula::Functions);
     connect(ui->radioButtonFunctions, &QRadioButton::clicked, this, ClearFilterFormulaInputs);
 
@@ -530,10 +584,16 @@ void DialogEditWrongFormula::InitVariables()
 
 //---------------------------------------------------------------------------------------------------------------------
 void DialogEditWrongFormula::SetDescription(const QString &name, qreal value, bool specialUnits,
-                                            const QString &description)
+                                            const QString &description, bool square)
 {
-    const QString unit = specialUnits ? degreeSymbol : ' ' + postfix;
-    const QString desc = QStringLiteral("%1(%2%3) - %4").arg(name).arg(value).arg(unit, description);
+    QString unitName = postfix;
+    if (not specialUnits && square)
+    {
+        unitName += QStringLiteral("²");
+    }
+
+    const QString unit = specialUnits ? degreeSymbol : ' ' + unitName;
+    const auto desc = QStringLiteral("%1(%2%3) - %4").arg(name).arg(value).arg(unit, description);
     ui->labelDescription->setText(desc);
 }
 
@@ -545,13 +605,20 @@ auto DialogEditWrongFormula::Eval(const FormulaData &formulaData, bool &flag) ->
     return result;
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void DialogEditWrongFormula::InitIcons()
+{
+    const auto resource = QStringLiteral("icon");
+
+    ui->label->setPixmap(VTheme::GetPixmapResource(resource, QStringLiteral("24x24/equal.png")));
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 /**
  * @brief ShowVariable show variables in list
- * @param var container with variables
+ * @param vars container with variables
  */
-template <class key, class val>
-void DialogEditWrongFormula::ShowVariable(const QMap<key, val> &var)
+template <class T> void DialogEditWrongFormula::ShowVariable(const QList<T> &vars)
 {
     ui->tableWidget->blockSignals(true);
     ui->tableWidget->clearContents();
@@ -559,24 +626,26 @@ void DialogEditWrongFormula::ShowVariable(const QMap<key, val> &var)
     ui->tableWidget->setColumnHidden(ColumnFullName, true);
     ui->labelDescription->setText(QString());
 
-    QMapIterator<key, val> iMap(var);
-    while (iMap.hasNext())
+    const VTranslateVars *trVars = VAbstractApplication::VApp()->TrVars();
+
+    for (const auto &var : vars)
     {
-        iMap.next();
-        if (ui->checkBoxHideEmpty->isEnabled() && ui->checkBoxHideEmpty->isChecked() && iMap.value()->IsNotUsed())
+        if (ui->checkBoxHideEmpty->isEnabled() && ui->checkBoxHideEmpty->isChecked() && var->IsNotUsed())
         {
-            continue; //skip this measurement
+            continue; // skip this measurement
         }
-        if (iMap.value()->Filter(m_toolId) == false)
-        {// If we create this variable don't show
+
+        if (!var->Filter(m_toolId))
+        { // If we create this variable don't show
             ui->tableWidget->setRowCount(ui->tableWidget->rowCount() + 1);
-            auto *item = new QTableWidgetItem(iMap.key());
+            auto *item = new QTableWidgetItem(trVars->VarToUser(var->GetName()));
             QFont font = item->font();
             font.setBold(true);
             item->setFont(font);
-            ui->tableWidget->setItem(ui->tableWidget->rowCount()-1, ColumnName, item);
+            ui->tableWidget->setItem(ui->tableWidget->rowCount() - 1, ColumnName, item);
         }
     }
+
     ui->tableWidget->blockSignals(false);
     ui->tableWidget->selectRow(0);
     ui->tableWidget->horizontalHeader()->setSectionResizeMode(QHeaderView::Stretch);
@@ -585,9 +654,9 @@ void DialogEditWrongFormula::ShowVariable(const QMap<key, val> &var)
 //---------------------------------------------------------------------------------------------------------------------
 /**
  * @brief ShowMeasurements show measurements in table
- * @param var container with measurements
+ * @param vars container with measurements
  */
-void DialogEditWrongFormula::ShowMeasurements(const QMap<QString, QSharedPointer<VMeasurement> > &var)
+void DialogEditWrongFormula::ShowMeasurements(const QList<QSharedPointer<VMeasurement>> &vars)
 {
     ui->tableWidget->blockSignals(true);
     ui->tableWidget->clearContents();
@@ -595,18 +664,17 @@ void DialogEditWrongFormula::ShowMeasurements(const QMap<QString, QSharedPointer
     ui->tableWidget->setColumnHidden(ColumnFullName, false);
     ui->labelDescription->setText(QString());
 
-    QMapIterator<QString, QSharedPointer<VMeasurement>> iMap(var);
-    while (iMap.hasNext())
+    for (const auto &var : vars)
     {
-        iMap.next();
-        if (ui->checkBoxHideEmpty->isEnabled() && ui->checkBoxHideEmpty->isChecked() && iMap.value()->IsNotUsed())
+        if (ui->checkBoxHideEmpty->isEnabled() && ui->checkBoxHideEmpty->isChecked() && var->IsNotUsed())
         {
-            continue; //skip this measurement
+            continue; // skip this measurement
         }
-        if (not iMap.value()->Filter(m_toolId))
-        {// If we create this variable don't show
+
+        if (not var->Filter(m_toolId))
+        { // If we create this variable don't show
             ui->tableWidget->setRowCount(ui->tableWidget->rowCount() + 1);
-            auto *itemName = new QTableWidgetItem(iMap.key());
+            auto *itemName = new QTableWidgetItem(var->GetName());
             QFont fontName = itemName->font();
             fontName.setBold(true);
             itemName->setFont(fontName);
@@ -616,20 +684,29 @@ void DialogEditWrongFormula::ShowMeasurements(const QMap<QString, QSharedPointer
             QFont fontFullName = itemName->font();
             fontFullName.setBold(true);
             itemFullName->setFont(fontFullName);
-            if (iMap.value()->IsCustom())
+            if (var->IsCustom())
             {
-                itemFullName->setText(iMap.value()->GetGuiText());
+                itemFullName->setText(var->GetGuiText());
             }
             else
             {
-                itemFullName->setText(VAbstractApplication::VApp()->TrVars()->GuiText(iMap.value()->GetName()));
+                itemFullName->setText(QString());
+                if (VKnownMeasurementsDatabase *db = VAbstractApplication::VApp()->KnownMeasurementsDatabase())
+                {
+                    VKnownMeasurements const known = db->KnownMeasurements(var->GetKnownMeasurementsId());
+                    if (known.IsValid())
+                    {
+                        itemFullName->setText(known.Measurement(var->GetName()).fullName);
+                    }
+                }
             }
 
             itemFullName->setToolTip(itemFullName->text());
-            ui->tableWidget->setItem(ui->tableWidget->rowCount()-1, ColumnName, itemName);
-            ui->tableWidget->setItem(ui->tableWidget->rowCount()-1, ColumnFullName, itemFullName);
+            ui->tableWidget->setItem(ui->tableWidget->rowCount() - 1, ColumnName, itemName);
+            ui->tableWidget->setItem(ui->tableWidget->rowCount() - 1, ColumnFullName, itemFullName);
         }
     }
+
     ui->tableWidget->blockSignals(false);
     ui->tableWidget->selectRow(0);
     ui->tableWidget->horizontalHeader()->setSectionResizeMode(QHeaderView::Stretch);
@@ -647,6 +724,7 @@ void DialogEditWrongFormula::ShowFunctions()
     ui->tableWidget->setColumnHidden(ColumnFullName, true);
     ui->labelDescription->setText(QString());
 
+    VCommonSettings *settings = VAbstractApplication::VApp()->Settings();
     const VTranslateVars *trVars = VAbstractApplication::VApp()->TrVars();
     const QMap<QString, qmu::QmuTranslation> functionsDescriptions = trVars->GetFunctionsDescriptions();
     const QMap<QString, qmu::QmuTranslation> functions = trVars->GetFunctions();
@@ -654,17 +732,30 @@ void DialogEditWrongFormula::ShowFunctions()
     while (i != functions.constEnd())
     {
         ui->tableWidget->setRowCount(ui->tableWidget->rowCount() + 1);
-        auto *item = new QTableWidgetItem(i.value().translate(VAbstractApplication::VApp()->Settings()->GetLocale()));
+
+        QString const name = (!settings->IsTranslateFormula()
+                                  ? i.value().getMsourceText()
+                                  : i.value().translate(VAbstractApplication::VApp()->Settings()->GetLocale()));
+
+        auto *item = new QTableWidgetItem(name);
         item->setData(Qt::UserRole, i.key());
         QFont font = item->font();
         font.setBold(true);
         item->setFont(font);
-        ui->tableWidget->setItem(ui->tableWidget->rowCount()-1, ColumnName, item);
+        ui->tableWidget->setItem(ui->tableWidget->rowCount() - 1, ColumnName, item);
 
-        functionsDescriptions.contains(i.key())
-            ? item->setToolTip(functionsDescriptions.value(i.key())
-                               .translate(VAbstractApplication::VApp()->Settings()->GetLocale()))
-            : item->setToolTip(i.value().getMdisambiguation());
+        if (functionsDescriptions.contains(i.key()))
+        {
+            QString const description =
+                (!settings->IsTranslateFormula() ? functionsDescriptions.value(i.key()).getMsourceText()
+                                                 : functionsDescriptions.value(i.key()).translate(
+                                                       VAbstractApplication::VApp()->Settings()->GetLocale()));
+            item->setToolTip(description);
+        }
+        else
+        {
+            item->setToolTip(i.value().getMdisambiguation());
+        }
         ++i;
     }
 
@@ -678,20 +769,75 @@ void DialogEditWrongFormula::ShowIncrementsInPreviewCalculation(bool show)
 {
     ui->checkBoxHideEmpty->setEnabled(false);
 
-    QMap<QString, QSharedPointer<VIncrement> > increments;
+    QMap<QString, QSharedPointer<VIncrement>> increments;
 
-    const QMap<QString, QSharedPointer<VIncrement> > list = m_data->DataIncrements();
-    QMap<QString, QSharedPointer<VIncrement> >::const_iterator i = list.constBegin();
+    const QMap<QString, QSharedPointer<VIncrement>> list = m_data->DataIncrements();
+    QMap<QString, QSharedPointer<VIncrement>>::const_iterator i = list.constBegin();
     while (i != list.constEnd())
     {
-        if(i.value()->IsPreviewCalculation() == show)
+        if (i.value()->IsPreviewCalculation() == show)
         {
             increments.insert(i.key(), i.value());
         }
         ++i;
     }
 
-    ShowVariable(increments);
+    QList<QSharedPointer<VIncrement>> vars = increments.values();
+    std::stable_sort(vars.begin(), vars.end(),
+                     [](const QSharedPointer<VIncrement> &obj1, const QSharedPointer<VIncrement> &obj2)
+                     { return obj1->GetIndex() < obj2->GetIndex(); });
+
+    ShowVariable(vars);
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void DialogEditWrongFormula::SetMeasurementDescription(QTableWidgetItem *item, const QString &name)
+{
+    const QSharedPointer<VMeasurement> stable = m_data->GetVariable<VMeasurement>(name);
+
+    QString description;
+
+    if (!stable->IsCustom())
+    {
+        if (VKnownMeasurementsDatabase *db = VAbstractApplication::VApp()->KnownMeasurementsDatabase())
+        {
+            VKnownMeasurements const known = db->KnownMeasurements(stable->GetKnownMeasurementsId());
+            if (known.IsValid())
+            {
+                description = known.Measurement(stable->GetName()).description;
+            }
+        }
+    }
+    else
+    {
+        description = stable->GetDescription();
+    }
+
+    SetDescription(item->text(), *stable->GetValue(), stable->IsSpecialUnits(), description);
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void DialogEditWrongFormula::SetPieceAreaDescription(QTableWidgetItem *item, const QString &name)
+{
+    const bool specialUnits = false;
+    const QSharedPointer<VPieceArea> var = m_data->GetVariable<VPieceArea>(name);
+    QString description = tr("Area of piece");
+
+    try
+    {
+        VPiece const piece = m_data->GetPiece(var->GetPieceId());
+        QString const name = piece.GetName();
+        if (not name.isEmpty())
+        {
+            description += QStringLiteral(" '%1'").arg(piece.GetName());
+        }
+    }
+    catch (const VExceptionBadId &)
+    {
+        // do nothing
+    }
+
+    SetDescription(item->text(), *var->GetValue(), specialUnits, description, true);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -718,10 +864,11 @@ void DialogEditWrongFormula::FilterVariablesEdited(const QString &filter)
         }
 
         // show rows with matched filter
-        const QList<QTableWidgetItem*> items = ui->tableWidget->findItems(filter, Qt::MatchContains);
+        const QList<QTableWidgetItem *> items = ui->tableWidget->findItems(filter, Qt::MatchContains);
         for (auto *item : items)
         {
-            // If filter is empty findItems() for unknown reason returns nullptr items.
+            // If filter is empty findItems() for unknown reason returns nullptr
+            // items.
             if (item)
             {
                 ui->tableWidget->showRow(item->row());
