@@ -44,17 +44,24 @@
 
 #include "../../visualization/line/vistoolalongline.h"
 #include "../../visualization/visualization.h"
+#include "../ifc/ifcdef.h"
 #include "../ifc/xml/vabstractpattern.h"
 #include "../support/dialogeditwrongformula.h"
-#include "../vgeometry/../ifc/ifcdef.h"
 #include "../vgeometry/vpointf.h"
+#include "../vmisc/theme/vtheme.h"
 #include "../vmisc/vabstractapplication.h"
 #include "../vmisc/vcommonsettings.h"
-#include "../vpatterndb/vcontainer.h"
 #include "../vpatterndb/variables/vlinelength.h"
+#include "../vpatterndb/vcontainer.h"
 #include "../vpatterndb/vtranslatevars.h"
-#include "ui_dialogalongline.h"
 #include "../vwidgets/vabstractmainwindow.h"
+#include "ui_dialogalongline.h"
+
+#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
+#include "../vmisc/compatibility.h"
+#endif
+
+using namespace Qt::Literals::StringLiterals;
 
 //---------------------------------------------------------------------------------------------------------------------
 /**
@@ -62,20 +69,22 @@
  * @param data container with data
  * @param parent parent widget
  */
-DialogAlongLine::DialogAlongLine(const VContainer *data, quint32 toolId, QWidget *parent)
-    : DialogTool(data, toolId, parent),
-      ui(new Ui::DialogAlongLine),
-      m_timerFormula(new QTimer(this))
+DialogAlongLine::DialogAlongLine(const VContainer *data, VAbstractPattern *doc, quint32 toolId, QWidget *parent)
+  : DialogTool(data, doc, toolId, parent),
+    ui(new Ui::DialogAlongLine),
+    m_timerFormula(new QTimer(this))
 {
     ui->setupUi(this);
 
+    InitIcons();
+
     m_timerFormula->setSingleShot(true);
     connect(m_timerFormula, &QTimer::timeout, this, &DialogAlongLine::EvalFormula);
 
     ui->lineEditNamePoint->setClearButtonEnabled(true);
 
     ui->lineEditNamePoint->setText(
-                VAbstractValApplication::VApp()->getCurrentDocument()->GenerateLabel(LabelType::NewLabel));
+        VAbstractValApplication::VApp()->getCurrentDocument()->GenerateLabel(LabelType::NewLabel));
 
     this->m_formulaBaseHeight = ui->plainTextEditFormula->height();
     ui->plainTextEditFormula->installEventFilter(this);
@@ -84,29 +93,28 @@ DialogAlongLine::DialogAlongLine(const VContainer *data, quint32 toolId, QWidget
 
     FillComboBoxPoints(ui->comboBoxFirstPoint);
     FillComboBoxPoints(ui->comboBoxSecondPoint);
-    FillComboBoxTypeLine(ui->comboBoxLineType, LineStylesPics());
+    FillComboBoxTypeLine(ui->comboBoxLineType, LineStylesPics(ui->comboBoxLineType->palette().color(QPalette::Base),
+                                                              ui->comboBoxLineType->palette().color(QPalette::Text)));
     FillComboBoxLineColors(ui->comboBoxLineColor);
 
     connect(ui->toolButtonExprLength, &QPushButton::clicked, this, &DialogAlongLine::FXLength);
-    connect(ui->lineEditNamePoint, &QLineEdit::textChanged, this, [this]()
-    {
-        CheckPointLabel(this, ui->lineEditNamePoint, ui->labelEditNamePoint, m_pointName, this->data, m_flagName);
-        CheckState();
-    });
-    connect(ui->plainTextEditFormula, &QPlainTextEdit::textChanged, this, [this]()
-    {
-        m_timerFormula->start(formulaTimerTimeout);
-    });
+    connect(ui->lineEditNamePoint, &QLineEdit::textChanged, this,
+            [this]()
+            {
+                CheckPointLabel(this, ui->lineEditNamePoint, ui->labelEditNamePoint, m_pointName, this->data,
+                                m_flagName);
+                CheckState();
+            });
+    connect(ui->plainTextEditFormula, &QPlainTextEdit::textChanged, this,
+            [this]() { m_timerFormula->start(formulaTimerTimeout); });
     connect(ui->pushButtonGrowLength, &QPushButton::clicked, this, &DialogAlongLine::DeployFormulaTextEdit);
-    connect(ui->comboBoxFirstPoint, &QComboBox::currentTextChanged,
-            this, &DialogAlongLine::PointChanged);
-    connect(ui->comboBoxSecondPoint, &QComboBox::currentTextChanged,
-            this, &DialogAlongLine::PointChanged);
+    connect(ui->comboBoxFirstPoint, &QComboBox::currentTextChanged, this, &DialogAlongLine::PointChanged);
+    connect(ui->comboBoxSecondPoint, &QComboBox::currentTextChanged, this, &DialogAlongLine::PointChanged);
 
     vis = new VisToolAlongLine(data);
 
     // Call after initialization vis!!!!
-    SetTypeLine(TypeLineNone);//By default don't show line
+    SetTypeLine(TypeLineNone); // By default don't show line
 
     ui->tabWidget->setCurrentIndex(0);
     SetTabStopDistance(ui->plainTextEditToolNotes);
@@ -155,7 +163,6 @@ void DialogAlongLine::EvalFormula()
     formulaData.labelEditFormula = ui->labelEditFormula;
     formulaData.labelResult = ui->labelResultCalculation;
     formulaData.postfix = UnitsToStr(VAbstractValApplication::VApp()->patternUnits(), true);
-    formulaData.checkZero = false;
 
     Eval(formulaData, m_flagFormula);
 }
@@ -186,7 +193,7 @@ DialogAlongLine::~DialogAlongLine()
  */
 void DialogAlongLine::ChosenObject(quint32 id, const SceneObject &type)
 {
-    if (prepare)// After first choose we ignore all objects
+    if (prepare) // After first choose we ignore all objects
     {
         return;
     }
@@ -239,6 +246,24 @@ void DialogAlongLine::closeEvent(QCloseEvent *event)
     DialogTool::closeEvent(event);
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void DialogAlongLine::changeEvent(QEvent *event)
+{
+    if (event->type() == QEvent::LanguageChange)
+    {
+        ui->retranslateUi(this);
+    }
+
+    if (event->type() == QEvent::PaletteChange)
+    {
+        InitIcons();
+        InitDialogButtonBoxIcons(ui->buttonBox);
+    }
+
+    // remember to call base class implementation
+    DialogTool::changeEvent(event);
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void DialogAlongLine::SetCurrentLength()
 {
@@ -252,15 +277,15 @@ void DialogAlongLine::SetCurrentLength()
     }
     catch (const VExceptionBadId &)
     {
-        QScopedPointer<VPointF> p1(new VPointF());
-        QScopedPointer<VPointF> p2(new VPointF());
+        QScopedPointer<VPointF> const p1(new VPointF());
+        QScopedPointer<VPointF> const p2(new VPointF());
         length = new VLengthLine(p1.data(), GetFirstPointId(), p2.data(), GetSecondPointId(), *data->GetPatternUnit());
     }
 
     SCASSERT(length != nullptr)
     length->SetName(currentLength);
 
-    auto *locData = const_cast<VContainer *> (data);
+    auto *locData = const_cast<VContainer *>(data);
     locData->AddVariable(length);
 }
 
@@ -277,13 +302,12 @@ void DialogAlongLine::ChosenSecondPoint(quint32 id, const QString &toolTip)
             line->SetPoint2Id(id);
             if (m_buildMidpoint)
             {
-                SetFormula(currentLength + QStringLiteral("/2"));
+                SetFormula(currentLength + "/2"_L1);
                 line->SetMode(Mode::Show);
             }
             else
             {
-                auto *window = qobject_cast<VAbstractMainWindow *>(
-                    VAbstractValApplication::VApp()->getMainWindow());
+                auto *window = qobject_cast<VAbstractMainWindow *>(VAbstractValApplication::VApp()->getMainWindow());
                 SCASSERT(window != nullptr)
                 connect(line, &Visualization::ToolTip, window, &VAbstractMainWindow::ShowToolTip);
             }
@@ -292,10 +316,9 @@ void DialogAlongLine::ChosenSecondPoint(quint32 id, const QString &toolTip)
 
             prepare = true;
 
-            if (m_buildMidpoint)
+            if (m_buildMidpoint || not VAbstractValApplication::VApp()->Settings()->IsInteractiveTools())
             {
-                setModal(true);
-                show();
+                FinishCreating();
             }
         }
         else
@@ -305,6 +328,25 @@ void DialogAlongLine::ChosenSecondPoint(quint32 id, const QString &toolTip)
     }
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void DialogAlongLine::FinishCreating()
+{
+    vis->SetMode(Mode::Show);
+    vis->RefreshGeometry();
+    emit ToolTip(QString());
+    setModal(true);
+    show();
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void DialogAlongLine::InitIcons()
+{
+    const auto resource = QStringLiteral("icon");
+
+    ui->toolButtonExprLength->setIcon(VTheme::GetIconResource(resource, QStringLiteral("24x24/fx.png")));
+    ui->labelEqual->setPixmap(VTheme::GetPixmapResource(resource, QStringLiteral("24x24/equal.png")));
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 /**
  * @brief SetSecondPointId set id second point of line
@@ -366,12 +408,12 @@ void DialogAlongLine::ShowDialog(bool click)
 
         const QSharedPointer<VPointF> p1 = data->GeometricObject<VPointF>(GetFirstPointId());
         const QSharedPointer<VPointF> p2 = data->GeometricObject<VPointF>(GetSecondPointId());
-        QLineF baseLine(static_cast<QPointF>(*p1), static_cast<QPointF>(*p2));
+        QLineF const baseLine(static_cast<QPointF>(*p1), static_cast<QPointF>(*p2));
 
-        QLineF line(static_cast<QPointF>(*p1), scene->getScenePos());
+        QLineF const line(static_cast<QPointF>(*p1), scene->getScenePos());
 
         qreal len = line.length();
-        qreal angleTo = baseLine.angleTo(line);
+        qreal const angleTo = baseLine.angleTo(line);
         if (angleTo > 90 && angleTo < 270)
         {
             len *= -1;
@@ -380,13 +422,7 @@ void DialogAlongLine::ShowDialog(bool click)
         SetFormula(QString::number(FromPixel(len, *data->GetPatternUnit())));
     }
 
-    vis->SetMode(Mode::Show);
-    vis->RefreshGeometry();
-
-    emit ToolTip(QString());
-
-    setModal(true);
-    show();
+    FinishCreating();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -410,8 +446,8 @@ void DialogAlongLine::SetFirstPointId(quint32 value)
  */
 void DialogAlongLine::SetFormula(const QString &value)
 {
-    m_formula = VAbstractApplication::VApp()->TrVars()
-            ->FormulaToUser(value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    m_formula = VAbstractApplication::VApp()->TrVars()->FormulaToUser(
+        value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
     // increase height if needed.
     if (m_formula.length() > 80)
     {
