@@ -28,7 +28,6 @@
 
 #include "dialogarc.h"
 
-#include <climits>
 #include <QDialog>
 #include <QLabel>
 #include <QPlainTextEdit>
@@ -36,20 +35,21 @@
 #include <QPushButton>
 #include <QTimer>
 #include <QToolButton>
-#include <Qt>
+#include <climits>
 
-#include "../vpatterndb/vtranslatevars.h"
-#include "../vpatterndb/vcontainer.h"
 #include "../../visualization/path/vistoolarc.h"
 #include "../../visualization/visualization.h"
+#include "../qmuparser/qmudef.h"
 #include "../support/dialogeditwrongformula.h"
+#include "../vgeometry/varc.h"
+#include "../vmisc/theme/vtheme.h"
 #include "../vmisc/vabstractapplication.h"
 #include "../vmisc/vcommonsettings.h"
-#include "ui_dialogarc.h"
-#include "../vgeometry/varc.h"
-#include "../qmuparser/qmudef.h"
-#include "../vwidgets/vabstractmainwindow.h"
+#include "../vpatterndb/vcontainer.h"
+#include "../vpatterndb/vtranslatevars.h"
 #include "../vwidgets/global.h"
+#include "../vwidgets/vabstractmainwindow.h"
+#include "ui_dialogarc.h"
 
 //---------------------------------------------------------------------------------------------------------------------
 /**
@@ -57,15 +57,17 @@
  * @param data container with data
  * @param parent parent widget
  */
-DialogArc::DialogArc(const VContainer *data, quint32 toolId, QWidget *parent)
-    : DialogTool(data, toolId, parent),
-      ui(new Ui::DialogArc),
-      m_timerRadius(new QTimer(this)),
-      m_timerF1(new QTimer(this)),
-      m_timerF2(new QTimer(this))
+DialogArc::DialogArc(const VContainer *data, VAbstractPattern *doc, quint32 toolId, QWidget *parent)
+  : DialogTool(data, doc, toolId, parent),
+    ui(new Ui::DialogArc),
+    m_timerRadius(new QTimer(this)),
+    m_timerF1(new QTimer(this)),
+    m_timerF2(new QTimer(this))
 {
     ui->setupUi(this);
 
+    InitIcons();
+
     ui->doubleSpinBoxApproximationScale->setMaximum(maxCurveApproximationScale);
 
     this->m_formulaBaseHeight = ui->plainTextEditFormula->height();
@@ -89,26 +91,22 @@ DialogArc::DialogArc(const VContainer *data, quint32 toolId, QWidget *parent)
 
     FillComboBoxPoints(ui->comboBoxBasePoint);
     FillComboBoxLineColors(ui->comboBoxColor);
-    FillComboBoxTypeLine(ui->comboBoxPenStyle, CurvePenStylesPics());
+    FillComboBoxTypeLine(ui->comboBoxPenStyle,
+                         CurvePenStylesPics(ui->comboBoxPenStyle->palette().color(QPalette::Base),
+                                            ui->comboBoxPenStyle->palette().color(QPalette::Text)));
 
     connect(ui->toolButtonExprRadius, &QPushButton::clicked, this, &DialogArc::FXRadius);
     connect(ui->toolButtonExprF1, &QPushButton::clicked, this, &DialogArc::FXF1);
     connect(ui->toolButtonExprF2, &QPushButton::clicked, this, &DialogArc::FXF2);
 
-    connect(ui->plainTextEditFormula, &QPlainTextEdit::textChanged, this, [this]()
-    {
-        m_timerRadius->start(formulaTimerTimeout);
-    });
+    connect(ui->plainTextEditFormula, &QPlainTextEdit::textChanged, this,
+            [this]() { m_timerRadius->start(formulaTimerTimeout); });
 
-    connect(ui->plainTextEditF1, &QPlainTextEdit::textChanged, this, [this]()
-    {
-        m_timerF1->start(formulaTimerTimeout);
-    });
+    connect(ui->plainTextEditF1, &QPlainTextEdit::textChanged, this,
+            [this]() { m_timerF1->start(formulaTimerTimeout); });
 
-    connect(ui->plainTextEditF2, &QPlainTextEdit::textChanged, this, [this]()
-    {
-        m_timerF2->start(formulaTimerTimeout);
-    });
+    connect(ui->plainTextEditF2, &QPlainTextEdit::textChanged, this,
+            [this]() { m_timerF2->start(formulaTimerTimeout); });
 
     connect(ui->pushButtonGrowLength, &QPushButton::clicked, this, &DialogArc::DeployFormulaTextEdit);
     connect(ui->pushButtonGrowLengthF1, &QPushButton::clicked, this, &DialogArc::DeployF1TextEdit);
@@ -167,8 +165,8 @@ void DialogArc::SetCenter(const quint32 &value)
  */
 void DialogArc::SetF2(const QString &value)
 {
-    m_f2 = VAbstractApplication::VApp()->TrVars()
-            ->FormulaToUser(value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    m_f2 = VAbstractApplication::VApp()->TrVars()->FormulaToUser(
+        value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
     // increase height if needed.
     if (m_f2.length() > 80)
     {
@@ -257,17 +255,6 @@ void DialogArc::ShowDialog(bool click)
         auto *arcVis = qobject_cast<VisToolArc *>(vis);
         SCASSERT(arcVis != nullptr)
 
-        auto FinishCreating = [this, arcVis]()
-        {
-            arcVis->SetMode(Mode::Show);
-            arcVis->RefreshGeometry();
-
-            emit ToolTip(QString());
-
-            setModal(true);
-            show();
-        };
-
         if (click)
         {
             // The check need to ignore first release of mouse button.
@@ -282,9 +269,9 @@ void DialogArc::ShowDialog(bool click)
             auto *scene = qobject_cast<VMainGraphicsScene *>(VAbstractValApplication::VApp()->getCurrentScene());
             SCASSERT(scene != nullptr)
             const QSharedPointer<VPointF> point = data->GeometricObject<VPointF>(GetCenter());
-            QLineF line = QLineF(static_cast<QPointF>(*point), scene->getScenePos());
+            auto const line = QLineF(static_cast<QPointF>(*point), scene->getScenePos());
 
-            auto Angle = [line]()
+            auto Angle = [&line]()
             {
                 if (QGuiApplication::keyboardModifiers() == Qt::ShiftModifier)
                 {
@@ -298,8 +285,8 @@ void DialogArc::ShowDialog(bool click)
 
             if (m_stageRadius)
             {
-                //Radius of point circle, but little bigger. Need handle with hover sizes.
-                if (line.length() <= ScaledRadius(SceneScale(VAbstractValApplication::VApp()->getCurrentScene()))*1.5)
+                // Radius of point circle, but little bigger. Need handle with hover sizes.
+                if (line.length() <= ScaledRadius(SceneScale(VAbstractValApplication::VApp()->getCurrentScene())) * 1.5)
                 {
                     return;
                 }
@@ -335,8 +322,8 @@ void DialogArc::ShowDialog(bool click)
  */
 void DialogArc::SetF1(const QString &value)
 {
-    m_f1 = VAbstractApplication::VApp()->TrVars()
-            ->FormulaToUser(value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    m_f1 = VAbstractApplication::VApp()->TrVars()->FormulaToUser(
+        value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
     // increase height if needed.
     if (m_f1.length() > 80)
     {
@@ -358,8 +345,8 @@ void DialogArc::SetF1(const QString &value)
  */
 void DialogArc::SetRadius(const QString &value)
 {
-    m_radius = VAbstractApplication::VApp()->TrVars()
-            ->FormulaToUser(value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    m_radius = VAbstractApplication::VApp()->TrVars()->FormulaToUser(
+        value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
     // increase height if needed.
     if (m_radius.length() > 80)
     {
@@ -382,25 +369,24 @@ void DialogArc::SetRadius(const QString &value)
  */
 void DialogArc::ChosenObject(quint32 id, const SceneObject &type)
 {
-    if (not prepare)// After first choose we ignore all objects
+    if (not prepare && type == SceneObject::Point &&
+        SetObject(id, ui->comboBoxBasePoint, QString())) // After first choose we ignore all objects
     {
-        if (type == SceneObject::Point)
+        if (vis != nullptr)
         {
-            if (SetObject(id, ui->comboBoxBasePoint, QString()))
-            {
-                if (vis != nullptr)
-                {
-                    auto *window = qobject_cast<VAbstractMainWindow *>(
-                                VAbstractValApplication::VApp()->getMainWindow());
-                    SCASSERT(window != nullptr)
-                    connect(vis.data(), &Visualization::ToolTip, window, &VAbstractMainWindow::ShowToolTip);
+            auto *window = qobject_cast<VAbstractMainWindow *>(VAbstractValApplication::VApp()->getMainWindow());
+            SCASSERT(window != nullptr)
+            connect(vis.data(), &Visualization::ToolTip, window, &VAbstractMainWindow::ShowToolTip);
 
-                    vis->VisualMode(id);
-                    vis->RefreshToolTip();
-                }
+            vis->VisualMode(id);
+            vis->RefreshToolTip();
+        }
 
-                prepare = true;
-            }
+        prepare = true;
+
+        if (not VAbstractValApplication::VApp()->Settings()->IsInteractiveTools())
+        {
+            FinishCreating();
         }
     }
 }
@@ -438,13 +424,31 @@ void DialogArc::closeEvent(QCloseEvent *event)
     DialogTool::closeEvent(event);
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void DialogArc::changeEvent(QEvent *event)
+{
+    if (event->type() == QEvent::LanguageChange)
+    {
+        ui->retranslateUi(this);
+    }
+
+    if (event->type() == QEvent::PaletteChange)
+    {
+        InitIcons();
+        InitDialogButtonBoxIcons(ui->buttonBox);
+    }
+
+    // remember to call base class implementation
+    DialogTool::changeEvent(event);
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void DialogArc::ValidateAlias()
 {
-    QRegularExpression rx(NameRegExp());
     VArc arc;
     arc.SetAliasSuffix(GetAliasSuffix());
-    if (not GetAliasSuffix().isEmpty() &&
+    if (QRegularExpression const rx(NameRegExp());
+        not GetAliasSuffix().isEmpty() &&
         (not rx.match(arc.GetAlias()).hasMatch() ||
          (m_originAliasSuffix != GetAliasSuffix() && not data->IsUnique(arc.GetAlias()))))
     {
@@ -515,17 +519,7 @@ void DialogArc::EvalRadius()
     formulaData.labelResult = ui->labelResultRadius;
     formulaData.postfix = UnitsToStr(VAbstractValApplication::VApp()->patternUnits(), true);
 
-    const qreal radius = Eval(formulaData, m_flagRadius);
-
-    if (radius < 0)
-    {
-        m_flagRadius = false;
-        ChangeColor(ui->labelEditRadius, errorColor);
-        ui->labelResultRadius->setText(tr("Error"));
-        ui->labelResultRadius->setToolTip(tr("Radius can't be negative"));
-
-        DialogArc::CheckState();
-    }
+    Eval(formulaData, m_flagRadius);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -540,7 +534,6 @@ void DialogArc::EvalF()
     formulaData.labelEditFormula = ui->labelEditF1;
     formulaData.labelResult = ui->labelResultF1;
     formulaData.postfix = degreeSymbol;
-    formulaData.checkZero = false;
 
     m_angleF1 = Eval(formulaData, m_flagF1);
 
@@ -551,6 +544,34 @@ void DialogArc::EvalF()
     m_angleF2 = Eval(formulaData, m_flagF2);
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void DialogArc::FinishCreating()
+{
+    vis->SetMode(Mode::Show);
+    vis->RefreshGeometry();
+
+    emit ToolTip(QString());
+
+    setModal(true);
+    show();
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void DialogArc::InitIcons()
+{
+    const auto resource = QStringLiteral("icon");
+
+    const auto fxIcon = QStringLiteral("24x24/fx.png");
+    ui->toolButtonExprRadius->setIcon(VTheme::GetIconResource(resource, fxIcon));
+    ui->toolButtonExprF1->setIcon(VTheme::GetIconResource(resource, fxIcon));
+    ui->toolButtonExprF2->setIcon(VTheme::GetIconResource(resource, fxIcon));
+
+    const auto equalIcon = QStringLiteral("24x24/equal.png");
+    ui->label_2->setPixmap(VTheme::GetPixmapResource(resource, equalIcon));
+    ui->label_3->setPixmap(VTheme::GetPixmapResource(resource, equalIcon));
+    ui->label_5->setPixmap(VTheme::GetPixmapResource(resource, equalIcon));
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 /**
  * @brief GetCenter return id of center point
