@@ -28,7 +28,6 @@
 
 #include "dialogarcwithlength.h"
 
-#include <climits>
 #include <QDialog>
 #include <QLabel>
 #include <QPlainTextEdit>
@@ -36,31 +35,34 @@
 #include <QPushButton>
 #include <QTimer>
 #include <QToolButton>
-#include <Qt>
+#include <climits>
 
-#include "../vpatterndb/vtranslatevars.h"
-#include "../vpatterndb/vcontainer.h"
 #include "../../visualization/path/vistoolarcwithlength.h"
+#include "../../visualization/visualization.h"
+#include "../qmuparser/qmudef.h"
 #include "../support/dialogeditwrongformula.h"
+#include "../vgeometry/varc.h"
+#include "../vmisc/theme/vtheme.h"
 #include "../vmisc/vabstractapplication.h"
 #include "../vmisc/vcommonsettings.h"
-#include "../../visualization/visualization.h"
-#include "ui_dialogarcwithlength.h"
-#include "../vgeometry/varc.h"
-#include "../qmuparser/qmudef.h"
-#include "../vwidgets/vabstractmainwindow.h"
+#include "../vpatterndb/vcontainer.h"
+#include "../vpatterndb/vtranslatevars.h"
 #include "../vwidgets/global.h"
+#include "../vwidgets/vabstractmainwindow.h"
+#include "ui_dialogarcwithlength.h"
 
 //---------------------------------------------------------------------------------------------------------------------
-DialogArcWithLength::DialogArcWithLength(const VContainer *data, quint32 toolId, QWidget *parent)
-    : DialogTool(data, toolId, parent),
-      ui(new Ui::DialogArcWithLength),
-      m_timerRadius(new QTimer(this)),
-      m_timerF1(new QTimer(this)),
-      m_timerLength(new QTimer(this))
+DialogArcWithLength::DialogArcWithLength(const VContainer *data, VAbstractPattern *doc, quint32 toolId, QWidget *parent)
+  : DialogTool(data, doc, toolId, parent),
+    ui(new Ui::DialogArcWithLength),
+    m_timerRadius(new QTimer(this)),
+    m_timerF1(new QTimer(this)),
+    m_timerLength(new QTimer(this))
 {
     ui->setupUi(this);
 
+    InitIcons();
+
     this->m_formulaBaseHeightRadius = ui->plainTextEditRadius->height();
     this->m_formulaBaseHeightF1 = ui->plainTextEditF1->height();
     this->m_formulaBaseHeightLength = ui->plainTextEditLength->height();
@@ -82,7 +84,9 @@ DialogArcWithLength::DialogArcWithLength(const VContainer *data, quint32 toolId,
 
     FillComboBoxPoints(ui->comboBoxCenter);
     FillComboBoxLineColors(ui->comboBoxColor);
-    FillComboBoxTypeLine(ui->comboBoxPenStyle, CurvePenStylesPics());
+    FillComboBoxTypeLine(ui->comboBoxPenStyle,
+                         CurvePenStylesPics(ui->comboBoxPenStyle->palette().color(QPalette::Base),
+                                            ui->comboBoxPenStyle->palette().color(QPalette::Text)));
 
     ui->doubleSpinBoxApproximationScale->setMaximum(maxCurveApproximationScale);
 
@@ -90,20 +94,14 @@ DialogArcWithLength::DialogArcWithLength(const VContainer *data, quint32 toolId,
     connect(ui->toolButtonExprF1, &QPushButton::clicked, this, &DialogArcWithLength::FXF1);
     connect(ui->toolButtonExprLength, &QPushButton::clicked, this, &DialogArcWithLength::FXLength);
 
-    connect(ui->plainTextEditRadius, &QPlainTextEdit::textChanged, this, [this]()
-    {
-        m_timerRadius->start(formulaTimerTimeout);
-    });
+    connect(ui->plainTextEditRadius, &QPlainTextEdit::textChanged, this,
+            [this]() { m_timerRadius->start(formulaTimerTimeout); });
 
-    connect(ui->plainTextEditF1, &QPlainTextEdit::textChanged, this, [this]()
-    {
-        m_timerF1->start(formulaTimerTimeout);
-    });
+    connect(ui->plainTextEditF1, &QPlainTextEdit::textChanged, this,
+            [this]() { m_timerF1->start(formulaTimerTimeout); });
 
-    connect(ui->plainTextEditLength, &QPlainTextEdit::textChanged, this, [this]()
-    {
-        m_timerLength->start(formulaTimerTimeout);
-    });
+    connect(ui->plainTextEditLength, &QPlainTextEdit::textChanged, this,
+            [this]() { m_timerLength->start(formulaTimerTimeout); });
 
     connect(ui->pushButtonGrowLengthRadius, &QPushButton::clicked, this, &DialogArcWithLength::DeployRadiusTextEdit);
     connect(ui->pushButtonGrowLengthF1, &QPushButton::clicked, this, &DialogArcWithLength::DeployF1TextEdit);
@@ -147,8 +145,8 @@ auto DialogArcWithLength::GetRadius() const -> QString
 //---------------------------------------------------------------------------------------------------------------------
 void DialogArcWithLength::SetRadius(const QString &value)
 {
-    m_radius = VAbstractApplication::VApp()->TrVars()
-            ->FormulaToUser(value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    m_radius = VAbstractApplication::VApp()->TrVars()->FormulaToUser(
+        value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
     // increase height if needed.
     if (m_radius.length() > 80)
     {
@@ -172,8 +170,8 @@ auto DialogArcWithLength::GetF1() const -> QString
 //---------------------------------------------------------------------------------------------------------------------
 void DialogArcWithLength::SetF1(const QString &value)
 {
-    m_f1 = VAbstractApplication::VApp()->TrVars()
-            ->FormulaToUser(value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    m_f1 = VAbstractApplication::VApp()->TrVars()->FormulaToUser(
+        value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
     // increase height if needed.
     if (m_f1.length() > 80)
     {
@@ -197,8 +195,8 @@ auto DialogArcWithLength::GetLength() const -> QString
 //---------------------------------------------------------------------------------------------------------------------
 void DialogArcWithLength::SetLength(const QString &value)
 {
-    m_length = VAbstractApplication::VApp()->TrVars()
-            ->FormulaToUser(value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    m_length = VAbstractApplication::VApp()->TrVars()->FormulaToUser(
+        value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
     // increase height if needed.
     if (m_length.length() > 80)
     {
@@ -284,17 +282,6 @@ void DialogArcWithLength::ShowDialog(bool click)
 {
     if (prepare)
     {
-        auto FinishCreating = [this]()
-        {
-            vis->SetMode(Mode::Show);
-            vis->RefreshGeometry();
-
-            emit ToolTip(QString());
-
-            setModal(true);
-            show();
-        };
-
         if (click)
         {
             // The check need to ignore first release of mouse button.
@@ -309,9 +296,9 @@ void DialogArcWithLength::ShowDialog(bool click)
             auto *scene = qobject_cast<VMainGraphicsScene *>(VAbstractValApplication::VApp()->getCurrentScene());
             SCASSERT(scene != nullptr)
             const QSharedPointer<VPointF> point = data->GeometricObject<VPointF>(GetCenter());
-            QLineF line = QLineF(static_cast<QPointF>(*point), scene->getScenePos());
+            auto const line = QLineF(static_cast<QPointF>(*point), scene->getScenePos());
 
-            auto Angle = [line]()
+            auto Angle = [&line]()
             {
                 if (QGuiApplication::keyboardModifiers() == Qt::ShiftModifier)
                 {
@@ -325,8 +312,8 @@ void DialogArcWithLength::ShowDialog(bool click)
 
             if (m_stageRadius)
             {
-                //Radius of point circle, but little bigger. Need handle with hover sizes.
-                if (line.length() <= ScaledRadius(SceneScale(VAbstractValApplication::VApp()->getCurrentScene()))*1.5)
+                // Radius of point circle, but little bigger. Need handle with hover sizes.
+                if (line.length() <= ScaledRadius(SceneScale(VAbstractValApplication::VApp()->getCurrentScene())) * 1.5)
                 {
                     return;
                 }
@@ -349,7 +336,7 @@ void DialogArcWithLength::ShowDialog(bool click)
             {
                 const qreal r = Visualization::FindLengthFromUser(m_radius, data->DataVariables());
                 const qreal angle1 = Visualization::FindValFromUser(m_f1, data->DataVariables());
-                VArc arc(*point, r, angle1, line.angle());
+                VArc const arc(*point, r, angle1, line.angle());
 
                 SetLength(QString::number(VAbstractValApplication::VApp()->fromPixel(arc.GetLength())));
 
@@ -366,25 +353,24 @@ void DialogArcWithLength::ShowDialog(bool click)
 //---------------------------------------------------------------------------------------------------------------------
 void DialogArcWithLength::ChosenObject(quint32 id, const SceneObject &type)
 {
-    if (not prepare)// After first choose we ignore all objects
+    if (not prepare && type == SceneObject::Point &&
+        SetObject(id, ui->comboBoxCenter, QString())) // After first choose we ignore all objects
     {
-        if (type == SceneObject::Point)
+        if (vis != nullptr)
         {
-            if (SetObject(id, ui->comboBoxCenter, QString()))
-            {
-                if (vis != nullptr)
-                {
-                    auto *window = qobject_cast<VAbstractMainWindow *>(
-                                VAbstractValApplication::VApp()->getMainWindow());
-                    SCASSERT(window != nullptr)
-                    connect(vis.data(), &Visualization::ToolTip, window, &VAbstractMainWindow::ShowToolTip);
+            auto *window = qobject_cast<VAbstractMainWindow *>(VAbstractValApplication::VApp()->getMainWindow());
+            SCASSERT(window != nullptr)
+            connect(vis.data(), &Visualization::ToolTip, window, &VAbstractMainWindow::ShowToolTip);
 
-                    vis->VisualMode(id);
-                    vis->RefreshToolTip();
-                }
+            vis->VisualMode(id);
+            vis->RefreshToolTip();
+        }
 
-                prepare = true;
-            }
+        prepare = true;
+
+        if (not VAbstractValApplication::VApp()->Settings()->IsInteractiveTools())
+        {
+            FinishCreating();
         }
     }
 }
@@ -482,13 +468,31 @@ void DialogArcWithLength::closeEvent(QCloseEvent *event)
     DialogTool::closeEvent(event);
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void DialogArcWithLength::changeEvent(QEvent *event)
+{
+    if (event->type() == QEvent::LanguageChange)
+    {
+        ui->retranslateUi(this);
+    }
+
+    if (event->type() == QEvent::PaletteChange)
+    {
+        InitIcons();
+        InitDialogButtonBoxIcons(ui->buttonBox);
+    }
+
+    // remember to call base class implementation
+    DialogTool::changeEvent(event);
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void DialogArcWithLength::ValidateAlias()
 {
-    QRegularExpression rx(NameRegExp());
     VArc arc;
     arc.SetAliasSuffix(GetAliasSuffix());
-    if (not GetAliasSuffix().isEmpty() &&
+    if (QRegularExpression const rx(NameRegExp());
+        not GetAliasSuffix().isEmpty() &&
         (not rx.match(arc.GetAlias()).hasMatch() ||
          (m_originAliasSuffix != GetAliasSuffix() && not data->IsUnique(arc.GetAlias()))))
     {
@@ -540,7 +544,34 @@ void DialogArcWithLength::EvalF()
     formulaData.labelEditFormula = ui->labelEditF1;
     formulaData.labelResult = ui->labelResultF1;
     formulaData.postfix = degreeSymbol;
-    formulaData.checkZero = false;
 
     Eval(formulaData, m_flagF1);
 }
+
+//---------------------------------------------------------------------------------------------------------------------
+void DialogArcWithLength::FinishCreating()
+{
+    vis->SetMode(Mode::Show);
+    vis->RefreshGeometry();
+
+    emit ToolTip(QString());
+
+    setModal(true);
+    show();
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void DialogArcWithLength::InitIcons()
+{
+    const auto resource = QStringLiteral("icon");
+
+    const auto fxIcon = QStringLiteral("24x24/fx.png");
+    ui->toolButtonExprRadius->setIcon(VTheme::GetIconResource(resource, fxIcon));
+    ui->toolButtonExprF1->setIcon(VTheme::GetIconResource(resource, fxIcon));
+    ui->toolButtonExprLength->setIcon(VTheme::GetIconResource(resource, fxIcon));
+
+    const auto equalIcon = QStringLiteral("24x24/equal.png");
+    ui->label_6->setPixmap(VTheme::GetPixmapResource(resource, equalIcon));
+    ui->label_9->setPixmap(VTheme::GetPixmapResource(resource, equalIcon));
+    ui->label_10->setPixmap(VTheme::GetPixmapResource(resource, equalIcon));
+}
