@@ -44,14 +44,15 @@
 #include "../../visualization/visualization.h"
 #include "../ifc/xml/vabstractpattern.h"
 #include "../support/dialogeditwrongformula.h"
+#include "../vgeometry/vpointf.h"
+#include "../vmisc/theme/vtheme.h"
 #include "../vmisc/vabstractapplication.h"
 #include "../vmisc/vcommonsettings.h"
-#include "../vpatterndb/vtranslatevars.h"
 #include "../vpatterndb/vcontainer.h"
-#include "ui_dialogbisector.h"
-#include "../vwidgets/vabstractmainwindow.h"
+#include "../vpatterndb/vtranslatevars.h"
 #include "../vtools/tools/drawTools/toolpoint/toolsinglepoint/toollinepoint/vtoolbisector.h"
-#include "../vgeometry/vpointf.h"
+#include "../vwidgets/vabstractmainwindow.h"
+#include "ui_dialogbisector.h"
 
 //---------------------------------------------------------------------------------------------------------------------
 /**
@@ -59,20 +60,22 @@
  * @param data container with data
  * @param parent parent widget
  */
-DialogBisector::DialogBisector(const VContainer *data, quint32 toolId, QWidget *parent)
-    : DialogTool(data, toolId, parent),
-      ui(new Ui::DialogBisector),
-      m_timerFormula(new QTimer(this))
+DialogBisector::DialogBisector(const VContainer *data, VAbstractPattern *doc, quint32 toolId, QWidget *parent)
+  : DialogTool(data, doc, toolId, parent),
+    ui(new Ui::DialogBisector),
+    m_timerFormula(new QTimer(this))
 {
     ui->setupUi(this);
 
+    InitIcons();
+
     m_timerFormula->setSingleShot(true);
     connect(m_timerFormula, &QTimer::timeout, this, &DialogBisector::EvalFormula);
 
     ui->lineEditNamePoint->setClearButtonEnabled(true);
 
     ui->lineEditNamePoint->setText(
-                VAbstractValApplication::VApp()->getCurrentDocument()->GenerateLabel(LabelType::NewLabel));
+        VAbstractValApplication::VApp()->getCurrentDocument()->GenerateLabel(LabelType::NewLabel));
     this->m_formulaBaseHeight = ui->plainTextEditFormula->height();
     ui->plainTextEditFormula->installEventFilter(this);
 
@@ -80,27 +83,25 @@ DialogBisector::DialogBisector(const VContainer *data, quint32 toolId, QWidget *
 
     FillComboBoxPoints(ui->comboBoxFirstPoint);
     FillComboBoxPoints(ui->comboBoxSecondPoint);
-    FillComboBoxTypeLine(ui->comboBoxLineType, LineStylesPics());
+    FillComboBoxTypeLine(ui->comboBoxLineType, LineStylesPics(ui->comboBoxLineType->palette().color(QPalette::Base),
+                                                              ui->comboBoxLineType->palette().color(QPalette::Text)));
     FillComboBoxPoints(ui->comboBoxThirdPoint);
     FillComboBoxLineColors(ui->comboBoxLineColor);
 
     connect(ui->toolButtonExprLength, &QPushButton::clicked, this, &DialogBisector::FXLength);
-    connect(ui->lineEditNamePoint, &QLineEdit::textChanged, this, [this]()
-    {
-        CheckPointLabel(this, ui->lineEditNamePoint, ui->labelEditNamePoint, m_pointName, this->data, m_flagName);
-        CheckState();
-    });
-    connect(ui->plainTextEditFormula, &QPlainTextEdit::textChanged, this, [this]()
-    {
-        m_timerFormula->start(formulaTimerTimeout);
-    });
+    connect(ui->lineEditNamePoint, &QLineEdit::textChanged, this,
+            [this]()
+            {
+                CheckPointLabel(this, ui->lineEditNamePoint, ui->labelEditNamePoint, m_pointName, this->data,
+                                m_flagName);
+                CheckState();
+            });
+    connect(ui->plainTextEditFormula, &QPlainTextEdit::textChanged, this,
+            [this]() { m_timerFormula->start(formulaTimerTimeout); });
     connect(ui->pushButtonGrowLength, &QPushButton::clicked, this, &DialogBisector::DeployFormulaTextEdit);
-    connect(ui->comboBoxFirstPoint, &QComboBox::currentTextChanged,
-            this, &DialogBisector::PointNameChanged);
-    connect(ui->comboBoxSecondPoint, &QComboBox::currentTextChanged,
-            this, &DialogBisector::PointNameChanged);
-    connect(ui->comboBoxThirdPoint, &QComboBox::currentTextChanged,
-            this, &DialogBisector::PointNameChanged);
+    connect(ui->comboBoxFirstPoint, &QComboBox::currentTextChanged, this, &DialogBisector::PointNameChanged);
+    connect(ui->comboBoxSecondPoint, &QComboBox::currentTextChanged, this, &DialogBisector::PointNameChanged);
+    connect(ui->comboBoxThirdPoint, &QComboBox::currentTextChanged, this, &DialogBisector::PointNameChanged);
 
     vis = new VisToolBisector(data);
 
@@ -156,7 +157,6 @@ void DialogBisector::EvalFormula()
     formulaData.labelEditFormula = ui->labelEditFormula;
     formulaData.labelResult = ui->labelResultCalculation;
     formulaData.postfix = UnitsToStr(VAbstractValApplication::VApp()->patternUnits(), true);
-    formulaData.checkZero = false;
 
     Eval(formulaData, m_flagFormula);
 }
@@ -193,7 +193,7 @@ auto DialogBisector::GetPointName() const -> QString
  */
 void DialogBisector::ChosenObject(quint32 id, const SceneObject &type)
 {
-    if (prepare)// After first choose we ignore all objects
+    if (prepare) // After first choose we ignore all objects
     {
         return;
     }
@@ -213,14 +213,12 @@ void DialogBisector::ChosenObject(quint32 id, const SceneObject &type)
                 }
                 break;
             case 1:
-                if (getCurrentObjectId(ui->comboBoxFirstPoint) != id)
+                if (getCurrentObjectId(ui->comboBoxFirstPoint) != id &&
+                    SetObject(id, ui->comboBoxSecondPoint, tr("Select third point of angle")))
                 {
-                    if (SetObject(id, ui->comboBoxSecondPoint, tr("Select third point of angle")))
-                    {
-                        m_number++;
-                        line->SetPoint2Id(id);
-                        line->RefreshGeometry();
-                    }
+                    m_number++;
+                    line->SetPoint2Id(id);
+                    line->RefreshGeometry();
                 }
                 break;
             case 2:
@@ -261,8 +259,8 @@ void DialogBisector::SetTypeLine(const QString &value)
  */
 void DialogBisector::SetFormula(const QString &value)
 {
-    m_formula = VAbstractApplication::VApp()->TrVars()
-            ->FormulaToUser(value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    m_formula = VAbstractApplication::VApp()->TrVars()->FormulaToUser(
+        value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
     // increase height if needed.
     if (m_formula.length() > 80)
     {
@@ -368,17 +366,16 @@ void DialogBisector::ShowDialog(bool click)
         const QSharedPointer<VPointF> p2 = data->GeometricObject<VPointF>(GetSecondPointId());
         const QSharedPointer<VPointF> p3 = data->GeometricObject<VPointF>(GetThirdPointId());
 
-        qreal angle = VToolBisector::BisectorAngle(static_cast<QPointF>(*p1),
-                                                   static_cast<QPointF>(*p2),
-                                                   static_cast<QPointF>(*p3));
+        qreal const angle = VToolBisector::BisectorAngle(static_cast<QPointF>(*p1), static_cast<QPointF>(*p2),
+                                                         static_cast<QPointF>(*p3));
 
         QLineF baseLine(static_cast<QPointF>(*p2), static_cast<QPointF>(*p3));
         baseLine.setAngle(angle);
 
-        QLineF line(static_cast<QPointF>(*p2), scene->getScenePos());
+        QLineF const line(static_cast<QPointF>(*p2), scene->getScenePos());
 
         qreal len = line.length();
-        qreal angleTo = baseLine.angleTo(line);
+        qreal const angleTo = baseLine.angleTo(line);
         if (angleTo > 90 && angleTo < 270)
         {
             len *= -1;
@@ -387,13 +384,7 @@ void DialogBisector::ShowDialog(bool click)
         SetFormula(QString::number(FromPixel(len, *data->GetPatternUnit())));
     }
 
-    vis->SetMode(Mode::Show);
-    vis->RefreshGeometry();
-
-    emit ToolTip(QString());
-
-    setModal(true);
-    show();
+    FinishCreating();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -420,6 +411,24 @@ void DialogBisector::closeEvent(QCloseEvent *event)
     DialogTool::closeEvent(event);
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void DialogBisector::changeEvent(QEvent *event)
+{
+    if (event->type() == QEvent::LanguageChange)
+    {
+        ui->retranslateUi(this);
+    }
+
+    if (event->type() == QEvent::PaletteChange)
+    {
+        InitIcons();
+        InitDialogButtonBoxIcons(ui->buttonBox);
+    }
+
+    // remember to call base class implementation
+    DialogTool::changeEvent(event);
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void DialogBisector::ChosenThirdPoint(quint32 id)
 {
@@ -428,25 +437,45 @@ void DialogBisector::ChosenThirdPoint(quint32 id)
     set.insert(getCurrentObjectId(ui->comboBoxSecondPoint));
     set.insert(id);
 
-    if (set.size() == 3)
+    if (set.size() == 3 && SetObject(id, ui->comboBoxThirdPoint, QString()))
     {
-        if (SetObject(id, ui->comboBoxThirdPoint, QString()))
+        auto *window = qobject_cast<VAbstractMainWindow *>(VAbstractValApplication::VApp()->getMainWindow());
+        SCASSERT(window != nullptr)
+
+        auto *line = qobject_cast<VisToolBisector *>(vis);
+        SCASSERT(line != nullptr)
+        connect(line, &Visualization::ToolTip, window, &VAbstractMainWindow::ShowToolTip);
+
+        line->SetPoint3Id(id);
+        line->RefreshGeometry();
+        prepare = true;
+
+        if (not VAbstractValApplication::VApp()->Settings()->IsInteractiveTools())
         {
-            auto *window = qobject_cast<VAbstractMainWindow *>(
-                VAbstractValApplication::VApp()->getMainWindow());
-            SCASSERT(window != nullptr)
-
-            auto *line = qobject_cast<VisToolBisector *>(vis);
-            SCASSERT(line != nullptr)
-            connect(line, &Visualization::ToolTip, window, &VAbstractMainWindow::ShowToolTip);
-
-            line->SetPoint3Id(id);
-            line->RefreshGeometry();
-            prepare = true;
+            FinishCreating();
         }
     }
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void DialogBisector::FinishCreating()
+{
+    vis->SetMode(Mode::Show);
+    vis->RefreshGeometry();
+    emit ToolTip(QString());
+    setModal(true);
+    show();
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void DialogBisector::InitIcons()
+{
+    auto const resource = QStringLiteral("icon");
+
+    ui->toolButtonExprLength->setIcon(VTheme::GetIconResource(resource, QStringLiteral("24x24/fx.png")));
+    ui->label_3->setPixmap(VTheme::GetPixmapResource(resource, QStringLiteral("24x24/equal.png")));
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 /**
  * @brief GetTypeLine return type of line
