@@ -37,19 +37,19 @@
 
 #include "../../visualization/path/vistoolcubicbezier.h"
 #include "../../visualization/visualization.h"
+#include "../qmuparser/qmudef.h"
 #include "../vgeometry/vpointf.h"
 #include "../vpatterndb/vcontainer.h"
 #include "dialogtool.h"
 #include "ui_dialogcubicbezier.h"
-#include "../qmuparser/qmudef.h"
 
 //---------------------------------------------------------------------------------------------------------------------
-DialogCubicBezier::DialogCubicBezier(const VContainer *data, quint32 toolId, QWidget *parent)
-    : DialogTool(data, toolId, parent),
-      ui(new Ui::DialogCubicBezier),
-      spl(),
-      newDuplicate(-1),
-      flagError(false)
+DialogCubicBezier::DialogCubicBezier(const VContainer *data, VAbstractPattern *doc, quint32 toolId, QWidget *parent)
+  : DialogTool(data, doc, toolId, parent),
+    ui(new Ui::DialogCubicBezier),
+    spl(),
+    newDuplicate(-1),
+    flagError(false)
 {
     ui->setupUi(this);
     InitOkCancelApply(ui);
@@ -59,18 +59,16 @@ DialogCubicBezier::DialogCubicBezier(const VContainer *data, quint32 toolId, QWi
     FillComboBoxPoints(ui->comboBoxP3);
     FillComboBoxPoints(ui->comboBoxP4);
     FillComboBoxLineColors(ui->comboBoxColor);
-    FillComboBoxTypeLine(ui->comboBoxPenStyle, CurvePenStylesPics());
+    FillComboBoxTypeLine(ui->comboBoxPenStyle,
+                         CurvePenStylesPics(ui->comboBoxPenStyle->palette().color(QPalette::Base),
+                                            ui->comboBoxPenStyle->palette().color(QPalette::Text)));
 
     ui->doubleSpinBoxApproximationScale->setMaximum(maxCurveApproximationScale);
 
-    connect(ui->comboBoxP1, &QComboBox::currentTextChanged,
-            this, &DialogCubicBezier::PointNameChanged);
-    connect(ui->comboBoxP2, &QComboBox::currentTextChanged,
-            this, &DialogCubicBezier::PointNameChanged);
-    connect(ui->comboBoxP3, &QComboBox::currentTextChanged,
-            this, &DialogCubicBezier::PointNameChanged);
-    connect(ui->comboBoxP4, &QComboBox::currentTextChanged,
-            this, &DialogCubicBezier::PointNameChanged);
+    connect(ui->comboBoxP1, &QComboBox::currentTextChanged, this, &DialogCubicBezier::PointNameChanged);
+    connect(ui->comboBoxP2, &QComboBox::currentTextChanged, this, &DialogCubicBezier::PointNameChanged);
+    connect(ui->comboBoxP3, &QComboBox::currentTextChanged, this, &DialogCubicBezier::PointNameChanged);
+    connect(ui->comboBoxP4, &QComboBox::currentTextChanged, this, &DialogCubicBezier::PointNameChanged);
 
     connect(ui->lineEditAlias, &QLineEdit::textEdited, this, &DialogCubicBezier::ValidateAlias);
 
@@ -87,7 +85,7 @@ DialogCubicBezier::~DialogCubicBezier()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VCubicBezier DialogCubicBezier::GetSpline() const
+auto DialogCubicBezier::GetSpline() const -> VCubicBezier
 {
     return spl;
 }
@@ -112,7 +110,7 @@ void DialogCubicBezier::SetSpline(const VCubicBezier &spline)
     ui->lineEditAlias->setText(originAliasSuffix);
     ValidateAlias();
 
-    auto path = qobject_cast<VisToolCubicBezier *>(vis);
+    auto *path = qobject_cast<VisToolCubicBezier *>(vis);
     SCASSERT(path != nullptr)
     path->SetApproximationScale(spl.GetApproximationScale());
     path->SetPoint1Id(spl.GetP1().id());
@@ -124,57 +122,51 @@ void DialogCubicBezier::SetSpline(const VCubicBezier &spline)
 //---------------------------------------------------------------------------------------------------------------------
 void DialogCubicBezier::ChosenObject(quint32 id, const SceneObject &type)
 {
-    if (prepare == false)// After first choose we ignore all objects
+    if (prepare == false && type == SceneObject::Point) // After first choose we ignore all objects
     {
-        if (type == SceneObject::Point)
+        auto *path = qobject_cast<VisToolCubicBezier *>(vis);
+        SCASSERT(path != nullptr)
+
+        switch (number)
         {
-            auto *path = qobject_cast<VisToolCubicBezier *>(vis);
-            SCASSERT(path != nullptr)
+            case 0:
+                if (SetObject(id, ui->comboBoxP1, tr("Select the second point of curve")))
+                {
+                    ++number;
+                    path->VisualMode(id);
+                }
+                break;
+            case 1:
+                if (SetObject(id, ui->comboBoxP2, tr("Select the third point of curve")))
+                {
+                    ++number;
 
-            switch (number)
-            {
-                case 0:
-                    if (SetObject(id, ui->comboBoxP1, tr("Select the second point of curve")))
-                    {
-                        ++number;
-                        path->VisualMode(id);
-                    }
-                    break;
-                case 1:
-                    if (SetObject(id, ui->comboBoxP2, tr("Select the third point of curve")))
-                    {
-                        ++number;
+                    path->SetPoint2Id(id);
+                    path->RefreshGeometry();
+                }
+                break;
+            case 2:
+                if (SetObject(id, ui->comboBoxP3, tr("Select the fourth point of curve")))
+                {
+                    ++number;
 
-                        path->SetPoint2Id(id);
-                        path->RefreshGeometry();
-                    }
-                    break;
-                case 2:
-                    if (SetObject(id, ui->comboBoxP3, tr("Select the fourth point of curve")))
-                    {
-                        ++number;
+                    path->SetPoint3Id(id);
+                    path->RefreshGeometry();
+                }
+                break;
+            case 3:
+                if (getCurrentObjectId(ui->comboBoxP1) != id && SetObject(id, ui->comboBoxP4, QString()))
+                {
+                    ++number;
 
-                        path->SetPoint3Id(id);
-                        path->RefreshGeometry();
-                    }
-                    break;
-                case 3:
-                    if (getCurrentObjectId(ui->comboBoxP1) != id)
-                    {
-                        if (SetObject(id, ui->comboBoxP4, QString()))
-                        {
-                            ++number;
-
-                            path->SetPoint4Id(id);
-                            path->RefreshGeometry();
-                            prepare = true;
-                            DialogAccepted();
-                        }
-                    }
-                    break;
-                default:
-                    break;
-            }
+                    path->SetPoint4Id(id);
+                    path->RefreshGeometry();
+                    prepare = true;
+                    DialogAccepted();
+                }
+                break;
+            default:
+                break;
         }
     }
 }
@@ -249,10 +241,10 @@ void DialogCubicBezier::SaveData()
     spl.SetColor(GetComboBoxCurrentData(ui->comboBoxColor, ColorBlack));
     spl.SetAliasSuffix(ui->lineEditAlias->text());
 
-    const quint32 d = spl.GetDuplicate();//Save previous value
+    const quint32 d = spl.GetDuplicate(); // Save previous value
     newDuplicate <= -1 ? spl.SetDuplicate(d) : spl.SetDuplicate(static_cast<quint32>(newDuplicate));
 
-    auto path = qobject_cast<VisToolCubicBezier *>(vis);
+    auto *path = qobject_cast<VisToolCubicBezier *>(vis);
     SCASSERT(path != nullptr)
     path->SetApproximationScale(ui->doubleSpinBoxApproximationScale->value());
     path->SetPoint1Id(p1->id());
@@ -266,10 +258,10 @@ void DialogCubicBezier::SaveData()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogCubicBezier::ValidateAlias()
 {
-    QRegularExpression rx(NameRegExp());
     VCubicBezier spline = spl;
     spline.SetAliasSuffix(ui->lineEditAlias->text());
-    if (not ui->lineEditAlias->text().isEmpty() &&
+    if (QRegularExpression const rx(NameRegExp());
+        not ui->lineEditAlias->text().isEmpty() &&
         (not rx.match(spline.GetAlias()).hasMatch() ||
          (originAliasSuffix != ui->lineEditAlias->text() && not data->IsUnique(spline.GetAlias()))))
     {
@@ -286,25 +278,25 @@ void DialogCubicBezier::ValidateAlias()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-const QSharedPointer<VPointF> DialogCubicBezier::GetP1() const
+auto DialogCubicBezier::GetP1() const -> QSharedPointer<VPointF>
 {
     return data->GeometricObject<VPointF>(getCurrentObjectId(ui->comboBoxP1));
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-const QSharedPointer<VPointF> DialogCubicBezier::GetP2() const
+auto DialogCubicBezier::GetP2() const -> QSharedPointer<VPointF>
 {
     return data->GeometricObject<VPointF>(getCurrentObjectId(ui->comboBoxP2));
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-const QSharedPointer<VPointF> DialogCubicBezier::GetP3() const
+auto DialogCubicBezier::GetP3() const -> QSharedPointer<VPointF>
 {
     return data->GeometricObject<VPointF>(getCurrentObjectId(ui->comboBoxP3));
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-const QSharedPointer<VPointF> DialogCubicBezier::GetP4() const
+auto DialogCubicBezier::GetP4() const -> QSharedPointer<VPointF>
 {
     return data->GeometricObject<VPointF>(getCurrentObjectId(ui->comboBoxP4));
 }
@@ -316,7 +308,7 @@ void DialogCubicBezier::SetNotes(const QString &notes)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogCubicBezier::GetNotes() const
+auto DialogCubicBezier::GetNotes() const -> QString
 {
     return ui->plainTextEditToolNotes->toPlainText();
 }
