@@ -41,46 +41,55 @@
 #include <QSharedPointer>
 #include <QVariant>
 #include <QVector>
-#include <Qt>
-#include <new>
 
 #include "../../visualization/path/vistoolcubicbezierpath.h"
 #include "../../visualization/visualization.h"
 #include "../ifc/ifcdef.h"
+#include "../qmuparser/qmudef.h"
 #include "../vmisc/vabstractapplication.h"
-#if QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
-#include "../vmisc/backport/qoverload.h"
-#endif // QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
 #include "../vpatterndb/vcontainer.h"
 #include "../vwidgets/vabstractmainwindow.h"
 #include "dialogtool.h"
 #include "ui_dialogcubicbezierpath.h"
-#include "../qmuparser/qmudef.h"
 
 class QWidget;
 
 //---------------------------------------------------------------------------------------------------------------------
-DialogCubicBezierPath::DialogCubicBezierPath(const VContainer *data, quint32 toolId, QWidget *parent)
-    : DialogTool(data, toolId, parent),
-      ui(new Ui::DialogCubicBezierPath),
-      path(),
-      newDuplicate(-1),
-      flagError(false)
+DialogCubicBezierPath::DialogCubicBezierPath(const VContainer *data, VAbstractPattern *doc, quint32 toolId,
+                                             QWidget *parent)
+  : DialogTool(data, doc, toolId, parent),
+    ui(new Ui::DialogCubicBezierPath),
+    path(),
+    newDuplicate(-1),
+    flagError(false)
 {
     ui->setupUi(this);
 
     InitOkCancelApply(ui);
     bOk->setEnabled(false);
 
+    FillComboBoxPoints(ui->comboBoxNewPoint);
     FillComboBoxPoints(ui->comboBoxPoint);
     FillComboBoxLineColors(ui->comboBoxColor);
-    FillComboBoxTypeLine(ui->comboBoxPenStyle, CurvePenStylesPics());
+    FillComboBoxTypeLine(ui->comboBoxPenStyle,
+                         CurvePenStylesPics(ui->comboBoxPenStyle->palette().color(QPalette::Base),
+                                            ui->comboBoxPenStyle->palette().color(QPalette::Text)));
 
     ui->doubleSpinBoxApproximationScale->setMaximum(maxCurveApproximationScale);
 
     connect(ui->listWidget, &QListWidget::currentRowChanged, this, &DialogCubicBezierPath::PointChanged);
-    connect(ui->comboBoxPoint, QOverload<int>::of(&QComboBox::currentIndexChanged),
-            this, &DialogCubicBezierPath::currentPointChanged);
+    connect(ui->comboBoxPoint, QOverload<int>::of(&QComboBox::currentIndexChanged), this,
+            &DialogCubicBezierPath::currentPointChanged);
+    connect(ui->comboBoxNewPoint, QOverload<int>::of(&QComboBox::currentIndexChanged), this,
+            &DialogCubicBezierPath::NewPointChanged);
+
+    connect(ui->toolButtonAddPoint, &QToolButton::clicked, this, &DialogCubicBezierPath::AddPoint);
+    connect(ui->toolButtonRemovePoint, &QToolButton::clicked, this, &DialogCubicBezierPath::RemovePoint);
+
+    connect(ui->toolButtonTop, &QToolButton::clicked, this, &DialogCubicBezierPath::MoveTop);
+    connect(ui->toolButtonUp, &QToolButton::clicked, this, &DialogCubicBezierPath::MoveUp);
+    connect(ui->toolButtonDown, &QToolButton::clicked, this, &DialogCubicBezierPath::MoveDown);
+    connect(ui->toolButtonBottom, &QToolButton::clicked, this, &DialogCubicBezierPath::MoveBottom);
 
     connect(ui->lineEditAlias, &QLineEdit::textEdited, this, &DialogCubicBezierPath::ValidateAlias);
 
@@ -97,7 +106,7 @@ DialogCubicBezierPath::~DialogCubicBezierPath()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VCubicBezierPath DialogCubicBezierPath::GetPath() const
+auto DialogCubicBezierPath::GetPath() const -> VCubicBezierPath
 {
     return path;
 }
@@ -123,7 +132,7 @@ void DialogCubicBezierPath::SetPath(const VCubicBezierPath &value)
     ChangeCurrentData(ui->comboBoxPenStyle, path.GetPenStyle());
     ChangeCurrentData(ui->comboBoxColor, path.GetColor());
 
-    auto visPath = qobject_cast<VisToolCubicBezierPath *>(vis);
+    auto *visPath = qobject_cast<VisToolCubicBezierPath *>(vis);
     SCASSERT(visPath != nullptr)
     visPath->SetPath(path);
     ui->listWidget->blockSignals(false);
@@ -134,6 +143,9 @@ void DialogCubicBezierPath::SetPath(const VCubicBezierPath &value)
     }
 
     ValidatePath();
+
+    ui->toolButtonRemovePoint->setEnabled(ui->listWidget->count() > 7);
+    MoveControls();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -151,15 +163,14 @@ void DialogCubicBezierPath::ChosenObject(quint32 id, const SceneObject &type)
 
         SavePath();
 
-        auto visPath = qobject_cast<VisToolCubicBezierPath *>(vis);
+        auto *visPath = qobject_cast<VisToolCubicBezierPath *>(vis);
         SCASSERT(visPath != nullptr)
         visPath->SetPath(path);
 
         if (path.CountPoints() == 1)
         {
             visPath->VisualMode(NULL_ID);
-            VAbstractMainWindow *window =
-                    qobject_cast<VAbstractMainWindow *>(VAbstractValApplication::VApp()->getMainWindow());
+            auto *window = qobject_cast<VAbstractMainWindow *>(VAbstractValApplication::VApp()->getMainWindow());
             SCASSERT(window != nullptr)
             connect(visPath, &VisToolCubicBezierPath::ToolTip, window, &VAbstractMainWindow::ShowToolTip);
         }
@@ -173,23 +184,23 @@ void DialogCubicBezierPath::ChosenObject(quint32 id, const SceneObject &type)
 //---------------------------------------------------------------------------------------------------------------------
 void DialogCubicBezierPath::ShowDialog(bool click)
 {
-    if (click == false)
+    if (click)
     {
-        const int size = path.CountPoints();
-        if (size >= 7)
+        return;
+    }
+
+    const auto size = path.CountPoints();
+    if (size >= 7 && size - VCubicBezierPath::SubSplPointsCount(path.CountSubSpl()) == 0)
+    {
+        // Accept only if all subpaths are completed
+        emit ToolTip(QString());
+
+        if (not data->IsUnique(path.name()))
         {
-            if (size - VCubicBezierPath::SubSplPointsCount(path.CountSubSpl()) == 0)
-            {// Accept only if all subpaths are completed
-                emit ToolTip(QString());
-
-                if (not data->IsUnique(path.name()))
-                {
-                    path.SetDuplicate(DNumber(path.name()));
-                }
-
-                DialogAccepted();
-            }
+            path.SetDuplicate(DNumber(path.name()));
         }
+
+        DialogAccepted();
     }
 }
 
@@ -202,7 +213,7 @@ void DialogCubicBezierPath::ShowVisualization()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogCubicBezierPath::SaveData()
 {
-    const quint32 d = path.GetDuplicate();//Save previous value
+    const quint32 d = path.GetDuplicate(); // Save previous value
     SavePath();
     newDuplicate <= -1 ? path.SetDuplicate(d) : path.SetDuplicate(static_cast<quint32>(newDuplicate));
 
@@ -211,7 +222,7 @@ void DialogCubicBezierPath::SaveData()
     path.SetApproximationScale(ui->doubleSpinBoxApproximationScale->value());
     path.SetAliasSuffix(ui->lineEditAlias->text());
 
-    auto visPath = qobject_cast<VisToolCubicBezierPath *>(vis);
+    auto *visPath = qobject_cast<VisToolCubicBezierPath *>(vis);
     SCASSERT(visPath != nullptr)
     visPath->SetPath(path);
     visPath->SetMode(Mode::Show);
@@ -223,9 +234,15 @@ void DialogCubicBezierPath::PointChanged(int row)
 {
     if (ui->listWidget->count() == 0)
     {
+        ui->toolButtonTop->setEnabled(false);
+        ui->toolButtonUp->setEnabled(false);
+        ui->toolButtonDown->setEnabled(false);
+        ui->toolButtonBottom->setEnabled(false);
         return;
     }
 
+    MoveControls();
+
     const auto p = qvariant_cast<VPointF>(ui->listWidget->item(row)->data(Qt::UserRole));
     DataPoint(p);
 }
@@ -233,11 +250,11 @@ void DialogCubicBezierPath::PointChanged(int row)
 //---------------------------------------------------------------------------------------------------------------------
 void DialogCubicBezierPath::currentPointChanged(int index)
 {
-    const quint32 id = qvariant_cast<quint32>(ui->comboBoxPoint->itemData(index));
+    const auto id = qvariant_cast<quint32>(ui->comboBoxPoint->itemData(index));
 
     try
     {
-        QListWidgetItem *item = ui->listWidget->item( ui->listWidget->currentRow() );
+        QListWidgetItem *item = ui->listWidget->item(ui->listWidget->currentRow());
         const auto point = data->GeometricObject<VPointF>(id);
         DataPoint(*point);
         item->setData(Qt::UserRole, QVariant::fromValue(*point));
@@ -258,10 +275,10 @@ void DialogCubicBezierPath::currentPointChanged(int index)
 //---------------------------------------------------------------------------------------------------------------------
 void DialogCubicBezierPath::ValidateAlias()
 {
-    QRegularExpression rx(NameRegExp());
     VCubicBezierPath tempPath = path;
     tempPath.SetAliasSuffix(ui->lineEditAlias->text());
-    if (not ui->lineEditAlias->text().isEmpty() &&
+    if (QRegularExpression const rx(NameRegExp());
+        not ui->lineEditAlias->text().isEmpty() &&
         (not rx.match(tempPath.GetAlias()).hasMatch() ||
          (originAliasSuffix != ui->lineEditAlias->text() && not data->IsUnique(tempPath.GetAlias()))))
     {
@@ -277,10 +294,92 @@ void DialogCubicBezierPath::ValidateAlias()
     CheckState();
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void DialogCubicBezierPath::NewPointChanged()
+{
+    ui->toolButtonAddPoint->setEnabled(ui->comboBoxNewPoint->currentIndex() != -1);
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void DialogCubicBezierPath::AddPoint()
+{
+    const auto id = qvariant_cast<quint32>(ui->comboBoxNewPoint->currentData());
+    const auto point = data->GeometricObject<VPointF>(id);
+    NewItem(*point);
+    SavePath();
+
+    flagError = IsPathValid();
+    CheckState(); // Disable Ok and Apply buttons if something wrong.
+
+    ui->comboBoxNewPoint->blockSignals(true);
+    ui->comboBoxNewPoint->setCurrentIndex(-1);
+    ui->comboBoxNewPoint->blockSignals(false);
+    ui->toolButtonAddPoint->setDisabled(true);
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void DialogCubicBezierPath::RemovePoint()
+{
+    if (ui->listWidget->count() <= 7)
+    {
+        ui->toolButtonRemovePoint->setDisabled(true);
+        return;
+    }
+
+    QListWidgetItem *selectedItem = ui->listWidget->currentItem();
+    if (selectedItem)
+    {
+        delete ui->listWidget->takeItem(ui->listWidget->row(selectedItem));
+        ui->listWidget->setCurrentRow(0);
+        ui->toolButtonRemovePoint->setDisabled(ui->listWidget->count() <= 7);
+    }
+
+    SavePath();
+
+    flagError = IsPathValid();
+    CheckState(); // Disable Ok and Apply buttons if something wrong.
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void DialogCubicBezierPath::MoveTop()
+{
+    MoveListRowTop(ui->listWidget);
+    SavePath();
+    flagError = IsPathValid();
+    CheckState(); // Disable Ok and Apply buttons if something wrong.
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void DialogCubicBezierPath::MoveUp()
+{
+    MoveListRowUp(ui->listWidget);
+    SavePath();
+    flagError = IsPathValid();
+    CheckState(); // Disable Ok and Apply buttons if something wrong.
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void DialogCubicBezierPath::MoveDown()
+{
+    MoveListRowDown(ui->listWidget);
+    SavePath();
+    flagError = IsPathValid();
+    CheckState(); // Disable Ok and Apply buttons if something wrong.
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void DialogCubicBezierPath::MoveBottom()
+{
+    MoveListRowBottom(ui->listWidget);
+    SavePath();
+    flagError = IsPathValid();
+    CheckState(); // Disable Ok and Apply buttons if something wrong.
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void DialogCubicBezierPath::NewItem(const VPointF &point)
 {
-    auto* item = new QListWidgetItem(point.name());
+    auto *item = new QListWidgetItem(point.name());
     item->setFont(NodeFont(item->font()));
     item->setData(Qt::UserRole, QVariant::fromValue(point));
 
@@ -311,28 +410,29 @@ void DialogCubicBezierPath::SavePath()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QSet<quint32> DialogCubicBezierPath::AllPathBackboneIds() const
+auto DialogCubicBezierPath::AllPathBackboneIds() const -> QSet<quint32>
 {
     QVector<quint32> points;
+    points.reserve(ui->listWidget->count());
     for (qint32 i = 0; i < ui->listWidget->count(); ++i)
     {
         points.append(qvariant_cast<VPointF>(ui->listWidget->item(i)->data(Qt::UserRole)).id());
     }
 
     QSet<quint32> ids;
-    const qint32 count = VCubicBezierPath::CountSubSpl(points.size());// Count subpaths
+    const auto count = VCubicBezierPath::CountSubSpl(points.size()); // Count subpaths
     for (qint32 i = 1; i <= count; ++i)
     {
-        const qint32 base = VCubicBezierPath::SubSplOffset(i);
-        ids.insert(points.at(base));// The first subpath's point
-        ids.insert(points.at(base + 3));// The last subpath's point
+        const auto base = VCubicBezierPath::SubSplOffset(i);
+        ids.insert(points.at(base));     // The first subpath's point
+        ids.insert(points.at(base + 3)); // The last subpath's point
     }
 
     return ids;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool DialogCubicBezierPath::IsPathValid() const
+auto DialogCubicBezierPath::IsPathValid() const -> bool
 {
     if (path.CountPoints() < 7)
     {
@@ -343,9 +443,10 @@ bool DialogCubicBezierPath::IsPathValid() const
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VCubicBezierPath DialogCubicBezierPath::ExtractPath() const
+auto DialogCubicBezierPath::ExtractPath() const -> VCubicBezierPath
 {
     QVector<VPointF> points;
+    points.reserve(ui->listWidget->count());
     for (qint32 i = 0; i < ui->listWidget->count(); ++i)
     {
         points.append(qvariant_cast<VPointF>(ui->listWidget->item(i)->data(Qt::UserRole)));
@@ -371,9 +472,9 @@ void DialogCubicBezierPath::ValidatePath()
         color = OkColor(this);
 
         auto first = qvariant_cast<VPointF>(ui->listWidget->item(0)->data(Qt::UserRole));
-        auto last = qvariant_cast<VPointF>(ui->listWidget->item(ui->listWidget->count()-1)->data(Qt::UserRole));
+        auto last = qvariant_cast<VPointF>(ui->listWidget->item(ui->listWidget->count() - 1)->data(Qt::UserRole));
 
-        if (first.id() == path.at(0).id() && last.id() == path.at(path.CountPoints()-1).id())
+        if (first.id() == path.at(0).id() && last.id() == path.at(path.CountPoints() - 1).id())
         {
             newDuplicate = -1;
             ui->lineEditSplPathName->setText(VAbstractApplication::VApp()->TrVars()->VarToUser(path.name()));
@@ -396,6 +497,17 @@ void DialogCubicBezierPath::ValidatePath()
     ChangeColor(ui->labelPoint, color);
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void DialogCubicBezierPath::MoveControls()
+{
+    const int index = ui->listWidget->currentRow();
+
+    ui->toolButtonTop->setEnabled(index > 0);
+    ui->toolButtonUp->setEnabled(index > 0);
+    ui->toolButtonDown->setEnabled(index != -1 && index < ui->listWidget->count() - 1);
+    ui->toolButtonBottom->setEnabled(index != -1 && index < ui->listWidget->count() - 1);
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void DialogCubicBezierPath::SetNotes(const QString &notes)
 {
@@ -403,7 +515,7 @@ void DialogCubicBezierPath::SetNotes(const QString &notes)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogCubicBezierPath::GetNotes() const
+auto DialogCubicBezierPath::GetNotes() const -> QString
 {
     return ui->plainTextEditToolNotes->toPlainText();
 }
