@@ -29,7 +29,6 @@
 #ifndef DIALOGCUBICBEZIERPATH_H
 #define DIALOGCUBICBEZIERPATH_H
 
-#include <qcompilerdetection.h>
 #include <QMetaObject>
 #include <QObject>
 #include <QSet>
@@ -43,33 +42,46 @@
 
 namespace Ui
 {
-    class DialogCubicBezierPath;
+class DialogCubicBezierPath;
 }
 
-class DialogCubicBezierPath : public DialogTool
+class DialogCubicBezierPath final : public DialogTool
 {
     Q_OBJECT // NOLINT
 
 public:
-    explicit DialogCubicBezierPath(const VContainer *data, quint32 toolId, QWidget *parent = nullptr);
-    virtual ~DialogCubicBezierPath();
+    explicit DialogCubicBezierPath(const VContainer *data, VAbstractPattern *doc, quint32 toolId,
+                                   QWidget *parent = nullptr);
+    ~DialogCubicBezierPath() override;
 
-    VCubicBezierPath GetPath() const;
-    void             SetPath(const VCubicBezierPath &value);
+    auto GetPath() const -> VCubicBezierPath;
+    void SetPath(const VCubicBezierPath &value);
+
+    void SetNotes(const QString &notes);
+    auto GetNotes() const -> QString;
 
-    void    SetNotes(const QString &notes);
-    QString GetNotes() const;
 public slots:
-    virtual void ChosenObject(quint32 id, const SceneObject &type) override;
-    virtual void ShowDialog(bool click) override;
+    void ChosenObject(quint32 id, const SceneObject &type) override;
+    void ShowDialog(bool click) override;
+
 protected:
-    virtual void ShowVisualization() override;
-    virtual void SaveData() override;
-    virtual bool IsValid() const final;
+    void ShowVisualization() override;
+    void SaveData() override;
+    auto IsValid() const -> bool override;
+
 private slots:
     void PointChanged(int row);
     void currentPointChanged(int index);
     void ValidateAlias();
+    void NewPointChanged();
+
+    void AddPoint();
+    void RemovePoint();
+
+    void MoveTop();
+    void MoveUp();
+    void MoveDown();
+    void MoveBottom();
 
 private:
     Q_DISABLE_COPY_MOVE(DialogCubicBezierPath) // NOLINT
@@ -85,17 +97,18 @@ private:
 
     QString originAliasSuffix{};
 
-    void             NewItem(const VPointF &point);
-    void             DataPoint(const VPointF &p);
-    void             SavePath();
-    QSet<quint32>    AllPathBackboneIds() const;
-    bool             IsPathValid() const;
-    VCubicBezierPath ExtractPath() const;
-    void             ValidatePath();
+    void NewItem(const VPointF &point);
+    void DataPoint(const VPointF &p);
+    void SavePath();
+    auto AllPathBackboneIds() const -> QSet<quint32>;
+    auto IsPathValid() const -> bool;
+    auto ExtractPath() const -> VCubicBezierPath;
+    void ValidatePath();
+    void MoveControls();
 };
 
 //---------------------------------------------------------------------------------------------------------------------
-inline bool DialogCubicBezierPath::IsValid() const
+inline auto DialogCubicBezierPath::IsValid() const -> bool
 {
     return flagError && flagAlias;
 }
