@@ -40,42 +40,46 @@
 #include <QToolButton>
 #include <new>
 
-#include "../vgeometry/vpointf.h"
-#include "../vpatterndb/vcontainer.h"
-#include "../vpatterndb/vtranslatevars.h"
-#include "../vwidgets/vmaingraphicsscene.h"
-#include "../vwidgets/vabstractmainwindow.h"
 #include "../../visualization/line/vistoolcurveintersectaxis.h"
 #include "../../visualization/visualization.h"
+#include "../dialogtoolbox.h"
 #include "../ifc/xml/vabstractpattern.h"
+#include "../qmuparser/qmudef.h"
 #include "../support/dialogeditwrongformula.h"
+#include "../vgeometry/vpointf.h"
+#include "../vmisc/theme/vtheme.h"
 #include "../vmisc/vabstractapplication.h"
 #include "../vmisc/vcommonsettings.h"
-#include "../qmuparser/qmudef.h"
-#include "../dialogtoolbox.h"
-#include "ui_dialogcurveintersectaxis.h"
+#include "../vpatterndb/vcontainer.h"
+#include "../vpatterndb/vtranslatevars.h"
 #include "../vwidgets/global.h"
+#include "../vwidgets/vabstractmainwindow.h"
+#include "../vwidgets/vmaingraphicsscene.h"
+#include "ui_dialogcurveintersectaxis.h"
 
 //---------------------------------------------------------------------------------------------------------------------
-DialogCurveIntersectAxis::DialogCurveIntersectAxis(const VContainer *data, quint32 toolId, QWidget *parent)
-    : DialogTool(data, toolId, parent),
-      ui(new Ui::DialogCurveIntersectAxis),
-      formulaAngle(),
-      formulaBaseHeightAngle(0),
-      pointName(),
-      m_firstRelease(false),
-      timerFormula(new QTimer(this)),
-      flagFormula(false),
-      flagName(true)
+DialogCurveIntersectAxis::DialogCurveIntersectAxis(const VContainer *data, VAbstractPattern *doc, quint32 toolId,
+                                                   QWidget *parent)
+  : DialogTool(data, doc, toolId, parent),
+    ui(new Ui::DialogCurveIntersectAxis),
+    formulaAngle(),
+    formulaBaseHeightAngle(0),
+    pointName(),
+    m_firstRelease(false),
+    timerFormula(new QTimer(this)),
+    flagFormula(false),
+    flagName(true)
 {
     ui->setupUi(this);
 
+    InitIcons();
+
     timerFormula->setSingleShot(true);
 
     ui->lineEditNamePoint->setClearButtonEnabled(true);
 
     ui->lineEditNamePoint->setText(
-                VAbstractValApplication::VApp()->getCurrentDocument()->GenerateLabel(LabelType::NewLabel));
+        VAbstractValApplication::VApp()->getCurrentDocument()->GenerateLabel(LabelType::NewLabel));
     formulaBaseHeightAngle = ui->plainTextEditFormula->height();
     ui->plainTextEditFormula->installEventFilter(this);
 
@@ -83,19 +87,19 @@ DialogCurveIntersectAxis::DialogCurveIntersectAxis(const VContainer *data, quint
 
     FillComboBoxPoints(ui->comboBoxAxisPoint);
     FillComboBoxCurves(ui->comboBoxCurve);
-    FillComboBoxTypeLine(ui->comboBoxLineType, LineStylesPics());
+    FillComboBoxTypeLine(ui->comboBoxLineType, LineStylesPics(ui->comboBoxLineType->palette().color(QPalette::Base),
+                                                              ui->comboBoxLineType->palette().color(QPalette::Text)));
     FillComboBoxLineColors(ui->comboBoxLineColor);
 
     connect(ui->toolButtonExprAngle, &QPushButton::clicked, this, &DialogCurveIntersectAxis::FXAngle);
-    connect(ui->lineEditNamePoint, &QLineEdit::textChanged, this, [this]()
-    {
-        CheckPointLabel(this, ui->lineEditNamePoint, ui->labelEditNamePoint, pointName, this->data, flagName);
-        CheckState();
-    });
-    connect(ui->plainTextEditFormula, &QPlainTextEdit::textChanged, this, [this]()
-    {
-        timerFormula->start(formulaTimerTimeout);
-    });
+    connect(ui->lineEditNamePoint, &QLineEdit::textChanged, this,
+            [this]()
+            {
+                CheckPointLabel(this, ui->lineEditNamePoint, ui->labelEditNamePoint, pointName, this->data, flagName);
+                CheckState();
+            });
+    connect(ui->plainTextEditFormula, &QPlainTextEdit::textChanged, this,
+            [this]() { timerFormula->start(formulaTimerTimeout); });
     connect(ui->pushButtonGrowLengthAngle, &QPushButton::clicked, this, &DialogCurveIntersectAxis::DeployAngleTextEdit);
     connect(timerFormula, &QTimer::timeout, this, &DialogCurveIntersectAxis::EvalAngle);
     connect(ui->lineEditAlias1, &QLineEdit::textEdited, this, &DialogCurveIntersectAxis::ValidateAlias);
@@ -114,7 +118,7 @@ DialogCurveIntersectAxis::~DialogCurveIntersectAxis()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogCurveIntersectAxis::GetPointName() const
+auto DialogCurveIntersectAxis::GetPointName() const -> QString
 {
     return pointName;
 }
@@ -127,7 +131,7 @@ void DialogCurveIntersectAxis::SetPointName(const QString &value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogCurveIntersectAxis::GetTypeLine() const
+auto DialogCurveIntersectAxis::GetTypeLine() const -> QString
 {
     return GetComboBoxCurrentData(ui->comboBoxLineType, TypeLineLine);
 }
@@ -140,7 +144,7 @@ void DialogCurveIntersectAxis::SetTypeLine(const QString &value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogCurveIntersectAxis::GetAngle() const
+auto DialogCurveIntersectAxis::GetAngle() const -> QString
 {
     return VTranslateVars::TryFormulaFromUser(formulaAngle, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
 }
@@ -148,8 +152,8 @@ QString DialogCurveIntersectAxis::GetAngle() const
 //---------------------------------------------------------------------------------------------------------------------
 void DialogCurveIntersectAxis::SetAngle(const QString &value)
 {
-    formulaAngle = VAbstractApplication::VApp()->TrVars()
-            ->FormulaToUser(value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    formulaAngle = VAbstractApplication::VApp()->TrVars()->FormulaToUser(
+        value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
     // increase height if needed. TODO : see if I can get the max number of caracters in one line
     // of this PlainTextEdit to change 80 to this value
     if (formulaAngle.length() > 80)
@@ -158,7 +162,7 @@ void DialogCurveIntersectAxis::SetAngle(const QString &value)
     }
     ui->plainTextEditFormula->setPlainText(formulaAngle);
 
-    VisToolCurveIntersectAxis *line = qobject_cast<VisToolCurveIntersectAxis *>(vis);
+    auto *line = qobject_cast<VisToolCurveIntersectAxis *>(vis);
     SCASSERT(line != nullptr)
     line->SetAngle(formulaAngle);
 
@@ -166,7 +170,7 @@ void DialogCurveIntersectAxis::SetAngle(const QString &value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-quint32 DialogCurveIntersectAxis::GetBasePointId() const
+auto DialogCurveIntersectAxis::GetBasePointId() const -> quint32
 {
     return getCurrentObjectId(ui->comboBoxAxisPoint);
 }
@@ -176,13 +180,13 @@ void DialogCurveIntersectAxis::SetBasePointId(quint32 value)
 {
     setCurrentPointId(ui->comboBoxAxisPoint, value);
 
-    VisToolCurveIntersectAxis *line = qobject_cast<VisToolCurveIntersectAxis *>(vis);
+    auto *line = qobject_cast<VisToolCurveIntersectAxis *>(vis);
     SCASSERT(line != nullptr)
     line->setAxisPointId(value);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-quint32 DialogCurveIntersectAxis::getCurveId() const
+auto DialogCurveIntersectAxis::getCurveId() const -> quint32
 {
     return getCurrentObjectId(ui->comboBoxCurve);
 }
@@ -192,13 +196,13 @@ void DialogCurveIntersectAxis::setCurveId(quint32 value)
 {
     setCurrentCurveId(ui->comboBoxCurve, value);
 
-    VisToolCurveIntersectAxis *line = qobject_cast<VisToolCurveIntersectAxis *>(vis);
+    auto *line = qobject_cast<VisToolCurveIntersectAxis *>(vis);
     SCASSERT(line != nullptr)
     line->SetCurveId(value);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogCurveIntersectAxis::GetLineColor() const
+auto DialogCurveIntersectAxis::GetLineColor() const -> QString
 {
     return GetComboBoxCurrentData(ui->comboBoxLineColor, ColorBlack);
 }
@@ -225,65 +229,63 @@ void DialogCurveIntersectAxis::ShowDialog(bool click)
             }
 
             /*We will ignore click if poinet is in point circle*/
-            VMainGraphicsScene *scene =
-                    qobject_cast<VMainGraphicsScene *>(VAbstractValApplication::VApp()->getCurrentScene());
+            auto *scene = qobject_cast<VMainGraphicsScene *>(VAbstractValApplication::VApp()->getCurrentScene());
             SCASSERT(scene != nullptr)
             const QSharedPointer<VPointF> point = data->GeometricObject<VPointF>(GetBasePointId());
-            QLineF line = QLineF(static_cast<QPointF>(*point), scene->getScenePos());
+            auto const line = QLineF(static_cast<QPointF>(*point), scene->getScenePos());
 
-            //Radius of point circle, but little bigger. Need handle with hover sizes.
-            if (line.length() <= ScaledRadius(SceneScale(VAbstractValApplication::VApp()->getCurrentScene()))*1.5)
+            // Radius of point circle, but little bigger. Need handle with hover sizes.
+            if (line.length() <= ScaledRadius(SceneScale(VAbstractValApplication::VApp()->getCurrentScene())) * 1.5)
             {
                 return;
             }
         }
 
-        VisToolCurveIntersectAxis *line = qobject_cast<VisToolCurveIntersectAxis *>(vis);
+        auto *line = qobject_cast<VisToolCurveIntersectAxis *>(vis);
         SCASSERT(line != nullptr)
+        SetAngle(line->Angle()); // Show in dialog angle what user choose
 
-        this->SetAngle(line->Angle());//Show in dialog angle what user choose
         emit ToolTip(QString());
-
-        DialogAccepted();// Just set default values and don't show dialog
+        DialogAccepted(); // Just set default values and don't show dialog
     }
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void DialogCurveIntersectAxis::ChosenObject(quint32 id, const SceneObject &type)
 {
-    if (prepare == false)// After first choose we ignore all objects
+    if (prepare == false) // After first choose we ignore all objects
     {
-        VisToolCurveIntersectAxis *line = qobject_cast<VisToolCurveIntersectAxis *>(vis);
+        auto *line = qobject_cast<VisToolCurveIntersectAxis *>(vis);
         SCASSERT(line != nullptr)
 
         switch (number)
         {
             case (0):
-                if (type == SceneObject::Spline
-                        || type == SceneObject::Arc
-                        || type == SceneObject::ElArc
-                        || type == SceneObject::SplinePath)
+                if ((type == SceneObject::Spline || type == SceneObject::Arc || type == SceneObject::ElArc ||
+                     type == SceneObject::SplinePath) &&
+                    SetObject(id, ui->comboBoxCurve, tr("Select axis point")))
                 {
-                    if (SetObject(id, ui->comboBoxCurve, tr("Select axis point")))
-                    {
-                        number++;
-                        line->VisualMode(id);
-                        VAbstractMainWindow *window =
-                                qobject_cast<VAbstractMainWindow *>(VAbstractValApplication::VApp()->getMainWindow());
-                        SCASSERT(window != nullptr)
-                        connect(line, &VisToolCurveIntersectAxis::ToolTip, window, &VAbstractMainWindow::ShowToolTip);
-
-                    }
+                    number++;
+                    line->VisualMode(id);
+                    auto *window =
+                        qobject_cast<VAbstractMainWindow *>(VAbstractValApplication::VApp()->getMainWindow());
+                    SCASSERT(window != nullptr)
+                    connect(line, &VisToolCurveIntersectAxis::ToolTip, window, &VAbstractMainWindow::ShowToolTip);
                 }
                 break;
             case (1):
-                if (type == SceneObject::Point)
+                if (type == SceneObject::Point && SetObject(id, ui->comboBoxAxisPoint, QString()))
                 {
-                    if (SetObject(id, ui->comboBoxAxisPoint, QString()))
+                    line->setAxisPointId(id);
+                    line->RefreshGeometry();
+                    prepare = true;
+
+                    if (not VAbstractValApplication::VApp()->Settings()->IsInteractiveTools())
                     {
-                        line->setAxisPointId(id);
-                        line->RefreshGeometry();
-                        prepare = true;
+                        emit ToolTip(QString());
+
+                        setModal(true);
+                        show();
                     }
                 }
                 break;
@@ -302,7 +304,6 @@ void DialogCurveIntersectAxis::EvalAngle()
     formulaData.labelEditFormula = ui->labelEditFormula;
     formulaData.labelResult = ui->labelResultCalculation;
     formulaData.postfix = degreeSymbol;
-    formulaData.checkZero = false;
 
     Eval(formulaData, flagFormula);
 }
@@ -316,7 +317,7 @@ void DialogCurveIntersectAxis::DeployAngleTextEdit()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogCurveIntersectAxis::FXAngle()
 {
-    DialogEditWrongFormula *dialog = new DialogEditWrongFormula(data, toolId, this);
+    auto *dialog = new DialogEditWrongFormula(data, toolId, this);
     dialog->setWindowTitle(tr("Edit angle"));
     dialog->SetFormula(GetAngle());
     dialog->setPostfix(degreeSymbol);
@@ -339,7 +340,7 @@ void DialogCurveIntersectAxis::SaveData()
     pointName = ui->lineEditNamePoint->text();
     formulaAngle = ui->plainTextEditFormula->toPlainText();
 
-    VisToolCurveIntersectAxis *line = qobject_cast<VisToolCurveIntersectAxis *>(vis);
+    auto *line = qobject_cast<VisToolCurveIntersectAxis *>(vis);
     SCASSERT(line != nullptr)
 
     line->SetCurveId(getCurveId());
@@ -356,19 +357,35 @@ void DialogCurveIntersectAxis::closeEvent(QCloseEvent *event)
     DialogTool::closeEvent(event);
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void DialogCurveIntersectAxis::changeEvent(QEvent *event)
+{
+    if (event->type() == QEvent::LanguageChange)
+    {
+        ui->retranslateUi(this);
+    }
+
+    if (event->type() == QEvent::PaletteChange)
+    {
+        InitIcons();
+        InitDialogButtonBoxIcons(ui->buttonBox);
+    }
+
+    // remember to call base class implementation
+    DialogTool::changeEvent(event);
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void DialogCurveIntersectAxis::ValidateAlias()
 {
-    QRegularExpression rx(NameRegExp());
+    QRegularExpression const rx(NameRegExp());
 
     const QSharedPointer<VAbstractCurve> curve = data->GeometricObject<VAbstractCurve>(getCurveId());
-    QPair<QString, QString> alias = SegmentAliases(curve->getType(), GetAliasSuffix1(), GetAliasSuffix2());
-
+    auto const [aliasFirst, aliasSecond] = SegmentAliases(curve->getType(), GetAliasSuffix1(), GetAliasSuffix2());
 
     if (not GetAliasSuffix1().isEmpty() &&
-        (not rx.match(alias.first).hasMatch() ||
-         (originAliasSuffix1 != GetAliasSuffix1() && not data->IsUnique(alias.first)) ||
-         alias.first == alias.second))
+        (not rx.match(aliasFirst).hasMatch() ||
+         (originAliasSuffix1 != GetAliasSuffix1() && not data->IsUnique(aliasFirst)) || aliasFirst == aliasSecond))
     {
         flagAlias1 = false;
         ChangeColor(ui->labelAlias1, errorColor);
@@ -380,9 +397,8 @@ void DialogCurveIntersectAxis::ValidateAlias()
     }
 
     if (not GetAliasSuffix2().isEmpty() &&
-        (not rx.match(alias.second).hasMatch() ||
-         (originAliasSuffix2 != GetAliasSuffix2() && not data->IsUnique(alias.second)) ||
-         alias.first == alias.second))
+        (not rx.match(aliasSecond).hasMatch() ||
+         (originAliasSuffix2 != GetAliasSuffix2() && not data->IsUnique(aliasSecond)) || aliasFirst == aliasSecond))
     {
         flagAlias2 = false;
         ChangeColor(ui->labelAlias2, errorColor);
@@ -396,6 +412,15 @@ void DialogCurveIntersectAxis::ValidateAlias()
     CheckState();
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void DialogCurveIntersectAxis::InitIcons()
+{
+    auto const resource = QStringLiteral("icon");
+
+    ui->toolButtonExprAngle->setIcon(VTheme::GetIconResource(resource, QStringLiteral("24x24/fx.png")));
+    ui->label_3->setPixmap(VTheme::GetPixmapResource(resource, QStringLiteral("24x24/equal.png")));
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void DialogCurveIntersectAxis::SetNotes(const QString &notes)
 {
@@ -403,7 +428,7 @@ void DialogCurveIntersectAxis::SetNotes(const QString &notes)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogCurveIntersectAxis::GetNotes() const
+auto DialogCurveIntersectAxis::GetNotes() const -> QString
 {
     return ui->plainTextEditToolNotes->toPlainText();
 }
@@ -417,7 +442,7 @@ void DialogCurveIntersectAxis::SetAliasSuffix1(const QString &alias)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogCurveIntersectAxis::GetAliasSuffix1() const
+auto DialogCurveIntersectAxis::GetAliasSuffix1() const -> QString
 {
     return ui->lineEditAlias1->text();
 }
@@ -431,7 +456,7 @@ void DialogCurveIntersectAxis::SetAliasSuffix2(const QString &alias)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogCurveIntersectAxis::GetAliasSuffix2() const
+auto DialogCurveIntersectAxis::GetAliasSuffix2() const -> QString
 {
     return ui->lineEditAlias2->text();
 }
