@@ -42,32 +42,27 @@
 #include <QSharedPointer>
 #include <QStringList>
 #include <QToolButton>
-#include <Qt>
-#include <new>
 
-#include "../../visualization/visualization.h"
+#include "../../tools/drawTools/operation/vabstractoperation.h"
 #include "../../visualization/line/operation/vistoolflippingbyaxis.h"
+#include "../../visualization/visualization.h"
 #include "../ifc/xml/vabstractpattern.h"
-#include "../ifc/xml/vdomdocument.h"
 #include "../qmuparser/qmudef.h"
-#if QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
-#include "../vmisc/backport/qoverload.h"
-#endif // QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
 #include "../vpatterndb/vcontainer.h"
 #include "../vwidgets/vmaingraphicsscene.h"
 #include "../vwidgets/vmaingraphicsview.h"
 #include "ui_dialogflippingbyaxis.h"
-#include "../../tools/drawTools/operation/vabstractoperation.h"
 
 //---------------------------------------------------------------------------------------------------------------------
-DialogFlippingByAxis::DialogFlippingByAxis(const VContainer *data, quint32 toolId, QWidget *parent)
-    : DialogTool(data, toolId, parent),
-      ui(new Ui::DialogFlippingByAxis),
-      stage1(true),
-      m_suffix(),
-      flagName(true),
-      flagGroupName(true),
-      flagError(false)
+DialogFlippingByAxis::DialogFlippingByAxis(const VContainer *data, VAbstractPattern *doc, quint32 toolId,
+                                           QWidget *parent)
+  : DialogTool(data, doc, toolId, parent),
+    ui(new Ui::DialogFlippingByAxis),
+    stage1(true),
+    m_suffix(),
+    flagName(true),
+    flagGroupName(true),
+    flagError(false)
 {
     ui->setupUi(this);
 
@@ -77,15 +72,17 @@ DialogFlippingByAxis::DialogFlippingByAxis(const VContainer *data, quint32 toolI
 
     FillComboBoxPoints(ui->comboBoxOriginPoint);
     FillComboBoxAxisType(ui->comboBoxAxisType);
-    FillComboBoxTypeLine(ui->comboBoxPenStyle, OperationLineStylesPics(), TypeLineDefault);
+    FillComboBoxTypeLine(ui->comboBoxPenStyle,
+                         OperationLineStylesPics(ui->comboBoxPenStyle->palette().color(QPalette::Base),
+                                                 ui->comboBoxPenStyle->palette().color(QPalette::Text)),
+                         TypeLineDefault);
     FillComboBoxLineColors(ui->comboBoxColor, VAbstractOperation::OperationColorsList());
 
     ui->comboBoxOriginPoint->setCurrentIndex(-1);
 
     connect(ui->lineEditSuffix, &QLineEdit::textChanged, this, &DialogFlippingByAxis::SuffixChanged);
     connect(ui->lineEditVisibilityGroup, &QLineEdit::textChanged, this, &DialogFlippingByAxis::GroupNameChanged);
-    connect(ui->comboBoxOriginPoint, &QComboBox::currentTextChanged,
-            this, &DialogFlippingByAxis::PointChanged);
+    connect(ui->comboBoxOriginPoint, &QComboBox::currentTextChanged, this, &DialogFlippingByAxis::PointChanged);
 
     connect(ui->listWidget, &QListWidget::currentRowChanged, this, &DialogFlippingByAxis::ShowSourceDetails);
     connect(ui->lineEditAlias, &QLineEdit::textEdited, this, &DialogFlippingByAxis::AliasChanged);
@@ -94,7 +91,6 @@ DialogFlippingByAxis::DialogFlippingByAxis(const VContainer *data, quint32 toolI
     connect(ui->comboBoxColor, QOverload<int>::of(&QComboBox::currentIndexChanged), this,
             &DialogFlippingByAxis::ColorChanged);
 
-
     vis = new VisToolFlippingByAxis(data);
 
     ui->tabWidget->setCurrentIndex(0);
@@ -108,7 +104,7 @@ DialogFlippingByAxis::~DialogFlippingByAxis()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-quint32 DialogFlippingByAxis::GetOriginPointId() const
+auto DialogFlippingByAxis::GetOriginPointId() const -> quint32
 {
     return getCurrentObjectId(ui->comboBoxOriginPoint);
 }
@@ -117,13 +113,13 @@ quint32 DialogFlippingByAxis::GetOriginPointId() const
 void DialogFlippingByAxis::SetOriginPointId(quint32 value)
 {
     ChangeCurrentData(ui->comboBoxOriginPoint, value);
-    VisToolFlippingByAxis *operation = qobject_cast<VisToolFlippingByAxis *>(vis);
+    auto *operation = qobject_cast<VisToolFlippingByAxis *>(vis);
     SCASSERT(operation != nullptr)
     operation->SetOriginPointId(value);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-AxisType DialogFlippingByAxis::GetAxisType() const
+auto DialogFlippingByAxis::GetAxisType() const -> AxisType
 {
     return getCurrentCrossPoint<AxisType>(ui->comboBoxAxisType);
 }
@@ -136,14 +132,14 @@ void DialogFlippingByAxis::SetAxisType(AxisType type)
     {
         ui->comboBoxAxisType->setCurrentIndex(index);
 
-        auto operation = qobject_cast<VisToolFlippingByAxis *>(vis);
+        auto *operation = qobject_cast<VisToolFlippingByAxis *>(vis);
         SCASSERT(operation != nullptr)
         operation->SetAxisType(type);
     }
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogFlippingByAxis::GetSuffix() const
+auto DialogFlippingByAxis::GetSuffix() const -> QString
 {
     return m_suffix;
 }
@@ -156,7 +152,7 @@ void DialogFlippingByAxis::SetSuffix(const QString &value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogFlippingByAxis::GetVisibilityGroupName() const
+auto DialogFlippingByAxis::GetVisibilityGroupName() const -> QString
 {
     return ui->lineEditVisibilityGroup->text();
 }
@@ -168,7 +164,7 @@ void DialogFlippingByAxis::SetVisibilityGroupName(const QString &name)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool DialogFlippingByAxis::HasLinkedVisibilityGroup() const
+auto DialogFlippingByAxis::HasLinkedVisibilityGroup() const -> bool
 {
     return ui->groupBoxVisibilityGroup->isChecked();
 }
@@ -186,7 +182,7 @@ void DialogFlippingByAxis::SetVisibilityGroupTags(const QStringList &tags)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QStringList DialogFlippingByAxis::GetVisibilityGroupTags() const
+auto DialogFlippingByAxis::GetVisibilityGroupTags() const -> QStringList
 {
     return ui->lineEditGroupTags->text().split(',');
 }
@@ -210,12 +206,11 @@ void DialogFlippingByAxis::ShowDialog(bool click)
 
         stage1 = false;
 
-        VMainGraphicsScene *scene =
-                qobject_cast<VMainGraphicsScene *>(VAbstractValApplication::VApp()->getCurrentScene());
+        auto *scene = qobject_cast<VMainGraphicsScene *>(VAbstractValApplication::VApp()->getCurrentScene());
         SCASSERT(scene != nullptr)
         scene->clearSelection();
 
-        VisToolFlippingByAxis *operation = qobject_cast<VisToolFlippingByAxis *>(vis);
+        auto *operation = qobject_cast<VisToolFlippingByAxis *>(vis);
         SCASSERT(operation != nullptr)
         operation->SetObjects(SourceToObjects(sourceObjects));
         operation->VisualMode();
@@ -246,7 +241,7 @@ void DialogFlippingByAxis::ShowDialog(bool click)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QVector<SourceItem> DialogFlippingByAxis::GetSourceObjects() const
+auto DialogFlippingByAxis::GetSourceObjects() const -> QVector<SourceItem>
 {
     return sourceObjects;
 }
@@ -257,7 +252,7 @@ void DialogFlippingByAxis::SetSourceObjects(const QVector<SourceItem> &value)
     sourceObjects = value;
     FillSourceList();
 
-    VisToolFlippingByAxis *operation = qobject_cast<VisToolFlippingByAxis *>(vis);
+    auto *operation = qobject_cast<VisToolFlippingByAxis *>(vis);
     SCASSERT(operation != nullptr)
     operation->SetObjects(SourceToObjects(sourceObjects));
 }
@@ -265,28 +260,25 @@ void DialogFlippingByAxis::SetSourceObjects(const QVector<SourceItem> &value)
 //---------------------------------------------------------------------------------------------------------------------
 void DialogFlippingByAxis::ChosenObject(quint32 id, const SceneObject &type)
 {
-    if (not stage1 && not prepare)// After first choose we ignore all objects
+    if (not stage1 && not prepare && type == SceneObject::Point) // After first choose we ignore all objects
     {
-        if (type == SceneObject::Point)
+        auto obj = std::find_if(sourceObjects.begin(), sourceObjects.end(),
+                                [id](const SourceItem &sItem) { return sItem.id == id; });
+
+        if (obj != sourceObjects.end())
         {
-            auto obj = std::find_if(sourceObjects.begin(), sourceObjects.end(),
-                                    [id](const SourceItem &sItem) { return sItem.id == id; });
+            emit ToolTip(tr("Select origin point that is not part of the list of objects"));
+            return;
+        }
 
-            if (obj != sourceObjects.end())
-            {
-                emit ToolTip(tr("Select origin point that is not part of the list of objects"));
-                return;
-            }
+        if (SetObject(id, ui->comboBoxOriginPoint, QString()))
+        {
+            auto *operation = qobject_cast<VisToolFlippingByAxis *>(vis);
+            SCASSERT(operation != nullptr)
+            operation->SetOriginPointId(id);
+            operation->RefreshGeometry();
 
-            if (SetObject(id, ui->comboBoxOriginPoint, QString()))
-            {
-                VisToolFlippingByAxis *operation = qobject_cast<VisToolFlippingByAxis *>(vis);
-                SCASSERT(operation != nullptr)
-                operation->SetOriginPointId(id);
-                operation->RefreshGeometry();
-
-                prepare = true;
-            }
+            prepare = true;
         }
     }
 }
@@ -321,7 +313,7 @@ void DialogFlippingByAxis::SelectedObject(bool selected, quint32 object, quint32
 //---------------------------------------------------------------------------------------------------------------------
 void DialogFlippingByAxis::SuffixChanged()
 {
-    QLineEdit* edit = qobject_cast<QLineEdit*>(sender());
+    auto *edit = qobject_cast<QLineEdit *>(sender());
     if (edit)
     {
         const QString suffix = edit->text();
@@ -333,23 +325,21 @@ void DialogFlippingByAxis::SuffixChanged()
             CheckState();
             return;
         }
-        else
+
+        if (m_suffix != suffix)
         {
-            if (m_suffix != suffix)
+            QRegularExpression const rx(NameRegExp());
+            const QStringList uniqueNames = data->AllUniqueNames();
+            for (const auto &uniqueName : uniqueNames)
             {
-                QRegularExpression rx(NameRegExp());
-                const QStringList uniqueNames = data->AllUniqueNames();
-                for (auto &uniqueName : uniqueNames)
+                const QString name = uniqueName + suffix;
+                if (not rx.match(name).hasMatch() || not data->IsUnique(name))
                 {
-                    const QString name = uniqueName + suffix;
-                    if (not rx.match(name).hasMatch() || not data->IsUnique(name))
-                    {
-                        flagName = false;
-                        ChangeColor(ui->labelSuffix, errorColor);
-                        ui->labelStatus->setText(tr("Invalid suffix"));
-                        CheckState();
-                        return;
-                    }
+                    flagName = false;
+                    ChangeColor(ui->labelSuffix, errorColor);
+                    ui->labelStatus->setText(tr("Invalid suffix"));
+                    CheckState();
+                    return;
                 }
             }
         }
@@ -363,7 +353,7 @@ void DialogFlippingByAxis::SuffixChanged()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogFlippingByAxis::GroupNameChanged()
 {
-    QLineEdit* edit = qobject_cast<QLineEdit*>(sender());
+    auto *edit = qobject_cast<QLineEdit *>(sender());
     if (edit)
     {
         const QString name = edit->text();
@@ -415,7 +405,7 @@ void DialogFlippingByAxis::ShowSourceDetails(int row)
     {
         ui->labelAlias->setText(tr("Alias:"));
 
-        auto SetValue = [sourceItem](QComboBox *box, const QString &value, const QString &def)
+        auto SetValue = [](QComboBox *box, const QString &value, const QString &def)
         {
             box->blockSignals(true);
 
@@ -437,8 +427,7 @@ void DialogFlippingByAxis::ShowSourceDetails(int row)
 
         if (sourceItem.penStyle.isEmpty() || sourceItem.penStyle == TypeLineDefault)
         {
-            const QSharedPointer<VAbstractCurve> curve = data->GeometricObject<VAbstractCurve>(sourceItem.id);
-            int index = ui->comboBoxPenStyle->currentIndex();
+            int const index = ui->comboBoxPenStyle->currentIndex();
             ui->comboBoxPenStyle->setItemText(index, '<' + tr("Default") + '>');
         }
 
@@ -447,8 +436,9 @@ void DialogFlippingByAxis::ShowSourceDetails(int row)
         if (sourceItem.color.isEmpty() || sourceItem.color == ColorDefault)
         {
             const QSharedPointer<VAbstractCurve> curve = data->GeometricObject<VAbstractCurve>(sourceItem.id);
-            int index = ui->comboBoxColor->currentIndex();
-            ui->comboBoxColor->setItemIcon(index, LineColor(ui->comboBoxColor->iconSize().height(), curve->GetColor()));
+            int const index = ui->comboBoxColor->currentIndex();
+            ui->comboBoxColor->setItemIcon(index, LineColor(ui->comboBoxColor->palette().color(QPalette::Text),
+                                                            ui->comboBoxColor->iconSize().height(), curve->GetColor()));
         }
 
         ui->comboBoxPenStyle->setEnabled(true);
@@ -529,7 +519,7 @@ void DialogFlippingByAxis::SaveData()
     sourceObjects.clear();
     sourceObjects.reserve(ui->listWidget->count());
 
-    for (int i=0; i<ui->listWidget->count(); ++i)
+    for (int i = 0; i < ui->listWidget->count(); ++i)
     {
         if (const QListWidgetItem *item = ui->listWidget->item(i))
         {
@@ -538,7 +528,7 @@ void DialogFlippingByAxis::SaveData()
         }
     }
 
-    VisToolFlippingByAxis *operation = qobject_cast<VisToolFlippingByAxis *>(vis);
+    auto *operation = qobject_cast<VisToolFlippingByAxis *>(vis);
     SCASSERT(operation != nullptr)
 
     operation->SetObjects(SourceToObjects(sourceObjects));
@@ -563,7 +553,7 @@ void DialogFlippingByAxis::SaveData()
 void DialogFlippingByAxis::PointChanged()
 {
     QColor color;
-    quint32 id = getCurrentObjectId(ui->comboBoxOriginPoint);
+    quint32 const id = getCurrentObjectId(ui->comboBoxOriginPoint);
     auto obj = std::find_if(sourceObjects.begin(), sourceObjects.end(),
                             [id](const SourceItem &sItem) { return sItem.id == id; });
     if (obj != sourceObjects.end())
@@ -602,7 +592,7 @@ void DialogFlippingByAxis::FillSourceList()
     for (auto &sourceItem : sourceObjects)
     {
         const QSharedPointer<VGObject> obj = data->GetGObject(sourceItem.id);
-        bool valid = SourceAliasValid(sourceItem, obj, data, OriginAlias(sourceItem.id, sourceObjects, obj));
+        bool const valid = SourceAliasValid(sourceItem, obj, data, OriginAlias(sourceItem.id, sourceObjects, obj));
 
         auto *item = new QListWidgetItem(valid ? obj->ObjectName() : obj->ObjectName() + '*');
         item->setToolTip(obj->ObjectName());
@@ -623,7 +613,7 @@ void DialogFlippingByAxis::FillSourceList()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogFlippingByAxis::ValidateSourceAliases()
 {
-    for (int i=0; i<ui->listWidget->count(); ++i)
+    for (int i = 0; i < ui->listWidget->count(); ++i)
     {
         if (const QListWidgetItem *item = ui->listWidget->item(i))
         {
@@ -639,10 +629,8 @@ void DialogFlippingByAxis::ValidateSourceAliases()
                 CheckState();
                 return;
             }
-            else
-            {
-                SetAliasValid(sourceItem.id, true);
-            }
+
+            SetAliasValid(sourceItem.id, true);
         }
     }
 
@@ -675,15 +663,15 @@ void DialogFlippingByAxis::SetNotes(const QString &notes)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogFlippingByAxis::GetNotes() const
+auto DialogFlippingByAxis::GetNotes() const -> QString
 {
     return ui->plainTextEditToolNotes->toPlainText();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool DialogFlippingByAxis::IsValid() const
+auto DialogFlippingByAxis::IsValid() const -> bool
 {
-    bool ready = flagError && flagName && flagGroupName && flagAlias;
+    bool const ready = flagError && flagName && flagGroupName && flagAlias;
 
     if (ready)
     {
