@@ -42,37 +42,27 @@
 #include <QSharedPointer>
 #include <QStringList>
 #include <QToolButton>
-#include <Qt>
-#include <new>
 
-#include "../../visualization/visualization.h"
+#include "../../tools/drawTools/operation/vabstractoperation.h"
 #include "../../visualization/line/operation/vistoolflippingbyline.h"
+#include "../../visualization/visualization.h"
 #include "../ifc/xml/vabstractpattern.h"
-#include "../ifc/xml/vdomdocument.h"
 #include "../qmuparser/qmudef.h"
-#include "../vgeometry/vpointf.h"
-#include "../vmisc/vabstractapplication.h"
-#include "../vmisc/vcommonsettings.h"
-#include "../vmisc/compatibility.h"
-#if QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
-#include "../vmisc/backport/qoverload.h"
-#endif // QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
 #include "../vpatterndb/vcontainer.h"
-#include "../vwidgets/vabstractmainwindow.h"
 #include "../vwidgets/vmaingraphicsscene.h"
 #include "../vwidgets/vmaingraphicsview.h"
 #include "ui_dialogflippingbyline.h"
-#include "../../tools/drawTools/operation/vabstractoperation.h"
 
 //---------------------------------------------------------------------------------------------------------------------
-DialogFlippingByLine::DialogFlippingByLine(const VContainer *data, quint32 toolId, QWidget *parent)
-    : DialogTool(data, toolId, parent),
-      ui(new Ui::DialogFlippingByLine),
-      stage1(true),
-      m_suffix(),
-      flagName(true),
-      flagGroupName(true),
-      flagError(false)
+DialogFlippingByLine::DialogFlippingByLine(const VContainer *data, VAbstractPattern *doc, quint32 toolId,
+                                           QWidget *parent)
+  : DialogTool(data, doc, toolId, parent),
+    ui(new Ui::DialogFlippingByLine),
+    stage1(true),
+    m_suffix(),
+    flagName(true),
+    flagGroupName(true),
+    flagError(false)
 {
     ui->setupUi(this);
 
@@ -82,15 +72,16 @@ DialogFlippingByLine::DialogFlippingByLine(const VContainer *data, quint32 toolI
 
     FillComboBoxPoints(ui->comboBoxFirstLinePoint);
     FillComboBoxPoints(ui->comboBoxSecondLinePoint);
-    FillComboBoxTypeLine(ui->comboBoxPenStyle, OperationLineStylesPics(), TypeLineDefault);
+    FillComboBoxTypeLine(ui->comboBoxPenStyle,
+                         OperationLineStylesPics(ui->comboBoxPenStyle->palette().color(QPalette::Base),
+                                                 ui->comboBoxPenStyle->palette().color(QPalette::Text)),
+                         TypeLineDefault);
     FillComboBoxLineColors(ui->comboBoxColor, VAbstractOperation::OperationColorsList());
 
     connect(ui->lineEditSuffix, &QLineEdit::textChanged, this, &DialogFlippingByLine::SuffixChanged);
     connect(ui->lineEditVisibilityGroup, &QLineEdit::textChanged, this, &DialogFlippingByLine::GroupNameChanged);
-    connect(ui->comboBoxFirstLinePoint, &QComboBox::currentTextChanged,
-            this, &DialogFlippingByLine::PointChanged);
-    connect(ui->comboBoxSecondLinePoint, &QComboBox::currentTextChanged,
-            this, &DialogFlippingByLine::PointChanged);
+    connect(ui->comboBoxFirstLinePoint, &QComboBox::currentTextChanged, this, &DialogFlippingByLine::PointChanged);
+    connect(ui->comboBoxSecondLinePoint, &QComboBox::currentTextChanged, this, &DialogFlippingByLine::PointChanged);
 
     connect(ui->listWidget, &QListWidget::currentRowChanged, this, &DialogFlippingByLine::ShowSourceDetails);
     connect(ui->lineEditAlias, &QLineEdit::textEdited, this, &DialogFlippingByLine::AliasChanged);
@@ -112,7 +103,7 @@ DialogFlippingByLine::~DialogFlippingByLine()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-quint32 DialogFlippingByLine::GetFirstLinePointId() const
+auto DialogFlippingByLine::GetFirstLinePointId() const -> quint32
 {
     return getCurrentObjectId(ui->comboBoxFirstLinePoint);
 }
@@ -121,13 +112,13 @@ quint32 DialogFlippingByLine::GetFirstLinePointId() const
 void DialogFlippingByLine::SetFirstLinePointId(quint32 value)
 {
     ChangeCurrentData(ui->comboBoxFirstLinePoint, value);
-    VisToolFlippingByLine *operation = qobject_cast<VisToolFlippingByLine *>(vis);
+    auto *operation = qobject_cast<VisToolFlippingByLine *>(vis);
     SCASSERT(operation != nullptr)
     operation->SetFirstLinePointId(value);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-quint32 DialogFlippingByLine::GetSecondLinePointId() const
+auto DialogFlippingByLine::GetSecondLinePointId() const -> quint32
 {
     return getCurrentObjectId(ui->comboBoxSecondLinePoint);
 }
@@ -136,13 +127,13 @@ quint32 DialogFlippingByLine::GetSecondLinePointId() const
 void DialogFlippingByLine::SetSecondLinePointId(quint32 value)
 {
     ChangeCurrentData(ui->comboBoxSecondLinePoint, value);
-    VisToolFlippingByLine *operation = qobject_cast<VisToolFlippingByLine *>(vis);
+    auto *operation = qobject_cast<VisToolFlippingByLine *>(vis);
     SCASSERT(operation != nullptr)
     operation->SetSecondLinePointId(value);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogFlippingByLine::GetSuffix() const
+auto DialogFlippingByLine::GetSuffix() const -> QString
 {
     return m_suffix;
 }
@@ -155,7 +146,7 @@ void DialogFlippingByLine::SetSuffix(const QString &value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogFlippingByLine::GetVisibilityGroupName() const
+auto DialogFlippingByLine::GetVisibilityGroupName() const -> QString
 {
     return ui->lineEditVisibilityGroup->text();
 }
@@ -167,7 +158,7 @@ void DialogFlippingByLine::SetVisibilityGroupName(const QString &name)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool DialogFlippingByLine::HasLinkedVisibilityGroup() const
+auto DialogFlippingByLine::HasLinkedVisibilityGroup() const -> bool
 {
     return ui->groupBoxVisibilityGroup->isChecked();
 }
@@ -185,7 +176,7 @@ void DialogFlippingByLine::SetVisibilityGroupTags(const QStringList &tags)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QStringList DialogFlippingByLine::GetVisibilityGroupTags() const
+auto DialogFlippingByLine::GetVisibilityGroupTags() const -> QStringList
 {
     return ui->lineEditGroupTags->text().split(',');
 }
@@ -209,12 +200,11 @@ void DialogFlippingByLine::ShowDialog(bool click)
 
         stage1 = false;
 
-        VMainGraphicsScene *scene =
-                qobject_cast<VMainGraphicsScene *>(VAbstractValApplication::VApp()->getCurrentScene());
+        auto *scene = qobject_cast<VMainGraphicsScene *>(VAbstractValApplication::VApp()->getCurrentScene());
         SCASSERT(scene != nullptr)
         scene->clearSelection();
 
-        VisToolFlippingByLine *operation = qobject_cast<VisToolFlippingByLine *>(vis);
+        auto *operation = qobject_cast<VisToolFlippingByLine *>(vis);
         SCASSERT(operation != nullptr)
         operation->SetObjects(SourceToObjects(sourceObjects));
         operation->VisualMode();
@@ -244,7 +234,7 @@ void DialogFlippingByLine::ShowDialog(bool click)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QVector<SourceItem> DialogFlippingByLine::GetSourceObjects() const
+auto DialogFlippingByLine::GetSourceObjects() const -> QVector<SourceItem>
 {
     return sourceObjects;
 }
@@ -255,7 +245,7 @@ void DialogFlippingByLine::SetSourceObjects(const QVector<SourceItem> &value)
     sourceObjects = value;
     FillSourceList();
 
-    VisToolFlippingByLine *operation = qobject_cast<VisToolFlippingByLine *>(vis);
+    auto *operation = qobject_cast<VisToolFlippingByLine *>(vis);
     SCASSERT(operation != nullptr)
     operation->SetObjects(SourceToObjects(sourceObjects));
 }
@@ -263,57 +253,49 @@ void DialogFlippingByLine::SetSourceObjects(const QVector<SourceItem> &value)
 //---------------------------------------------------------------------------------------------------------------------
 void DialogFlippingByLine::ChosenObject(quint32 id, const SceneObject &type)
 {
-    if (not stage1 && not prepare)// After first choose we ignore all objects
+    if (not stage1 && not prepare && type == SceneObject::Point) // After first choose we ignore all objects
     {
-        if (type == SceneObject::Point)
+        auto obj = std::find_if(sourceObjects.begin(), sourceObjects.end(),
+                                [id](const SourceItem &sItem) { return sItem.id == id; });
+        switch (number)
         {
-            auto obj = std::find_if(sourceObjects.begin(), sourceObjects.end(),
-                                    [id](const SourceItem &sItem) { return sItem.id == id; });
-            switch (number)
-            {
-                case 0:
-                    if (obj != sourceObjects.end())
-                    {
-                        emit ToolTip(tr("Select first line point that is not part of the list of objects"));
-                        return;
-                    }
+            case 0:
+                if (obj != sourceObjects.end())
+                {
+                    emit ToolTip(tr("Select first line point that is not part of the list of objects"));
+                    return;
+                }
 
-                    if (SetObject(id, ui->comboBoxFirstLinePoint, tr("Select second line point")))
-                    {
-                        number++;
-                        VisToolFlippingByLine *operation = qobject_cast<VisToolFlippingByLine *>(vis);
-                        SCASSERT(operation != nullptr)
-                        operation->SetFirstLinePointId(id);
-                        operation->RefreshGeometry();
-                    }
-                    break;
-                case 1:
-                    if (obj != sourceObjects.end())
-                    {
-                        emit ToolTip(tr("Select second line point that is not part of the list of objects"));
-                        return;
-                    }
+                if (SetObject(id, ui->comboBoxFirstLinePoint, tr("Select second line point")))
+                {
+                    number++;
+                    auto *operation = qobject_cast<VisToolFlippingByLine *>(vis);
+                    SCASSERT(operation != nullptr)
+                    operation->SetFirstLinePointId(id);
+                    operation->RefreshGeometry();
+                }
+                break;
+            case 1:
+                if (obj != sourceObjects.end())
+                {
+                    emit ToolTip(tr("Select second line point that is not part of the list of objects"));
+                    return;
+                }
 
-                    if (getCurrentObjectId(ui->comboBoxFirstLinePoint) != id)
-                    {
-                        if (SetObject(id, ui->comboBoxSecondLinePoint, QString()))
-                        {
-                            if (flagError)
-                            {
-                                number = 0;
-                                prepare = true;
+                if (getCurrentObjectId(ui->comboBoxFirstLinePoint) != id &&
+                    SetObject(id, ui->comboBoxSecondLinePoint, QString()) && flagError)
+                {
+                    number = 0;
+                    prepare = true;
 
-                                VisToolFlippingByLine *operation = qobject_cast<VisToolFlippingByLine *>(vis);
-                                SCASSERT(operation != nullptr)
-                                operation->SetSecondLinePointId(id);
-                                operation->RefreshGeometry();
-                            }
-                        }
-                    }
-                    break;
-                default:
-                    break;
-            }
+                    auto *operation = qobject_cast<VisToolFlippingByLine *>(vis);
+                    SCASSERT(operation != nullptr)
+                    operation->SetSecondLinePointId(id);
+                    operation->RefreshGeometry();
+                }
+                break;
+            default:
+                break;
         }
     }
 }
@@ -348,7 +330,7 @@ void DialogFlippingByLine::SelectedObject(bool selected, quint32 object, quint32
 //---------------------------------------------------------------------------------------------------------------------
 void DialogFlippingByLine::SuffixChanged()
 {
-    QLineEdit* edit = qobject_cast<QLineEdit*>(sender());
+    auto *edit = qobject_cast<QLineEdit *>(sender());
     if (edit)
     {
         const QString suffix = edit->text();
@@ -360,23 +342,21 @@ void DialogFlippingByLine::SuffixChanged()
             CheckState();
             return;
         }
-        else
+
+        if (m_suffix != suffix)
         {
-            if (m_suffix != suffix)
+            QRegularExpression const rx(NameRegExp());
+            const QStringList uniqueNames = data->AllUniqueNames();
+            for (const auto &uniqueName : uniqueNames)
             {
-                QRegularExpression rx(NameRegExp());
-                const QStringList uniqueNames = data->AllUniqueNames();
-                for (auto &uniqueName : uniqueNames)
+                const QString name = uniqueName + suffix;
+                if (not rx.match(name).hasMatch() || not data->IsUnique(name))
                 {
-                    const QString name = uniqueName + suffix;
-                    if (not rx.match(name).hasMatch() || not data->IsUnique(name))
-                    {
-                        flagName = false;
-                        ChangeColor(ui->labelSuffix, errorColor);
-                        ui->labelStatus->setText(tr("Invalid suffix"));
-                        CheckState();
-                        return;
-                    }
+                    flagName = false;
+                    ChangeColor(ui->labelSuffix, errorColor);
+                    ui->labelStatus->setText(tr("Invalid suffix"));
+                    CheckState();
+                    return;
                 }
             }
         }
@@ -390,7 +370,7 @@ void DialogFlippingByLine::SuffixChanged()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogFlippingByLine::GroupNameChanged()
 {
-    QLineEdit* edit = qobject_cast<QLineEdit*>(sender());
+    auto *edit = qobject_cast<QLineEdit *>(sender());
     if (edit)
     {
         const QString name = edit->text();
@@ -442,7 +422,7 @@ void DialogFlippingByLine::ShowSourceDetails(int row)
     {
         ui->labelAlias->setText(tr("Alias:"));
 
-        auto SetValue = [sourceItem](QComboBox *box, const QString &value, const QString &def)
+        auto SetValue = [](QComboBox *box, const QString &value, const QString &def)
         {
             box->blockSignals(true);
 
@@ -464,8 +444,8 @@ void DialogFlippingByLine::ShowSourceDetails(int row)
 
         if (sourceItem.penStyle.isEmpty() || sourceItem.penStyle == TypeLineDefault)
         {
-            const QSharedPointer<VAbstractCurve> curve = data->GeometricObject<VAbstractCurve>(sourceItem.id);
-            int index = ui->comboBoxPenStyle->currentIndex();
+            ;
+            int const index = ui->comboBoxPenStyle->currentIndex();
             ui->comboBoxPenStyle->setItemText(index, '<' + tr("Default") + '>');
         }
 
@@ -474,8 +454,9 @@ void DialogFlippingByLine::ShowSourceDetails(int row)
         if (sourceItem.color.isEmpty() || sourceItem.color == ColorDefault)
         {
             const QSharedPointer<VAbstractCurve> curve = data->GeometricObject<VAbstractCurve>(sourceItem.id);
-            int index = ui->comboBoxColor->currentIndex();
-            ui->comboBoxColor->setItemIcon(index, LineColor(ui->comboBoxColor->iconSize().height(), curve->GetColor()));
+            int const index = ui->comboBoxColor->currentIndex();
+            ui->comboBoxColor->setItemIcon(index, LineColor(ui->comboBoxColor->palette().color(QPalette::Text),
+                                                            ui->comboBoxColor->iconSize().height(), curve->GetColor()));
         }
 
         ui->comboBoxPenStyle->setEnabled(true);
@@ -556,7 +537,7 @@ void DialogFlippingByLine::SaveData()
     sourceObjects.clear();
     sourceObjects.reserve(ui->listWidget->count());
 
-    for (int i=0; i<ui->listWidget->count(); ++i)
+    for (int i = 0; i < ui->listWidget->count(); ++i)
     {
         if (const QListWidgetItem *item = ui->listWidget->item(i))
         {
@@ -565,7 +546,7 @@ void DialogFlippingByLine::SaveData()
         }
     }
 
-    VisToolFlippingByLine *operation = qobject_cast<VisToolFlippingByLine *>(vis);
+    auto *operation = qobject_cast<VisToolFlippingByLine *>(vis);
     SCASSERT(operation != nullptr)
 
     operation->SetObjects(SourceToObjects(sourceObjects));
@@ -594,11 +575,11 @@ void DialogFlippingByLine::PointChanged()
     ChangeColor(ui->labelFirstLinePoint, color);
     ChangeColor(ui->labelSecondLinePoint, color);
 
-    quint32 id1 = getCurrentObjectId(ui->comboBoxFirstLinePoint);
+    quint32 const id1 = getCurrentObjectId(ui->comboBoxFirstLinePoint);
     auto obj1 = std::find_if(sourceObjects.begin(), sourceObjects.end(),
-                            [id1](const SourceItem &sItem) { return sItem.id == id1; });
+                             [id1](const SourceItem &sItem) { return sItem.id == id1; });
 
-    quint32 id2 = getCurrentObjectId(ui->comboBoxSecondLinePoint);
+    quint32 const id2 = getCurrentObjectId(ui->comboBoxSecondLinePoint);
     auto obj2 = std::find_if(sourceObjects.begin(), sourceObjects.end(),
                              [id2](const SourceItem &sItem) { return sItem.id == id2; });
 
@@ -640,7 +621,7 @@ void DialogFlippingByLine::FillSourceList()
     for (auto &sourceItem : sourceObjects)
     {
         const QSharedPointer<VGObject> obj = data->GetGObject(sourceItem.id);
-        bool valid = SourceAliasValid(sourceItem, obj, data, OriginAlias(sourceItem.id, sourceObjects, obj));
+        bool const valid = SourceAliasValid(sourceItem, obj, data, OriginAlias(sourceItem.id, sourceObjects, obj));
 
         auto *item = new QListWidgetItem(valid ? obj->ObjectName() : obj->ObjectName() + '*');
         item->setToolTip(obj->ObjectName());
@@ -661,7 +642,7 @@ void DialogFlippingByLine::FillSourceList()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogFlippingByLine::ValidateSourceAliases()
 {
-    for (int i=0; i<ui->listWidget->count(); ++i)
+    for (int i = 0; i < ui->listWidget->count(); ++i)
     {
         if (const QListWidgetItem *item = ui->listWidget->item(i))
         {
@@ -677,10 +658,8 @@ void DialogFlippingByLine::ValidateSourceAliases()
                 CheckState();
                 return;
             }
-            else
-            {
-                SetAliasValid(sourceItem.id, true);
-            }
+
+            SetAliasValid(sourceItem.id, true);
         }
     }
 
@@ -713,15 +692,15 @@ void DialogFlippingByLine::SetNotes(const QString &notes)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogFlippingByLine::GetNotes() const
+auto DialogFlippingByLine::GetNotes() const -> QString
 {
     return ui->plainTextEditToolNotes->toPlainText();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool DialogFlippingByLine::IsValid() const
+auto DialogFlippingByLine::IsValid() const -> bool
 {
-    bool ready = flagError && flagName && flagGroupName && flagAlias;
+    bool const ready = flagError && flagName && flagGroupName && flagAlias;
 
     if (ready)
     {
