@@ -40,9 +40,9 @@
 #include <QSharedPointer>
 #include <new>
 
+#include "../../visualization/line/visline.h"
 #include "../../visualization/line/vistoolheight.h"
 #include "../../visualization/visualization.h"
-#include "../../visualization/line/visline.h"
 #include "../ifc/xml/vabstractpattern.h"
 #include "../vgeometry/vgobject.h"
 #include "../vgeometry/vpointf.h"
@@ -56,35 +56,35 @@
  * @param data container with data
  * @param parent parent widget
  */
-DialogHeight::DialogHeight(const VContainer *data, quint32 toolId, QWidget *parent)
-    : DialogTool(data, toolId, parent),
-      ui(new Ui::DialogHeight)
+DialogHeight::DialogHeight(const VContainer *data, VAbstractPattern *doc, quint32 toolId, QWidget *parent)
+  : DialogTool(data, doc, toolId, parent),
+    ui(new Ui::DialogHeight)
 {
     ui->setupUi(this);
 
     ui->lineEditNamePoint->setClearButtonEnabled(true);
 
     ui->lineEditNamePoint->setText(
-                VAbstractValApplication::VApp()->getCurrentDocument()->GenerateLabel(LabelType::NewLabel));
+        VAbstractValApplication::VApp()->getCurrentDocument()->GenerateLabel(LabelType::NewLabel));
     InitOkCancelApply(ui);
 
     FillComboBoxPoints(ui->comboBoxBasePoint);
     FillComboBoxPoints(ui->comboBoxP1Line);
     FillComboBoxPoints(ui->comboBoxP2Line);
-    FillComboBoxTypeLine(ui->comboBoxLineType, LineStylesPics());
+    FillComboBoxTypeLine(ui->comboBoxLineType, LineStylesPics(ui->comboBoxLineType->palette().color(QPalette::Base),
+                                                              ui->comboBoxLineType->palette().color(QPalette::Text)));
     FillComboBoxLineColors(ui->comboBoxLineColor);
 
-    connect(ui->lineEditNamePoint, &QLineEdit::textChanged, this, [this]()
-    {
-        CheckPointLabel(this, ui->lineEditNamePoint, ui->labelEditNamePoint, m_pointName, this->data, m_flagName);
-        CheckState();
-    });
-    connect(ui->comboBoxBasePoint, &QComboBox::currentTextChanged,
-            this, &DialogHeight::PointNameChanged);
-    connect(ui->comboBoxP1Line, &QComboBox::currentTextChanged,
-            this, &DialogHeight::PointNameChanged);
-    connect(ui->comboBoxP2Line, &QComboBox::currentTextChanged,
-            this, &DialogHeight::PointNameChanged);
+    connect(ui->lineEditNamePoint, &QLineEdit::textChanged, this,
+            [this]()
+            {
+                CheckPointLabel(this, ui->lineEditNamePoint, ui->labelEditNamePoint, m_pointName, this->data,
+                                m_flagName);
+                CheckState();
+            });
+    connect(ui->comboBoxBasePoint, &QComboBox::currentTextChanged, this, &DialogHeight::PointNameChanged);
+    connect(ui->comboBoxP1Line, &QComboBox::currentTextChanged, this, &DialogHeight::PointNameChanged);
+    connect(ui->comboBoxP2Line, &QComboBox::currentTextChanged, this, &DialogHeight::PointNameChanged);
 
     vis = new VisToolHeight(data);
 
@@ -188,7 +188,7 @@ void DialogHeight::SetLineColor(const QString &value)
  */
 void DialogHeight::ChosenObject(quint32 id, const SceneObject &type)
 {
-    if (prepare)// After first choose we ignore all objects
+    if (prepare) // After first choose we ignore all objects
     {
         return;
     }
@@ -208,14 +208,12 @@ void DialogHeight::ChosenObject(quint32 id, const SceneObject &type)
                 }
                 break;
             case (1):
-                if (getCurrentObjectId(ui->comboBoxBasePoint) != id)
+                if (getCurrentObjectId(ui->comboBoxBasePoint) != id &&
+                    SetObject(id, ui->comboBoxP1Line, tr("Select second point of line")))
                 {
-                    if (SetObject(id, ui->comboBoxP1Line, tr("Select second point of line")))
-                    {
-                        m_number++;
-                        line->SetLineP1Id(id);
-                        line->RefreshGeometry();
-                    }
+                    m_number++;
+                    line->SetLineP1Id(id);
+                    line->RefreshGeometry();
                 }
                 break;
             case (2):
@@ -225,18 +223,15 @@ void DialogHeight::ChosenObject(quint32 id, const SceneObject &type)
                 set.insert(getCurrentObjectId(ui->comboBoxP1Line));
                 set.insert(id);
 
-                if (set.size() == 3)
+                if (set.size() == 3 && SetObject(id, ui->comboBoxP2Line, QString()))
                 {
-                    if (SetObject(id, ui->comboBoxP2Line, QString()))
-                    {
-                        line->SetLineP2Id(id);
-                        line->RefreshGeometry();
-                        prepare = true;
-                        DialogAccepted();
-                    }
+                    line->SetLineP2Id(id);
+                    line->RefreshGeometry();
+                    prepare = true;
+                    DialogAccepted();
                 }
             }
-                break;
+            break;
             default:
                 break;
         }
@@ -274,9 +269,9 @@ void DialogHeight::PointNameChanged()
 
     try
     {
-        const QPointF basePoint = static_cast<QPointF>(*data->GeometricObject<VPointF>(basePointId));
-        const QPointF p1Line = static_cast<QPointF>(*data->GeometricObject<VPointF>(p1LineId));
-        const QPointF p2Line = static_cast<QPointF>(*data->GeometricObject<VPointF>(p2LineId));
+        const auto basePoint = static_cast<QPointF>(*data->GeometricObject<VPointF>(basePointId));
+        const auto p1Line = static_cast<QPointF>(*data->GeometricObject<VPointF>(p1LineId));
+        const auto p2Line = static_cast<QPointF>(*data->GeometricObject<VPointF>(p2LineId));
 
         if (set.size() != 3 || VGObject::ClosestPoint(QLineF(p1Line, p2Line), basePoint) == QPointF())
         {
