@@ -39,16 +39,12 @@
 #include <QPushButton>
 #include <QSet>
 #include <QSharedPointer>
-#include <new>
 
-#include "../../visualization/visualization.h"
 #include "../../visualization/line/vistoollineintersect.h"
+#include "../../visualization/visualization.h"
 #include "../ifc/xml/vabstractpattern.h"
 #include "../vgeometry/vpointf.h"
 #include "../vmisc/compatibility.h"
-#if QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
-#include "../vmisc/backport/qoverload.h"
-#endif // QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
 #include "../vpatterndb/vcontainer.h"
 #include "dialogtool.h"
 #include "ui_dialoglineintersect.h"
@@ -59,13 +55,13 @@
  * @param data container with data
  * @param parent parent widget
  */
-DialogLineIntersect::DialogLineIntersect(const VContainer *data, quint32 toolId, QWidget *parent)
-    : DialogTool(data, toolId, parent),
-      ui(new Ui::DialogLineIntersect),
-      pointName(),
-      flagError(true),
-      flagPoint(true),
-      flagName(true)
+DialogLineIntersect::DialogLineIntersect(const VContainer *data, VAbstractPattern *doc, quint32 toolId, QWidget *parent)
+  : DialogTool(data, doc, toolId, parent),
+    ui(new Ui::DialogLineIntersect),
+    pointName(),
+    flagError(true),
+    flagPoint(true),
+    flagName(true)
 {
     ui->setupUi(this);
 
@@ -74,26 +70,23 @@ DialogLineIntersect::DialogLineIntersect(const VContainer *data, quint32 toolId,
     number = 0;
     InitOkCancelApply(ui);
     ui->lineEditNamePoint->setText(
-                VAbstractValApplication::VApp()->getCurrentDocument()->GenerateLabel(LabelType::NewLabel));
+        VAbstractValApplication::VApp()->getCurrentDocument()->GenerateLabel(LabelType::NewLabel));
 
     FillComboBoxPoints(ui->comboBoxP1Line1);
     FillComboBoxPoints(ui->comboBoxP2Line1);
     FillComboBoxPoints(ui->comboBoxP1Line2);
     FillComboBoxPoints(ui->comboBoxP2Line2);
 
-    connect(ui->lineEditNamePoint, &QLineEdit::textChanged, this, [this]()
-    {
-        CheckPointLabel(this, ui->lineEditNamePoint, ui->labelEditNamePoint, pointName, this->data, flagName);
-        CheckState();
-    });
-    connect(ui->comboBoxP1Line1, &QComboBox::currentTextChanged,
-            this, &DialogLineIntersect::PointNameChanged);
-    connect(ui->comboBoxP2Line1, &QComboBox::currentTextChanged,
-            this, &DialogLineIntersect::PointNameChanged);
-    connect(ui->comboBoxP1Line2, &QComboBox::currentTextChanged,
-            this, &DialogLineIntersect::PointNameChanged);
-    connect(ui->comboBoxP2Line2, &QComboBox::currentTextChanged,
-            this, &DialogLineIntersect::PointNameChanged);
+    connect(ui->lineEditNamePoint, &QLineEdit::textChanged, this,
+            [this]()
+            {
+                CheckPointLabel(this, ui->lineEditNamePoint, ui->labelEditNamePoint, pointName, this->data, flagName);
+                CheckState();
+            });
+    connect(ui->comboBoxP1Line1, &QComboBox::currentTextChanged, this, &DialogLineIntersect::PointNameChanged);
+    connect(ui->comboBoxP2Line1, &QComboBox::currentTextChanged, this, &DialogLineIntersect::PointNameChanged);
+    connect(ui->comboBoxP1Line2, &QComboBox::currentTextChanged, this, &DialogLineIntersect::PointNameChanged);
+    connect(ui->comboBoxP2Line2, &QComboBox::currentTextChanged, this, &DialogLineIntersect::PointNameChanged);
 
     vis = new VisToolLineIntersect(data);
 
@@ -115,82 +108,74 @@ DialogLineIntersect::~DialogLineIntersect()
  */
 void DialogLineIntersect::ChosenObject(quint32 id, const SceneObject &type)
 {
-    if (prepare == false)// After first choose we ignore all objects
+    if (prepare == false && type == SceneObject::Point) // After first choose we ignore all objects
     {
-        if (type == SceneObject::Point)
+        auto *line = qobject_cast<VisToolLineIntersect *>(vis);
+        SCASSERT(line != nullptr)
+
+        switch (number)
         {
-            VisToolLineIntersect *line = qobject_cast<VisToolLineIntersect *>(vis);
-            SCASSERT(line != nullptr)
-
-            switch (number)
-            {
-                case 0:
-                    if (SetObject(id, ui->comboBoxP1Line1, tr("Select second point of first line")))
-                    {
-                        number++;
-                        line->VisualMode(id);
-                    }
-                    break;
-                case 1:
-                    if (getCurrentObjectId(ui->comboBoxP1Line1) != id)
-                    {
-                        if (SetObject(id, ui->comboBoxP2Line1, tr("Select first point of second line")))
-                        {
-                            number++;
-                            line->SetLine1P2Id(id);
-                            line->RefreshGeometry();
-                        }
-                    }
-                    break;
-                case 2:
-                    if (SetObject(id, ui->comboBoxP1Line2, tr("Select second point of second line")))
-                    {
-                        number++;
-                        line->SetLine2P1Id(id);
-                        line->RefreshGeometry();
-                    }
-                    break;
-                case 3:
+            case 0:
+                if (SetObject(id, ui->comboBoxP1Line1, tr("Select second point of first line")))
                 {
-                    QSet<quint32> set;
-                    set.insert(getCurrentObjectId(ui->comboBoxP1Line1));
-                    set.insert(getCurrentObjectId(ui->comboBoxP2Line1));
-                    set.insert(getCurrentObjectId(ui->comboBoxP1Line2));
-                    set.insert(id);
+                    number++;
+                    line->VisualMode(id);
+                }
+                break;
+            case 1:
+                if (getCurrentObjectId(ui->comboBoxP1Line1) != id &&
+                    SetObject(id, ui->comboBoxP2Line1, tr("Select first point of second line")))
+                {
+                    number++;
+                    line->SetLine1P2Id(id);
+                    line->RefreshGeometry();
+                }
+                break;
+            case 2:
+                if (SetObject(id, ui->comboBoxP1Line2, tr("Select second point of second line")))
+                {
+                    number++;
+                    line->SetLine2P1Id(id);
+                    line->RefreshGeometry();
+                }
+                break;
+            case 3:
+            {
+                QSet<quint32> set;
+                set.insert(getCurrentObjectId(ui->comboBoxP1Line1));
+                set.insert(getCurrentObjectId(ui->comboBoxP2Line1));
+                set.insert(getCurrentObjectId(ui->comboBoxP1Line2));
+                set.insert(id);
 
-                    if (set.size() >= 3)
+                if (set.size() >= 3 && SetObject(id, ui->comboBoxP2Line2, QString()))
+                {
+                    line->SetLine2P2Id(id);
+                    line->RefreshGeometry();
+                    prepare = true;
+                    flagPoint = CheckIntersecion();
+                    CheckState();
+                    if (flagPoint)
                     {
-                        if (SetObject(id, ui->comboBoxP2Line2, QString()))
-                        {
-                            line->SetLine2P2Id(id);
-                            line->RefreshGeometry();
-                            prepare = true;
-                            flagPoint = CheckIntersecion();
-                            CheckState();
-                            if (flagPoint)
-                            {
-                                DialogAccepted();
-                            }
-                            else
-                            {
-                                this->setModal(true);
-                                this->show();
-                                connect(ui->comboBoxP1Line1, QOverload<int>::of(&QComboBox::currentIndexChanged), this,
-                                        &DialogLineIntersect::PointChanged);
-                                connect(ui->comboBoxP2Line1, QOverload<int>::of(&QComboBox::currentIndexChanged), this,
-                                        &DialogLineIntersect::PointChanged);
-                                connect(ui->comboBoxP1Line2, QOverload<int>::of(&QComboBox::currentIndexChanged), this,
-                                        &DialogLineIntersect::PointChanged);
-                                connect(ui->comboBoxP2Line2, QOverload<int>::of(&QComboBox::currentIndexChanged), this,
-                                        &DialogLineIntersect::PointChanged);
-                            }
-                        }
+                        DialogAccepted();
+                    }
+                    else
+                    {
+                        this->setModal(true);
+                        this->show();
+                        connect(ui->comboBoxP1Line1, QOverload<int>::of(&QComboBox::currentIndexChanged), this,
+                                &DialogLineIntersect::PointChanged);
+                        connect(ui->comboBoxP2Line1, QOverload<int>::of(&QComboBox::currentIndexChanged), this,
+                                &DialogLineIntersect::PointChanged);
+                        connect(ui->comboBoxP1Line2, QOverload<int>::of(&QComboBox::currentIndexChanged), this,
+                                &DialogLineIntersect::PointChanged);
+                        connect(ui->comboBoxP2Line2, QOverload<int>::of(&QComboBox::currentIndexChanged), this,
+                                &DialogLineIntersect::PointChanged);
                     }
                 }
-                    break;
-                default:
-                    break;
             }
+            break;
+            default:
+                break;
         }
     }
 }
@@ -200,7 +185,7 @@ void DialogLineIntersect::SaveData()
 {
     pointName = ui->lineEditNamePoint->text();
 
-    VisToolLineIntersect *line = qobject_cast<VisToolLineIntersect *>(vis);
+    auto *line = qobject_cast<VisToolLineIntersect *>(vis);
     SCASSERT(line != nullptr)
 
     line->SetLine1P1Id(GetP1Line1());
@@ -243,13 +228,12 @@ void DialogLineIntersect::PointNameChanged()
         const QSharedPointer<VPointF> p1Line2 = data->GeometricObject<VPointF>(p1Line2Id);
         const QSharedPointer<VPointF> p2Line2 = data->GeometricObject<VPointF>(p2Line2Id);
 
-        QLineF line1(static_cast<QPointF>(*p1Line1), static_cast<QPointF>(*p2Line1));
-        QLineF line2(static_cast<QPointF>(*p1Line2), static_cast<QPointF>(*p2Line2));
+        QLineF const line1(static_cast<QPointF>(*p1Line1), static_cast<QPointF>(*p2Line1));
+        QLineF const line2(static_cast<QPointF>(*p1Line2), static_cast<QPointF>(*p2Line2));
         QPointF fPoint;
-        QLineF::IntersectType intersect = Intersects(line1, line2, &fPoint);
+        QLineF::IntersectType const intersect = line1.intersects(line2, &fPoint);
 
-
-        flagError = not (set.size() < 3 || intersect == QLineF::NoIntersection);
+        flagError = not(set.size() < 3 || intersect == QLineF::NoIntersection);
         color = flagError ? OkColor(this) : errorColor;
     }
     catch (const VExceptionBadId &)
@@ -276,7 +260,7 @@ void DialogLineIntersect::ShowVisualization()
  * @brief CheckIntersecion check intersection of points
  * @return true - line have intersection, false = don't have
  */
-bool DialogLineIntersect::CheckIntersecion()
+auto DialogLineIntersect::CheckIntersecion() -> bool
 {
     try
     {
@@ -285,10 +269,10 @@ bool DialogLineIntersect::CheckIntersecion()
         const QSharedPointer<VPointF> p1L2 = data->GeometricObject<VPointF>(GetP1Line2());
         const QSharedPointer<VPointF> p2L2 = data->GeometricObject<VPointF>(GetP2Line2());
 
-        QLineF line1(static_cast<QPointF>(*p1L1), static_cast<QPointF>(*p2L1));
-        QLineF line2(static_cast<QPointF>(*p1L2), static_cast<QPointF>(*p2L2));
+        QLineF const line1(static_cast<QPointF>(*p1L1), static_cast<QPointF>(*p2L1));
+        QLineF const line2(static_cast<QPointF>(*p1L2), static_cast<QPointF>(*p2L2));
         QPointF fPoint;
-        QLineF::IntersectType intersect = Intersects(line1, line2, &fPoint);
+        QLineF::IntersectType const intersect = line1.intersects(line2, &fPoint);
         return intersect == QLineF::UnboundedIntersection || intersect == QLineF::BoundedIntersection;
     }
     catch (const VExceptionBadId &)
@@ -306,13 +290,13 @@ void DialogLineIntersect::SetP2Line2(quint32 value)
 {
     setCurrentPointId(ui->comboBoxP2Line2, value);
 
-    VisToolLineIntersect *line = qobject_cast<VisToolLineIntersect *>(vis);
+    auto *line = qobject_cast<VisToolLineIntersect *>(vis);
     SCASSERT(line != nullptr)
-            line->SetLine2P2Id(value);
+    line->SetLine2P2Id(value);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogLineIntersect::GetPointName() const
+auto DialogLineIntersect::GetPointName() const -> QString
 {
     return pointName;
 }
@@ -326,7 +310,7 @@ void DialogLineIntersect::SetP1Line2(quint32 value)
 {
     setCurrentPointId(ui->comboBoxP1Line2, value);
 
-    VisToolLineIntersect *line = qobject_cast<VisToolLineIntersect *>(vis);
+    auto *line = qobject_cast<VisToolLineIntersect *>(vis);
     SCASSERT(line != nullptr)
     line->SetLine2P1Id(value);
 }
@@ -340,7 +324,7 @@ void DialogLineIntersect::SetP2Line1(quint32 value)
 {
     setCurrentPointId(ui->comboBoxP2Line1, value);
 
-    VisToolLineIntersect *line = qobject_cast<VisToolLineIntersect *>(vis);
+    auto *line = qobject_cast<VisToolLineIntersect *>(vis);
     SCASSERT(line != nullptr)
     line->SetLine1P2Id(value);
 }
@@ -354,7 +338,7 @@ void DialogLineIntersect::SetP1Line1(quint32 value)
 {
     setCurrentPointId(ui->comboBoxP1Line1, value);
 
-    VisToolLineIntersect *line = qobject_cast<VisToolLineIntersect *>(vis);
+    auto *line = qobject_cast<VisToolLineIntersect *>(vis);
     SCASSERT(line != nullptr)
     line->SetLine1P1Id(value);
 }
@@ -375,7 +359,7 @@ void DialogLineIntersect::SetPointName(const QString &value)
  * @brief GetP1Line1 return id first point of first line
  * @return id
  */
-quint32 DialogLineIntersect::GetP1Line1() const
+auto DialogLineIntersect::GetP1Line1() const -> quint32
 {
     return getCurrentObjectId(ui->comboBoxP1Line1);
 }
@@ -385,7 +369,7 @@ quint32 DialogLineIntersect::GetP1Line1() const
  * @brief GetP2Line1 return id second point of first line
  * @return id
  */
-quint32 DialogLineIntersect::GetP2Line1() const
+auto DialogLineIntersect::GetP2Line1() const -> quint32
 {
     return getCurrentObjectId(ui->comboBoxP2Line1);
 }
@@ -395,7 +379,7 @@ quint32 DialogLineIntersect::GetP2Line1() const
  * @brief GetP1Line2 return id first point of second line
  * @return id
  */
-quint32 DialogLineIntersect::GetP1Line2() const
+auto DialogLineIntersect::GetP1Line2() const -> quint32
 {
     return getCurrentObjectId(ui->comboBoxP1Line2);
 }
@@ -405,7 +389,7 @@ quint32 DialogLineIntersect::GetP1Line2() const
  * @brief GetP2Line2 return id second point of second line
  * @return id
  */
-quint32 DialogLineIntersect::GetP2Line2() const
+auto DialogLineIntersect::GetP2Line2() const -> quint32
 {
     return getCurrentObjectId(ui->comboBoxP2Line2);
 }
@@ -417,7 +401,7 @@ void DialogLineIntersect::SetNotes(const QString &notes)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogLineIntersect::GetNotes() const
+auto DialogLineIntersect::GetNotes() const -> QString
 {
     return ui->plainTextEditToolNotes->toPlainText();
 }
