@@ -44,41 +44,45 @@
 #include <QToolButton>
 #include <new>
 
-#include "../vgeometry/vpointf.h"
-#include "../vpatterndb/vcontainer.h"
-#include "../vpatterndb/vtranslatevars.h"
-#include "../vwidgets/vmaingraphicsscene.h"
-#include "../vwidgets/vabstractmainwindow.h"
-#include "../vwidgets/global.h"
 #include "../../visualization/line/vistoollineintersectaxis.h"
 #include "../../visualization/visualization.h"
 #include "../ifc/xml/vabstractpattern.h"
 #include "../support/dialogeditwrongformula.h"
+#include "../vgeometry/vpointf.h"
+#include "../vmisc/theme/vtheme.h"
 #include "../vmisc/vabstractapplication.h"
 #include "../vmisc/vcommonsettings.h"
+#include "../vpatterndb/vcontainer.h"
+#include "../vpatterndb/vtranslatevars.h"
+#include "../vwidgets/global.h"
+#include "../vwidgets/vabstractmainwindow.h"
+#include "../vwidgets/vmaingraphicsscene.h"
 #include "ui_dialoglineintersectaxis.h"
 
 //---------------------------------------------------------------------------------------------------------------------
-DialogLineIntersectAxis::DialogLineIntersectAxis(const VContainer *data, quint32 toolId, QWidget *parent)
-    : DialogTool(data, toolId, parent),
-      ui(new Ui::DialogLineIntersectAxis),
-      formulaAngle(),
-      formulaBaseHeightAngle(0),
-      pointName(),
-      m_firstRelease(false),
-      timerFormula(new QTimer(this)),
-      flagFormula(false),
-      flagError(true),
-      flagName(true)
+DialogLineIntersectAxis::DialogLineIntersectAxis(const VContainer *data, VAbstractPattern *doc, quint32 toolId,
+                                                 QWidget *parent)
+  : DialogTool(data, doc, toolId, parent),
+    ui(new Ui::DialogLineIntersectAxis),
+    formulaAngle(),
+    formulaBaseHeightAngle(0),
+    pointName(),
+    m_firstRelease(false),
+    timerFormula(new QTimer(this)),
+    flagFormula(false),
+    flagError(true),
+    flagName(true)
 {
     ui->setupUi(this);
 
+    InitIcons();
+
     timerFormula->setSingleShot(true);
 
     ui->lineEditNamePoint->setClearButtonEnabled(true);
 
     ui->lineEditNamePoint->setText(
-                VAbstractValApplication::VApp()->getCurrentDocument()->GenerateLabel(LabelType::NewLabel));
+        VAbstractValApplication::VApp()->getCurrentDocument()->GenerateLabel(LabelType::NewLabel));
     this->formulaBaseHeightAngle = ui->plainTextEditFormula->height();
     ui->plainTextEditFormula->installEventFilter(this);
 
@@ -87,27 +91,26 @@ DialogLineIntersectAxis::DialogLineIntersectAxis(const VContainer *data, quint32
     FillComboBoxPoints(ui->comboBoxAxisPoint);
     FillComboBoxPoints(ui->comboBoxFirstLinePoint);
     FillComboBoxPoints(ui->comboBoxSecondLinePoint);
-    FillComboBoxTypeLine(ui->comboBoxLineType, LineStylesPics());
+    FillComboBoxTypeLine(ui->comboBoxLineType, LineStylesPics(ui->comboBoxLineType->palette().color(QPalette::Base),
+                                                              ui->comboBoxLineType->palette().color(QPalette::Text)));
     FillComboBoxLineColors(ui->comboBoxLineColor);
 
     connect(ui->toolButtonExprAngle, &QPushButton::clicked, this, &DialogLineIntersectAxis::FXAngle);
-    connect(ui->lineEditNamePoint, &QLineEdit::textChanged, this, [this]()
-    {
-        CheckPointLabel(this, ui->lineEditNamePoint, ui->labelEditNamePoint, pointName, this->data, flagName);
-        CheckState();
-    });
-    connect(ui->plainTextEditFormula, &QPlainTextEdit::textChanged, this, [this]()
-    {
-        timerFormula->start(formulaTimerTimeout);
-    });
+    connect(ui->lineEditNamePoint, &QLineEdit::textChanged, this,
+            [this]()
+            {
+                CheckPointLabel(this, ui->lineEditNamePoint, ui->labelEditNamePoint, pointName, this->data, flagName);
+                CheckState();
+            });
+    connect(ui->plainTextEditFormula, &QPlainTextEdit::textChanged, this,
+            [this]() { timerFormula->start(formulaTimerTimeout); });
     connect(ui->pushButtonGrowLengthAngle, &QPushButton::clicked, this, &DialogLineIntersectAxis::DeployAngleTextEdit);
     connect(timerFormula, &QTimer::timeout, this, &DialogLineIntersectAxis::EvalAngle);
-    connect(ui->comboBoxFirstLinePoint, &QComboBox::currentTextChanged,
-            this, &DialogLineIntersectAxis::PointNameChanged);
-    connect(ui->comboBoxSecondLinePoint, &QComboBox::currentTextChanged,
-            this, &DialogLineIntersectAxis::PointNameChanged);
-    connect(ui->comboBoxAxisPoint, &QComboBox::currentTextChanged,
-            this, &DialogLineIntersectAxis::PointNameChanged);
+    connect(ui->comboBoxFirstLinePoint, &QComboBox::currentTextChanged, this,
+            &DialogLineIntersectAxis::PointNameChanged);
+    connect(ui->comboBoxSecondLinePoint, &QComboBox::currentTextChanged, this,
+            &DialogLineIntersectAxis::PointNameChanged);
+    connect(ui->comboBoxAxisPoint, &QComboBox::currentTextChanged, this, &DialogLineIntersectAxis::PointNameChanged);
 
     vis = new VisToolLineIntersectAxis(data);
 
@@ -122,7 +125,7 @@ DialogLineIntersectAxis::~DialogLineIntersectAxis()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogLineIntersectAxis::GetPointName() const
+auto DialogLineIntersectAxis::GetPointName() const -> QString
 {
     return pointName;
 }
@@ -135,7 +138,7 @@ void DialogLineIntersectAxis::SetPointName(const QString &value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogLineIntersectAxis::GetTypeLine() const
+auto DialogLineIntersectAxis::GetTypeLine() const -> QString
 {
     return GetComboBoxCurrentData(ui->comboBoxLineType, TypeLineLine);
 }
@@ -148,7 +151,7 @@ void DialogLineIntersectAxis::SetTypeLine(const QString &value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogLineIntersectAxis::GetAngle() const
+auto DialogLineIntersectAxis::GetAngle() const -> QString
 {
     return VTranslateVars::TryFormulaFromUser(formulaAngle, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
 }
@@ -156,8 +159,8 @@ QString DialogLineIntersectAxis::GetAngle() const
 //---------------------------------------------------------------------------------------------------------------------
 void DialogLineIntersectAxis::SetAngle(const QString &value)
 {
-    formulaAngle = VAbstractApplication::VApp()->TrVars()
-            ->FormulaToUser(value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    formulaAngle = VAbstractApplication::VApp()->TrVars()->FormulaToUser(
+        value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
     // increase height if needed. TODO : see if I can get the max number of caracters in one line
     // of this PlainTextEdit to change 80 to this value
     if (formulaAngle.length() > 80)
@@ -166,7 +169,7 @@ void DialogLineIntersectAxis::SetAngle(const QString &value)
     }
     ui->plainTextEditFormula->setPlainText(formulaAngle);
 
-    VisToolLineIntersectAxis *line = qobject_cast<VisToolLineIntersectAxis *>(vis);
+    auto *line = qobject_cast<VisToolLineIntersectAxis *>(vis);
     SCASSERT(line != nullptr)
     line->SetAngle(formulaAngle);
 
@@ -174,7 +177,7 @@ void DialogLineIntersectAxis::SetAngle(const QString &value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-quint32 DialogLineIntersectAxis::GetBasePointId() const
+auto DialogLineIntersectAxis::GetBasePointId() const -> quint32
 {
     return getCurrentObjectId(ui->comboBoxAxisPoint);
 }
@@ -184,13 +187,13 @@ void DialogLineIntersectAxis::SetBasePointId(quint32 value)
 {
     setCurrentPointId(ui->comboBoxAxisPoint, value);
 
-    VisToolLineIntersectAxis *line = qobject_cast<VisToolLineIntersectAxis *>(vis);
+    auto *line = qobject_cast<VisToolLineIntersectAxis *>(vis);
     SCASSERT(line != nullptr)
     line->SetAxisPointId(value);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-quint32 DialogLineIntersectAxis::GetFirstPointId() const
+auto DialogLineIntersectAxis::GetFirstPointId() const -> quint32
 {
     return getCurrentObjectId(ui->comboBoxFirstLinePoint);
 }
@@ -200,13 +203,13 @@ void DialogLineIntersectAxis::SetFirstPointId(quint32 value)
 {
     setCurrentPointId(ui->comboBoxFirstLinePoint, value);
 
-    VisToolLineIntersectAxis *line = qobject_cast<VisToolLineIntersectAxis *>(vis);
+    auto *line = qobject_cast<VisToolLineIntersectAxis *>(vis);
     SCASSERT(line != nullptr)
     line->SetPoint1Id(value);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-quint32 DialogLineIntersectAxis::GetSecondPointId() const
+auto DialogLineIntersectAxis::GetSecondPointId() const -> quint32
 {
     return getCurrentObjectId(ui->comboBoxSecondLinePoint);
 }
@@ -216,13 +219,13 @@ void DialogLineIntersectAxis::SetSecondPointId(quint32 value)
 {
     setCurrentPointId(ui->comboBoxSecondLinePoint, value);
 
-    VisToolLineIntersectAxis *line = qobject_cast<VisToolLineIntersectAxis *>(vis);
+    auto *line = qobject_cast<VisToolLineIntersectAxis *>(vis);
     SCASSERT(line != nullptr)
     line->SetPoint2Id(value);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogLineIntersectAxis::GetLineColor() const
+auto DialogLineIntersectAxis::GetLineColor() const -> QString
 {
     return GetComboBoxCurrentData(ui->comboBoxLineColor, ColorBlack);
 }
@@ -249,84 +252,82 @@ void DialogLineIntersectAxis::ShowDialog(bool click)
             }
 
             /*We will ignore click if poinet is in point circle*/
-            VMainGraphicsScene *scene =
-                    qobject_cast<VMainGraphicsScene *>(VAbstractValApplication::VApp()->getCurrentScene());
+            auto *scene = qobject_cast<VMainGraphicsScene *>(VAbstractValApplication::VApp()->getCurrentScene());
             SCASSERT(scene != nullptr)
             const QSharedPointer<VPointF> point = data->GeometricObject<VPointF>(GetBasePointId());
-            QLineF line = QLineF(static_cast<QPointF>(*point), scene->getScenePos());
+            auto const line = QLineF(static_cast<QPointF>(*point), scene->getScenePos());
 
-            //Radius of point circle, but little bigger. Need handle with hover sizes.
-            if (line.length() <= ScaledRadius(SceneScale(VAbstractValApplication::VApp()->getCurrentScene()))*1.5)
+            // Radius of point circle, but little bigger. Need handle with hover sizes.
+            if (line.length() <= ScaledRadius(SceneScale(VAbstractValApplication::VApp()->getCurrentScene())) * 1.5)
             {
                 return;
             }
         }
 
-        VisToolLineIntersectAxis *line = qobject_cast<VisToolLineIntersectAxis *>(vis);
+        auto *line = qobject_cast<VisToolLineIntersectAxis *>(vis);
         SCASSERT(line != nullptr)
+        SetAngle(line->Angle()); // Show in dialog angle what user choose
 
-        this->SetAngle(line->Angle());//Show in dialog angle what user choose
+        line->SetMode(Mode::Show);
         emit ToolTip(QString());
-
-        DialogAccepted();// Just set default values and don't show dialog
+        DialogAccepted(); // Just set default values and don't show dialog
     }
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void DialogLineIntersectAxis::ChosenObject(quint32 id, const SceneObject &type)
 {
-    if (prepare == false)// After first choose we ignore all objects
+    if (prepare == false && type == SceneObject::Point) // After first choose we ignore all objects
     {
-        if (type == SceneObject::Point)
+        auto *line = qobject_cast<VisToolLineIntersectAxis *>(vis);
+        SCASSERT(line != nullptr)
+
+        switch (number)
         {
-            VisToolLineIntersectAxis *line = qobject_cast<VisToolLineIntersectAxis *>(vis);
-            SCASSERT(line != nullptr)
-
-            switch (number)
-            {
-                case (0):
-                    if (SetObject(id, ui->comboBoxFirstLinePoint, tr("Select second point of line")))
-                    {
-                        number++;
-                        line->VisualMode(id);
-                        VAbstractMainWindow *window =
-                                qobject_cast<VAbstractMainWindow *>(VAbstractValApplication::VApp()->getMainWindow());
-                        SCASSERT(window != nullptr)
-                        connect(line, &VisToolLineIntersectAxis::ToolTip, window, &VAbstractMainWindow::ShowToolTip);
-                    }
-                    break;
-                case (1):
-                    if (getCurrentObjectId(ui->comboBoxFirstLinePoint) != id)
-                    {
-                        if (SetObject(id, ui->comboBoxSecondLinePoint, tr("Select axis point")))
-                        {
-                            number++;
-                            line->SetPoint2Id(id);
-                            line->RefreshGeometry();
-                        }
-                    }
-                    break;
-                case (2):
+            case (0):
+                if (SetObject(id, ui->comboBoxFirstLinePoint, tr("Select second point of line")))
                 {
-                    QSet<quint32> set;
-                    set.insert(getCurrentObjectId(ui->comboBoxFirstLinePoint));
-                    set.insert(getCurrentObjectId(ui->comboBoxSecondLinePoint));
-                    set.insert(id);
+                    number++;
+                    line->VisualMode(id);
+                    auto *window =
+                        qobject_cast<VAbstractMainWindow *>(VAbstractValApplication::VApp()->getMainWindow());
+                    SCASSERT(window != nullptr)
+                    connect(line, &VisToolLineIntersectAxis::ToolTip, window, &VAbstractMainWindow::ShowToolTip);
+                }
+                break;
+            case (1):
+                if (getCurrentObjectId(ui->comboBoxFirstLinePoint) != id &&
+                    SetObject(id, ui->comboBoxSecondLinePoint, tr("Select axis point")))
+                {
+                    number++;
+                    line->SetPoint2Id(id);
+                    line->RefreshGeometry();
+                }
+                break;
+            case (2):
+            {
+                QSet<quint32> set;
+                set.insert(getCurrentObjectId(ui->comboBoxFirstLinePoint));
+                set.insert(getCurrentObjectId(ui->comboBoxSecondLinePoint));
+                set.insert(id);
 
-                    if (set.size() == 3)
+                if (set.size() == 3 && SetObject(id, ui->comboBoxAxisPoint, QString()))
+                {
+                    line->SetAxisPointId(id);
+                    line->RefreshGeometry();
+                    prepare = true;
+
+                    if (not VAbstractValApplication::VApp()->Settings()->IsInteractiveTools())
                     {
-                        if (SetObject(id, ui->comboBoxAxisPoint, QString()))
-                        {
-                            line->SetAxisPointId(id);
-                            line->RefreshGeometry();
-                            prepare = true;
-                        }
+                        vis->SetMode(Mode::Show);
+                        emit ToolTip(QString());
+                        show();
                     }
                 }
-                    break;
-                default:
-                    break;
             }
+            break;
+            default:
+                break;
         }
     }
 }
@@ -340,7 +341,6 @@ void DialogLineIntersectAxis::EvalAngle()
     formulaData.labelEditFormula = ui->labelEditFormula;
     formulaData.labelResult = ui->labelResultCalculation;
     formulaData.postfix = degreeSymbol;
-    formulaData.checkZero = false;
 
     Eval(formulaData, flagFormula);
 }
@@ -379,7 +379,7 @@ void DialogLineIntersectAxis::PointNameChanged()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogLineIntersectAxis::FXAngle()
 {
-    DialogEditWrongFormula *dialog = new DialogEditWrongFormula(data, toolId, this);
+    auto *dialog = new DialogEditWrongFormula(data, toolId, this);
     dialog->setWindowTitle(tr("Edit angle"));
     dialog->SetFormula(GetAngle());
     dialog->setPostfix(degreeSymbol);
@@ -402,7 +402,7 @@ void DialogLineIntersectAxis::SaveData()
     pointName = ui->lineEditNamePoint->text();
     formulaAngle = ui->plainTextEditFormula->toPlainText();
 
-    VisToolLineIntersectAxis *line = qobject_cast<VisToolLineIntersectAxis *>(vis);
+    auto *line = qobject_cast<VisToolLineIntersectAxis *>(vis);
     SCASSERT(line != nullptr)
 
     line->SetPoint1Id(GetFirstPointId());
@@ -420,6 +420,33 @@ void DialogLineIntersectAxis::closeEvent(QCloseEvent *event)
     DialogTool::closeEvent(event);
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void DialogLineIntersectAxis::changeEvent(QEvent *event)
+{
+    if (event->type() == QEvent::LanguageChange)
+    {
+        ui->retranslateUi(this);
+    }
+
+    if (event->type() == QEvent::PaletteChange)
+    {
+        InitIcons();
+        InitDialogButtonBoxIcons(ui->buttonBox);
+    }
+
+    // remember to call base class implementation
+    DialogTool::changeEvent(event);
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void DialogLineIntersectAxis::InitIcons()
+{
+    const auto resource = QStringLiteral("icon");
+
+    ui->toolButtonExprAngle->setIcon(VTheme::GetIconResource(resource, QStringLiteral("24x24/fx.png")));
+    ui->label_3->setPixmap(VTheme::GetPixmapResource(resource, QStringLiteral("24x24/equal.png")));
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void DialogLineIntersectAxis::SetNotes(const QString &notes)
 {
@@ -427,7 +454,7 @@ void DialogLineIntersectAxis::SetNotes(const QString &notes)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogLineIntersectAxis::GetNotes() const
+auto DialogLineIntersectAxis::GetNotes() const -> QString
 {
     return ui->plainTextEditToolNotes->toPlainText();
 }
