@@ -45,55 +45,51 @@
 #include <QStringList>
 #include <QTimer>
 #include <QToolButton>
-#include <Qt>
 #include <new>
 
-#include "../../visualization/visualization.h"
+#include "../../tools/drawTools/operation/vabstractoperation.h"
 #include "../../visualization/line/operation/vistoolmove.h"
+#include "../../visualization/visualization.h"
 #include "../ifc/xml/vabstractpattern.h"
-#include "../ifc/xml/vdomdocument.h"
 #include "../qmuparser/qmudef.h"
 #include "../support/dialogeditwrongformula.h"
-#include "../vgeometry/vpointf.h"
+#include "../vmisc/theme/vtheme.h"
 #include "../vmisc/vabstractapplication.h"
 #include "../vmisc/vcommonsettings.h"
-#include "../vmisc/compatibility.h"
-#if QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
-#include "../vmisc/backport/qoverload.h"
-#endif // QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
 #include "../vpatterndb/vcontainer.h"
 #include "../vpatterndb/vtranslatevars.h"
 #include "../vwidgets/vabstractmainwindow.h"
 #include "../vwidgets/vmaingraphicsscene.h"
 #include "../vwidgets/vmaingraphicsview.h"
 #include "ui_dialogmove.h"
-#include "../../tools/drawTools/operation/vabstractoperation.h"
 
 //---------------------------------------------------------------------------------------------------------------------
-DialogMove::DialogMove(const VContainer *data, quint32 toolId, QWidget *parent)
-    : DialogTool(data, toolId, parent),
-      ui(new Ui::DialogMove),
-      timerAngle(new QTimer(this)),
-      timerRotationAngle(new QTimer(this)),
-      timerLength(new QTimer(this)),
-      formulaAngle(),
-      formulaRotationAngle(),
-      formulaLength(),
-      formulaBaseHeightAngle(0),
-      formulaBaseHeightRotationAngle(0),
-      formulaBaseHeightLength(0),
-      stage1(true),
-      stage2(false),
-      m_suffix(),
-      optionalRotationOrigin(false),
-      flagAngle(false),
-      flagRotationAngle(false),
-      flagLength(false),
-      flagName(true),
-      flagGroupName(true)
+DialogMove::DialogMove(const VContainer *data, VAbstractPattern *doc, quint32 toolId, QWidget *parent)
+  : DialogTool(data, doc, toolId, parent),
+    ui(new Ui::DialogMove),
+    timerAngle(new QTimer(this)),
+    timerRotationAngle(new QTimer(this)),
+    timerLength(new QTimer(this)),
+    formulaAngle(),
+    formulaRotationAngle(),
+    formulaLength(),
+    formulaBaseHeightAngle(0),
+    formulaBaseHeightRotationAngle(0),
+    formulaBaseHeightLength(0),
+    stage1(true),
+    stage2(false),
+    m_suffix(),
+    optionalRotationOrigin(false),
+    flagAngle(false),
+    flagRotationAngle(false),
+    flagLength(false),
+    flagName(true),
+    flagGroupName(true)
 {
     ui->setupUi(this);
 
+    InitIcons();
+
     this->formulaBaseHeightAngle = ui->plainTextEditAngle->height();
     ui->plainTextEditAngle->installEventFilter(this);
 
@@ -116,7 +112,10 @@ DialogMove::DialogMove(const VContainer *data, quint32 toolId, QWidget *parent)
 
     InitOkCancelApply(ui);
 
-    FillComboBoxTypeLine(ui->comboBoxPenStyle, OperationLineStylesPics(), TypeLineDefault);
+    FillComboBoxTypeLine(ui->comboBoxPenStyle,
+                         OperationLineStylesPics(ui->comboBoxPenStyle->palette().color(QPalette::Base),
+                                                 ui->comboBoxPenStyle->palette().color(QPalette::Text)),
+                         TypeLineDefault);
     FillComboBoxLineColors(ui->comboBoxColor, VAbstractOperation::OperationColorsList());
     FillComboBoxPoints(ui->comboBoxRotationOriginPoint);
 
@@ -129,20 +128,14 @@ DialogMove::DialogMove(const VContainer *data, quint32 toolId, QWidget *parent)
     connect(ui->toolButtonExprAngle, &QPushButton::clicked, this, &DialogMove::FXAngle);
     connect(ui->toolButtonExprRotationAngle, &QPushButton::clicked, this, &DialogMove::FXRotationAngle);
     connect(ui->toolButtonExprLength, &QPushButton::clicked, this, &DialogMove::FXLength);
-    connect(ui->plainTextEditAngle, &QPlainTextEdit::textChanged, this, [this]()
-    {
-        timerAngle->start(formulaTimerTimeout);
-    });
+    connect(ui->plainTextEditAngle, &QPlainTextEdit::textChanged, this,
+            [this]() { timerAngle->start(formulaTimerTimeout); });
 
-    connect(ui->plainTextEditRotationAngle, &QPlainTextEdit::textChanged, this, [this]()
-    {
-        timerRotationAngle->start(formulaTimerTimeout);
-    });
+    connect(ui->plainTextEditRotationAngle, &QPlainTextEdit::textChanged, this,
+            [this]() { timerRotationAngle->start(formulaTimerTimeout); });
 
-    connect(ui->plainTextEditLength, &QPlainTextEdit::textChanged, this, [this]()
-    {
-        timerLength->start(formulaTimerTimeout);
-    });
+    connect(ui->plainTextEditLength, &QPlainTextEdit::textChanged, this,
+            [this]() { timerLength->start(formulaTimerTimeout); });
 
     connect(ui->pushButtonGrowAngle, &QPushButton::clicked, this, &DialogMove::DeployAngleTextEdit);
     connect(ui->pushButtonGrowRotationAngle, &QPushButton::clicked, this, &DialogMove::DeployRotationAngleTextEdit);
@@ -169,7 +162,7 @@ DialogMove::~DialogMove()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogMove::GetAngle() const
+auto DialogMove::GetAngle() const -> QString
 {
     return VTranslateVars::TryFormulaFromUser(formulaAngle, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
 }
@@ -177,8 +170,8 @@ QString DialogMove::GetAngle() const
 //---------------------------------------------------------------------------------------------------------------------
 void DialogMove::SetAngle(const QString &value)
 {
-    formulaAngle = VAbstractApplication::VApp()->TrVars()
-            ->FormulaToUser(value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    formulaAngle = VAbstractApplication::VApp()->TrVars()->FormulaToUser(
+        value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
     // increase height if needed.
     if (formulaAngle.length() > 80)
     {
@@ -186,7 +179,7 @@ void DialogMove::SetAngle(const QString &value)
     }
     ui->plainTextEditAngle->setPlainText(formulaAngle);
 
-    VisToolMove *operation = qobject_cast<VisToolMove *>(vis);
+    auto *operation = qobject_cast<VisToolMove *>(vis);
     SCASSERT(operation != nullptr)
     operation->SetAngle(formulaAngle);
 
@@ -194,16 +187,17 @@ void DialogMove::SetAngle(const QString &value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogMove::GetLength() const
+auto DialogMove::GetLength() const -> QString
 {
-    return VTranslateVars::TryFormulaFromUser(formulaLength, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    return VTranslateVars::TryFormulaFromUser(formulaLength,
+                                              VAbstractApplication::VApp()->Settings()->GetOsSeparator());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void DialogMove::SetLength(const QString &value)
 {
-    formulaLength = VAbstractApplication::VApp()->TrVars()
-            ->FormulaToUser(value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    formulaLength = VAbstractApplication::VApp()->TrVars()->FormulaToUser(
+        value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
     // increase height if needed.
     if (formulaLength.length() > 80)
     {
@@ -211,7 +205,7 @@ void DialogMove::SetLength(const QString &value)
     }
     ui->plainTextEditLength->setPlainText(formulaLength);
 
-    VisToolMove *operation = qobject_cast<VisToolMove *>(vis);
+    auto *operation = qobject_cast<VisToolMove *>(vis);
     SCASSERT(operation != nullptr)
     operation->SetLength(formulaLength);
 
@@ -219,16 +213,17 @@ void DialogMove::SetLength(const QString &value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogMove::GetRotationAngle() const
+auto DialogMove::GetRotationAngle() const -> QString
 {
-    return VTranslateVars::TryFormulaFromUser(formulaRotationAngle, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    return VTranslateVars::TryFormulaFromUser(formulaRotationAngle,
+                                              VAbstractApplication::VApp()->Settings()->GetOsSeparator());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void DialogMove::SetRotationAngle(const QString &value)
 {
-    formulaRotationAngle = VAbstractApplication::VApp()->TrVars()
-            ->FormulaToUser(value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    formulaRotationAngle = VAbstractApplication::VApp()->TrVars()->FormulaToUser(
+        value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
     // increase height if needed.
     if (formulaRotationAngle.length() > 80)
     {
@@ -236,7 +231,7 @@ void DialogMove::SetRotationAngle(const QString &value)
     }
     ui->plainTextEditRotationAngle->setPlainText(formulaRotationAngle);
 
-    VisToolMove *operation = qobject_cast<VisToolMove *>(vis);
+    auto *operation = qobject_cast<VisToolMove *>(vis);
     SCASSERT(operation != nullptr)
     operation->SetRotationAngle(formulaRotationAngle);
 
@@ -244,7 +239,7 @@ void DialogMove::SetRotationAngle(const QString &value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogMove::GetSuffix() const
+auto DialogMove::GetSuffix() const -> QString
 {
     return m_suffix;
 }
@@ -257,7 +252,7 @@ void DialogMove::SetSuffix(const QString &value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-quint32 DialogMove::GetRotationOrigPointId() const
+auto DialogMove::GetRotationOrigPointId() const -> quint32
 {
     return getCurrentObjectId(ui->comboBoxRotationOriginPoint);
 }
@@ -266,13 +261,13 @@ quint32 DialogMove::GetRotationOrigPointId() const
 void DialogMove::SetRotationOrigPointId(const quint32 &value)
 {
     ChangeCurrentData(ui->comboBoxRotationOriginPoint, value);
-    VisToolMove *operation = qobject_cast<VisToolMove *>(vis);
+    auto *operation = qobject_cast<VisToolMove *>(vis);
     SCASSERT(operation != nullptr)
     operation->SetRotationOriginPointId(value);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogMove::GetVisibilityGroupName() const
+auto DialogMove::GetVisibilityGroupName() const -> QString
 {
     return ui->lineEditVisibilityGroup->text();
 }
@@ -284,7 +279,7 @@ void DialogMove::SetVisibilityGroupName(const QString &name)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool DialogMove::HasLinkedVisibilityGroup() const
+auto DialogMove::HasLinkedVisibilityGroup() const -> bool
 {
     return ui->groupBoxVisibilityGroup->isChecked();
 }
@@ -302,7 +297,7 @@ void DialogMove::SetVisibilityGroupTags(const QStringList &tags)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QStringList DialogMove::GetVisibilityGroupTags() const
+auto DialogMove::GetVisibilityGroupTags() const -> QStringList
 {
     return ui->lineEditGroupTags->text().split(',');
 }
@@ -361,10 +356,10 @@ void DialogMove::ShowDialog(bool click)
 
         if (operation->LengthValue() > 0)
         {
-            formulaAngle = VAbstractApplication::VApp()->TrVars()
-                    ->FormulaToUser(operation->Angle(), VAbstractApplication::VApp()->Settings()->GetOsSeparator());
-            formulaLength = VAbstractApplication::VApp()->TrVars()
-                    ->FormulaToUser(operation->Length(), VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+            formulaAngle = VAbstractApplication::VApp()->TrVars()->FormulaToUser(
+                operation->Angle(), VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+            formulaLength = VAbstractApplication::VApp()->TrVars()->FormulaToUser(
+                operation->Length(), VAbstractApplication::VApp()->Settings()->GetOsSeparator());
             operation->SetAngle(formulaAngle);
             operation->SetLength(formulaLength);
             operation->RefreshGeometry();
@@ -389,10 +384,10 @@ void DialogMove::ShowDialog(bool click)
         }
         else
         {
-            SetAngle(VAbstractApplication::VApp()->TrVars()
-                     ->FormulaFromUser(formulaAngle, VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
-            SetLength(VAbstractApplication::VApp()->TrVars()
-                      ->FormulaFromUser(formulaLength, VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
+            SetAngle(VAbstractApplication::VApp()->TrVars()->FormulaFromUser(
+                formulaAngle, VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
+            SetLength(VAbstractApplication::VApp()->TrVars()->FormulaFromUser(
+                formulaLength, VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
             SetRotationAngle(operation->RotationAngle());
             setModal(true);
             emit ToolTip(QString());
@@ -407,20 +402,16 @@ void DialogMove::ShowDialog(bool click)
 //---------------------------------------------------------------------------------------------------------------------
 void DialogMove::ChosenObject(quint32 id, const SceneObject &type)
 {
-    if (not stage1 && stage2 && prepare)// After first choose we ignore all objects
+    if (not stage1 && stage2 && prepare && type == SceneObject::Point &&
+        QGuiApplication::keyboardModifiers() == Qt::ControlModifier &&
+        SetObject(id, ui->comboBoxRotationOriginPoint, QString())) // After first choose we ignore all objects
     {
-        if (type == SceneObject::Point && QGuiApplication::keyboardModifiers() == Qt::ControlModifier)
-        {
-            if (SetObject(id, ui->comboBoxRotationOriginPoint, QString()))
-            {
-                auto *operation = qobject_cast<VisToolMove *>(vis);
-                SCASSERT(operation != nullptr)
+        auto *operation = qobject_cast<VisToolMove *>(vis);
+        SCASSERT(operation != nullptr)
 
-                operation->SetRotationOriginPointId(id);
-                operation->RefreshGeometry();
-                optionalRotationOrigin = true;
-            }
-        }
+        operation->SetRotationOriginPointId(id);
+        operation->RefreshGeometry();
+        optionalRotationOrigin = true;
     }
 }
 
@@ -430,11 +421,11 @@ void DialogMove::SelectedObject(bool selected, quint32 object, quint32 tool)
     Q_UNUSED(tool)
     if (stage1)
     {
-        auto *obj = std::find_if(sourceObjects.begin(), sourceObjects.end(),
-                                 [object](const SourceItem &sItem) { return sItem.id == object; });
+        auto obj = std::find_if(sourceObjects.begin(), sourceObjects.end(),
+                                [object](const SourceItem &sItem) { return sItem.id == object; });
         if (selected)
         {
-            if (obj == sourceObjects.cend())
+            if (obj == sourceObjects.end())
             {
                 SourceItem item;
                 item.id = object;
@@ -443,7 +434,7 @@ void DialogMove::SelectedObject(bool selected, quint32 object, quint32 tool)
         }
         else
         {
-            if (obj != sourceObjects.cend())
+            if (obj != sourceObjects.end())
             {
                 sourceObjects.erase(obj);
             }
@@ -460,7 +451,8 @@ void DialogMove::DeployAngleTextEdit()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogMove::DeployRotationAngleTextEdit()
 {
-    DeployFormula(this, ui->plainTextEditRotationAngle, ui->pushButtonGrowRotationAngle, formulaBaseHeightRotationAngle);
+    DeployFormula(this, ui->plainTextEditRotationAngle, ui->pushButtonGrowRotationAngle,
+                  formulaBaseHeightRotationAngle);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -472,7 +464,7 @@ void DialogMove::DeployLengthTextEdit()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogMove::FXAngle()
 {
-    DialogEditWrongFormula *dialog = new DialogEditWrongFormula(data, toolId, this);
+    auto *dialog = new DialogEditWrongFormula(data, toolId, this);
     dialog->setWindowTitle(tr("Edit angle"));
     dialog->SetFormula(GetAngle());
     dialog->setPostfix(degreeSymbol);
@@ -486,7 +478,7 @@ void DialogMove::FXAngle()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogMove::FXRotationAngle()
 {
-    DialogEditWrongFormula *dialog = new DialogEditWrongFormula(data, toolId, this);
+    auto *dialog = new DialogEditWrongFormula(data, toolId, this);
     dialog->setWindowTitle(tr("Edit rotation angle"));
     dialog->SetFormula(GetRotationAngle());
     dialog->setPostfix(degreeSymbol);
@@ -500,7 +492,7 @@ void DialogMove::FXRotationAngle()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogMove::FXLength()
 {
-    DialogEditWrongFormula *dialog = new DialogEditWrongFormula(data, toolId, this);
+    auto *dialog = new DialogEditWrongFormula(data, toolId, this);
     dialog->setWindowTitle(tr("Edit length"));
     dialog->SetFormula(GetLength());
     dialog->setPostfix(UnitsToStr(VAbstractValApplication::VApp()->patternUnits(), true));
@@ -514,7 +506,7 @@ void DialogMove::FXLength()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogMove::SuffixChanged()
 {
-    QLineEdit* edit = qobject_cast<QLineEdit*>(sender());
+    auto *edit = qobject_cast<QLineEdit *>(sender());
     if (edit)
     {
         const QString suffix = edit->text();
@@ -526,23 +518,21 @@ void DialogMove::SuffixChanged()
             CheckState();
             return;
         }
-        else
+
+        if (m_suffix != suffix)
         {
-            if (m_suffix != suffix)
+            QRegularExpression const rx(NameRegExp());
+            const QStringList uniqueNames = data->AllUniqueNames();
+            for (const auto &uniqueName : uniqueNames)
             {
-                QRegularExpression rx(NameRegExp());
-                const QStringList uniqueNames = data->AllUniqueNames();
-                for (auto &uniqueName : uniqueNames)
+                const QString name = uniqueName + suffix;
+                if (not rx.match(name).hasMatch() || not data->IsUnique(name))
                 {
-                    const QString name = uniqueName + suffix;
-                    if (not rx.match(name).hasMatch() || not data->IsUnique(name))
-                    {
-                        flagName = false;
-                        ChangeColor(ui->labelSuffix, errorColor);
-                        ui->labelStatus->setText(tr("Invalid suffix"));
-                        CheckState();
-                        return;
-                    }
+                    flagName = false;
+                    ChangeColor(ui->labelSuffix, errorColor);
+                    ui->labelStatus->setText(tr("Invalid suffix"));
+                    CheckState();
+                    return;
                 }
             }
         }
@@ -556,7 +546,7 @@ void DialogMove::SuffixChanged()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogMove::GroupNameChanged()
 {
-    QLineEdit* edit = qobject_cast<QLineEdit*>(sender());
+    auto *edit = qobject_cast<QLineEdit *>(sender());
     if (edit)
     {
         const QString name = edit->text();
@@ -608,7 +598,7 @@ void DialogMove::ShowSourceDetails(int row)
     {
         ui->labelAlias->setText(tr("Alias:"));
 
-        auto SetValue = [sourceItem](QComboBox *box, const QString &value, const QString &def)
+        auto SetValue = [](QComboBox *box, const QString &value, const QString &def)
         {
             box->blockSignals(true);
 
@@ -631,7 +621,7 @@ void DialogMove::ShowSourceDetails(int row)
         if (sourceItem.penStyle.isEmpty() || sourceItem.penStyle == TypeLineDefault)
         {
             const QSharedPointer<VAbstractCurve> curve = data->GeometricObject<VAbstractCurve>(sourceItem.id);
-            int index = ui->comboBoxPenStyle->currentIndex();
+            int const index = ui->comboBoxPenStyle->currentIndex();
             ui->comboBoxPenStyle->setItemText(index, '<' + tr("Default") + '>');
         }
 
@@ -640,8 +630,9 @@ void DialogMove::ShowSourceDetails(int row)
         if (sourceItem.color.isEmpty() || sourceItem.color == ColorDefault)
         {
             const QSharedPointer<VAbstractCurve> curve = data->GeometricObject<VAbstractCurve>(sourceItem.id);
-            int index = ui->comboBoxColor->currentIndex();
-            ui->comboBoxColor->setItemIcon(index, LineColor(ui->comboBoxColor->iconSize().height(), curve->GetColor()));
+            int const index = ui->comboBoxColor->currentIndex();
+            ui->comboBoxColor->setItemIcon(index, LineColor(ui->comboBoxColor->palette().color(QPalette::Text),
+                                                            ui->comboBoxColor->iconSize().height(), curve->GetColor()));
         }
 
         ui->comboBoxPenStyle->setEnabled(true);
@@ -725,7 +716,7 @@ void DialogMove::SaveData()
     sourceObjects.clear();
     sourceObjects.reserve(ui->listWidget->count());
 
-    for (int i=0; i<ui->listWidget->count(); ++i)
+    for (int i = 0; i < ui->listWidget->count(); ++i)
     {
         if (const QListWidgetItem *item = ui->listWidget->item(i))
         {
@@ -734,7 +725,7 @@ void DialogMove::SaveData()
         }
     }
 
-    VisToolMove *operation = qobject_cast<VisToolMove *>(vis);
+    auto *operation = qobject_cast<VisToolMove *>(vis);
     SCASSERT(operation != nullptr)
 
     operation->SetObjects(SourceToObjects(sourceObjects));
@@ -767,7 +758,7 @@ void DialogMove::closeEvent(QCloseEvent *event)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QVector<SourceItem> DialogMove::GetSourceObjects() const
+auto DialogMove::GetSourceObjects() const -> QVector<SourceItem>
 {
     return sourceObjects;
 }
@@ -778,7 +769,7 @@ void DialogMove::SetSourceObjects(const QVector<SourceItem> &value)
     sourceObjects = value;
     FillSourceList();
 
-    VisToolMove *operation = qobject_cast<VisToolMove *>(vis);
+    auto *operation = qobject_cast<VisToolMove *>(vis);
     SCASSERT(operation != nullptr)
     operation->SetObjects(SourceToObjects(sourceObjects));
 }
@@ -792,7 +783,6 @@ void DialogMove::EvalAngle()
     formulaData.labelEditFormula = ui->labelEditAngle;
     formulaData.labelResult = ui->labelResultAngle;
     formulaData.postfix = degreeSymbol;
-    formulaData.checkZero = false;
 
     Eval(formulaData, flagAngle);
 
@@ -811,7 +801,6 @@ void DialogMove::EvalRotationAngle()
     formulaData.labelEditFormula = ui->labelEditRotationAngle;
     formulaData.labelResult = ui->labelResultRotationAngle;
     formulaData.postfix = degreeSymbol;
-    formulaData.checkZero = false;
 
     Eval(formulaData, flagRotationAngle);
 
@@ -851,7 +840,7 @@ void DialogMove::FillSourceList()
     for (auto &sourceItem : sourceObjects)
     {
         const QSharedPointer<VGObject> obj = data->GetGObject(sourceItem.id);
-        bool valid = SourceAliasValid(sourceItem, obj, data, OriginAlias(sourceItem.id, sourceObjects, obj));
+        bool const valid = SourceAliasValid(sourceItem, obj, data, OriginAlias(sourceItem.id, sourceObjects, obj));
 
         auto *item = new QListWidgetItem(valid ? obj->ObjectName() : obj->ObjectName() + '*');
         item->setToolTip(obj->ObjectName());
@@ -872,7 +861,7 @@ void DialogMove::FillSourceList()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogMove::ValidateSourceAliases()
 {
-    for (int i=0; i<ui->listWidget->count(); ++i)
+    for (int i = 0; i < ui->listWidget->count(); ++i)
     {
         if (const QListWidgetItem *item = ui->listWidget->item(i))
         {
@@ -888,10 +877,8 @@ void DialogMove::ValidateSourceAliases()
                 CheckState();
                 return;
             }
-            else
-            {
-                SetAliasValid(sourceItem.id, true);
-            }
+
+            SetAliasValid(sourceItem.id, true);
         }
     }
 
@@ -917,6 +904,22 @@ void DialogMove::SetAliasValid(quint32 id, bool valid)
     }
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void DialogMove::InitIcons()
+{
+    const auto resource = QStringLiteral("icon");
+
+    const auto fxIcon = QStringLiteral("24x24/fx.png");
+    ui->toolButtonExprAngle->setIcon(VTheme::GetIconResource(resource, fxIcon));
+    ui->toolButtonExprLength->setIcon(VTheme::GetIconResource(resource, fxIcon));
+    ui->toolButtonExprRotationAngle->setIcon(VTheme::GetIconResource(resource, fxIcon));
+
+    const auto equalIcon = QStringLiteral("24x24/equal.png");
+    ui->label_2->setPixmap(VTheme::GetPixmapResource(resource, equalIcon));
+    ui->label_3->setPixmap(VTheme::GetPixmapResource(resource, equalIcon));
+    ui->label_4->setPixmap(VTheme::GetPixmapResource(resource, equalIcon));
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void DialogMove::SetNotes(const QString &notes)
 {
@@ -924,15 +927,15 @@ void DialogMove::SetNotes(const QString &notes)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogMove::GetNotes() const
+auto DialogMove::GetNotes() const -> QString
 {
     return ui->plainTextEditToolNotes->toPlainText();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool DialogMove::IsValid() const
+auto DialogMove::IsValid() const -> bool
 {
-    bool ready = flagAngle && flagRotationAngle && flagLength && flagName && flagGroupName && flagAlias;
+    bool const ready = flagAngle && flagRotationAngle && flagLength && flagName && flagGroupName && flagAlias;
 
     if (ready)
     {
