@@ -32,24 +32,25 @@
 #include <QLineEdit>
 #include <QPointer>
 
-#include "../../visualization/visualization.h"
 #include "../../visualization/line/vistoolpointfromarcandtangent.h"
-#include "dialogs/tools/dialogtool.h"
+#include "../../visualization/visualization.h"
+#include "dialogtool.h"
 #include "ui_dialogpointfromarcandtangent.h"
 
 //---------------------------------------------------------------------------------------------------------------------
-DialogPointFromArcAndTangent::DialogPointFromArcAndTangent(const VContainer *data, quint32 toolId, QWidget *parent)
-    : DialogTool(data, toolId, parent),
-      ui(new Ui::DialogPointFromArcAndTangent),
-      pointName(),
-      flagName(true)
+DialogPointFromArcAndTangent::DialogPointFromArcAndTangent(const VContainer *data, VAbstractPattern *doc,
+                                                           quint32 toolId, QWidget *parent)
+  : DialogTool(data, doc, toolId, parent),
+    ui(new Ui::DialogPointFromArcAndTangent),
+    pointName(),
+    flagName(true)
 {
     ui->setupUi(this);
 
     ui->lineEditNamePoint->setClearButtonEnabled(true);
 
     ui->lineEditNamePoint->setText(
-                VAbstractValApplication::VApp()->getCurrentDocument()->GenerateLabel(LabelType::NewLabel));
+        VAbstractValApplication::VApp()->getCurrentDocument()->GenerateLabel(LabelType::NewLabel));
 
     InitOkCancelApply(ui);
 
@@ -57,11 +58,12 @@ DialogPointFromArcAndTangent::DialogPointFromArcAndTangent(const VContainer *dat
     FillComboBoxArcs(ui->comboBoxArc);
     FillComboBoxCrossCirclesPoints(ui->comboBoxResult);
 
-    connect(ui->lineEditNamePoint, &QLineEdit::textChanged, this, [this]()
-    {
-        CheckPointLabel(this, ui->lineEditNamePoint, ui->labelEditNamePoint, pointName, this->data, flagName);
-        CheckState();
-    });
+    connect(ui->lineEditNamePoint, &QLineEdit::textChanged, this,
+            [this]()
+            {
+                CheckPointLabel(this, ui->lineEditNamePoint, ui->labelEditNamePoint, pointName, this->data, flagName);
+                CheckState();
+            });
 
     vis = new VisToolPointFromArcAndTangent(data);
 
@@ -76,7 +78,7 @@ DialogPointFromArcAndTangent::~DialogPointFromArcAndTangent()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogPointFromArcAndTangent::GetPointName() const
+auto DialogPointFromArcAndTangent::GetPointName() const -> QString
 {
     return pointName;
 }
@@ -89,7 +91,7 @@ void DialogPointFromArcAndTangent::SetPointName(const QString &value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-quint32 DialogPointFromArcAndTangent::GetArcId() const
+auto DialogPointFromArcAndTangent::GetArcId() const -> quint32
 {
     return getCurrentObjectId(ui->comboBoxArc);
 }
@@ -99,13 +101,13 @@ void DialogPointFromArcAndTangent::SetArcId(quint32 value)
 {
     setCurrentArcId(ui->comboBoxArc, value);
 
-    VisToolPointFromArcAndTangent *point = qobject_cast<VisToolPointFromArcAndTangent *>(vis);
+    auto *point = qobject_cast<VisToolPointFromArcAndTangent *>(vis);
     SCASSERT(point != nullptr)
     point->SetArcId(value);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-quint32 DialogPointFromArcAndTangent::GetTangentPointId() const
+auto DialogPointFromArcAndTangent::GetTangentPointId() const -> quint32
 {
     return getCurrentObjectId(ui->comboBoxTangentPoint);
 }
@@ -121,7 +123,7 @@ void DialogPointFromArcAndTangent::SetTangentPointId(quint32 value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-CrossCirclesPoint DialogPointFromArcAndTangent::GetCrossCirclesPoint() const
+auto DialogPointFromArcAndTangent::GetCrossCirclesPoint() const -> CrossCirclesPoint
 {
     return getCurrentCrossPoint<CrossCirclesPoint>(ui->comboBoxResult);
 }
@@ -134,7 +136,7 @@ void DialogPointFromArcAndTangent::SetCrossCirclesPoint(CrossCirclesPoint p)
     {
         ui->comboBoxResult->setCurrentIndex(index);
 
-        VisToolPointFromArcAndTangent *point = qobject_cast<VisToolPointFromArcAndTangent *>(vis);
+        auto *point = qobject_cast<VisToolPointFromArcAndTangent *>(vis);
         SCASSERT(point != nullptr)
         point->SetCrossPoint(p);
     }
@@ -143,41 +145,33 @@ void DialogPointFromArcAndTangent::SetCrossCirclesPoint(CrossCirclesPoint p)
 //---------------------------------------------------------------------------------------------------------------------
 void DialogPointFromArcAndTangent::ChosenObject(quint32 id, const SceneObject &type)
 {
-    if (prepare == false)// After first choose we ignore all objects
+    if (prepare == false &&
+        (type == SceneObject::Point || type == SceneObject::Arc)) // After first choose we ignore all objects
     {
-        if (type == SceneObject::Point || type == SceneObject::Arc)
-        {
-            VisToolPointFromArcAndTangent *point = qobject_cast<VisToolPointFromArcAndTangent *>(vis);
-            SCASSERT(point != nullptr)
+        auto *point = qobject_cast<VisToolPointFromArcAndTangent *>(vis);
+        SCASSERT(point != nullptr)
 
-            switch (number)
-            {
-                case 0:
-                    if (type == SceneObject::Point)
-                    {
-                        if (SetObject(id, ui->comboBoxTangentPoint, tr("Select an arc")))
-                        {
-                            number++;
-                            point->VisualMode(id);
-                        }
-                    }
-                    break;
-                case 1:
-                    if (type == SceneObject::Arc)
-                    {
-                        if (SetObject(id, ui->comboBoxArc, QString()))
-                        {
-                            number = 0;
-                            point->SetArcId(id);
-                            point->RefreshGeometry();
-                            prepare = true;
-                            DialogAccepted();
-                        }
-                    }
-                    break;
-                default:
-                    break;
-            }
+        switch (number)
+        {
+            case 0:
+                if (type == SceneObject::Point && SetObject(id, ui->comboBoxTangentPoint, tr("Select an arc")))
+                {
+                    number++;
+                    point->VisualMode(id);
+                }
+                break;
+            case 1:
+                if (type == SceneObject::Arc && SetObject(id, ui->comboBoxArc, QString()))
+                {
+                    number = 0;
+                    point->SetArcId(id);
+                    point->RefreshGeometry();
+                    prepare = true;
+                    DialogAccepted();
+                }
+                break;
+            default:
+                break;
         }
     }
 }
@@ -209,7 +203,7 @@ void DialogPointFromArcAndTangent::SetNotes(const QString &notes)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogPointFromArcAndTangent::GetNotes() const
+auto DialogPointFromArcAndTangent::GetNotes() const -> QString
 {
     return ui->plainTextEditToolNotes->toPlainText();
 }
