@@ -40,17 +40,18 @@
 #include <QTimer>
 #include <QToolButton>
 
-#include "../vpatterndb/vtranslatevars.h"
-#include "../vpatterndb/vcontainer.h"
-#include "../../visualization/visualization.h"
 #include "../../visualization/line/vistoolpointofcontact.h"
+#include "../../visualization/visualization.h"
 #include "../ifc/xml/vabstractpattern.h"
 #include "../support/dialogeditwrongformula.h"
+#include "../vgeometry/vpointf.h"
+#include "../vmisc/theme/vtheme.h"
 #include "../vmisc/vabstractapplication.h"
 #include "../vmisc/vcommonsettings.h"
-#include "ui_dialogpointofcontact.h"
+#include "../vpatterndb/vcontainer.h"
+#include "../vpatterndb/vtranslatevars.h"
 #include "../vwidgets/vabstractmainwindow.h"
-#include "../vgeometry/vpointf.h"
+#include "ui_dialogpointofcontact.h"
 
 //---------------------------------------------------------------------------------------------------------------------
 /**
@@ -58,20 +59,23 @@
  * @param data container with data
  * @param parent parent widget
  */
-DialogPointOfContact::DialogPointOfContact(const VContainer *data, quint32 toolId, QWidget *parent)
-    : DialogTool(data, toolId, parent),
-      ui(new Ui::DialogPointOfContact),
-      m_timerFormula(new QTimer(this))
+DialogPointOfContact::DialogPointOfContact(const VContainer *data, VAbstractPattern *doc, quint32 toolId,
+                                           QWidget *parent)
+  : DialogTool(data, doc, toolId, parent),
+    ui(new Ui::DialogPointOfContact),
+    m_timerFormula(new QTimer(this))
 {
     ui->setupUi(this);
 
+    InitIcons();
+
     m_timerFormula->setSingleShot(true);
     connect(m_timerFormula, &QTimer::timeout, this, &DialogPointOfContact::EvalFormula);
 
     ui->lineEditNamePoint->setClearButtonEnabled(true);
 
     ui->lineEditNamePoint->setText(
-                VAbstractValApplication::VApp()->getCurrentDocument()->GenerateLabel(LabelType::NewLabel));
+        VAbstractValApplication::VApp()->getCurrentDocument()->GenerateLabel(LabelType::NewLabel));
     this->m_formulaBaseHeight = ui->plainTextEditFormula->height();
     ui->plainTextEditFormula->installEventFilter(this);
 
@@ -82,22 +86,19 @@ DialogPointOfContact::DialogPointOfContact(const VContainer *data, quint32 toolI
     FillComboBoxPoints(ui->comboBoxCenter);
 
     connect(ui->toolButtonExprRadius, &QPushButton::clicked, this, &DialogPointOfContact::FXRadius);
-    connect(ui->lineEditNamePoint, &QLineEdit::textChanged, this, [this]()
-    {
-        CheckPointLabel(this, ui->lineEditNamePoint, ui->labelEditNamePoint, m_pointName, this->data, m_flagName);
-        CheckState();
-    });
-    connect(ui->plainTextEditFormula, &QPlainTextEdit::textChanged, this, [this]()
-    {
-        m_timerFormula->start(formulaTimerTimeout);
-    });
+    connect(ui->lineEditNamePoint, &QLineEdit::textChanged, this,
+            [this]()
+            {
+                CheckPointLabel(this, ui->lineEditNamePoint, ui->labelEditNamePoint, m_pointName, this->data,
+                                m_flagName);
+                CheckState();
+            });
+    connect(ui->plainTextEditFormula, &QPlainTextEdit::textChanged, this,
+            [this]() { m_timerFormula->start(formulaTimerTimeout); });
     connect(ui->pushButtonGrowLength, &QPushButton::clicked, this, &DialogPointOfContact::DeployFormulaTextEdit);
-    connect(ui->comboBoxFirstPoint, &QComboBox::currentTextChanged,
-            this, &DialogPointOfContact::PointNameChanged);
-    connect(ui->comboBoxSecondPoint, &QComboBox::currentTextChanged,
-            this, &DialogPointOfContact::PointNameChanged);
-    connect(ui->comboBoxCenter, &QComboBox::currentTextChanged,
-            this, &DialogPointOfContact::PointNameChanged);
+    connect(ui->comboBoxFirstPoint, &QComboBox::currentTextChanged, this, &DialogPointOfContact::PointNameChanged);
+    connect(ui->comboBoxSecondPoint, &QComboBox::currentTextChanged, this, &DialogPointOfContact::PointNameChanged);
+    connect(ui->comboBoxCenter, &QComboBox::currentTextChanged, this, &DialogPointOfContact::PointNameChanged);
 
     vis = new VisToolPointOfContact(data);
 
@@ -204,18 +205,12 @@ void DialogPointOfContact::ShowDialog(bool click)
 
         const QSharedPointer<VPointF> center = data->GeometricObject<VPointF>(GetCenter());
 
-        QLineF line(static_cast<QPointF>(*center), scene->getScenePos());
+        QLineF const line(static_cast<QPointF>(*center), scene->getScenePos());
 
         SetRadius(QString::number(FromPixel(line.length(), *data->GetPatternUnit())));
     }
 
-    vis->SetMode(Mode::Show);
-    vis->RefreshGeometry();
-
-    emit ToolTip(QString());
-
-    setModal(true);
-    show();
+    FinishCreating();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -226,7 +221,7 @@ void DialogPointOfContact::ShowDialog(bool click)
  */
 void DialogPointOfContact::ChosenObject(quint32 id, const SceneObject &type)
 {
-    if (prepare)// After first choose we ignore all objects
+    if (prepare) // After first choose we ignore all objects
     {
         return;
     }
@@ -249,14 +244,12 @@ void DialogPointOfContact::ChosenObject(quint32 id, const SceneObject &type)
             }
             break;
         case 1:
-            if (getCurrentObjectId(ui->comboBoxFirstPoint) != id)
+            if (getCurrentObjectId(ui->comboBoxFirstPoint) != id &&
+                SetObject(id, ui->comboBoxSecondPoint, tr("Select point of center of arc")))
             {
-                if (SetObject(id, ui->comboBoxSecondPoint, tr("Select point of center of arc")))
-                {
-                    m_number++;
-                    line->SetLineP2Id(id);
-                    line->RefreshGeometry();
-                }
+                m_number++;
+                line->SetLineP2Id(id);
+                line->RefreshGeometry();
             }
             break;
         case 2:
@@ -266,22 +259,23 @@ void DialogPointOfContact::ChosenObject(quint32 id, const SceneObject &type)
             set.insert(getCurrentObjectId(ui->comboBoxSecondPoint));
             set.insert(id);
 
-            if (set.size() == 3)
+            if (set.size() == 3 && SetObject(id, ui->comboBoxCenter, QString()))
             {
-                if (SetObject(id, ui->comboBoxCenter, QString()))
-                {
-                    auto *window = qobject_cast<VAbstractMainWindow *>(
-                        VAbstractValApplication::VApp()->getMainWindow());
-                    SCASSERT(window != nullptr)
-                    connect(line, &Visualization::ToolTip, window, &VAbstractMainWindow::ShowToolTip);
+                auto *window = qobject_cast<VAbstractMainWindow *>(VAbstractValApplication::VApp()->getMainWindow());
+                SCASSERT(window != nullptr)
+                connect(line, &Visualization::ToolTip, window, &VAbstractMainWindow::ShowToolTip);
 
-                    line->SetRadiusId(id);
-                    line->RefreshGeometry();
-                    prepare = true;
+                line->SetRadiusId(id);
+                line->RefreshGeometry();
+                prepare = true;
+
+                if (not VAbstractValApplication::VApp()->Settings()->IsInteractiveTools())
+                {
+                    FinishCreating();
                 }
             }
         }
-            break;
+        break;
         default:
             break;
     }
@@ -310,6 +304,45 @@ void DialogPointOfContact::closeEvent(QCloseEvent *event)
     DialogTool::closeEvent(event);
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void DialogPointOfContact::changeEvent(QEvent *event)
+{
+    if (event->type() == QEvent::LanguageChange)
+    {
+        ui->retranslateUi(this);
+    }
+
+    if (event->type() == QEvent::PaletteChange)
+    {
+        InitIcons();
+        InitDialogButtonBoxIcons(ui->buttonBox);
+    }
+
+    // remember to call base class implementation
+    DialogTool::changeEvent(event);
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void DialogPointOfContact::FinishCreating()
+{
+    vis->SetMode(Mode::Show);
+    vis->RefreshGeometry();
+
+    emit ToolTip(QString());
+
+    setModal(true);
+    show();
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void DialogPointOfContact::InitIcons()
+{
+    const auto resource = QStringLiteral("icon");
+
+    ui->toolButtonExprRadius->setIcon(VTheme::GetIconResource(resource, QStringLiteral("24x24/fx.png")));
+    ui->label->setPixmap(VTheme::GetPixmapResource(resource, QStringLiteral("24x24/equal.png")));
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 /**
  * @brief SetSecondPoint set id second point
@@ -359,8 +392,8 @@ void DialogPointOfContact::SetCenter(quint32 value)
  */
 void DialogPointOfContact::SetRadius(const QString &value)
 {
-    m_radius = VAbstractApplication::VApp()->TrVars()
-            ->FormulaToUser(value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    m_radius = VAbstractApplication::VApp()->TrVars()->FormulaToUser(
+        value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
     // increase height if needed.
     if (m_radius.length() > 80)
     {
