@@ -29,7 +29,6 @@
 #ifndef DIALOGPOINTOFINTERSECTION_H
 #define DIALOGPOINTOFINTERSECTION_H
 
-#include <qcompilerdetection.h>
 #include <QMetaObject>
 #include <QObject>
 #include <QString>
@@ -40,40 +39,44 @@
 
 namespace Ui
 {
-    class DialogPointOfIntersection;
+class DialogPointOfIntersection;
 }
 
 /**
  * @brief The DialogPointOfIntersection class dialog for ToolPointOfIntersection. Help create point and edit option.
  */
-class DialogPointOfIntersection : public DialogTool
+class DialogPointOfIntersection final : public DialogTool
 {
     Q_OBJECT // NOLINT
+
 public:
-    DialogPointOfIntersection(const VContainer *data, quint32 toolId, QWidget *parent = nullptr);
-    virtual ~DialogPointOfIntersection() override;
+    DialogPointOfIntersection(const VContainer *data, VAbstractPattern *doc, quint32 toolId, QWidget *parent = nullptr);
+    ~DialogPointOfIntersection() override;
 
-    QString        GetPointName() const;
-    void           SetPointName(const QString &value);
+    auto GetPointName() const -> QString;
+    void SetPointName(const QString &value);
 
-    quint32        GetFirstPointId() const;
-    void           SetFirstPointId(quint32 value);
+    auto GetFirstPointId() const -> quint32;
+    void SetFirstPointId(quint32 value);
 
-    quint32        GetSecondPointId() const;
-    void           SetSecondPointId(quint32 value);
+    auto GetSecondPointId() const -> quint32;
+    void SetSecondPointId(quint32 value);
+
+    void SetNotes(const QString &notes);
+    auto GetNotes() const -> QString;
 
-    void    SetNotes(const QString &notes);
-    QString GetNotes() const;
 public slots:
-    virtual void   ChosenObject(quint32 id, const SceneObject &type) override;
-    virtual void   PointNameChanged() override;
+    void ChosenObject(quint32 id, const SceneObject &type) override;
+    void PointNameChanged() override;
+
 protected:
-    virtual void   ShowVisualization() override;
+    void ShowVisualization() override;
     /**
      * @brief SaveData Put dialog data in local variables
      */
-    virtual void   SaveData() override;
-    virtual bool   IsValid() const final;
+    void SaveData() override;
+    auto IsValid() const -> bool override;
+
 private:
     Q_DISABLE_COPY_MOVE(DialogPointOfIntersection) // NOLINT
 
@@ -86,11 +89,11 @@ private:
     bool flagError;
 
     /** @brief number number of handled objects */
-    qint32  number{0};
+    qint32 number{0};
 };
 
 //---------------------------------------------------------------------------------------------------------------------
-inline bool DialogPointOfIntersection::IsValid() const
+inline auto DialogPointOfIntersection::IsValid() const -> bool
 {
     return flagName && flagError;
 }
