@@ -29,7 +29,6 @@
 #ifndef DIALOGPOINTOFINTERSECTIONCIRCLES_H
 #define DIALOGPOINTOFINTERSECTIONCIRCLES_H
 
-#include <qcompilerdetection.h>
 #include <QMetaObject>
 #include <QObject>
 #include <QString>
@@ -41,15 +40,16 @@
 
 namespace Ui
 {
-    class DialogPointOfIntersectionCircles;
+class DialogPointOfIntersectionCircles;
 }
 
-class DialogPointOfIntersectionCircles : public DialogTool
+class DialogPointOfIntersectionCircles final : public DialogTool
 {
     Q_OBJECT // NOLINT
 
 public:
-    DialogPointOfIntersectionCircles(const VContainer *data, quint32 toolId, QWidget *parent = nullptr);
+    DialogPointOfIntersectionCircles(const VContainer *data, VAbstractPattern *doc, quint32 toolId,
+                                     QWidget *parent = nullptr);
     ~DialogPointOfIntersectionCircles() override;
 
     auto GetPointName() const -> QString;
@@ -95,7 +95,8 @@ protected:
      */
     void SaveData() override;
     void closeEvent(QCloseEvent *event) override;
-    auto IsValid() const -> bool final;
+    void changeEvent(QEvent *event) override;
+    auto IsValid() const -> bool override;
 
 private:
     Q_DISABLE_COPY_MOVE(DialogPointOfIntersectionCircles) // NOLINT
@@ -122,6 +123,10 @@ private:
 
     /** @brief number number of handled objects */
     qint32 m_stage{0};
+
+    void FinishCreating();
+
+    void InitIcons();
 };
 
 //---------------------------------------------------------------------------------------------------------------------
