@@ -45,47 +45,45 @@
 #include <QStringList>
 #include <QTimer>
 #include <QToolButton>
-#include <Qt>
 #include <new>
 
-#include "../../visualization/visualization.h"
+#include "../../tools/drawTools/operation/vabstractoperation.h"
 #include "../../visualization/line/operation/vistoolrotation.h"
+#include "../../visualization/visualization.h"
 #include "../ifc/xml/vabstractpattern.h"
-#include "../ifc/xml/vdomdocument.h"
 #include "../qmuparser/qmudef.h"
 #include "../support/dialogeditwrongformula.h"
 #include "../vgeometry/vpointf.h"
+#include "../vmisc/theme/vtheme.h"
 #include "../vmisc/vabstractapplication.h"
 #include "../vmisc/vcommonsettings.h"
-#if QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
-#include "../vmisc/backport/qoverload.h"
-#endif // QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
 #include "../vpatterndb/vcontainer.h"
 #include "../vpatterndb/vtranslatevars.h"
+#include "../vwidgets/global.h"
 #include "../vwidgets/vabstractmainwindow.h"
 #include "../vwidgets/vmaingraphicsscene.h"
 #include "../vwidgets/vmaingraphicsview.h"
-#include "../vwidgets/global.h"
 #include "ui_dialogrotation.h"
-#include "../../tools/drawTools/operation/vabstractoperation.h"
 
 //---------------------------------------------------------------------------------------------------------------------
-DialogRotation::DialogRotation(const VContainer *data, quint32 toolId, QWidget *parent)
-    : DialogTool(data, toolId, parent),
-      ui(new Ui::DialogRotation),
-      timerAngle(new QTimer(this)),
-      formulaAngle(),
-      formulaBaseHeightAngle(0),
-      stage1(true),
-      m_suffix(),
-      m_firstRelease(false),
-      flagAngle(false),
-      flagName(true),
-      flagGroupName(true),
-      flagError(false)
+DialogRotation::DialogRotation(const VContainer *data, VAbstractPattern *doc, quint32 toolId, QWidget *parent)
+  : DialogTool(data, doc, toolId, parent),
+    ui(new Ui::DialogRotation),
+    timerAngle(new QTimer(this)),
+    formulaAngle(),
+    formulaBaseHeightAngle(0),
+    stage1(true),
+    m_suffix(),
+    m_firstRelease(false),
+    flagAngle(false),
+    flagName(true),
+    flagGroupName(true),
+    flagError(false)
 {
     ui->setupUi(this);
 
+    InitIcons();
+
     this->formulaBaseHeightAngle = ui->plainTextEditFormula->height();
     ui->plainTextEditFormula->installEventFilter(this);
 
@@ -97,19 +95,19 @@ DialogRotation::DialogRotation(const VContainer *data, quint32 toolId, QWidget *
     InitOkCancelApply(ui);
 
     FillComboBoxPoints(ui->comboBoxOriginPoint);
-    FillComboBoxTypeLine(ui->comboBoxPenStyle, OperationLineStylesPics(), TypeLineDefault);
+    FillComboBoxTypeLine(ui->comboBoxPenStyle,
+                         OperationLineStylesPics(ui->comboBoxPenStyle->palette().color(QPalette::Base),
+                                                 ui->comboBoxPenStyle->palette().color(QPalette::Text)),
+                         TypeLineDefault);
     FillComboBoxLineColors(ui->comboBoxColor, VAbstractOperation::OperationColorsList());
 
     connect(ui->lineEditSuffix, &QLineEdit::textChanged, this, &DialogRotation::SuffixChanged);
     connect(ui->lineEditVisibilityGroup, &QLineEdit::textChanged, this, &DialogRotation::GroupNameChanged);
     connect(ui->toolButtonExprAngle, &QPushButton::clicked, this, &DialogRotation::FXAngle);
-    connect(ui->plainTextEditFormula, &QPlainTextEdit::textChanged, this, [this]()
-    {
-        timerAngle->start(formulaTimerTimeout);
-    });
+    connect(ui->plainTextEditFormula, &QPlainTextEdit::textChanged, this,
+            [this]() { timerAngle->start(formulaTimerTimeout); });
     connect(ui->pushButtonGrowLength, &QPushButton::clicked, this, &DialogRotation::DeployAngleTextEdit);
-    connect(ui->comboBoxOriginPoint, &QComboBox::currentTextChanged,
-            this, &DialogRotation::PointChanged);
+    connect(ui->comboBoxOriginPoint, &QComboBox::currentTextChanged, this, &DialogRotation::PointChanged);
 
     connect(ui->listWidget, &QListWidget::currentRowChanged, this, &DialogRotation::ShowSourceDetails);
     connect(ui->lineEditAlias, &QLineEdit::textEdited, this, &DialogRotation::AliasChanged);
@@ -131,7 +129,7 @@ DialogRotation::~DialogRotation()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-quint32 DialogRotation::GetOrigPointId() const
+auto DialogRotation::GetOrigPointId() const -> quint32
 {
     return getCurrentObjectId(ui->comboBoxOriginPoint);
 }
@@ -140,13 +138,13 @@ quint32 DialogRotation::GetOrigPointId() const
 void DialogRotation::SetOrigPointId(quint32 value)
 {
     ChangeCurrentData(ui->comboBoxOriginPoint, value);
-    VisToolRotation *operation = qobject_cast<VisToolRotation *>(vis);
+    auto *operation = qobject_cast<VisToolRotation *>(vis);
     SCASSERT(operation != nullptr)
     operation->SetOriginPointId(value);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogRotation::GetAngle() const
+auto DialogRotation::GetAngle() const -> QString
 {
     return VTranslateVars::TryFormulaFromUser(formulaAngle, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
 }
@@ -154,8 +152,8 @@ QString DialogRotation::GetAngle() const
 //---------------------------------------------------------------------------------------------------------------------
 void DialogRotation::SetAngle(const QString &value)
 {
-    formulaAngle = VAbstractApplication::VApp()->TrVars()
-            ->FormulaToUser(value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    formulaAngle = VAbstractApplication::VApp()->TrVars()->FormulaToUser(
+        value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
     // increase height if needed.
     if (formulaAngle.length() > 80)
     {
@@ -171,7 +169,7 @@ void DialogRotation::SetAngle(const QString &value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogRotation::GetSuffix() const
+auto DialogRotation::GetSuffix() const -> QString
 {
     return m_suffix;
 }
@@ -184,7 +182,7 @@ void DialogRotation::SetSuffix(const QString &value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogRotation::GetVisibilityGroupName() const
+auto DialogRotation::GetVisibilityGroupName() const -> QString
 {
     return ui->lineEditVisibilityGroup->text();
 }
@@ -196,7 +194,7 @@ void DialogRotation::SetVisibilityGroupName(const QString &name)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool DialogRotation::HasLinkedVisibilityGroup() const
+auto DialogRotation::HasLinkedVisibilityGroup() const -> bool
 {
     return ui->groupBoxVisibilityGroup->isChecked();
 }
@@ -214,7 +212,7 @@ void DialogRotation::SetVisibilityGroupTags(const QStringList &tags)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QStringList DialogRotation::GetVisibilityGroupTags() const
+auto DialogRotation::GetVisibilityGroupTags() const -> QStringList
 {
     return ui->lineEditGroupTags->text().split(',');
 }
@@ -279,10 +277,10 @@ void DialogRotation::ShowDialog(bool click)
         try
         {
             const QSharedPointer<VPointF> point = data->GeometricObject<VPointF>(GetOrigPointId());
-            const QLineF line = QLineF(static_cast<QPointF>(*point), scene->getScenePos());
+            const auto line = QLineF(static_cast<QPointF>(*point), scene->getScenePos());
 
-            //Radius of point circle, but little bigger. Need handle with hover sizes.
-            if (line.length() <= ScaledRadius(SceneScale(VAbstractValApplication::VApp()->getCurrentScene()))*1.5)
+            // Radius of point circle, but little bigger. Need handle with hover sizes.
+            if (line.length() <= ScaledRadius(SceneScale(VAbstractValApplication::VApp()->getCurrentScene())) * 1.5)
             {
                 return;
             }
@@ -295,7 +293,7 @@ void DialogRotation::ShowDialog(bool click)
         auto *operation = qobject_cast<VisToolRotation *>(vis);
         SCASSERT(operation != nullptr)
 
-        SetAngle(operation->Angle());//Show in dialog angle that a user choose
+        SetAngle(operation->Angle()); // Show in dialog angle that a user choose
         setModal(true);
         emit ToolTip(QString());
         timerAngle->start();
@@ -304,7 +302,7 @@ void DialogRotation::ShowDialog(bool click)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QVector<SourceItem> DialogRotation::GetSourceObjects() const
+auto DialogRotation::GetSourceObjects() const -> QVector<SourceItem>
 {
     return sourceObjects;
 }
@@ -323,44 +321,41 @@ void DialogRotation::SetSourceObjects(const QVector<SourceItem> &value)
 //---------------------------------------------------------------------------------------------------------------------
 void DialogRotation::ChosenObject(quint32 id, const SceneObject &type)
 {
-    if (not stage1 && not prepare)// After first choose we ignore all objects
+    if (not stage1 && not prepare && type == SceneObject::Point) // After first choose we ignore all objects
     {
-        if (type == SceneObject::Point)
+        auto *operation = qobject_cast<VisToolRotation *>(vis);
+        SCASSERT(operation != nullptr)
+
+        auto obj = std::find_if(sourceObjects.begin(), sourceObjects.end(),
+                                [id](const SourceItem &sItem) { return sItem.id == id; });
+
+        if (obj != sourceObjects.end())
         {
-            auto *operation = qobject_cast<VisToolRotation *>(vis);
-            SCASSERT(operation != nullptr)
-
-            auto *obj = std::find_if(sourceObjects.begin(), sourceObjects.end(),
-                                     [id](const SourceItem &sItem) { return sItem.id == id; });
-
-            if (obj != sourceObjects.cend())
+            if (sourceObjects.size() > 1)
             {
-                if (sourceObjects.size() > 1)
-                {
-                    // It's not really logical for a user that a center of rotation no need to select.
-                    // To fix this issue we just silently remove it from the list.
-                    sourceObjects.erase(obj);
-                    operation->SetObjects(SourceToObjects(sourceObjects));
-                }
-                else
-                {
-                    emit ToolTip(tr("This point cannot be origin point. Please, select another origin point"));
-                    return;
-                }
+                // It's not really logical for a user that a center of rotation no need to select.
+                // To fix this issue we just silently remove it from the list.
+                sourceObjects.erase(obj);
+                operation->SetObjects(SourceToObjects(sourceObjects));
             }
-
-            if (SetObject(id, ui->comboBoxOriginPoint, QString()))
+            else
             {
-                auto *window = qobject_cast<VAbstractMainWindow *>(VAbstractValApplication::VApp()->getMainWindow());
-                SCASSERT(window != nullptr)
-                connect(operation, &Visualization::ToolTip, window, &VAbstractMainWindow::ShowToolTip);
-
-                operation->SetOriginPointId(id);
-                operation->RefreshGeometry();
-
-                prepare = true;
+                emit ToolTip(tr("This point cannot be origin point. Please, select another origin point"));
+                return;
             }
         }
+
+        if (SetObject(id, ui->comboBoxOriginPoint, QString()))
+        {
+            auto *window = qobject_cast<VAbstractMainWindow *>(VAbstractValApplication::VApp()->getMainWindow());
+            SCASSERT(window != nullptr)
+            connect(operation, &Visualization::ToolTip, window, &VAbstractMainWindow::ShowToolTip);
+
+            operation->SetOriginPointId(id);
+            operation->RefreshGeometry();
+
+            prepare = true;
+        }
     }
 }
 
@@ -370,11 +365,11 @@ void DialogRotation::SelectedObject(bool selected, quint32 object, quint32 tool)
     Q_UNUSED(tool)
     if (stage1)
     {
-        auto *obj = std::find_if(sourceObjects.begin(), sourceObjects.end(),
-                                 [object](const SourceItem &sItem) { return sItem.id == object; });
+        auto obj = std::find_if(sourceObjects.begin(), sourceObjects.end(),
+                                [object](const SourceItem &sItem) { return sItem.id == object; });
         if (selected)
         {
-            if (obj == sourceObjects.cend())
+            if (obj == sourceObjects.end())
             {
                 SourceItem item;
                 item.id = object;
@@ -383,7 +378,7 @@ void DialogRotation::SelectedObject(bool selected, quint32 object, quint32 tool)
         }
         else
         {
-            if (obj != sourceObjects.cend())
+            if (obj != sourceObjects.end())
             {
                 sourceObjects.erase(obj);
             }
@@ -414,7 +409,7 @@ void DialogRotation::FXAngle()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogRotation::SuffixChanged()
 {
-    auto* edit = qobject_cast<QLineEdit*>(sender());
+    auto *edit = qobject_cast<QLineEdit *>(sender());
     if (edit)
     {
         const QString suffix = edit->text();
@@ -426,23 +421,21 @@ void DialogRotation::SuffixChanged()
             CheckState();
             return;
         }
-        else
+
+        if (m_suffix != suffix)
         {
-            if (m_suffix != suffix)
+            QRegularExpression const rx(NameRegExp());
+            const QStringList uniqueNames = data->AllUniqueNames();
+            for (const auto &uniqueName : uniqueNames)
             {
-                QRegularExpression rx(NameRegExp());
-                const QStringList uniqueNames = data->AllUniqueNames();
-                for (const auto &uniqueName : uniqueNames)
+                const QString name = uniqueName + suffix;
+                if (not rx.match(name).hasMatch() || not data->IsUnique(name))
                 {
-                    const QString name = uniqueName + suffix;
-                    if (not rx.match(name).hasMatch() || not data->IsUnique(name))
-                    {
-                        flagName = false;
-                        ChangeColor(ui->labelSuffix, errorColor);
-                        ui->labelStatus->setText(tr("Invalid suffix"));
-                        CheckState();
-                        return;
-                    }
+                    flagName = false;
+                    ChangeColor(ui->labelSuffix, errorColor);
+                    ui->labelStatus->setText(tr("Invalid suffix"));
+                    CheckState();
+                    return;
                 }
             }
         }
@@ -456,7 +449,7 @@ void DialogRotation::SuffixChanged()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogRotation::GroupNameChanged()
 {
-    auto* edit = qobject_cast<QLineEdit*>(sender());
+    auto *edit = qobject_cast<QLineEdit *>(sender());
     if (edit)
     {
         const QString name = edit->text();
@@ -490,7 +483,7 @@ void DialogRotation::SaveData()
     sourceObjects.clear();
     sourceObjects.reserve(ui->listWidget->count());
 
-    for (int i=0; i<ui->listWidget->count(); ++i)
+    for (int i = 0; i < ui->listWidget->count(); ++i)
     {
         if (const QListWidgetItem *item = ui->listWidget->item(i))
         {
@@ -527,16 +520,34 @@ void DialogRotation::closeEvent(QCloseEvent *event)
     DialogTool::closeEvent(event);
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void DialogRotation::changeEvent(QEvent *event)
+{
+    if (event->type() == QEvent::LanguageChange)
+    {
+        ui->retranslateUi(this);
+    }
+
+    if (event->type() == QEvent::PaletteChange)
+    {
+        InitIcons();
+        InitDialogButtonBoxIcons(ui->buttonBox);
+    }
+
+    // remember to call base class implementation
+    DialogTool::changeEvent(event);
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void DialogRotation::PointChanged()
 {
-    quint32 id = getCurrentObjectId(ui->comboBoxOriginPoint);
+    quint32 const id = getCurrentObjectId(ui->comboBoxOriginPoint);
 
-    auto *obj = std::find_if(sourceObjects.begin(), sourceObjects.end(),
-                             [id](const SourceItem &sItem) { return sItem.id == id; });
+    auto obj = std::find_if(sourceObjects.begin(), sourceObjects.end(),
+                            [id](const SourceItem &sItem) { return sItem.id == id; });
 
     QColor color;
-    if (obj != sourceObjects.cend())
+    if (obj != sourceObjects.end())
     {
         flagError = false;
         color = errorColor;
@@ -563,7 +574,7 @@ void DialogRotation::FillSourceList()
     for (auto &sourceItem : sourceObjects)
     {
         const QSharedPointer<VGObject> obj = data->GetGObject(sourceItem.id);
-        bool valid = SourceAliasValid(sourceItem, obj, data, OriginAlias(sourceItem.id, sourceObjects, obj));
+        bool const valid = SourceAliasValid(sourceItem, obj, data, OriginAlias(sourceItem.id, sourceObjects, obj));
 
         auto *item = new QListWidgetItem(valid ? obj->ObjectName() : obj->ObjectName() + '*');
         item->setToolTip(obj->ObjectName());
@@ -584,7 +595,7 @@ void DialogRotation::FillSourceList()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogRotation::ValidateSourceAliases()
 {
-    for (int i=0; i<ui->listWidget->count(); ++i)
+    for (int i = 0; i < ui->listWidget->count(); ++i)
     {
         if (const QListWidgetItem *item = ui->listWidget->item(i))
         {
@@ -627,6 +638,15 @@ void DialogRotation::SetAliasValid(quint32 id, bool valid)
     }
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void DialogRotation::InitIcons()
+{
+    const auto resource = QStringLiteral("icon");
+
+    ui->toolButtonExprAngle->setIcon(VTheme::GetIconResource(resource, QStringLiteral("24x24/fx.png")));
+    ui->label_2->setPixmap(VTheme::GetPixmapResource(resource, QStringLiteral("24x24/equal.png")));
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void DialogRotation::EvalAngle()
 {
@@ -636,7 +656,6 @@ void DialogRotation::EvalAngle()
     formulaData.labelEditFormula = ui->labelEditAngle;
     formulaData.labelResult = ui->labelResultAngle;
     formulaData.postfix = degreeSymbol;
-    formulaData.checkZero = false;
 
     Eval(formulaData, flagAngle);
 
@@ -679,7 +698,7 @@ void DialogRotation::ShowSourceDetails(int row)
     {
         ui->labelAlias->setText(tr("Alias:"));
 
-        auto SetValue = [sourceItem](QComboBox *box, const QString &value, const QString &def)
+        auto SetValue = [](QComboBox *box, const QString &value, const QString &def)
         {
             box->blockSignals(true);
 
@@ -701,8 +720,7 @@ void DialogRotation::ShowSourceDetails(int row)
 
         if (sourceItem.penStyle.isEmpty() || sourceItem.penStyle == TypeLineDefault)
         {
-            const QSharedPointer<VAbstractCurve> curve = data->GeometricObject<VAbstractCurve>(sourceItem.id);
-            int index = ui->comboBoxPenStyle->currentIndex();
+            int const index = ui->comboBoxPenStyle->currentIndex();
             ui->comboBoxPenStyle->setItemText(index, '<' + tr("Default") + '>');
         }
 
@@ -711,8 +729,9 @@ void DialogRotation::ShowSourceDetails(int row)
         if (sourceItem.color.isEmpty() || sourceItem.color == ColorDefault)
         {
             const QSharedPointer<VAbstractCurve> curve = data->GeometricObject<VAbstractCurve>(sourceItem.id);
-            int index = ui->comboBoxColor->currentIndex();
-            ui->comboBoxColor->setItemIcon(index, LineColor(ui->comboBoxColor->iconSize().height(), curve->GetColor()));
+            int const index = ui->comboBoxColor->currentIndex();
+            ui->comboBoxColor->setItemIcon(index, LineColor(ui->comboBoxColor->palette().color(QPalette::Text),
+                                                            ui->comboBoxColor->iconSize().height(), curve->GetColor()));
         }
 
         ui->comboBoxPenStyle->setEnabled(true);
@@ -786,15 +805,15 @@ void DialogRotation::SetNotes(const QString &notes)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogRotation::GetNotes() const
+auto DialogRotation::GetNotes() const -> QString
 {
     return ui->plainTextEditToolNotes->toPlainText();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool DialogRotation::IsValid() const
+auto DialogRotation::IsValid() const -> bool
 {
-    bool ready = flagAngle && flagName && flagError && flagGroupName && flagAlias;
+    bool const ready = flagAngle && flagName && flagError && flagGroupName && flagAlias;
 
     if (ready)
     {
