@@ -40,17 +40,18 @@
 #include <QTimer>
 #include <QToolButton>
 
-#include "../vpatterndb/vtranslatevars.h"
-#include "../../visualization/visualization.h"
 #include "../../visualization/line/vistoolshoulderpoint.h"
+#include "../../visualization/visualization.h"
 #include "../ifc/xml/vabstractpattern.h"
 #include "../support/dialogeditwrongformula.h"
+#include "../vgeometry/vpointf.h"
+#include "../vmisc/theme/vtheme.h"
 #include "../vmisc/vabstractapplication.h"
 #include "../vmisc/vcommonsettings.h"
-#include "ui_dialogshoulderpoint.h"
 #include "../vpatterndb/vcontainer.h"
+#include "../vpatterndb/vtranslatevars.h"
 #include "../vwidgets/vabstractmainwindow.h"
-#include "../vgeometry/vpointf.h"
+#include "ui_dialogshoulderpoint.h"
 
 //---------------------------------------------------------------------------------------------------------------------
 /**
@@ -58,48 +59,48 @@
  * @param data container with data
  * @param parent parent widget
  */
-DialogShoulderPoint::DialogShoulderPoint(const VContainer *data, quint32 toolId, QWidget *parent)
-    : DialogTool(data, toolId, parent),
-      ui(new Ui::DialogShoulderPoint),
-      m_timerFormula(new QTimer(this))
+DialogShoulderPoint::DialogShoulderPoint(const VContainer *data, VAbstractPattern *doc, quint32 toolId, QWidget *parent)
+  : DialogTool(data, doc, toolId, parent),
+    ui(new Ui::DialogShoulderPoint),
+    m_timerFormula(new QTimer(this))
 {
     ui->setupUi(this);
 
+    InitIcons();
+
     m_timerFormula->setSingleShot(true);
     connect(m_timerFormula, &QTimer::timeout, this, &DialogShoulderPoint::EvalFormula);
 
     ui->lineEditNamePoint->setClearButtonEnabled(true);
 
     ui->lineEditNamePoint->setText(
-                VAbstractValApplication::VApp()->getCurrentDocument()->GenerateLabel(LabelType::NewLabel));
+        VAbstractValApplication::VApp()->getCurrentDocument()->GenerateLabel(LabelType::NewLabel));
     m_formulaBaseHeight = ui->plainTextEditFormula->height();
     ui->plainTextEditFormula->installEventFilter(this);
 
     InitOkCancelApply(ui);
 
-    FillComboBoxTypeLine(ui->comboBoxLineType, LineStylesPics());
+    FillComboBoxTypeLine(ui->comboBoxLineType, LineStylesPics(ui->comboBoxLineType->palette().color(QPalette::Base),
+                                                              ui->comboBoxLineType->palette().color(QPalette::Text)));
     FillComboBoxPoints(ui->comboBoxP1Line);
     FillComboBoxPoints(ui->comboBoxP2Line);
     FillComboBoxPoints(ui->comboBoxP3);
     FillComboBoxLineColors(ui->comboBoxLineColor);
 
     connect(ui->toolButtonExprLength, &QPushButton::clicked, this, &DialogShoulderPoint::FXLength);
-    connect(ui->lineEditNamePoint, &QLineEdit::textChanged, this, [this]()
-    {
-        CheckPointLabel(this, ui->lineEditNamePoint, ui->labelEditNamePoint, m_pointName, this->data, m_flagName);
-        CheckState();
-    });
-    connect(ui->plainTextEditFormula, &QPlainTextEdit::textChanged, this, [this]()
-    {
-        m_timerFormula->start(formulaTimerTimeout);
-    });
+    connect(ui->lineEditNamePoint, &QLineEdit::textChanged, this,
+            [this]()
+            {
+                CheckPointLabel(this, ui->lineEditNamePoint, ui->labelEditNamePoint, m_pointName, this->data,
+                                m_flagName);
+                CheckState();
+            });
+    connect(ui->plainTextEditFormula, &QPlainTextEdit::textChanged, this,
+            [this]() { m_timerFormula->start(formulaTimerTimeout); });
     connect(ui->pushButtonGrowLength, &QPushButton::clicked, this, &DialogShoulderPoint::DeployFormulaTextEdit);
-    connect(ui->comboBoxP1Line, &QComboBox::currentTextChanged,
-            this, &DialogShoulderPoint::PointNameChanged);
-    connect(ui->comboBoxP2Line, &QComboBox::currentTextChanged,
-            this, &DialogShoulderPoint::PointNameChanged);
-    connect(ui->comboBoxP3, &QComboBox::currentTextChanged,
-            this, &DialogShoulderPoint::PointNameChanged);
+    connect(ui->comboBoxP1Line, &QComboBox::currentTextChanged, this, &DialogShoulderPoint::PointNameChanged);
+    connect(ui->comboBoxP2Line, &QComboBox::currentTextChanged, this, &DialogShoulderPoint::PointNameChanged);
+    connect(ui->comboBoxP3, &QComboBox::currentTextChanged, this, &DialogShoulderPoint::PointNameChanged);
 
     vis = new VisToolShoulderPoint(data);
 
@@ -211,14 +212,12 @@ void DialogShoulderPoint::ChosenObject(quint32 id, const SceneObject &type)
                 }
                 break;
             case 1:
-                if (getCurrentObjectId(ui->comboBoxP3) != id)
+                if (getCurrentObjectId(ui->comboBoxP3) != id &&
+                    SetObject(id, ui->comboBoxP1Line, tr("Select second point of line")))
                 {
-                    if (SetObject(id, ui->comboBoxP1Line, tr("Select second point of line")))
-                    {
-                        m_number++;
-                        line->SetLineP1Id(id);
-                        line->RefreshGeometry();
-                    }
+                    m_number++;
+                    line->SetLineP1Id(id);
+                    line->RefreshGeometry();
                 }
                 break;
             case 2:
@@ -254,6 +253,24 @@ void DialogShoulderPoint::closeEvent(QCloseEvent *event)
     DialogTool::closeEvent(event);
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void DialogShoulderPoint::changeEvent(QEvent *event)
+{
+    if (event->type() == QEvent::LanguageChange)
+    {
+        ui->retranslateUi(this);
+    }
+
+    if (event->type() == QEvent::PaletteChange)
+    {
+        InitIcons();
+        InitDialogButtonBoxIcons(ui->buttonBox);
+    }
+
+    // remember to call base class implementation
+    DialogTool::changeEvent(event);
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void DialogShoulderPoint::ChosenThirdPoint(quint32 id)
 {
@@ -262,25 +279,45 @@ void DialogShoulderPoint::ChosenThirdPoint(quint32 id)
     set.insert(getCurrentObjectId(ui->comboBoxP1Line));
     set.insert(id);
 
-    if (set.size() == 3)
+    if (set.size() == 3 && SetObject(id, ui->comboBoxP2Line, QString()))
     {
-        if (SetObject(id, ui->comboBoxP2Line, QString()))
+        auto *window = qobject_cast<VAbstractMainWindow *>(VAbstractValApplication::VApp()->getMainWindow());
+        SCASSERT(window != nullptr)
+
+        auto *line = qobject_cast<VisToolShoulderPoint *>(vis);
+        SCASSERT(line != nullptr)
+        connect(line, &Visualization::ToolTip, window, &VAbstractMainWindow::ShowToolTip);
+
+        line->SetLineP2Id(id);
+        line->RefreshGeometry();
+        prepare = true;
+
+        if (not VAbstractValApplication::VApp()->Settings()->IsInteractiveTools())
         {
-            auto *window = qobject_cast<VAbstractMainWindow *>(
-                VAbstractValApplication::VApp()->getMainWindow());
-            SCASSERT(window != nullptr)
-
-            auto *line = qobject_cast<VisToolShoulderPoint *>(vis);
-            SCASSERT(line != nullptr)
-            connect(line, &Visualization::ToolTip, window, &VAbstractMainWindow::ShowToolTip);
-
-            line->SetLineP2Id(id);
-            line->RefreshGeometry();
-            prepare = true;
+            FinishCreating();
         }
     }
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void DialogShoulderPoint::FinishCreating()
+{
+    vis->SetMode(Mode::Show);
+    vis->RefreshGeometry();
+    emit ToolTip(QString());
+    setModal(true);
+    show();
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void DialogShoulderPoint::InitIcons()
+{
+    const auto resource = QStringLiteral("icon");
+
+    ui->toolButtonExprLength->setIcon(VTheme::GetIconResource(resource, QStringLiteral("24x24/fx.png")));
+    ui->label_3->setPixmap(VTheme::GetPixmapResource(resource, QStringLiteral("24x24/equal.png")));
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 /**
  * @brief setPShoulder set id shoulder point
@@ -342,8 +379,8 @@ void DialogShoulderPoint::SetP1Line(const quint32 &value)
  */
 void DialogShoulderPoint::SetFormula(const QString &value)
 {
-    m_formula = VAbstractApplication::VApp()->TrVars()
-            ->FormulaToUser(value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    m_formula = VAbstractApplication::VApp()->TrVars()->FormulaToUser(
+        value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
     // increase height if needed.
     if (m_formula.length() > 80)
     {
@@ -463,15 +500,9 @@ void DialogShoulderPoint::ShowDialog(bool click)
         SCASSERT(scene != nullptr)
 
         const QSharedPointer<VPointF> p3 = data->GeometricObject<VPointF>(GetP3());
-        QLineF line(static_cast<QPointF>(*p3), scene->getScenePos());
+        QLineF const line(static_cast<QPointF>(*p3), scene->getScenePos());
         SetFormula(QString::number(FromPixel(line.length(), *data->GetPatternUnit())));
     }
 
-    vis->SetMode(Mode::Show);
-    vis->RefreshGeometry();
-
-    emit ToolTip(QString());
-
-    setModal(true);
-    show();
+    FinishCreating();
 }
