@@ -40,23 +40,21 @@
 #include <QSet>
 #include <QTimer>
 #include <QToolButton>
-#include <Qt>
-#include <new>
 
-#include "../../tools/vabstracttool.h"
-#include "../../visualization/visualization.h"
 #include "../../visualization/path/vistoolspline.h"
-#include "../ifc/xml/vdomdocument.h"
+#include "../../visualization/visualization.h"
+#include "../qmuparser/qmudef.h"
 #include "../support/dialogeditwrongformula.h"
 #include "../vgeometry/vpointf.h"
 #include "../vgeometry/vspline.h"
-#include "../vmisc/vabstractapplication.h"
+#include "../vmisc/def.h"
+#include "../vmisc/theme/vtheme.h"
+#include "../vmisc/vabstractvalapplication.h"
 #include "../vmisc/vcommonsettings.h"
 #include "../vpatterndb/vcontainer.h"
+#include "../vpatterndb/vtranslatevars.h"
 #include "../vwidgets/vmaingraphicsscene.h"
 #include "ui_dialogspline.h"
-#include "vtranslatevars.h"
-#include "../qmuparser/qmudef.h"
 
 //---------------------------------------------------------------------------------------------------------------------
 /**
@@ -64,27 +62,18 @@
  * @param data container with data
  * @param parent parent widget
  */
-DialogSpline::DialogSpline(const VContainer *data, quint32 toolId, QWidget *parent)
-    : DialogTool(data, toolId, parent),
-      ui(new Ui::DialogSpline),
-      spl(),
-      newDuplicate(-1),
-      formulaBaseHeightAngle1(0),
-      formulaBaseHeightAngle2(0),
-      formulaBaseHeightLength1(0),
-      formulaBaseHeightLength2(0),
-      timerAngle1(new QTimer(this)),
-      timerAngle2(new QTimer(this)),
-      timerLength1(new QTimer(this)),
-      timerLength2(new QTimer(this)),
-      flagAngle1(false),
-      flagAngle2(false),
-      flagLength1(false),
-      flagLength2(false),
-      flagError(false)
+DialogSpline::DialogSpline(const VContainer *data, VAbstractPattern *doc, quint32 toolId, QWidget *parent)
+  : DialogTool(data, doc, toolId, parent),
+    ui(new Ui::DialogSpline),
+    timerAngle1(new QTimer(this)),
+    timerAngle2(new QTimer(this)),
+    timerLength1(new QTimer(this)),
+    timerLength2(new QTimer(this))
 {
     ui->setupUi(this);
 
+    InitIcons();
+
     formulaBaseHeightAngle1 = ui->plainTextEditAngle1F->height();
     formulaBaseHeightAngle2 = ui->plainTextEditAngle2F->height();
     formulaBaseHeightLength1 = ui->plainTextEditLength1F->height();
@@ -110,39 +99,31 @@ DialogSpline::DialogSpline(const VContainer *data, quint32 toolId, QWidget *pare
     FillComboBoxPoints(ui->comboBoxP1);
     FillComboBoxPoints(ui->comboBoxP4);
     FillComboBoxLineColors(ui->comboBoxColor);
-    FillComboBoxTypeLine(ui->comboBoxPenStyle, CurvePenStylesPics());
+    FillComboBoxTypeLine(ui->comboBoxPenStyle,
+                         CurvePenStylesPics(ui->comboBoxPenStyle->palette().color(QPalette::Base),
+                                            ui->comboBoxPenStyle->palette().color(QPalette::Text)));
 
     ui->doubleSpinBoxApproximationScale->setMaximum(maxCurveApproximationScale);
 
-    connect(ui->comboBoxP1, &QComboBox::currentTextChanged,
-            this, &DialogSpline::PointNameChanged);
-    connect(ui->comboBoxP4, &QComboBox::currentTextChanged,
-            this, &DialogSpline::PointNameChanged);
+    connect(ui->comboBoxP1, &QComboBox::currentTextChanged, this, &DialogSpline::PointNameChanged);
+    connect(ui->comboBoxP4, &QComboBox::currentTextChanged, this, &DialogSpline::PointNameChanged);
 
     connect(ui->toolButtonExprAngle1, &QPushButton::clicked, this, &DialogSpline::FXAngle1);
     connect(ui->toolButtonExprAngle2, &QPushButton::clicked, this, &DialogSpline::FXAngle2);
     connect(ui->toolButtonExprLength1, &QPushButton::clicked, this, &DialogSpline::FXLength1);
     connect(ui->toolButtonExprLength2, &QPushButton::clicked, this, &DialogSpline::FXLength2);
 
-    connect(ui->plainTextEditAngle1F, &QPlainTextEdit::textChanged, this, [this]()
-    {
-        timerAngle1->start(formulaTimerTimeout);
-    });
+    connect(ui->plainTextEditAngle1F, &QPlainTextEdit::textChanged, this,
+            [this]() { timerAngle1->start(formulaTimerTimeout); });
 
-    connect(ui->plainTextEditAngle2F, &QPlainTextEdit::textChanged, this, [this]()
-    {
-        timerAngle2->start(formulaTimerTimeout);
-    });
+    connect(ui->plainTextEditAngle2F, &QPlainTextEdit::textChanged, this,
+            [this]() { timerAngle2->start(formulaTimerTimeout); });
 
-    connect(ui->plainTextEditLength1F, &QPlainTextEdit::textChanged, this, [this]()
-    {
-        timerLength1->start(formulaTimerTimeout);
-    });
+    connect(ui->plainTextEditLength1F, &QPlainTextEdit::textChanged, this,
+            [this]() { timerLength1->start(formulaTimerTimeout); });
 
-    connect(ui->plainTextEditLength2F, &QPlainTextEdit::textChanged, this, [this]()
-    {
-        timerLength2->start(formulaTimerTimeout);
-    });
+    connect(ui->plainTextEditLength2F, &QPlainTextEdit::textChanged, this,
+            [this]() { timerLength2->start(formulaTimerTimeout); });
 
     connect(ui->pushButtonGrowAngle1, &QPushButton::clicked, this, &DialogSpline::DeployAngle1TextEdit);
     connect(ui->pushButtonGrowAngle2, &QPushButton::clicked, this, &DialogSpline::DeployAngle2TextEdit);
@@ -152,10 +133,10 @@ DialogSpline::DialogSpline(const VContainer *data, quint32 toolId, QWidget *pare
     connect(ui->lineEditAlias, &QLineEdit::textEdited, this, &DialogSpline::ValidateAlias);
 
     vis = new VisToolSpline(data);
-    auto path = qobject_cast<VisToolSpline *>(vis);
+    auto *path = qobject_cast<VisToolSpline *>(vis);
     SCASSERT(path != nullptr)
 
-    auto scene = qobject_cast<VMainGraphicsScene *>(VAbstractValApplication::VApp()->getCurrentScene());
+    auto *scene = qobject_cast<VMainGraphicsScene *>(VAbstractValApplication::VApp()->getCurrentScene());
     SCASSERT(scene != nullptr)
     connect(scene, &VMainGraphicsScene::MouseLeftPressed, path, &VisToolSpline::MouseLeftPressed);
     connect(scene, &VMainGraphicsScene::MouseLeftReleased, path, &VisToolSpline::MouseLeftReleased);
@@ -178,40 +159,34 @@ DialogSpline::~DialogSpline()
  */
 void DialogSpline::ChosenObject(quint32 id, const SceneObject &type)
 {
-    if (prepare == false)// After first choose we ignore all objects
+    if (!prepare && type == SceneObject::Point) // After first choose we ignore all objects
     {
-        if (type == SceneObject::Point)
+        auto *path = qobject_cast<VisToolSpline *>(vis);
+        SCASSERT(path != nullptr)
+
+        switch (number)
         {
-            auto *path = qobject_cast<VisToolSpline *>(vis);
-            SCASSERT(path != nullptr)
-
-            switch (number)
-            {
-                case 0:
-                    if (SetObject(id, ui->comboBoxP1, tr("Select last point of curve")))
-                    {
-                        ++number;
-                        path->VisualMode(id);
-                    }
-                    break;
-                case 1:
+            case 0:
+                if (SetObject(id, ui->comboBoxP1, tr("Select last point of curve")))
                 {
-                    if (getCurrentObjectId(ui->comboBoxP1) != id)
-                    {
-                        if (SetObject(id, ui->comboBoxP4, QString()))
-                        {
-                            ++number;
-
-                            path->SetPoint4Id(id);
-                            path->RefreshGeometry();
-                            prepare = true;
-                        }
-                    }
-                    break;
+                    ++number;
+                    path->VisualMode(id);
                 }
-                default:
-                    break;
+                break;
+            case 1:
+            {
+                if (getCurrentObjectId(ui->comboBoxP1) != id && SetObject(id, ui->comboBoxP4, QString()))
+                {
+                    ++number;
+
+                    path->SetPoint4Id(id);
+                    path->RefreshGeometry();
+                    prepare = true;
+                }
+                break;
             }
+            default:
+                break;
         }
     }
 }
@@ -219,12 +194,12 @@ void DialogSpline::ChosenObject(quint32 id, const SceneObject &type)
 //---------------------------------------------------------------------------------------------------------------------
 void DialogSpline::SaveData()
 {
-    const quint32 d = spl.GetDuplicate();//Save previous value
+    const quint32 d = spl.GetDuplicate(); // Save previous value
     spl = CurrentSpline();
 
     newDuplicate <= -1 ? spl.SetDuplicate(d) : spl.SetDuplicate(static_cast<quint32>(newDuplicate));
 
-    auto path = qobject_cast<VisToolSpline *>(vis);
+    auto *path = qobject_cast<VisToolSpline *>(vis);
     SCASSERT(path != nullptr)
 
     path->SetPoint1Id(GetP1()->id());
@@ -249,6 +224,24 @@ void DialogSpline::closeEvent(QCloseEvent *event)
     DialogTool::closeEvent(event);
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void DialogSpline::changeEvent(QEvent *event)
+{
+    if (event->type() == QEvent::LanguageChange)
+    {
+        ui->retranslateUi(this);
+    }
+
+    if (event->type() == QEvent::PaletteChange)
+    {
+        InitIcons();
+        InitDialogButtonBoxIcons(ui->buttonBox);
+    }
+
+    // remember to call base class implementation
+    DialogTool::changeEvent(event);
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void DialogSpline::DeployAngle1TextEdit()
 {
@@ -276,7 +269,7 @@ void DialogSpline::DeployLength2TextEdit()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogSpline::FXAngle1()
 {
-    auto* dialog = new DialogEditWrongFormula(data, toolId, this);
+    auto *dialog = new DialogEditWrongFormula(data, toolId, this);
     dialog->setWindowTitle(tr("Edit first control point angle"));
     QString angle1F = VTranslateVars::TryFormulaFromUser(ui->plainTextEditAngle1F->toPlainText(),
                                                          VAbstractApplication::VApp()->Settings()->GetOsSeparator());
@@ -284,8 +277,8 @@ void DialogSpline::FXAngle1()
     dialog->setPostfix(degreeSymbol);
     if (dialog->exec() == QDialog::Accepted)
     {
-        angle1F = VAbstractApplication::VApp()->TrVars()
-                ->FormulaToUser(dialog->GetFormula(), VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+        angle1F = VAbstractApplication::VApp()->TrVars()->FormulaToUser(
+            dialog->GetFormula(), VAbstractApplication::VApp()->Settings()->GetOsSeparator());
         // increase height if needed.
         if (angle1F.length() > 80)
         {
@@ -300,7 +293,7 @@ void DialogSpline::FXAngle1()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogSpline::FXAngle2()
 {
-    auto* dialog = new DialogEditWrongFormula(data, toolId, this);
+    auto *dialog = new DialogEditWrongFormula(data, toolId, this);
     dialog->setWindowTitle(tr("Edit second control point angle"));
     QString angle2F = VTranslateVars::TryFormulaFromUser(ui->plainTextEditAngle2F->toPlainText(),
                                                          VAbstractApplication::VApp()->Settings()->GetOsSeparator());
@@ -308,8 +301,8 @@ void DialogSpline::FXAngle2()
     dialog->setPostfix(degreeSymbol);
     if (dialog->exec() == QDialog::Accepted)
     {
-        angle2F = VAbstractApplication::VApp()->TrVars()
-                ->FormulaToUser(dialog->GetFormula(), VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+        angle2F = VAbstractApplication::VApp()->TrVars()->FormulaToUser(
+            dialog->GetFormula(), VAbstractApplication::VApp()->Settings()->GetOsSeparator());
         // increase height if needed.
         if (angle2F.length() > 80)
         {
@@ -324,7 +317,7 @@ void DialogSpline::FXAngle2()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogSpline::FXLength1()
 {
-    auto* dialog = new DialogEditWrongFormula(data, toolId, this);
+    auto *dialog = new DialogEditWrongFormula(data, toolId, this);
     dialog->setWindowTitle(tr("Edit first control point length"));
     QString length1F = VTranslateVars::TryFormulaFromUser(ui->plainTextEditLength1F->toPlainText(),
                                                           VAbstractApplication::VApp()->Settings()->GetOsSeparator());
@@ -332,8 +325,8 @@ void DialogSpline::FXLength1()
     dialog->setPostfix(UnitsToStr(VAbstractValApplication::VApp()->patternUnits(), true));
     if (dialog->exec() == QDialog::Accepted)
     {
-        length1F = VAbstractApplication::VApp()->TrVars()
-                ->FormulaToUser(dialog->GetFormula(), VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+        length1F = VAbstractApplication::VApp()->TrVars()->FormulaToUser(
+            dialog->GetFormula(), VAbstractApplication::VApp()->Settings()->GetOsSeparator());
         // increase height if needed.
         if (length1F.length() > 80)
         {
@@ -348,7 +341,7 @@ void DialogSpline::FXLength1()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogSpline::FXLength2()
 {
-    auto* dialog = new DialogEditWrongFormula(data, toolId, this);
+    auto *dialog = new DialogEditWrongFormula(data, toolId, this);
     dialog->setWindowTitle(tr("Edit second control point length"));
     QString length2F = VTranslateVars::TryFormulaFromUser(ui->plainTextEditLength2F->toPlainText(),
                                                           VAbstractApplication::VApp()->Settings()->GetOsSeparator());
@@ -356,8 +349,8 @@ void DialogSpline::FXLength2()
     dialog->setPostfix(UnitsToStr(VAbstractValApplication::VApp()->patternUnits(), true));
     if (dialog->exec() == QDialog::Accepted)
     {
-        length2F = VAbstractApplication::VApp()->TrVars()
-                ->FormulaToUser(dialog->GetFormula(), VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+        length2F = VAbstractApplication::VApp()->TrVars()->FormulaToUser(
+            dialog->GetFormula(), VAbstractApplication::VApp()->Settings()->GetOsSeparator());
         // increase height if needed.
         if (length2F.length() > 80)
         {
@@ -370,13 +363,13 @@ void DialogSpline::FXLength2()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-const QSharedPointer<VPointF> DialogSpline::GetP1() const
+auto DialogSpline::GetP1() const -> QSharedPointer<VPointF>
 {
     return data->GeometricObject<VPointF>(getCurrentObjectId(ui->comboBoxP1));
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-const QSharedPointer<VPointF> DialogSpline::GetP4() const
+auto DialogSpline::GetP4() const -> QSharedPointer<VPointF>
 {
     return data->GeometricObject<VPointF>(getCurrentObjectId(ui->comboBoxP4));
 }
@@ -390,7 +383,6 @@ void DialogSpline::EvalAngle1()
     formulaData.labelEditFormula = ui->labelEditAngle1;
     formulaData.labelResult = ui->labelResultAngle1;
     formulaData.postfix = degreeSymbol;
-    formulaData.checkZero = false;
 
     Eval(formulaData, flagAngle1);
 }
@@ -404,7 +396,6 @@ void DialogSpline::EvalAngle2()
     formulaData.labelEditFormula = ui->labelEditAngle2;
     formulaData.labelResult = ui->labelResultAngle2;
     formulaData.postfix = degreeSymbol;
-    formulaData.checkZero = false;
 
     Eval(formulaData, flagAngle2);
 }
@@ -418,7 +409,6 @@ void DialogSpline::EvalLength1()
     formulaData.labelEditFormula = ui->labelEditLength1;
     formulaData.labelResult = ui->labelResultLength1;
     formulaData.postfix = UnitsToStr(VAbstractValApplication::VApp()->patternUnits(), true);
-    formulaData.checkZero = false;
     formulaData.checkLessThanZero = true;
 
     Eval(formulaData, flagLength1);
@@ -433,7 +423,6 @@ void DialogSpline::EvalLength2()
     formulaData.labelEditFormula = ui->labelEditLength2;
     formulaData.labelResult = ui->labelResultLength2;
     formulaData.postfix = UnitsToStr(VAbstractValApplication::VApp()->patternUnits(), true);
-    formulaData.checkZero = false;
     formulaData.checkLessThanZero = true;
 
     Eval(formulaData, flagLength2);
@@ -442,12 +431,11 @@ void DialogSpline::EvalLength2()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogSpline::ValidateAlias()
 {
-    QRegularExpression rx(NameRegExp());
-
     VSpline spline = spl;
     spline.SetAliasSuffix(ui->lineEditAlias->text());
 
-    if (not ui->lineEditAlias->text().isEmpty() &&
+    if (QRegularExpression const rx(NameRegExp());
+        not ui->lineEditAlias->text().isEmpty() &&
         (not rx.match(spline.GetAlias()).hasMatch() ||
          (originAliasSuffix != ui->lineEditAlias->text() && not data->IsUnique(spline.GetAlias()))))
     {
@@ -464,14 +452,14 @@ void DialogSpline::ValidateAlias()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VSpline DialogSpline::CurrentSpline() const
+auto DialogSpline::CurrentSpline() const -> VSpline
 {
     QString angle1F = ui->plainTextEditAngle1F->toPlainText();
     QString angle2F = ui->plainTextEditAngle2F->toPlainText();
     QString length1F = ui->plainTextEditLength1F->toPlainText();
     QString length2F = ui->plainTextEditLength2F->toPlainText();
 
-    const QHash<QString, QSharedPointer<VInternalVariable> > *vars = data->DataVariables();
+    const QHash<QString, QSharedPointer<VInternalVariable>> *vars = data->DataVariables();
 
     const qreal angle1 = Visualization::FindValFromUser(angle1F, vars);
     const qreal angle2 = Visualization::FindValFromUser(angle2F, vars);
@@ -485,7 +473,7 @@ VSpline DialogSpline::CurrentSpline() const
     length1F = VTranslateVars::TryFormulaFromUser(length1F, separator);
     length2F = VTranslateVars::TryFormulaFromUser(length2F, separator);
 
-    VSpline spline(*GetP1(), *GetP4(), angle1, angle1F, angle2, angle2F, length1, length1F,  length2, length2F);
+    VSpline spline(*GetP1(), *GetP4(), angle1, angle1F, angle2, angle2F, length1, length1F, length2, length2F);
     spline.SetApproximationScale(ui->doubleSpinBoxApproximationScale->value());
     spline.SetPenStyle(GetComboBoxCurrentData(ui->comboBoxPenStyle, TypeLineLine));
     spline.SetColor(GetComboBoxCurrentData(ui->comboBoxColor, ColorBlack));
@@ -494,6 +482,24 @@ VSpline DialogSpline::CurrentSpline() const
     return spline;
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void DialogSpline::InitIcons()
+{
+    const auto resource = QStringLiteral("icon");
+
+    const auto fxIcon = QStringLiteral("24x24/fx.png");
+    ui->toolButtonExprLength1->setIcon(VTheme::GetIconResource(resource, fxIcon));
+    ui->toolButtonExprAngle1->setIcon(VTheme::GetIconResource(resource, fxIcon));
+    ui->toolButtonExprLength2->setIcon(VTheme::GetIconResource(resource, fxIcon));
+    ui->toolButtonExprAngle2->setIcon(VTheme::GetIconResource(resource, fxIcon));
+
+    const auto equalIcon = QStringLiteral("24x24/equal.png");
+    ui->label_5->setPixmap(VTheme::GetPixmapResource(resource, equalIcon));
+    ui->label_8->setPixmap(VTheme::GetPixmapResource(resource, equalIcon));
+    ui->label_9->setPixmap(VTheme::GetPixmapResource(resource, equalIcon));
+    ui->label_10->setPixmap(VTheme::GetPixmapResource(resource, equalIcon));
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void DialogSpline::PointNameChanged()
 {
@@ -514,11 +520,13 @@ void DialogSpline::PointNameChanged()
         flagError = true;
         color = OkColor(this);
 
+        const VTranslateVars *trVars = VAbstractApplication::VApp()->TrVars();
+
         if (getCurrentObjectId(ui->comboBoxP1) == spl.GetP1().id() &&
             getCurrentObjectId(ui->comboBoxP4) == spl.GetP4().id())
         {
             newDuplicate = -1;
-            ui->lineEditSplineName->setText(VAbstractApplication::VApp()->TrVars()->VarToUser(spl.name()));
+            ui->lineEditSplineName->setText(trVars->VarToUser(spl.name()));
         }
         else
         {
@@ -531,7 +539,7 @@ void DialogSpline::PointNameChanged()
                     newDuplicate = static_cast<qint32>(DNumber(spline.name()));
                     spline.SetDuplicate(static_cast<quint32>(newDuplicate));
                 }
-                ui->lineEditSplineName->setText(VAbstractApplication::VApp()->TrVars()->VarToUser(spline.name()));
+                ui->lineEditSplineName->setText(trVars->VarToUser(spline.name()));
             }
             catch (const VExceptionBadId &)
             {
@@ -556,28 +564,23 @@ void DialogSpline::ShowDialog(bool click)
 
         spl = VSpline(*GetP1(), path->GetP2(), path->GetP3(), *GetP4());
 
-        const QString angle1F = VAbstractApplication::VApp()->TrVars()
-                ->FormulaToUser(spl.GetStartAngleFormula(), VAbstractApplication::VApp()->Settings()->GetOsSeparator());
-        const QString angle2F = VAbstractApplication::VApp()->TrVars()
-                ->FormulaToUser(spl.GetEndAngleFormula(), VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+        const bool osSeparator = VAbstractApplication::VApp()->Settings()->GetOsSeparator();
+        const VTranslateVars *trVars = VAbstractApplication::VApp()->TrVars();
+
+        const QString angle1F = trVars->FormulaToUser(spl.GetStartAngleFormula(), osSeparator);
+        const QString angle2F = trVars->FormulaToUser(spl.GetEndAngleFormula(), osSeparator);
 
         ui->plainTextEditAngle1F->setPlainText(angle1F);
         ui->plainTextEditAngle2F->setPlainText(angle2F);
-        ui->plainTextEditLength1F->setPlainText(
-                    VAbstractApplication::VApp()->TrVars()
-                    ->FormulaToUser(spl.GetC1LengthFormula(),
-                                    VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
-        ui->plainTextEditLength2F->setPlainText(
-                    VAbstractApplication::VApp()->TrVars()
-                    ->FormulaToUser(spl.GetC2LengthFormula(),
-                                    VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
+        ui->plainTextEditLength1F->setPlainText(trVars->FormulaToUser(spl.GetC1LengthFormula(), osSeparator));
+        ui->plainTextEditLength2F->setPlainText(trVars->FormulaToUser(spl.GetC2LengthFormula(), osSeparator));
 
         if (not data->IsUnique(spl.name()))
         {
             spl.SetDuplicate(DNumber(spl.name()));
         }
 
-        ui->lineEditSplineName->setText(VAbstractApplication::VApp()->TrVars()->VarToUser(spl.name()));
+        ui->lineEditSplineName->setText(trVars->VarToUser(spl.name()));
 
         DialogAccepted();
     }
@@ -590,7 +593,7 @@ void DialogSpline::ShowVisualization()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VSpline DialogSpline::GetSpline() const
+auto DialogSpline::GetSpline() const -> VSpline
 {
     return spl;
 }
@@ -607,28 +610,27 @@ void DialogSpline::SetSpline(const VSpline &spline)
     setCurrentPointId(ui->comboBoxP1, spl.GetP1().id());
     setCurrentPointId(ui->comboBoxP4, spl.GetP4().id());
 
-    const QString angle1F = VAbstractApplication::VApp()->TrVars()->FormulaToUser(spl.GetStartAngleFormula(),
-                                                          VAbstractApplication::VApp()->Settings()->GetOsSeparator());
-    const QString angle2F = VAbstractApplication::VApp()->TrVars()->FormulaToUser(spl.GetEndAngleFormula(),
-                                                          VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    const bool osSeparator = VAbstractApplication::VApp()->Settings()->GetOsSeparator();
+    const VTranslateVars *trVars = VAbstractApplication::VApp()->TrVars();
+
+    const QString angle1F = trVars->FormulaToUser(spl.GetStartAngleFormula(), osSeparator);
+    const QString angle2F = trVars->FormulaToUser(spl.GetEndAngleFormula(), osSeparator);
 
     ui->plainTextEditAngle1F->setPlainText(angle1F);
     ui->plainTextEditAngle2F->setPlainText(angle2F);
 
-    const QString length1F = VAbstractApplication::VApp()->TrVars()->FormulaToUser(spl.GetC1LengthFormula(),
-                                                           VAbstractApplication::VApp()->Settings()->GetOsSeparator());
-    const QString length2F = VAbstractApplication::VApp()->TrVars()->FormulaToUser(spl.GetC2LengthFormula(),
-                                                           VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    const QString length1F = trVars->FormulaToUser(spl.GetC1LengthFormula(), osSeparator);
+    const QString length2F = trVars->FormulaToUser(spl.GetC2LengthFormula(), osSeparator);
 
     ui->plainTextEditLength1F->setPlainText(length1F);
     ui->plainTextEditLength2F->setPlainText(length2F);
-    ui->lineEditSplineName->setText(VAbstractApplication::VApp()->TrVars()->VarToUser(spl.name()));
+    ui->lineEditSplineName->setText(trVars->VarToUser(spl.name()));
 
     originAliasSuffix = spl.GetAliasSuffix();
     ui->lineEditAlias->setText(originAliasSuffix);
     ValidateAlias();
 
-    auto path = qobject_cast<VisToolSpline *>(vis);
+    auto *path = qobject_cast<VisToolSpline *>(vis);
     SCASSERT(path != nullptr)
 
     path->SetPoint1Id(spl.GetP1().id());
@@ -648,7 +650,7 @@ void DialogSpline::SetNotes(const QString &notes)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogSpline::GetNotes() const
+auto DialogSpline::GetNotes() const -> QString
 {
     return ui->plainTextEditToolNotes->toPlainText();
 }
