@@ -44,27 +44,29 @@
 #include <QSharedPointer>
 #include <QToolButton>
 #include <QVariant>
-#include <Qt>
-#include <new>
 
-#include "../../visualization/visualization.h"
 #include "../../visualization/path/vistoolsplinepath.h"
-#include "../ifc/xml/vdomdocument.h"
+#include "../../visualization/visualization.h"
+#include "../qmuparser/qmudef.h"
 #include "../support/dialogeditwrongformula.h"
 #include "../vgeometry/../ifc/ifcdef.h"
 #include "../vgeometry/vpointf.h"
 #include "../vgeometry/vsplinepoint.h"
+#include "../vmisc/theme/vtheme.h"
 #include "../vmisc/vabstractapplication.h"
 #include "../vmisc/vcommonsettings.h"
-#if QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
-#include "../vmisc/backport/qoverload.h"
-#endif // QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
 #include "../vpatterndb/vcontainer.h"
+#include "../vpatterndb/vtranslatevars.h"
 #include "../vwidgets/vabstractmainwindow.h"
 #include "../vwidgets/vmaingraphicsscene.h"
+#include "../vwidgets/vmousewheelwidgetadjustmentguard.h"
 #include "ui_dialogsplinepath.h"
-#include "vtranslatevars.h"
-#include "../qmuparser/qmudef.h"
+
+#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
+#include "../vmisc/compatibility.h"
+#endif
+
+using namespace Qt::Literals::StringLiterals;
 
 //---------------------------------------------------------------------------------------------------------------------
 /**
@@ -72,23 +74,21 @@
  * @param data container with data
  * @param parent parent widget
  */
-DialogSplinePath::DialogSplinePath(const VContainer *data, quint32 toolId, QWidget *parent)
-    : DialogTool(data, toolId, parent),
-      ui(new Ui::DialogSplinePath),
-      path(),
-      newDuplicate(-1),
-      formulaBaseHeightAngle1(0),
-      formulaBaseHeightAngle2(0),
-      formulaBaseHeightLength1(0),
-      formulaBaseHeightLength2(0),
-      flagAngle1(),
-      flagAngle2(),
-      flagLength1(),
-      flagLength2(),
-      flagError(false)
+DialogSplinePath::DialogSplinePath(const VContainer *data, VAbstractPattern *doc, quint32 toolId, QWidget *parent)
+  : DialogTool(data, doc, toolId, parent),
+    ui(new Ui::DialogSplinePath)
 {
     ui->setupUi(this);
 
+    // Prevent stealing focus when scrolling
+    VMouseWheelWidgetAdjustmentGuard::InstallEventFilter(ui->comboBoxNewPoint);
+    VMouseWheelWidgetAdjustmentGuard::InstallEventFilter(ui->comboBoxPoint);
+    VMouseWheelWidgetAdjustmentGuard::InstallEventFilter(ui->comboBoxPenStyle);
+    VMouseWheelWidgetAdjustmentGuard::InstallEventFilter(ui->comboBoxColor);
+    VMouseWheelWidgetAdjustmentGuard::InstallEventFilter(ui->doubleSpinBoxApproximationScale);
+
+    InitIcons();
+
     formulaBaseHeightAngle1 = ui->plainTextEditAngle1F->height();
     formulaBaseHeightAngle2 = ui->plainTextEditAngle2F->height();
     formulaBaseHeightLength1 = ui->plainTextEditLength1F->height();
@@ -102,15 +102,28 @@ DialogSplinePath::DialogSplinePath(const VContainer *data, quint32 toolId, QWidg
     InitOkCancelApply(ui);
     bOk->setEnabled(false);
 
+    FillComboBoxPoints(ui->comboBoxNewPoint);
     FillComboBoxPoints(ui->comboBoxPoint);
     FillComboBoxLineColors(ui->comboBoxColor);
-    FillComboBoxTypeLine(ui->comboBoxPenStyle, CurvePenStylesPics());
+    FillComboBoxTypeLine(ui->comboBoxPenStyle,
+                         CurvePenStylesPics(ui->comboBoxPenStyle->palette().color(QPalette::Base),
+                                            ui->comboBoxPenStyle->palette().color(QPalette::Text)));
 
     ui->doubleSpinBoxApproximationScale->setMaximum(maxCurveApproximationScale);
 
     connect(ui->listWidget, &QListWidget::currentRowChanged, this, &DialogSplinePath::PointChanged);
-    connect(ui->comboBoxPoint, QOverload<int>::of(&QComboBox::currentIndexChanged),
-            this, &DialogSplinePath::currentPointChanged);
+    connect(ui->comboBoxPoint, QOverload<int>::of(&QComboBox::currentIndexChanged), this,
+            &DialogSplinePath::currentPointChanged);
+    connect(ui->comboBoxNewPoint, QOverload<int>::of(&QComboBox::currentIndexChanged), this,
+            &DialogSplinePath::NewPointChanged);
+
+    connect(ui->toolButtonAddPoint, &QToolButton::clicked, this, &DialogSplinePath::AddPoint);
+    connect(ui->toolButtonRemovePoint, &QToolButton::clicked, this, &DialogSplinePath::RemovePoint);
+
+    connect(ui->toolButtonTop, &QToolButton::clicked, this, &DialogSplinePath::MoveTop);
+    connect(ui->toolButtonUp, &QToolButton::clicked, this, &DialogSplinePath::MoveUp);
+    connect(ui->toolButtonDown, &QToolButton::clicked, this, &DialogSplinePath::MoveDown);
+    connect(ui->toolButtonBottom, &QToolButton::clicked, this, &DialogSplinePath::MoveBottom);
 
     connect(ui->toolButtonExprAngle1, &QPushButton::clicked, this, &DialogSplinePath::FXAngle1);
     connect(ui->toolButtonExprAngle2, &QPushButton::clicked, this, &DialogSplinePath::FXAngle2);
@@ -130,10 +143,10 @@ DialogSplinePath::DialogSplinePath(const VContainer *data, quint32 toolId, QWidg
     connect(ui->lineEditAlias, &QLineEdit::textEdited, this, &DialogSplinePath::ValidateAlias);
 
     vis = new VisToolSplinePath(data);
-    auto path = qobject_cast<VisToolSplinePath *>(vis);
+    auto *path = qobject_cast<VisToolSplinePath *>(vis);
     SCASSERT(path != nullptr)
 
-    auto scene = qobject_cast<VMainGraphicsScene *>(VAbstractValApplication::VApp()->getCurrentScene());
+    auto *scene = qobject_cast<VMainGraphicsScene *>(VAbstractValApplication::VApp()->getCurrentScene());
     SCASSERT(scene != nullptr)
     connect(scene, &VMainGraphicsScene::MouseLeftPressed, path, &VisToolSplinePath::MouseLeftPressed);
     connect(scene, &VMainGraphicsScene::MouseLeftReleased, path, &VisToolSplinePath::MouseLeftReleased);
@@ -178,12 +191,15 @@ void DialogSplinePath::SetPath(const VSplinePath &value)
     ChangeCurrentData(ui->comboBoxPenStyle, path.GetPenStyle());
     ChangeCurrentData(ui->comboBoxColor, path.GetColor());
 
-    auto visPath = qobject_cast<VisToolSplinePath *>(vis);
+    auto *visPath = qobject_cast<VisToolSplinePath *>(vis);
     SCASSERT(visPath != nullptr)
     visPath->SetPath(path);
     ui->listWidget->blockSignals(false);
 
     flagError = IsPathValid();
+
+    ui->toolButtonRemovePoint->setEnabled(ui->listWidget->count() > 3);
+    MoveControls();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -209,15 +225,14 @@ void DialogSplinePath::ChosenObject(quint32 id, const SceneObject &type)
 
         SavePath();
 
-        auto visPath = qobject_cast<VisToolSplinePath *>(vis);
+        auto *visPath = qobject_cast<VisToolSplinePath *>(vis);
         SCASSERT(visPath != nullptr)
         visPath->SetPath(path);
 
         if (path.CountPoints() == 1)
         {
             visPath->VisualMode(NULL_ID);
-            VAbstractMainWindow *window =
-                    qobject_cast<VAbstractMainWindow *>(VAbstractValApplication::VApp()->getMainWindow());
+            auto *window = qobject_cast<VAbstractMainWindow *>(VAbstractValApplication::VApp()->getMainWindow());
             SCASSERT(window != nullptr)
             connect(visPath, &VisToolSplinePath::ToolTip, window, &VAbstractMainWindow::ShowToolTip);
 
@@ -236,11 +251,11 @@ void DialogSplinePath::ChosenObject(quint32 id, const SceneObject &type)
  */
 void DialogSplinePath::SaveData()
 {
-    const quint32 d = path.GetDuplicate();//Save previous value
+    const quint32 d = path.GetDuplicate(); // Save previous value
     SavePath();
     newDuplicate <= -1 ? path.SetDuplicate(d) : path.SetDuplicate(static_cast<quint32>(newDuplicate));
 
-    auto visPath = qobject_cast<VisToolSplinePath *>(vis);
+    auto *visPath = qobject_cast<VisToolSplinePath *>(vis);
     SCASSERT(visPath != nullptr)
     visPath->SetPath(path);
     visPath->SetMode(Mode::Show);
@@ -257,6 +272,24 @@ void DialogSplinePath::closeEvent(QCloseEvent *event)
     DialogTool::closeEvent(event);
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void DialogSplinePath::changeEvent(QEvent *event)
+{
+    if (event->type() == QEvent::LanguageChange)
+    {
+        ui->retranslateUi(this);
+    }
+
+    if (event->type() == QEvent::PaletteChange)
+    {
+        InitIcons();
+        InitDialogButtonBoxIcons(ui->buttonBox);
+    }
+
+    // remember to call base class implementation
+    DialogTool::changeEvent(event);
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void DialogSplinePath::DeployAngle1TextEdit()
 {
@@ -294,24 +327,22 @@ void DialogSplinePath::Angle1Changed()
     {
         QListWidgetItem *item = ui->listWidget->item(row);
         SCASSERT(item != nullptr)
-        VSplinePoint p = qvariant_cast<VSplinePoint>(item->data(Qt::UserRole));
+        auto p = qvariant_cast<VSplinePoint>(item->data(Qt::UserRole));
 
         const QString angle1F = ui->plainTextEditAngle1F->toPlainText();
         const qreal angle1 = Visualization::FindValFromUser(angle1F, data->DataVariables());
-        p.SetAngle1(angle1,
-                    VTranslateVars::TryFormulaFromUser(angle1F,
-                                                       VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
+        p.SetAngle1(angle1, VTranslateVars::TryFormulaFromUser(
+                                angle1F, VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
 
         item->setData(Qt::UserRole, QVariant::fromValue(p));
 
         EvalAngle1();
 
-        if (row != ui->listWidget->count()-1)
+        if (row != ui->listWidget->count() - 1)
         {
             ui->plainTextEditAngle2F->blockSignals(true);
-            ui->plainTextEditAngle2F->setPlainText(
-                        VAbstractApplication::VApp()->TrVars()
-                        ->FormulaToUser(p.Angle2Formula(), VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
+            ui->plainTextEditAngle2F->setPlainText(VAbstractApplication::VApp()->TrVars()->FormulaToUser(
+                p.Angle2Formula(), VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
             EvalAngle2();
             ui->plainTextEditAngle2F->blockSignals(false);
         }
@@ -327,17 +358,16 @@ void DialogSplinePath::Angle2Changed()
         return;
     }
 
-    if (row != ui->listWidget->count()-1)
+    if (row != ui->listWidget->count() - 1)
     {
         QListWidgetItem *item = ui->listWidget->item(row);
         SCASSERT(item != nullptr)
-        VSplinePoint p = qvariant_cast<VSplinePoint>(item->data(Qt::UserRole));
+        auto p = qvariant_cast<VSplinePoint>(item->data(Qt::UserRole));
 
         const QString angle2F = ui->plainTextEditAngle2F->toPlainText();
         const qreal angle2 = Visualization::FindValFromUser(angle2F, data->DataVariables());
-        p.SetAngle2(angle2,
-                    VTranslateVars::TryFormulaFromUser(angle2F,
-                                                       VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
+        p.SetAngle2(angle2, VTranslateVars::TryFormulaFromUser(
+                                angle2F, VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
 
         item->setData(Qt::UserRole, QVariant::fromValue(p));
 
@@ -346,9 +376,8 @@ void DialogSplinePath::Angle2Changed()
         if (row != 0)
         {
             ui->plainTextEditAngle1F->blockSignals(true);
-            ui->plainTextEditAngle1F->setPlainText(
-                        VAbstractApplication::VApp()->TrVars()
-                        ->FormulaToUser(p.Angle1Formula(), VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
+            ui->plainTextEditAngle1F->setPlainText(VAbstractApplication::VApp()->TrVars()->FormulaToUser(
+                p.Angle1Formula(), VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
             EvalAngle1();
             ui->plainTextEditAngle1F->blockSignals(false);
         }
@@ -368,13 +397,12 @@ void DialogSplinePath::Length1Changed()
     {
         QListWidgetItem *item = ui->listWidget->item(row);
         SCASSERT(item != nullptr)
-        VSplinePoint p = qvariant_cast<VSplinePoint>(item->data(Qt::UserRole));
+        auto p = qvariant_cast<VSplinePoint>(item->data(Qt::UserRole));
 
         const QString length1F = ui->plainTextEditLength1F->toPlainText();
         const qreal length1 = Visualization::FindLengthFromUser(length1F, data->DataVariables());
-        p.SetLength1(length1,
-                     VTranslateVars::TryFormulaFromUser(length1F,
-                                                        VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
+        p.SetLength1(length1, VTranslateVars::TryFormulaFromUser(
+                                  length1F, VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
 
         item->setData(Qt::UserRole, QVariant::fromValue(p));
 
@@ -391,17 +419,16 @@ void DialogSplinePath::Length2Changed()
         return;
     }
 
-    if (row != ui->listWidget->count()-1)
+    if (row != ui->listWidget->count() - 1)
     {
         QListWidgetItem *item = ui->listWidget->item(row);
         SCASSERT(item != nullptr)
-        VSplinePoint p = qvariant_cast<VSplinePoint>(item->data(Qt::UserRole));
+        auto p = qvariant_cast<VSplinePoint>(item->data(Qt::UserRole));
 
         const QString length2F = ui->plainTextEditLength2F->toPlainText();
         const qreal length2 = Visualization::FindLengthFromUser(length2F, data->DataVariables());
-        p.SetLength2(length2,
-                     VTranslateVars::TryFormulaFromUser(length2F,
-                                                        VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
+        p.SetLength2(length2, VTranslateVars::TryFormulaFromUser(
+                                  length2F, VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
 
         item->setData(Qt::UserRole, QVariant::fromValue(p));
 
@@ -412,7 +439,7 @@ void DialogSplinePath::Length2Changed()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogSplinePath::FXAngle1()
 {
-    auto* dialog = new DialogEditWrongFormula(data, toolId, this);
+    auto *dialog = new DialogEditWrongFormula(data, toolId, this);
     dialog->setWindowTitle(tr("Edit first control point angle"));
 
     QString angle1F = VTranslateVars::TryFormulaFromUser(ui->plainTextEditAngle1F->toPlainText(),
@@ -438,7 +465,7 @@ void DialogSplinePath::FXAngle1()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogSplinePath::FXAngle2()
 {
-    auto* dialog = new DialogEditWrongFormula(data, toolId, this);
+    auto *dialog = new DialogEditWrongFormula(data, toolId, this);
     dialog->setWindowTitle(tr("Edit second control point angle"));
 
     QString angle2F = VTranslateVars::TryFormulaFromUser(ui->plainTextEditAngle2F->toPlainText(),
@@ -464,7 +491,7 @@ void DialogSplinePath::FXAngle2()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogSplinePath::FXLength1()
 {
-    auto* dialog = new DialogEditWrongFormula(data, toolId, this);
+    auto *dialog = new DialogEditWrongFormula(data, toolId, this);
     dialog->setWindowTitle(tr("Edit first control point length"));
 
     QString length1F = VTranslateVars::TryFormulaFromUser(ui->plainTextEditLength1F->toPlainText(),
@@ -490,7 +517,7 @@ void DialogSplinePath::FXLength1()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogSplinePath::FXLength2()
 {
-    auto* dialog = new DialogEditWrongFormula(data, toolId, this);
+    auto *dialog = new DialogEditWrongFormula(data, toolId, this);
     dialog->setWindowTitle(tr("Edit second control point length"));
 
     QString length2F = VTranslateVars::TryFormulaFromUser(ui->plainTextEditLength2F->toPlainText(),
@@ -516,12 +543,11 @@ void DialogSplinePath::FXLength2()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogSplinePath::ValidateAlias()
 {
-    QRegularExpression rx(NameRegExp());
-
     VSplinePath tempPath = path;
     tempPath.SetAliasSuffix(ui->lineEditAlias->text());
 
-    if (not ui->lineEditAlias->text().isEmpty() &&
+    if (QRegularExpression const rx(NameRegExp());
+        not ui->lineEditAlias->text().isEmpty() &&
         (not rx.match(tempPath.GetAlias()).hasMatch() ||
          (originAliasSuffix != ui->lineEditAlias->text() && not data->IsUnique(tempPath.GetAlias()))))
     {
@@ -552,13 +578,12 @@ void DialogSplinePath::EvalAngle1()
     formulaData.labelEditFormula = ui->labelEditAngle1;
     formulaData.labelResult = ui->labelResultAngle1;
     formulaData.postfix = degreeSymbol;
-    formulaData.checkZero = false;
 
     Eval(formulaData, flagAngle1[row]);
 
     QListWidgetItem *item = ui->listWidget->item(row);
     SCASSERT(item != nullptr)
-    VSplinePoint p = qvariant_cast<VSplinePoint>(item->data(Qt::UserRole));
+    auto p = qvariant_cast<VSplinePoint>(item->data(Qt::UserRole));
 
     ShowPointIssue(p.P().name());
 }
@@ -578,13 +603,12 @@ void DialogSplinePath::EvalAngle2()
     formulaData.labelEditFormula = ui->labelEditAngle2;
     formulaData.labelResult = ui->labelResultAngle2;
     formulaData.postfix = degreeSymbol;
-    formulaData.checkZero = false;
 
     Eval(formulaData, flagAngle2[row]);
 
     QListWidgetItem *item = ui->listWidget->item(row);
     SCASSERT(item != nullptr)
-    VSplinePoint p = qvariant_cast<VSplinePoint>(item->data(Qt::UserRole));
+    auto p = qvariant_cast<VSplinePoint>(item->data(Qt::UserRole));
 
     ShowPointIssue(p.P().name());
 }
@@ -604,14 +628,13 @@ void DialogSplinePath::EvalLength1()
     formulaData.labelEditFormula = ui->labelEditLength1;
     formulaData.labelResult = ui->labelResultLength1;
     formulaData.postfix = UnitsToStr(VAbstractValApplication::VApp()->patternUnits(), true);
-    formulaData.checkZero = false;
     formulaData.checkLessThanZero = true;
 
     Eval(formulaData, flagLength1[row]);
 
     QListWidgetItem *item = ui->listWidget->item(row);
     SCASSERT(item != nullptr)
-    VSplinePoint p = qvariant_cast<VSplinePoint>(item->data(Qt::UserRole));
+    auto p = qvariant_cast<VSplinePoint>(item->data(Qt::UserRole));
 
     ShowPointIssue(p.P().name());
 }
@@ -631,14 +654,13 @@ void DialogSplinePath::EvalLength2()
     formulaData.labelEditFormula = ui->labelEditLength2;
     formulaData.labelResult = ui->labelResultLength2;
     formulaData.postfix = UnitsToStr(VAbstractValApplication::VApp()->patternUnits(), true);
-    formulaData.checkZero = false;
     formulaData.checkLessThanZero = true;
 
     Eval(formulaData, flagLength2[row]);
 
     QListWidgetItem *item = ui->listWidget->item(row);
     SCASSERT(item != nullptr)
-    VSplinePoint p = qvariant_cast<VSplinePoint>(item->data(Qt::UserRole));
+    auto p = qvariant_cast<VSplinePoint>(item->data(Qt::UserRole));
 
     ShowPointIssue(p.P().name());
 }
@@ -652,9 +674,15 @@ void DialogSplinePath::PointChanged(int row)
 {
     if (ui->listWidget->count() == 0)
     {
+        ui->toolButtonTop->setEnabled(false);
+        ui->toolButtonUp->setEnabled(false);
+        ui->toolButtonDown->setEnabled(false);
+        ui->toolButtonBottom->setEnabled(false);
         return;
     }
 
+    MoveControls();
+
     const auto p = qvariant_cast<VSplinePoint>(ui->listWidget->item(row)->data(Qt::UserRole));
     DataPoint(p);
 }
@@ -666,13 +694,13 @@ void DialogSplinePath::PointChanged(int row)
  */
 void DialogSplinePath::currentPointChanged(int index)
 {
-    const quint32 id = qvariant_cast<quint32>(ui->comboBoxPoint->itemData(index));
+    const auto id = qvariant_cast<quint32>(ui->comboBoxPoint->itemData(index));
     QColor color;
 
     try
     {
-        QListWidgetItem *item = ui->listWidget->item( ui->listWidget->currentRow() );
-        VSplinePoint p = qvariant_cast<VSplinePoint>(item->data(Qt::UserRole));
+        QListWidgetItem *item = ui->listWidget->item(ui->listWidget->currentRow());
+        auto p = qvariant_cast<VSplinePoint>(item->data(Qt::UserRole));
 
         const auto point = data->GeometricObject<VPointF>(id);
         p.SetP(*point);
@@ -694,9 +722,10 @@ void DialogSplinePath::currentPointChanged(int index)
             color = OkColor(this);
 
             auto first = qvariant_cast<VSplinePoint>(ui->listWidget->item(0)->data(Qt::UserRole));
-            auto last = qvariant_cast<VSplinePoint>(ui->listWidget->item(ui->listWidget->count()-1)->data(Qt::UserRole));
+            auto last =
+                qvariant_cast<VSplinePoint>(ui->listWidget->item(ui->listWidget->count() - 1)->data(Qt::UserRole));
 
-            if (first.P().id() == path.at(0).P().id() && last.P().id() == path.at(path.CountPoints()-1).P().id())
+            if (first.P().id() == path.at(0).P().id() && last.P().id() == path.at(path.CountPoints() - 1).P().id())
             {
                 newDuplicate = -1;
                 ui->lineEditSplPathName->setText(VAbstractApplication::VApp()->TrVars()->VarToUser(path.name()));
@@ -728,22 +757,108 @@ void DialogSplinePath::currentPointChanged(int index)
     CheckState();
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void DialogSplinePath::NewPointChanged()
+{
+    ui->toolButtonAddPoint->setEnabled(ui->comboBoxNewPoint->currentIndex() != -1);
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void DialogSplinePath::AddPoint()
+{
+    const auto id = qvariant_cast<quint32>(ui->comboBoxNewPoint->currentData());
+    const auto point = data->GeometricObject<VPointF>(id);
+    VSplinePoint p;
+    p.SetP(*point);
+    NewItem(p);
+    SavePath();
+
+    flagError = IsPathValid();
+    CheckState(); // Disable Ok and Apply buttons if something wrong.
+
+    ui->comboBoxNewPoint->blockSignals(true);
+    ui->comboBoxNewPoint->setCurrentIndex(-1);
+    ui->comboBoxNewPoint->blockSignals(false);
+    ui->toolButtonAddPoint->setDisabled(true);
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void DialogSplinePath::RemovePoint()
+{
+    if (ui->listWidget->count() <= 3)
+    {
+        ui->toolButtonRemovePoint->setDisabled(true);
+        return;
+    }
+
+    QListWidgetItem *selectedItem = ui->listWidget->currentItem();
+    if (selectedItem)
+    {
+        delete ui->listWidget->takeItem(ui->listWidget->row(selectedItem));
+        ui->listWidget->setCurrentRow(0);
+        ui->toolButtonRemovePoint->setDisabled(ui->listWidget->count() <= 3);
+    }
+
+    SavePath();
+
+    flagError = IsPathValid();
+    CheckState(); // Disable Ok and Apply buttons if something wrong.
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void DialogSplinePath::MoveTop()
+{
+    MoveListRowTop(ui->listWidget);
+    SavePath();
+    flagError = IsPathValid();
+    CheckState(); // Disable Ok and Apply buttons if something wrong.
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void DialogSplinePath::MoveUp()
+{
+    MoveListRowUp(ui->listWidget);
+    SavePath();
+    flagError = IsPathValid();
+    CheckState(); // Disable Ok and Apply buttons if something wrong.
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void DialogSplinePath::MoveDown()
+{
+    MoveListRowDown(ui->listWidget);
+    SavePath();
+    flagError = IsPathValid();
+    CheckState(); // Disable Ok and Apply buttons if something wrong.
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void DialogSplinePath::MoveBottom()
+{
+    MoveListRowBottom(ui->listWidget);
+    SavePath();
+    flagError = IsPathValid();
+    CheckState(); // Disable Ok and Apply buttons if something wrong.
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void DialogSplinePath::ShowDialog(bool click)
 {
-    if (click == false)
+    if (click)
     {
-        if (path.CountPoints() >= 3)
+        return;
+    }
+
+    if (path.CountPoints() >= 3)
+    {
+        emit ToolTip(QString());
+
+        if (not data->IsUnique(path.name()))
         {
-            emit ToolTip(QString());
-
-            if (not data->IsUnique(path.name()))
-            {
-                path.SetDuplicate(DNumber(path.name()));
-            }
-
-            DialogAccepted();
+            path.SetDuplicate(DNumber(path.name()));
         }
+
+        DialogAccepted();
     }
 }
 
@@ -771,7 +886,7 @@ void DialogSplinePath::NewItem(const VSplinePoint &point)
     flagAngle2.append(true);
     flagLength2.append(true);
 
-    auto* item = new QListWidgetItem(point.P().name());
+    auto *item = new QListWidgetItem(point.P().name());
     item->setFont(NodeFont(item->font()));
     item->setData(Qt::UserRole, QVariant::fromValue(point));
 
@@ -781,6 +896,7 @@ void DialogSplinePath::NewItem(const VSplinePoint &point)
     {
         bOk = ui->buttonBox->button(QDialogButtonBox::Ok);
         bOk->setEnabled(true);
+        ui->toolButtonRemovePoint->setEnabled(true);
     }
 
     DataPoint(point);
@@ -797,9 +913,9 @@ void DialogSplinePath::DataPoint(const VSplinePoint &p)
     ChangeCurrentData(ui->comboBoxPoint, p.P().id());
     ui->comboBoxPoint->blockSignals(false);
 
-    int row = ui->listWidget->currentRow();
+    int const row = ui->listWidget->currentRow();
     const QString field = tr("Not used");
-    const QString emptyRes = QString("_");
+    const QString emptyRes = QChar('_');
 
     if (row == 0)
     {
@@ -829,18 +945,16 @@ void DialogSplinePath::DataPoint(const VSplinePoint &p)
 
         ui->plainTextEditAngle2F->blockSignals(true);
         ui->plainTextEditLength2F->blockSignals(true);
-        ui->plainTextEditAngle2F->setPlainText(
-                    VAbstractApplication::VApp()->TrVars()
-                    ->FormulaToUser(p.Angle2Formula(),VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
+        ui->plainTextEditAngle2F->setPlainText(VAbstractApplication::VApp()->TrVars()->FormulaToUser(
+            p.Angle2Formula(), VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
         EvalAngle2();
-        ui->plainTextEditLength2F->setPlainText(
-                    VAbstractApplication::VApp()->TrVars()
-                    ->FormulaToUser(p.Length2Formula(), VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
+        ui->plainTextEditLength2F->setPlainText(VAbstractApplication::VApp()->TrVars()->FormulaToUser(
+            p.Length2Formula(), VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
         EvalLength2();
         ui->plainTextEditAngle2F->blockSignals(false);
         ui->plainTextEditLength2F->blockSignals(false);
     }
-    else if (row == ui->listWidget->count()-1)
+    else if (row == ui->listWidget->count() - 1)
     {
         ui->toolButtonExprAngle2->setEnabled(false);
         ui->labelResultAngle2->setText(emptyRes);
@@ -868,13 +982,11 @@ void DialogSplinePath::DataPoint(const VSplinePoint &p)
 
         ui->plainTextEditAngle1F->blockSignals(true);
         ui->plainTextEditLength1F->blockSignals(true);
-        ui->plainTextEditAngle1F->setPlainText(
-                    VAbstractApplication::VApp()->TrVars()
-                    ->FormulaToUser(p.Angle1Formula(), VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
+        ui->plainTextEditAngle1F->setPlainText(VAbstractApplication::VApp()->TrVars()->FormulaToUser(
+            p.Angle1Formula(), VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
         EvalAngle1();
-        ui->plainTextEditLength1F->setPlainText(
-                    VAbstractApplication::VApp()->TrVars()
-                    ->FormulaToUser(p.Length1Formula(), VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
+        ui->plainTextEditLength1F->setPlainText(VAbstractApplication::VApp()->TrVars()->FormulaToUser(
+            p.Length1Formula(), VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
         EvalLength1();
         ui->plainTextEditAngle1F->blockSignals(false);
         ui->plainTextEditLength1F->blockSignals(false);
@@ -896,18 +1008,14 @@ void DialogSplinePath::DataPoint(const VSplinePoint &p)
         ui->plainTextEditAngle2F->blockSignals(true);
         ui->plainTextEditLength2F->blockSignals(true);
 
-        ui->plainTextEditAngle1F->setPlainText(
-                    VAbstractApplication::VApp()->TrVars()
-                    ->FormulaToUser(p.Angle1Formula(), VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
-        ui->plainTextEditAngle2F->setPlainText(
-                    VAbstractApplication::VApp()->TrVars()
-                    ->FormulaToUser(p.Angle2Formula(), VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
-        ui->plainTextEditLength1F->setPlainText(
-                    VAbstractApplication::VApp()->TrVars()
-                    ->FormulaToUser(p.Length1Formula(), VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
-        ui->plainTextEditLength2F->setPlainText(
-                    VAbstractApplication::VApp()->TrVars()
-                    ->FormulaToUser(p.Length2Formula(), VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
+        ui->plainTextEditAngle1F->setPlainText(VAbstractApplication::VApp()->TrVars()->FormulaToUser(
+            p.Angle1Formula(), VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
+        ui->plainTextEditAngle2F->setPlainText(VAbstractApplication::VApp()->TrVars()->FormulaToUser(
+            p.Angle2Formula(), VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
+        ui->plainTextEditLength1F->setPlainText(VAbstractApplication::VApp()->TrVars()->FormulaToUser(
+            p.Length1Formula(), VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
+        ui->plainTextEditLength2F->setPlainText(VAbstractApplication::VApp()->TrVars()->FormulaToUser(
+            p.Length2Formula(), VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
 
         EvalAngle1();
         EvalLength1();
@@ -933,7 +1041,7 @@ void DialogSplinePath::SavePath()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QSet<quint32> DialogSplinePath::AllIds() const
+auto DialogSplinePath::AllIds() const -> QSet<quint32>
 {
     QSet<quint32> ids;
     for (qint32 i = 0; i < ui->listWidget->count(); ++i)
@@ -945,7 +1053,7 @@ QSet<quint32> DialogSplinePath::AllIds() const
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool DialogSplinePath::IsPathValid() const
+auto DialogSplinePath::IsPathValid() const -> bool
 {
     if (path.CountPoints() < 3)
     {
@@ -956,9 +1064,10 @@ bool DialogSplinePath::IsPathValid() const
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VSplinePath DialogSplinePath::ExtractPath() const
+auto DialogSplinePath::ExtractPath() const -> VSplinePath
 {
     QVector<VSplinePoint> points;
+    points.reserve(ui->listWidget->count());
     for (qint32 i = 0; i < ui->listWidget->count(); ++i)
     {
         points.append(qvariant_cast<VSplinePoint>(ui->listWidget->item(i)->data(Qt::UserRole)));
@@ -980,16 +1089,45 @@ void DialogSplinePath::ShowPointIssue(const QString &pName)
 
     if (flagAngle1.at(row) && flagAngle2.at(row) && flagLength1.at(row) && flagLength2.at(row))
     {
-       item->setText(pName);
+        item->setText(pName);
     }
     else
     {
-       item->setText(pName + QLatin1String("(!)"));
+        item->setText(pName + "(!)"_L1);
     }
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool DialogSplinePath::IsValid() const
+void DialogSplinePath::InitIcons()
+{
+    const auto resource = QStringLiteral("icon");
+
+    const auto fxIcon = QStringLiteral("24x24/fx.png");
+    ui->toolButtonExprLength1->setIcon(VTheme::GetIconResource(resource, fxIcon));
+    ui->toolButtonExprAngle1->setIcon(VTheme::GetIconResource(resource, fxIcon));
+    ui->toolButtonExprLength2->setIcon(VTheme::GetIconResource(resource, fxIcon));
+    ui->toolButtonExprAngle2->setIcon(VTheme::GetIconResource(resource, fxIcon));
+
+    const auto equalIcon = QStringLiteral("24x24/equal.png");
+    ui->label_8->setPixmap(VTheme::GetPixmapResource(resource, equalIcon));
+    ui->label_9->setPixmap(VTheme::GetPixmapResource(resource, equalIcon));
+    ui->label_10->setPixmap(VTheme::GetPixmapResource(resource, equalIcon));
+    ui->label_11->setPixmap(VTheme::GetPixmapResource(resource, equalIcon));
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void DialogSplinePath::MoveControls()
+{
+    const int index = ui->listWidget->currentRow();
+
+    ui->toolButtonTop->setEnabled(index > 0);
+    ui->toolButtonUp->setEnabled(index > 0);
+    ui->toolButtonDown->setEnabled(index != -1 && index < ui->listWidget->count() - 1);
+    ui->toolButtonBottom->setEnabled(index != -1 && index < ui->listWidget->count() - 1);
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto DialogSplinePath::IsValid() const -> bool
 {
     bool fAngle1 = true, fAngle2 = true, fLength1 = true, fLength2 = true;
 
@@ -1007,8 +1145,8 @@ bool DialogSplinePath::IsValid() const
 //---------------------------------------------------------------------------------------------------------------------
 void DialogSplinePath::showEvent(QShowEvent *event)
 {
-    QDialog::showEvent( event ); // NOLINT(bugprone-parent-virtual-call)
-    if ( event->spontaneous() )
+    QDialog::showEvent(event); // NOLINT(bugprone-parent-virtual-call)
+    if (event->spontaneous())
     {
         return;
     }
@@ -1024,7 +1162,7 @@ void DialogSplinePath::showEvent(QShowEvent *event)
         resize(sz);
     }
 
-    isInitialized = true;//first show windows are held
+    isInitialized = true; // first show windows are held
     ShowVisualization();
 
     CheckState();
@@ -1050,7 +1188,7 @@ void DialogSplinePath::SetNotes(const QString &notes)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogSplinePath::GetNotes() const
+auto DialogSplinePath::GetNotes() const -> QString
 {
     return ui->plainTextEditToolNotes->toPlainText();
 }
