@@ -28,9 +28,7 @@
 
 #include "dialogtool.h"
 
-#include <climits>
-#include <qiterator.h>
-#include <qnumeric.h>
+#include <QBuffer>
 #include <QCloseEvent>
 #include <QComboBox>
 #include <QDoubleSpinBox>
@@ -55,19 +53,25 @@
 #include <QTextCursor>
 #include <QTimer>
 #include <QWidget>
-#include <Qt>
 #include <QtDebug>
+#include <climits>
 #include <new>
-#include <QBuffer>
+#include <qiterator.h>
+#include <qnumeric.h>
 
-#include "../ifc/xml/vdomdocument.h"
-#include "../vgeometry/vpointf.h"
-#include "../vpatterndb/vcontainer.h"
-#include "../vpatterndb/vpiecenode.h"
 #include "../../tools/vabstracttool.h"
 #include "../ifc/xml/vabstractpattern.h"
 #include "../vgeometry/vabstractcurve.h"
 #include "../vgeometry/vgobject.h"
+#include "../vgeometry/vpointf.h"
+#include "../vpatterndb/vcontainer.h"
+#include "../vpatterndb/vpiecenode.h"
+
+#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
+#include "../vmisc/compatibility.h"
+#endif
+
+using namespace Qt::Literals::StringLiterals;
 
 template <class T> class QSharedPointer;
 
@@ -85,25 +89,25 @@ QT_WARNING_POP
  * @param data container with data
  * @param parent parent widget
  */
-DialogTool::DialogTool(const VContainer *data, quint32 toolId, QWidget *parent)
-    : QDialog(parent),
-      data(data),
-      isInitialized(false),
-      bOk(nullptr),
-      bApply(nullptr),
-      associatedTool(nullptr),
-      toolId(toolId),
-      prepare(false),
-      vis(nullptr)
+DialogTool::DialogTool(const VContainer *data, VAbstractPattern *doc, quint32 toolId, QWidget *parent)
+  : QDialog(parent),
+    data(data),
+    m_doc(doc),
+    isInitialized(false),
+    bOk(nullptr),
+    bApply(nullptr),
+    associatedTool(nullptr),
+    toolId(toolId),
+    prepare(false),
+    vis(nullptr)
 {
-    SCASSERT(data != nullptr)      
+    SCASSERT(data != nullptr);
+    SCASSERT(doc != nullptr);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 DialogTool::~DialogTool()
 {
-    emit ToolTip(QString());
-
     if (not vis.isNull())
     {
         delete vis;
@@ -128,8 +132,8 @@ void DialogTool::closeEvent(QCloseEvent *event)
  */
 void DialogTool::showEvent(QShowEvent *event)
 {
-    QDialog::showEvent( event );
-    if ( event->spontaneous() )
+    QDialog::showEvent(event);
+    if (event->spontaneous())
     {
         return;
     }
@@ -142,7 +146,7 @@ void DialogTool::showEvent(QShowEvent *event)
     setMaximumSize(size());
     setMinimumSize(size());
 
-    isInitialized = true;//first show windows are held
+    isInitialized = true; // first show windows are held
     ShowVisualization();
 
     CheckState();
@@ -159,7 +163,7 @@ void DialogTool::keyPressEvent(QKeyEvent *event)
         default:
             break;
     }
-    QDialog::keyPressEvent ( event );
+    QDialog::keyPressEvent(event);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -198,17 +202,14 @@ void DialogTool::FillComboBoxSplines(QComboBox *box) const
     SCASSERT(box != nullptr)
     box->blockSignals(true);
 
-    const auto objs = data->CalculationGObjects();
-    QHash<quint32, QSharedPointer<VGObject> >::const_iterator i;
+    const auto *const objs = data->CalculationGObjects();
+    QHash<quint32, QSharedPointer<VGObject>>::const_iterator i;
     QMap<QString, quint32> list;
     for (i = objs->constBegin(); i != objs->constEnd(); ++i)
     {
-        if (i.key() != toolId)
+        if (i.key() != toolId && IsSpline(i.value()))
         {
-            if (IsSpline(i.value()))
-            {
-                PrepareList<VAbstractCurve>(list, i.key());
-            }
+            PrepareList<VAbstractCurve>(list, i.key());
         }
     }
     FillList(box, list);
@@ -222,17 +223,14 @@ void DialogTool::FillComboBoxSplinesPath(QComboBox *box) const
     SCASSERT(box != nullptr)
     box->blockSignals(true);
 
-    const auto objs = data->CalculationGObjects();
-    QHash<quint32, QSharedPointer<VGObject> >::const_iterator i;
+    const auto *const objs = data->CalculationGObjects();
+    QHash<quint32, QSharedPointer<VGObject>>::const_iterator i;
     QMap<QString, quint32> list;
     for (i = objs->constBegin(); i != objs->constEnd(); ++i)
     {
-        if (i.key() != toolId)
+        if (i.key() != toolId && IsSplinePath(i.value()))
         {
-            if (IsSplinePath(i.value()))
-            {
-                PrepareList<VAbstractCurve>(list, i.key());
-            }
+            PrepareList<VAbstractCurve>(list, i.key());
         }
     }
     FillList(box, list);
@@ -244,20 +242,17 @@ void DialogTool::FillComboBoxSplinesPath(QComboBox *box) const
 void DialogTool::FillComboBoxCurves(QComboBox *box) const
 {
     SCASSERT(box != nullptr)
-    const auto objs = data->CalculationGObjects();
+    const auto *const objs = data->CalculationGObjects();
     QMap<QString, quint32> list;
-    QHash<quint32, QSharedPointer<VGObject> >::const_iterator i;
+    QHash<quint32, QSharedPointer<VGObject>>::const_iterator i;
     for (i = objs->constBegin(); i != objs->constEnd(); ++i)
     {
         if (i.key() != toolId)
         {
-            QSharedPointer<VGObject> obj = i.value();
-            if (obj->getType() == GOType::Arc
-                || obj->getType() == GOType::EllipticalArc
-                || obj->getType() == GOType::Spline
-                || obj->getType() == GOType::SplinePath
-                || obj->getType() == GOType::CubicBezier
-                || obj->getType() == GOType::CubicBezierPath)
+            QSharedPointer<VGObject> const obj = i.value();
+            if (obj->getType() == GOType::Arc || obj->getType() == GOType::EllipticalArc ||
+                obj->getType() == GOType::Spline || obj->getType() == GOType::SplinePath ||
+                obj->getType() == GOType::CubicBezier || obj->getType() == GOType::CubicBezierPath)
             {
                 PrepareList<VAbstractCurve>(list, i.key());
             }
@@ -304,7 +299,8 @@ void DialogTool::FillComboBoxLineColors(QComboBox *box, const QMap<QString, QStr
     QMap<QString, QString>::const_iterator i = lineColors.constBegin();
     while (i != lineColors.constEnd())
     {
-        box->addItem(LineColor(box->iconSize().height(), i.key()), i.value(), QVariant(i.key()));
+        box->addItem(LineColor(box->palette().color(QPalette::Text), box->iconSize().height(), i.key()), i.value(),
+                     QVariant(i.key()));
         ++i;
     }
 }
@@ -337,7 +333,7 @@ void DialogTool::FillComboBoxHCrossCurvesPoint(QComboBox *box) const
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogTool::GetComboBoxCurrentData(const QComboBox *box, const QString &def) const
+auto DialogTool::GetComboBoxCurrentData(const QComboBox *box, const QString &def) const -> QString
 {
     SCASSERT(box != nullptr)
     QString value;
@@ -367,7 +363,7 @@ void DialogTool::ChangeCurrentData(QComboBox *box, const QVariant &value) const
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool DialogTool::eventFilter(QObject *object, QEvent *event)
+auto DialogTool::eventFilter(QObject *object, QEvent *event) -> bool
 {
     const bool fitered = FilterObject(object, event);
     if (fitered)
@@ -379,14 +375,14 @@ bool DialogTool::eventFilter(QObject *object, QEvent *event)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-quint32 DialogTool::DNumber(const QString &baseName) const
+auto DialogTool::DNumber(const QString &baseName) const -> quint32
 {
     quint32 num = 0;
     QString name;
     do
     {
         ++num;
-        name = baseName + QString("_%1").arg(num);
+        name = baseName + u"_%1"_s.arg(num);
     } while (not data->IsUnique(name));
 
     return num;
@@ -408,31 +404,31 @@ void DialogTool::NewNodeItem(QListWidget *listWidget, const VPieceNode &node, bo
             name = GetNodeName(data, node, showPassmark);
             break;
         default:
-            qDebug()<<"Got wrong tools. Ignore.";
+            qDebug() << "Got wrong tools. Ignore.";
             return;
     }
 
     bool canAddNewPoint = false;
 
-    if(listWidget->count() == 0)
+    if (listWidget->count() == 0)
     {
         canAddNewPoint = true;
     }
     else
     {
-        if(RowNode(listWidget, listWidget->count()-1).GetId() != node.GetId())
+        if (RowNode(listWidget, listWidget->count() - 1).GetId() != node.GetId())
         {
             canAddNewPoint = true;
         }
     }
 
-    if(canAddNewPoint)
+    if (canAddNewPoint)
     {
-        QListWidgetItem *item = new QListWidgetItem(name);
+        auto *item = new QListWidgetItem(name);
         item->setFont(NodeFont(item->font(), showExclusion ? node.IsExcluded() : false));
         item->setData(Qt::UserRole, QVariant::fromValue(node));
         listWidget->addItem(item);
-        listWidget->setCurrentRow(listWidget->count()-1);
+        listWidget->setCurrentRow(listWidget->count() - 1);
     }
 }
 
@@ -502,12 +498,12 @@ void DialogTool::MoveListRowBottom(QListWidget *list)
     if (QListWidgetItem *currentItem = list->takeItem(currentIndex))
     {
         list->insertItem(list->count(), currentItem);
-        list->setCurrentRow(list->count()-1);
+        list->setCurrentRow(list->count() - 1);
     }
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool DialogTool::IsSplinePath(const QSharedPointer<VGObject> &obj) const
+auto DialogTool::IsSplinePath(const QSharedPointer<VGObject> &obj) const -> bool
 {
     return obj->getType() == GOType::SplinePath || obj->getType() == GOType::CubicBezierPath;
 }
@@ -517,7 +513,7 @@ bool DialogTool::IsSplinePath(const QSharedPointer<VGObject> &obj) const
  * @brief Eval evaluate formula and show result
  * @param formulaData options to control parsing
  */
-qreal DialogTool::Eval(const FormulaData &formulaData, bool &flag)
+auto DialogTool::Eval(const FormulaData &formulaData, bool &flag) -> qreal
 {
     const qreal result = EvalToolFormula(this, formulaData, flag);
     CheckState(); // Disable Ok and Apply buttons if something wrong.
@@ -525,8 +521,8 @@ qreal DialogTool::Eval(const FormulaData &formulaData, bool &flag)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void DialogTool::setCurrentPointId(QComboBox *box, const quint32 &value, FillComboBox rule,
-                                   const quint32 &ch1, const quint32 &ch2) const
+void DialogTool::setCurrentPointId(QComboBox *box, const quint32 &value, FillComboBox rule, const quint32 &ch1,
+                                   const quint32 &ch2) const
 {
     SCASSERT(box != nullptr)
 
@@ -553,8 +549,8 @@ void DialogTool::setCurrentSplineId(QComboBox *box, const quint32 &value) const
 /**
  * @brief setCurrentArcId
  */
-void DialogTool::setCurrentArcId(QComboBox *box, const quint32 &value, FillComboBox rule,
-                                 const quint32 &ch1, const quint32 &ch2) const
+void DialogTool::setCurrentArcId(QComboBox *box, const quint32 &value, FillComboBox rule, const quint32 &ch1,
+                                 const quint32 &ch2) const
 {
     SCASSERT(box != nullptr)
     FillComboBoxArcs(box, rule, ch1, ch2);
@@ -588,35 +584,32 @@ void DialogTool::setCurrentCurveId(QComboBox *box, const quint32 &value) const
  * @param box combobox
  * @return id or 0 if combobox is empty
  */
-quint32 DialogTool::getCurrentObjectId(QComboBox *box) const
+auto DialogTool::getCurrentObjectId(QComboBox *box) -> quint32
 {
     SCASSERT(box != nullptr)
-    qint32 index = box->currentIndex();
+    qint32 const index = box->currentIndex();
     if (index != -1)
     {
         return qvariant_cast<quint32>(box->itemData(index));
     }
-    else
-    {
-        return 0;
-    }
+
+    return 0;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool DialogTool::SetObject(const quint32 &id, QComboBox *box, const QString &toolTip)
+auto DialogTool::SetObject(const quint32 &id, QComboBox *box, const QString &toolTip) -> bool
 {
     SCASSERT(box != nullptr)
     const qint32 index = box->findData(id);
-    if ( index != -1 )
+    if (index != -1)
     { // -1 for not found
         box->setCurrentIndex(index);
         emit ToolTip(toolTip);
         return true;
     }
-    else
-    {
-        qWarning()<<"Can't find object by id"<<id;
-    }
+
+    qWarning() << "Can't find object by id" << id;
+
     return false;
 }
 
@@ -640,8 +633,7 @@ void DialogTool::FillList(QComboBox *box, const QMap<QString, quint32> &list) co
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-template <typename T>
-void DialogTool::PrepareList(QMap<QString, quint32> &list, quint32 id) const
+template <typename T> void DialogTool::PrepareList(QMap<QString, quint32> &list, quint32 id) const
 {
     const auto obj = data->GeometricObject<T>(id);
     SCASSERT(obj != nullptr)
@@ -649,7 +641,7 @@ void DialogTool::PrepareList(QMap<QString, quint32> &list, quint32 id) const
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool DialogTool::IsSpline(const QSharedPointer<VGObject> &obj) const
+auto DialogTool::IsSpline(const QSharedPointer<VGObject> &obj) const -> bool
 {
     return obj->getType() == GOType::Spline || obj->getType() == GOType::CubicBezier;
 }
@@ -663,7 +655,7 @@ void DialogTool::CheckState()
     SCASSERT(bOk != nullptr)
     bOk->setEnabled(IsValid());
     // In case dialog hasn't apply button
-    if ( bApply != nullptr)
+    if (bApply != nullptr)
     {
         bApply->setEnabled(bOk->isEnabled());
     }
@@ -717,7 +709,7 @@ void DialogTool::DialogRejected()
 
 //---------------------------------------------------------------------------------------------------------------------
 // cppcheck-suppress unusedFunction
-quint32 DialogTool::GetToolId() const
+auto DialogTool::GetToolId() const -> quint32
 {
     return toolId;
 }
@@ -787,8 +779,8 @@ void DialogTool::FillCombo(QComboBox *box, GOType gType, FillComboBox rule, cons
     SCASSERT(box != nullptr)
     box->blockSignals(true);
 
-    const QHash<quint32, QSharedPointer<VGObject> > *objs = data->CalculationGObjects();
-    QHash<quint32, QSharedPointer<VGObject> >::const_iterator i;
+    const QHash<quint32, QSharedPointer<VGObject>> *objs = data->CalculationGObjects();
+    QHash<quint32, QSharedPointer<VGObject>>::const_iterator i;
     QMap<QString, quint32> list;
     for (i = objs->constBegin(); i != objs->constEnd(); ++i)
     {
@@ -796,7 +788,7 @@ void DialogTool::FillCombo(QComboBox *box, GOType gType, FillComboBox rule, cons
         {
             if (i.key() != toolId && i.value()->getIdTool() != toolId && i.key() != ch1 && i.key() != ch2)
             {
-                QSharedPointer<VGObject> obj = i.value();
+                const QSharedPointer<VGObject> &obj = i.value();
                 if (obj->getType() == gType)
                 {
                     PrepareList<GObject>(list, i.key());
@@ -807,7 +799,7 @@ void DialogTool::FillCombo(QComboBox *box, GOType gType, FillComboBox rule, cons
         {
             if (i.key() != toolId && i.value()->getIdTool() != toolId)
             {
-                QSharedPointer<VGObject> obj = i.value();
+                const QSharedPointer<VGObject> &obj = i.value();
                 if (obj->getType() == gType && obj->getMode() == Draw::Calculation)
                 {
                     PrepareList<GObject>(list, i.key());
