@@ -29,7 +29,6 @@
 #ifndef DIALOGTRIANGLE_H
 #define DIALOGTRIANGLE_H
 
-#include <qcompilerdetection.h>
 #include <QMetaObject>
 #include <QObject>
 #include <QString>
@@ -40,46 +39,50 @@
 
 namespace Ui
 {
-    class DialogTriangle;
+class DialogTriangle;
 }
 
 /**
  * @brief The DialogTriangle class dialog for ToolTriangle. Help create point and edit option.
  */
-class DialogTriangle : public DialogTool
+class DialogTriangle final : public DialogTool
 {
     Q_OBJECT // NOLINT
+
 public:
-    DialogTriangle(const VContainer *data, quint32 toolId, QWidget *parent = nullptr);
-    virtual ~DialogTriangle() override;
+    DialogTriangle(const VContainer *data, VAbstractPattern *doc, quint32 toolId, QWidget *parent = nullptr);
+    ~DialogTriangle() override;
 
-    quint32        GetAxisP1Id() const;
-    void           SetAxisP1Id(const quint32 &value);
+    auto GetAxisP1Id() const -> quint32;
+    void SetAxisP1Id(const quint32 &value);
 
-    quint32        GetAxisP2Id() const;
-    void           SetAxisP2Id(const quint32 &value);
+    auto GetAxisP2Id() const -> quint32;
+    void SetAxisP2Id(const quint32 &value);
 
-    quint32        GetFirstPointId() const;
-    void           SetFirstPointId(const quint32 &value);
+    auto GetFirstPointId() const -> quint32;
+    void SetFirstPointId(const quint32 &value);
 
-    quint32        GetSecondPointId() const;
-    void           SetSecondPointId(const quint32 &value);
+    auto GetSecondPointId() const -> quint32;
+    void SetSecondPointId(const quint32 &value);
 
-    QString        GetPointName() const;
-    void           SetPointName(const QString &value);
+    auto GetPointName() const -> QString;
+    void SetPointName(const QString &value);
+
+    void SetNotes(const QString &notes);
+    auto GetNotes() const -> QString;
 
-    void    SetNotes(const QString &notes);
-    QString GetNotes() const;
 public slots:
-    virtual void   ChosenObject(quint32 id, const SceneObject &type) override;
-    virtual void   PointNameChanged() override;
+    void ChosenObject(quint32 id, const SceneObject &type) override;
+    void PointNameChanged() override;
+
 protected:
-    virtual void   ShowVisualization() override;
+    void ShowVisualization() override;
     /**
      * @brief SaveData Put dialog data in local variables
      */
-    virtual void   SaveData() override;
-    virtual bool   IsValid() const final;
+    void SaveData() override;
+    auto IsValid() const -> bool override;
+
 private:
     Q_DISABLE_COPY_MOVE(DialogTriangle) // NOLINT
 
@@ -92,11 +95,11 @@ private:
     bool flagError;
 
     /** @brief number number of handled objects */
-    qint32  number{0};
+    qint32 number{0};
 };
 
 //---------------------------------------------------------------------------------------------------------------------
-inline bool DialogTriangle::IsValid() const
+inline auto DialogTriangle::IsValid() const -> bool
 {
     return flagName && flagError;
 }
