@@ -37,10 +37,9 @@
 #include <QRegularExpression>
 #include <QRegularExpressionMatch>
 #include <QSet>
-#include <Qt>
 
-#include "../../visualization/visualization.h"
 #include "../../visualization/line/vistooltruedarts.h"
+#include "../../visualization/visualization.h"
 #include "../ifc/xml/vabstractpattern.h"
 #include "../qmuparser/qmudef.h"
 #include "../vpatterndb/vcontainer.h"
@@ -48,16 +47,16 @@
 #include "ui_dialogtruedarts.h"
 
 //---------------------------------------------------------------------------------------------------------------------
-DialogTrueDarts::DialogTrueDarts(const VContainer *data, quint32 toolId, QWidget *parent)
-    : DialogTool(data, toolId, parent),
-      ui(new Ui::DialogTrueDarts),
-      d1PointName(),
-      d2PointName(),
-      ch1(NULL_ID),
-      ch2(NULL_ID),
-      flagName1(true),
-      flagName2(true),
-      flagError(false)
+DialogTrueDarts::DialogTrueDarts(const VContainer *data, VAbstractPattern *doc, quint32 toolId, QWidget *parent)
+  : DialogTool(data, doc, toolId, parent),
+    ui(new Ui::DialogTrueDarts),
+    d1PointName(),
+    d2PointName(),
+    ch1(NULL_ID),
+    ch2(NULL_ID),
+    flagName1(true),
+    flagName2(true),
+    flagError(false)
 {
     ui->setupUi(this);
 
@@ -66,7 +65,7 @@ DialogTrueDarts::DialogTrueDarts(const VContainer *data, quint32 toolId, QWidget
 
     const QString name1 = VAbstractValApplication::VApp()->getCurrentDocument()->GenerateLabel(LabelType::NewLabel);
     const QString name2 =
-            VAbstractValApplication::VApp()->getCurrentDocument()->GenerateLabel(LabelType::NewLabel, name1);
+        VAbstractValApplication::VApp()->getCurrentDocument()->GenerateLabel(LabelType::NewLabel, name1);
     ui->lineEditFirstNewDartPoint->setText(name1);
     ui->lineEditSecondNewDartPoint->setText(name2);
 
@@ -76,16 +75,11 @@ DialogTrueDarts::DialogTrueDarts(const VContainer *data, quint32 toolId, QWidget
 
     connect(ui->lineEditFirstNewDartPoint, &QLineEdit::textChanged, this, &DialogTrueDarts::NameDartPoint1Changed);
     connect(ui->lineEditSecondNewDartPoint, &QLineEdit::textChanged, this, &DialogTrueDarts::NameDartPoint2Changed);
-    connect(ui->comboBoxFirstBasePoint, &QComboBox::currentTextChanged,
-            this, &DialogTrueDarts::PointNameChanged);
-    connect(ui->comboBoxSecondBasePoint, &QComboBox::currentTextChanged,
-            this, &DialogTrueDarts::PointNameChanged);
-    connect(ui->comboBoxFirstDartPoint, &QComboBox::currentTextChanged,
-            this, &DialogTrueDarts::PointNameChanged);
-    connect(ui->comboBoxSecondDartPoint, &QComboBox::currentTextChanged,
-            this, &DialogTrueDarts::PointNameChanged);
-    connect(ui->comboBoxThirdDartPoint, &QComboBox::currentTextChanged,
-            this, &DialogTrueDarts::PointNameChanged);
+    connect(ui->comboBoxFirstBasePoint, &QComboBox::currentTextChanged, this, &DialogTrueDarts::PointNameChanged);
+    connect(ui->comboBoxSecondBasePoint, &QComboBox::currentTextChanged, this, &DialogTrueDarts::PointNameChanged);
+    connect(ui->comboBoxFirstDartPoint, &QComboBox::currentTextChanged, this, &DialogTrueDarts::PointNameChanged);
+    connect(ui->comboBoxSecondDartPoint, &QComboBox::currentTextChanged, this, &DialogTrueDarts::PointNameChanged);
+    connect(ui->comboBoxThirdDartPoint, &QComboBox::currentTextChanged, this, &DialogTrueDarts::PointNameChanged);
 
     vis = new VisToolTrueDarts(data);
 
@@ -100,13 +94,13 @@ DialogTrueDarts::~DialogTrueDarts()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogTrueDarts::GetFirstNewDartPointName()
+auto DialogTrueDarts::GetFirstNewDartPointName() -> QString
 {
     return d1PointName;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogTrueDarts::GetSecondNewDartPointName()
+auto DialogTrueDarts::GetSecondNewDartPointName() -> QString
 {
     return d2PointName;
 }
@@ -127,13 +121,13 @@ void DialogTrueDarts::SetNewDartPointNames(const QString &firstPoint, const QStr
     ui->lineEditFirstNewDartPoint->blockSignals(false);
 
     CheckName(ui->lineEditFirstNewDartPoint, ui->labelFirstNewDartPoint, d1PointName, d2PointName,
-                ui->lineEditSecondNewDartPoint, flagName1);
+              ui->lineEditSecondNewDartPoint, flagName1);
     CheckName(ui->lineEditSecondNewDartPoint, ui->labelSecondNewDartPoint, d1PointName, d2PointName,
-                ui->lineEditFirstNewDartPoint, flagName2);
+              ui->lineEditFirstNewDartPoint, flagName2);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-quint32 DialogTrueDarts::GetFirstBasePointId() const
+auto DialogTrueDarts::GetFirstBasePointId() const -> quint32
 {
     return getCurrentObjectId(ui->comboBoxFirstBasePoint);
 }
@@ -143,13 +137,13 @@ void DialogTrueDarts::SetFirstBasePointId(const quint32 &value)
 {
     setCurrentPointId(ui->comboBoxFirstBasePoint, value, FillComboBox::NoChildren, ch1, ch2);
 
-    VisToolTrueDarts *points = qobject_cast<VisToolTrueDarts *>(vis);
+    auto *points = qobject_cast<VisToolTrueDarts *>(vis);
     SCASSERT(points != nullptr)
     points->SetBaseLineP1Id(value);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-quint32 DialogTrueDarts::GetSecondBasePointId() const
+auto DialogTrueDarts::GetSecondBasePointId() const -> quint32
 {
     return getCurrentObjectId(ui->comboBoxSecondBasePoint);
 }
@@ -159,13 +153,13 @@ void DialogTrueDarts::SetSecondBasePointId(const quint32 &value)
 {
     setCurrentPointId(ui->comboBoxSecondBasePoint, value, FillComboBox::NoChildren, ch1, ch2);
 
-    VisToolTrueDarts *points = qobject_cast<VisToolTrueDarts *>(vis);
+    auto *points = qobject_cast<VisToolTrueDarts *>(vis);
     SCASSERT(points != nullptr)
     points->SetBaseLineP2Id(value);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-quint32 DialogTrueDarts::GetFirstDartPointId() const
+auto DialogTrueDarts::GetFirstDartPointId() const -> quint32
 {
     return getCurrentObjectId(ui->comboBoxFirstDartPoint);
 }
@@ -175,13 +169,13 @@ void DialogTrueDarts::SetFirstDartPointId(const quint32 &value)
 {
     setCurrentPointId(ui->comboBoxFirstDartPoint, value, FillComboBox::NoChildren, ch1, ch2);
 
-    VisToolTrueDarts *points = qobject_cast<VisToolTrueDarts *>(vis);
+    auto *points = qobject_cast<VisToolTrueDarts *>(vis);
     SCASSERT(points != nullptr)
     points->SetD1PointId(value);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-quint32 DialogTrueDarts::GetSecondDartPointId() const
+auto DialogTrueDarts::GetSecondDartPointId() const -> quint32
 {
     return getCurrentObjectId(ui->comboBoxSecondDartPoint);
 }
@@ -191,13 +185,13 @@ void DialogTrueDarts::SetSecondDartPointId(const quint32 &value)
 {
     setCurrentPointId(ui->comboBoxSecondDartPoint, value, FillComboBox::NoChildren, ch1, ch2);
 
-    VisToolTrueDarts *points = qobject_cast<VisToolTrueDarts *>(vis);
+    auto *points = qobject_cast<VisToolTrueDarts *>(vis);
     SCASSERT(points != nullptr)
     points->SetD2PointId(value);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-quint32 DialogTrueDarts::GetThirdDartPointId() const
+auto DialogTrueDarts::GetThirdDartPointId() const -> quint32
 {
     return getCurrentObjectId(ui->comboBoxThirdDartPoint);
 }
@@ -207,7 +201,7 @@ void DialogTrueDarts::SetThirdDartPointId(const quint32 &value)
 {
     setCurrentPointId(ui->comboBoxThirdDartPoint, value, FillComboBox::NoChildren, ch1, ch2);
 
-    VisToolTrueDarts *points = qobject_cast<VisToolTrueDarts *>(vis);
+    auto *points = qobject_cast<VisToolTrueDarts *>(vis);
     SCASSERT(points != nullptr)
     points->SetD3PointId(value);
 }
@@ -223,94 +217,80 @@ void DialogTrueDarts::SetChildrenId(const quint32 &ch1, const quint32 &ch2)
 //---------------------------------------------------------------------------------------------------------------------
 void DialogTrueDarts::ChosenObject(quint32 id, const SceneObject &type)
 {
-    if (prepare == false)// After first choose we ignore all objects
+    if (prepare == false && type == SceneObject::Point) // After first choose we ignore all objects
     {
-        if (type == SceneObject::Point)
+        auto *points = qobject_cast<VisToolTrueDarts *>(vis);
+        SCASSERT(points != nullptr)
+
+        switch (number)
         {
-            VisToolTrueDarts *points = qobject_cast<VisToolTrueDarts *>(vis);
-            SCASSERT(points != nullptr)
-
-            switch (number)
+            case 0:
+                if (SetObject(id, ui->comboBoxFirstBasePoint, tr("Select the second base point")))
+                {
+                    number++;
+                    points->VisualMode(id);
+                }
+                break;
+            case 1:
+                if (getCurrentObjectId(ui->comboBoxFirstBasePoint) != id &&
+                    SetObject(id, ui->comboBoxSecondBasePoint, tr("Select the first dart point")))
+                {
+                    number++;
+                    points->SetBaseLineP2Id(id);
+                    points->RefreshGeometry();
+                }
+                break;
+            case 2:
             {
-                case 0:
-                    if (SetObject(id, ui->comboBoxFirstBasePoint, tr("Select the second base point")))
-                    {
-                        number++;
-                        points->VisualMode(id);
-                    }
-                    break;
-                case 1:
-                    if (getCurrentObjectId(ui->comboBoxFirstBasePoint) != id)
-                    {
-                        if (SetObject(id, ui->comboBoxSecondBasePoint, tr("Select the first dart point")))
-                        {
-                            number++;
-                            points->SetBaseLineP2Id(id);
-                            points->RefreshGeometry();
-                        }
-                    }
-                    break;
-                case 2:
-                {
-                    QSet<quint32> set;
-                    set.insert(getCurrentObjectId(ui->comboBoxFirstBasePoint));
-                    set.insert(getCurrentObjectId(ui->comboBoxSecondBasePoint));
-                    set.insert(id);
+                QSet<quint32> set;
+                set.insert(getCurrentObjectId(ui->comboBoxFirstBasePoint));
+                set.insert(getCurrentObjectId(ui->comboBoxSecondBasePoint));
+                set.insert(id);
 
-                    if (set.size() == 3)
-                    {
-                        if (SetObject(id, ui->comboBoxFirstDartPoint, tr("Select the second dart point")))
-                        {
-                            number++;
-                            points->SetD1PointId(id);
-                            points->RefreshGeometry();
-                        }
-                    }
-                    break;
-                }
-                case 3:
+                if (set.size() == 3 && SetObject(id, ui->comboBoxFirstDartPoint, tr("Select the second dart point")))
                 {
-                    QSet<quint32> set;
-                    set.insert(getCurrentObjectId(ui->comboBoxFirstBasePoint));
-                    set.insert(getCurrentObjectId(ui->comboBoxSecondBasePoint));
-                    set.insert(getCurrentObjectId(ui->comboBoxFirstDartPoint));
-                    set.insert(id);
-
-                    if (set.size() == 4)
-                    {
-                        if (SetObject(id, ui->comboBoxSecondDartPoint, tr("Select the third dart point")))
-                        {
-                            number++;
-                            points->SetD2PointId(id);
-                            points->RefreshGeometry();
-                        }
-                    }
-                    break;
+                    number++;
+                    points->SetD1PointId(id);
+                    points->RefreshGeometry();
                 }
-                case 4:
-                {
-                    QSet<quint32> set;
-                    set.insert(getCurrentObjectId(ui->comboBoxFirstBasePoint));
-                    set.insert(getCurrentObjectId(ui->comboBoxSecondBasePoint));
-                    set.insert(getCurrentObjectId(ui->comboBoxFirstDartPoint));
-                    set.insert(getCurrentObjectId(ui->comboBoxSecondDartPoint));
-                    set.insert(id);
-
-                    if (set.size() == 5)
-                    {
-                        if (SetObject(id, ui->comboBoxThirdDartPoint, QString()))
-                        {
-                            points->SetD3PointId(id);
-                            points->RefreshGeometry();
-                            prepare = true;
-                            DialogAccepted();
-                        }
-                    }
-                    break;
-                }
-                default:
-                    break;
+                break;
             }
+            case 3:
+            {
+                QSet<quint32> set;
+                set.insert(getCurrentObjectId(ui->comboBoxFirstBasePoint));
+                set.insert(getCurrentObjectId(ui->comboBoxSecondBasePoint));
+                set.insert(getCurrentObjectId(ui->comboBoxFirstDartPoint));
+                set.insert(id);
+
+                if (set.size() == 4 && SetObject(id, ui->comboBoxSecondDartPoint, tr("Select the third dart point")))
+                {
+                    number++;
+                    points->SetD2PointId(id);
+                    points->RefreshGeometry();
+                }
+                break;
+            }
+            case 4:
+            {
+                QSet<quint32> set;
+                set.insert(getCurrentObjectId(ui->comboBoxFirstBasePoint));
+                set.insert(getCurrentObjectId(ui->comboBoxSecondBasePoint));
+                set.insert(getCurrentObjectId(ui->comboBoxFirstDartPoint));
+                set.insert(getCurrentObjectId(ui->comboBoxSecondDartPoint));
+                set.insert(id);
+
+                if (set.size() == 5 && SetObject(id, ui->comboBoxThirdDartPoint, QString()))
+                {
+                    points->SetD3PointId(id);
+                    points->RefreshGeometry();
+                    prepare = true;
+                    DialogAccepted();
+                }
+                break;
+            }
+            default:
+                break;
         }
     }
 }
@@ -368,7 +348,7 @@ void DialogTrueDarts::SaveData()
     d1PointName = ui->lineEditFirstNewDartPoint->text();
     d2PointName = ui->lineEditSecondNewDartPoint->text();
 
-    VisToolTrueDarts *points = qobject_cast<VisToolTrueDarts *>(vis);
+    auto *points = qobject_cast<VisToolTrueDarts *>(vis);
     SCASSERT(points != nullptr)
 
     points->SetBaseLineP1Id(GetFirstBasePointId());
@@ -381,11 +361,11 @@ void DialogTrueDarts::SaveData()
 
 //---------------------------------------------------------------------------------------------------------------------
 void DialogTrueDarts::NameChanged(QLabel *labelEditNamePoint, const QString &pointD1Name, const QString &pointD2Name,
-                                  QLineEdit* secondPointName, bool &flagName)
+                                  QLineEdit *secondPointName, bool &flagName)
 {
     SCASSERT(labelEditNamePoint != nullptr)
     SCASSERT(secondPointName != nullptr)
-    QLineEdit* edit = qobject_cast<QLineEdit*>(sender());
+    auto *edit = qobject_cast<QLineEdit *>(sender());
     if (edit)
     {
         CheckName(edit, labelEditNamePoint, pointD1Name, pointD2Name, secondPointName, flagName);
@@ -413,11 +393,10 @@ void DialogTrueDarts::CheckName(QLineEdit *edit, QLabel *labelEditNamePoint, con
 
     const QString name = edit->text();
     const QString secondName = secondPointName->text();
-    QRegularExpression rx(NameRegExp());
-    if (name.isEmpty()
-            || secondName == name
-            || (pointD1Name != name && pointD2Name != name && data->IsUnique(name) == false)
-            || rx.match(name).hasMatch() == false)
+    if (QRegularExpression const rx(NameRegExp());
+        name.isEmpty() || secondName == name ||
+        (pointD1Name != name && pointD2Name != name && data->IsUnique(name) == false) ||
+        rx.match(name).hasMatch() == false)
     {
         flagName = false;
         ChangeColor(labelEditNamePoint, errorColor);
@@ -436,7 +415,7 @@ void DialogTrueDarts::SetNotes(const QString &notes)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogTrueDarts::GetNotes() const
+auto DialogTrueDarts::GetNotes() const -> QString
 {
     return ui->plainTextEditToolNotes->toPlainText();
 }
