@@ -27,28 +27,23 @@
  *************************************************************************/
 
 #include "dialoginsertnode.h"
-#include "ui_dialoginsertnode.h"
+#include "../vmisc/theme/themeDef.h"
 #include "../vpatterndb/vcontainer.h"
-#if QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
-#include "../vmisc/backport/qoverload.h"
-#endif // QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
+#include "ui_dialoginsertnode.h"
 
 #include <QMenu>
 
 //---------------------------------------------------------------------------------------------------------------------
-DialogInsertNode::DialogInsertNode(const VContainer *data, quint32 toolId, QWidget *parent)
-    : DialogTool(data, toolId, parent),
-      ui(new Ui::DialogInsertNode)
+DialogInsertNode::DialogInsertNode(const VContainer *data, VAbstractPattern *doc, quint32 toolId, QWidget *parent)
+  : DialogTool(data, doc, toolId, parent),
+    ui(new Ui::DialogInsertNode)
 {
     ui->setupUi(this);
     InitOkCancel(ui);
 
     CheckPieces();
 
-    connect(ui->comboBoxPiece, QOverload<int>::of(&QComboBox::currentIndexChanged), this, [this]()
-    {
-        CheckPieces();
-    });
+    connect(ui->comboBoxPiece, QOverload<int>::of(&QComboBox::currentIndexChanged), this, [this]() { CheckPieces(); });
 
     connect(ui->listWidget, &QListWidget::customContextMenuRequested, this, &DialogInsertNode::ShowContextMenu);
     connect(ui->listWidget, &QListWidget::itemSelectionChanged, this, &DialogInsertNode::NodeSelected);
@@ -75,7 +70,7 @@ void DialogInsertNode::SetPiecesList(const QVector<quint32> &list)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-quint32 DialogInsertNode::GetPieceId() const
+auto DialogInsertNode::GetPieceId() const -> quint32
 {
     return getCurrentObjectId(ui->comboBoxPiece);
 }
@@ -102,13 +97,13 @@ void DialogInsertNode::SetPieceId(quint32 id)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QVector<VPieceNode> DialogInsertNode::GetNodes() const
+auto DialogInsertNode::GetNodes() const -> QVector<VPieceNode>
 {
     QVector<VPieceNode> nodes;
     for (qint32 i = 0; i < ui->listWidget->count(); ++i)
     {
-        VPieceNode node = qvariant_cast<VPieceNode>(ui->listWidget->item(i)->data(Qt::UserRole));
-        for(int n = 1; n <= nodeNumbers.value(node.GetId(), 1); ++n)
+        auto const node = qvariant_cast<VPieceNode>(ui->listWidget->item(i)->data(Qt::UserRole));
+        for (int n = 1; n <= nodeNumbers.value(node.GetId(), 1); ++n)
         {
             nodes.append(node);
         }
@@ -218,12 +213,12 @@ void DialogInsertNode::ShowContextMenu(const QPoint &pos)
         return;
     }
 
-    QScopedPointer<QMenu> menu(new QMenu());
+    QScopedPointer<QMenu> const menu(new QMenu());
 
     QListWidgetItem *rowItem = ui->listWidget->item(row);
     SCASSERT(rowItem != nullptr);
 
-    QAction *actionDelete = menu->addAction(QIcon::fromTheme(editDeleteIcon), tr("Delete"));
+    QAction *actionDelete = menu->addAction(FromTheme(VThemeIcon::EditDelete), tr("Delete"));
 
     QAction *selectedAction = menu->exec(ui->listWidget->viewport()->mapToGlobal(pos));
     if (selectedAction == actionDelete)
@@ -248,7 +243,7 @@ void DialogInsertNode::NodeSelected()
         return;
     }
 
-    VPieceNode node = qvariant_cast<VPieceNode>(item->data(Qt::UserRole));
+    auto const node = qvariant_cast<VPieceNode>(item->data(Qt::UserRole));
     ui->spinBoxNodeNumber->setEnabled(true);
     ui->spinBoxNodeNumber->blockSignals(true);
     ui->spinBoxNodeNumber->setValue(nodeNumbers.value(node.GetId(), 1));
@@ -265,7 +260,7 @@ void DialogInsertNode::NodeNumberChanged(int val)
         return;
     }
 
-    VPieceNode node = qvariant_cast<VPieceNode>(item->data(Qt::UserRole));
+    auto const node = qvariant_cast<VPieceNode>(item->data(Qt::UserRole));
     nodeNumbers[node.GetId()] = val;
 }
 
