@@ -28,47 +28,44 @@
 #include "dialogplacelabel.h"
 #include "ui_dialogplacelabel.h"
 
-#include "visualization/line/vistoolspecialpoint.h"
+#include "../../../visualization/line/vistoolspecialpoint.h"
 #include "../../support/dialogeditwrongformula.h"
-#if QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
-#include "../vmisc/backport/qoverload.h"
-#endif // QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
+#include "../vmisc/theme/vtheme.h"
 #include "../vpatterndb/vcontainer.h"
 
 #include <QTimer>
 
 //---------------------------------------------------------------------------------------------------------------------
-DialogPlaceLabel::DialogPlaceLabel(const VContainer *data, quint32 toolId, QWidget *parent)
-    : DialogTool(data, toolId, parent),
-      ui(new Ui::DialogPlaceLabel),
-      m_showMode(false),
-      m_formulaBaseHeightWidth(0),
-      m_formulaBaseHeightHeight(0),
-      m_formulaBaseHeightAngle(0),
-      m_formulaBaseVisible(0),
-      timerAngle(new QTimer(this)),
-      timerWidth(new QTimer(this)),
-      timerHeight(new QTimer(this)),
-      m_timerVisible(new QTimer(this)),
-      m_flagPoint(false),
-      m_flagWidth(false),
-      m_flagHeight(false),
-      m_flagAngle(false),
-      m_flagFormulaVisible(false),
-      m_flagError(false)
+DialogPlaceLabel::DialogPlaceLabel(const VContainer *data, VAbstractPattern *doc, quint32 toolId, QWidget *parent)
+  : DialogTool(data, doc, toolId, parent),
+    ui(new Ui::DialogPlaceLabel),
+    m_showMode(false),
+    m_formulaBaseHeightWidth(0),
+    m_formulaBaseHeightHeight(0),
+    m_formulaBaseHeightAngle(0),
+    m_formulaBaseVisible(0),
+    timerAngle(new QTimer(this)),
+    timerWidth(new QTimer(this)),
+    timerHeight(new QTimer(this)),
+    m_timerVisible(new QTimer(this)),
+    m_flagPoint(false),
+    m_flagWidth(false),
+    m_flagHeight(false),
+    m_flagAngle(false),
+    m_flagFormulaVisible(false),
+    m_flagError(false)
 {
     ui->setupUi(this);
     InitOkCancel(ui);
 
+    InitIcons();
+
     InitPlaceLabelTab();
     InitControlTab();
 
     EvalVisible();
 
-    connect(ui->comboBoxPiece, QOverload<int>::of(&QComboBox::currentIndexChanged), this, [this]()
-    {
-        CheckPieces();
-    });
+    connect(ui->comboBoxPiece, QOverload<int>::of(&QComboBox::currentIndexChanged), this, [this]() { CheckPieces(); });
 
     vis = new VisToolSpecialPoint(data);
 }
@@ -88,7 +85,7 @@ void DialogPlaceLabel::EnbleShowMode(bool disable)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-quint32 DialogPlaceLabel::GetCenterPoint() const
+auto DialogPlaceLabel::GetCenterPoint() const -> quint32
 {
     return getCurrentObjectId(ui->comboBoxPoint);
 }
@@ -100,7 +97,7 @@ void DialogPlaceLabel::SetCenterPoint(quint32 id)
 
     if (not m_showMode)
     {
-        VisToolSpecialPoint *point = qobject_cast<VisToolSpecialPoint *>(vis);
+        auto *point = qobject_cast<VisToolSpecialPoint *>(vis);
         SCASSERT(point != nullptr)
         point->SetPointId(id);
     }
@@ -109,7 +106,7 @@ void DialogPlaceLabel::SetCenterPoint(quint32 id)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-PlaceLabelType DialogPlaceLabel::GetLabelType() const
+auto DialogPlaceLabel::GetLabelType() const -> PlaceLabelType
 {
     return static_cast<PlaceLabelType>(ui->comboBoxLabelType->currentData().toInt());
 }
@@ -125,7 +122,7 @@ void DialogPlaceLabel::SetLabelType(PlaceLabelType type)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogPlaceLabel::GetWidth() const
+auto DialogPlaceLabel::GetWidth() const -> QString
 {
     return VTranslateVars::TryFormulaFromUser(ui->plainTextEditFormulaWidth->toPlainText(),
                                               VAbstractApplication::VApp()->Settings()->GetOsSeparator());
@@ -134,8 +131,8 @@ QString DialogPlaceLabel::GetWidth() const
 //---------------------------------------------------------------------------------------------------------------------
 void DialogPlaceLabel::SetWidth(const QString &value)
 {
-    const QString formula = VAbstractApplication::VApp()->TrVars()
-            ->FormulaToUser(value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    const QString formula = VAbstractApplication::VApp()->TrVars()->FormulaToUser(
+        value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
     // increase height if needed. TODO : see if I can get the max number of caracters in one line
     // of this PlainTextEdit to change 80 to this value
     if (formula.length() > 80)
@@ -144,15 +141,15 @@ void DialogPlaceLabel::SetWidth(const QString &value)
     }
     ui->plainTextEditFormulaWidth->setPlainText(formula);
 
-//    VisToolPlaceLabel *point = qobject_cast<VisToolPlaceLabel *>(vis);
-//    SCASSERT(point != nullptr)
-//    point->SetPointId(id);
+    //    VisToolPlaceLabel *point = qobject_cast<VisToolPlaceLabel *>(vis);
+    //    SCASSERT(point != nullptr)
+    //    point->SetPointId(id);
 
     MoveCursorToEnd(ui->plainTextEditFormulaWidth);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogPlaceLabel::GetHeight() const
+auto DialogPlaceLabel::GetHeight() const -> QString
 {
     return VTranslateVars::TryFormulaFromUser(ui->plainTextEditFormulaHeight->toPlainText(),
                                               VAbstractApplication::VApp()->Settings()->GetOsSeparator());
@@ -161,8 +158,8 @@ QString DialogPlaceLabel::GetHeight() const
 //---------------------------------------------------------------------------------------------------------------------
 void DialogPlaceLabel::SetHeight(const QString &value)
 {
-    const QString formula = VAbstractApplication::VApp()->TrVars()
-            ->FormulaToUser(value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    const QString formula = VAbstractApplication::VApp()->TrVars()->FormulaToUser(
+        value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
     // increase height if needed. TODO : see if I can get the max number of caracters in one line
     // of this PlainTextEdit to change 80 to this value
     if (formula.length() > 80)
@@ -171,15 +168,15 @@ void DialogPlaceLabel::SetHeight(const QString &value)
     }
     ui->plainTextEditFormulaHeight->setPlainText(formula);
 
-//    VisToolPlaceLabel *point = qobject_cast<VisToolPlaceLabel *>(vis);
-//    SCASSERT(point != nullptr)
-//    point->SetPointId(id);
+    //    VisToolPlaceLabel *point = qobject_cast<VisToolPlaceLabel *>(vis);
+    //    SCASSERT(point != nullptr)
+    //    point->SetPointId(id);
 
     MoveCursorToEnd(ui->plainTextEditFormulaHeight);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogPlaceLabel::GetAngle() const
+auto DialogPlaceLabel::GetAngle() const -> QString
 {
     return VTranslateVars::TryFormulaFromUser(ui->plainTextEditFormulaAngle->toPlainText(),
                                               VAbstractApplication::VApp()->Settings()->GetOsSeparator());
@@ -188,8 +185,8 @@ QString DialogPlaceLabel::GetAngle() const
 //---------------------------------------------------------------------------------------------------------------------
 void DialogPlaceLabel::SetAngle(const QString &value)
 {
-    const QString formula = VAbstractApplication::VApp()->TrVars()
-            ->FormulaToUser(value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    const QString formula = VAbstractApplication::VApp()->TrVars()->FormulaToUser(
+        value, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
     // increase height if needed. TODO : see if I can get the max number of caracters in one line
     // of this PlainTextEdit to change 80 to this value
     if (formula.length() > 80)
@@ -198,15 +195,15 @@ void DialogPlaceLabel::SetAngle(const QString &value)
     }
     ui->plainTextEditFormulaAngle->setPlainText(formula);
 
-//    VisToolPlaceLabel *point = qobject_cast<VisToolPlaceLabel *>(vis);
-//    SCASSERT(point != nullptr)
-//    point->SetPointId(id);
+    //    VisToolPlaceLabel *point = qobject_cast<VisToolPlaceLabel *>(vis);
+    //    SCASSERT(point != nullptr)
+    //    point->SetPointId(id);
 
     MoveCursorToEnd(ui->plainTextEditFormulaAngle);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-quint32 DialogPlaceLabel::GetPieceId() const
+auto DialogPlaceLabel::GetPieceId() const -> quint32
 {
     return getCurrentObjectId(ui->comboBoxPiece);
 }
@@ -247,27 +244,21 @@ void DialogPlaceLabel::SetPiecesList(const QVector<quint32> &list)
 //---------------------------------------------------------------------------------------------------------------------
 void DialogPlaceLabel::ChosenObject(quint32 id, const SceneObject &type)
 {
-    if (not prepare)
+    if (not prepare && type == SceneObject::Point && SetObject(id, ui->comboBoxPoint, QString()))
     {
-        if (type == SceneObject::Point)
+        if (vis != nullptr)
         {
-            if (SetObject(id, ui->comboBoxPoint, QString()))
-            {
-                if (vis != nullptr)
-                {
-                    vis->VisualMode(id);
-                }
-                CheckPoint();
-                prepare = true;
-
-                timerWidth->setSingleShot(formulaTimerTimeout);
-                timerHeight->setSingleShot(formulaTimerTimeout);
-                timerAngle->setSingleShot(formulaTimerTimeout);
-
-                this->setModal(true);
-                this->show();
-            }
+            vis->VisualMode(id);
         }
+        CheckPoint();
+        prepare = true;
+
+        timerWidth->setSingleShot(formulaTimerTimeout.count());
+        timerHeight->setSingleShot(formulaTimerTimeout.count());
+        timerAngle->setSingleShot(formulaTimerTimeout.count());
+
+        this->setModal(true);
+        this->show();
     }
 }
 
@@ -290,6 +281,24 @@ void DialogPlaceLabel::closeEvent(QCloseEvent *event)
     DialogTool::closeEvent(event);
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void DialogPlaceLabel::changeEvent(QEvent *event)
+{
+    if (event->type() == QEvent::LanguageChange)
+    {
+        ui->retranslateUi(this);
+    }
+
+    if (event->type() == QEvent::PaletteChange)
+    {
+        InitIcons();
+        InitDialogButtonBoxIcons(ui->buttonBox);
+    }
+
+    // remember to call base class implementation
+    DialogTool::changeEvent(event);
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void DialogPlaceLabel::DeployFormulaWidthEdit()
 {
@@ -351,7 +360,6 @@ void DialogPlaceLabel::EvalAngle()
     formulaData.labelEditFormula = ui->labelEditFormulaAngle;
     formulaData.labelResult = ui->labelResultCalculationAngle;
     formulaData.postfix = degreeSymbol;
-    formulaData.checkZero = false;
 
     Eval(formulaData, m_flagAngle);
 }
@@ -365,7 +373,6 @@ void DialogPlaceLabel::EvalVisible()
     formulaData.labelEditFormula = ui->labelEditVisible;
     formulaData.labelResult = ui->labelResultVisible;
     formulaData.postfix = QString();
-    formulaData.checkZero = false;
     formulaData.checkLessThanZero = true;
 
     Eval(formulaData, m_flagFormulaVisible);
@@ -374,9 +381,10 @@ void DialogPlaceLabel::EvalVisible()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogPlaceLabel::FXWidth()
 {
-    QScopedPointer<DialogEditWrongFormula> dialog(new DialogEditWrongFormula(data, toolId, this));
+    QScopedPointer<DialogEditWrongFormula> const dialog(new DialogEditWrongFormula(data, toolId, this));
     dialog->setWindowTitle(tr("Edit rectangle width"));
     dialog->SetFormula(GetWidth());
+    dialog->setCheckLessThanZero(true);
     dialog->setPostfix(UnitsToStr(VAbstractValApplication::VApp()->patternUnits(), true));
     if (dialog->exec() == QDialog::Accepted)
     {
@@ -387,9 +395,10 @@ void DialogPlaceLabel::FXWidth()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogPlaceLabel::FXHeight()
 {
-    QScopedPointer<DialogEditWrongFormula> dialog(new DialogEditWrongFormula(data, toolId, this));
+    QScopedPointer<DialogEditWrongFormula> const dialog(new DialogEditWrongFormula(data, toolId, this));
     dialog->setWindowTitle(tr("Edit rectangle width"));
     dialog->SetFormula(GetHeight());
+    dialog->setCheckLessThanZero(true);
     dialog->setPostfix(UnitsToStr(VAbstractValApplication::VApp()->patternUnits(), true));
     if (dialog->exec() == QDialog::Accepted)
     {
@@ -400,7 +409,7 @@ void DialogPlaceLabel::FXHeight()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogPlaceLabel::FXAngle()
 {
-    QScopedPointer<DialogEditWrongFormula> dialog(new DialogEditWrongFormula(data, toolId, this));
+    QScopedPointer<DialogEditWrongFormula> const dialog(new DialogEditWrongFormula(data, toolId, this));
     dialog->setWindowTitle(tr("Edit angle"));
     dialog->SetFormula(GetAngle());
     dialog->setPostfix(degreeSymbol);
@@ -413,7 +422,7 @@ void DialogPlaceLabel::FXAngle()
 //---------------------------------------------------------------------------------------------------------------------
 void DialogPlaceLabel::FXVisible()
 {
-    QScopedPointer<DialogEditWrongFormula> dialog(new DialogEditWrongFormula(data, toolId, this));
+    QScopedPointer<DialogEditWrongFormula> const dialog(new DialogEditWrongFormula(data, toolId, this));
     dialog->setWindowTitle(tr("Control visibility"));
     dialog->SetFormula(GetFormulaVisible());
     if (dialog->exec() == QDialog::Accepted)
@@ -437,28 +446,22 @@ void DialogPlaceLabel::InitPlaceLabelTab()
     ui->plainTextEditFormulaAngle->installEventFilter(this);
 
     ui->plainTextEditFormulaWidth->setPlainText(
-                QString::number(UnitConvertor(1, Unit::Cm, VAbstractValApplication::VApp()->patternUnits())));
+        QString::number(UnitConvertor(1, Unit::Cm, VAbstractValApplication::VApp()->patternUnits())));
     ui->plainTextEditFormulaHeight->setPlainText(
-                QString::number(UnitConvertor(1, Unit::Cm, VAbstractValApplication::VApp()->patternUnits())));
+        QString::number(UnitConvertor(1, Unit::Cm, VAbstractValApplication::VApp()->patternUnits())));
 
     connect(ui->toolButtonExprWidth, &QPushButton::clicked, this, &DialogPlaceLabel::FXWidth);
     connect(ui->toolButtonExprHeight, &QPushButton::clicked, this, &DialogPlaceLabel::FXHeight);
     connect(ui->toolButtonExprAngle, &QPushButton::clicked, this, &DialogPlaceLabel::FXAngle);
 
-    connect(ui->plainTextEditFormulaWidth, &QPlainTextEdit::textChanged, this, [this]()
-    {
-        timerWidth->start(formulaTimerTimeout);
-    });
+    connect(ui->plainTextEditFormulaWidth, &QPlainTextEdit::textChanged, this,
+            [this]() { timerWidth->start(formulaTimerTimeout); });
 
-    connect(ui->plainTextEditFormulaHeight, &QPlainTextEdit::textChanged, this, [this]()
-    {
-        timerHeight->start(formulaTimerTimeout);
-    });
+    connect(ui->plainTextEditFormulaHeight, &QPlainTextEdit::textChanged, this,
+            [this]() { timerHeight->start(formulaTimerTimeout); });
 
-    connect(ui->plainTextEditFormulaAngle, &QPlainTextEdit::textChanged, this, [this]()
-    {
-        timerAngle->start(formulaTimerTimeout);
-    });
+    connect(ui->plainTextEditFormulaAngle, &QPlainTextEdit::textChanged, this,
+            [this]() { timerAngle->start(formulaTimerTimeout); });
 
     connect(ui->pushButtonGrowWidth, &QPushButton::clicked, this, &DialogPlaceLabel::DeployFormulaWidthEdit);
     connect(ui->pushButtonGrowHeight, &QPushButton::clicked, this, &DialogPlaceLabel::DeployFormulaHeightEdit);
@@ -488,12 +491,9 @@ void DialogPlaceLabel::InitControlTab()
 
     connect(m_timerVisible, &QTimer::timeout, this, &DialogPlaceLabel::EvalVisible);
     connect(ui->toolButtonExprVisible, &QPushButton::clicked, this, &DialogPlaceLabel::FXVisible);
-    connect(ui->plainTextEditFormulaVisible, &QPlainTextEdit::textChanged, this, [this]()
-    {
-        m_timerVisible->start(formulaTimerTimeout);
-    });
-    connect(ui->pushButtonGrowVisible, &QPushButton::clicked, this,
-            &DialogPlaceLabel::DeployVisibleFormulaTextEdit);
+    connect(ui->plainTextEditFormulaVisible, &QPlainTextEdit::textChanged, this,
+            [this]() { m_timerVisible->start(formulaTimerTimeout); });
+    connect(ui->pushButtonGrowVisible, &QPushButton::clicked, this, &DialogPlaceLabel::DeployVisibleFormulaTextEdit);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -548,17 +548,35 @@ void DialogPlaceLabel::CheckPoint()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString DialogPlaceLabel::GetFormulaVisible() const
+void DialogPlaceLabel::InitIcons()
 {
-    QString formula = ui->plainTextEditFormulaVisible->toPlainText();
+    const auto resource = QStringLiteral("icon");
+
+    const auto fxIcon = QStringLiteral("24x24/fx.png");
+    ui->toolButtonExprWidth->setIcon(VTheme::GetIconResource(resource, fxIcon));
+    ui->toolButtonExprHeight->setIcon(VTheme::GetIconResource(resource, fxIcon));
+    ui->toolButtonExprAngle->setIcon(VTheme::GetIconResource(resource, fxIcon));
+    ui->toolButtonExprVisible->setIcon(VTheme::GetIconResource(resource, fxIcon));
+
+    const auto equalIcon = QStringLiteral("24x24/equal.png");
+    ui->label_4->setPixmap(VTheme::GetPixmapResource(resource, equalIcon));
+    ui->label_5->setPixmap(VTheme::GetPixmapResource(resource, equalIcon));
+    ui->label_6->setPixmap(VTheme::GetPixmapResource(resource, equalIcon));
+    ui->label_8->setPixmap(VTheme::GetPixmapResource(resource, equalIcon));
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+auto DialogPlaceLabel::GetFormulaVisible() const -> QString
+{
+    QString const formula = ui->plainTextEditFormulaVisible->toPlainText();
     return VTranslateVars::TryFormulaFromUser(formula, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void DialogPlaceLabel::SetFormulaVisible(const QString &formula)
 {
-    const QString f = VAbstractApplication::VApp()->TrVars()
-            ->FormulaToUser(formula, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
+    const QString f = VAbstractApplication::VApp()->TrVars()->FormulaToUser(
+        formula, VAbstractApplication::VApp()->Settings()->GetOsSeparator());
     // increase height if needed.
     if (f.length() > 80)
     {
@@ -567,3 +585,15 @@ void DialogPlaceLabel::SetFormulaVisible(const QString &formula)
     ui->plainTextEditFormulaVisible->setPlainText(f);
     MoveCursorToEnd(ui->plainTextEditFormulaVisible);
 }
+
+//---------------------------------------------------------------------------------------------------------------------
+auto DialogPlaceLabel::IsNotMirrored() const -> bool
+{
+    return ui->checkBoxNotMirrored->isChecked();
+}
+
+//---------------------------------------------------------------------------------------------------------------------
+void DialogPlaceLabel::SetNotMirrored(bool value)
+{
+    ui->checkBoxNotMirrored->setChecked(value);
+}
