@@ -27,34 +27,35 @@
  *************************************************************************/
 
 #include "vbackgroundimageitem.h"
-#include "../vwidgets/global.h"
-#include "../vmisc/vabstractvalapplication.h"
-#include "../vwidgets/vmaingraphicsview.h"
-#include "../ifc/xml/vabstractpattern.h"
-#include "../../undocommands/image/movebackgroundimage.h"
+#include "../../undocommands/image/hidebackgroundimage.h"
 #include "../../undocommands/image/holdbackgroundimage.h"
+#include "../../undocommands/image/movebackgroundimage.h"
+#include "../../undocommands/image/opaquebackgroundimage.h"
+#include "../../undocommands/image/renamebackgroundimage.h"
+#include "../../undocommands/image/resetbackgroundimage.h"
 #include "../../undocommands/image/rotatebackgroundimage.h"
 #include "../../undocommands/image/scalebackgroundimage.h"
-#include "../../undocommands/image/renamebackgroundimage.h"
-#include "../../undocommands/image/hidebackgroundimage.h"
-#include "../../undocommands/image/resetbackgroundimage.h"
-#include "../../undocommands/image/opaquebackgroundimage.h"
+#include "../../undocommands/image/zvaluemovebackgroundimage.h"
+#include "../ifc/xml/vabstractpattern.h"
 #include "../toolsdef.h"
+#include "../vmisc/theme/themeDef.h"
+#include "../vmisc/vabstractvalapplication.h"
+#include "../vwidgets/vmaingraphicsview.h"
 
-#include <QUndoStack>
-#include <QGraphicsView>
-#include <QGraphicsSceneMouseEvent>
-#include <QMenu>
 #include <QGraphicsDropShadowEffect>
-#include <QMessageBox>
+#include <QGraphicsSceneMouseEvent>
+#include <QGraphicsView>
 #include <QKeyEvent>
+#include <QMenu>
+#include <QMessageBox>
+#include <QUndoStack>
 
 //---------------------------------------------------------------------------------------------------------------------
 VBackgroundImageItem::VBackgroundImageItem(const VBackgroundPatternImage &image, VAbstractPattern *doc,
                                            QGraphicsItem *parent)
-    : QGraphicsObject{parent},
-      m_image(image),
-      m_doc(doc)
+  : QGraphicsObject{parent},
+    m_image(image),
+    m_doc(doc)
 {
     SCASSERT(doc != nullptr)
 
@@ -154,7 +155,7 @@ void VBackgroundImageItem::paint(QPainter *painter, const QStyleOptionGraphicsIt
     {
         painter->save();
 
-        QBrush brush(QColor(177, 216, 250, 25));
+        QBrush const brush(QColor(177, 216, 250, 25));
         painter->setBrush(brush);
 
         painter->drawRect(boundingRect());
@@ -171,12 +172,12 @@ void VBackgroundImageItem::PositionChanged(QUuid id)
         return;
     }
 
-    QTransform oldMatrix = m_image.Matrix();
+    QTransform const oldMatrix = m_image.Matrix();
     m_image = m_doc->GetBackgroundImage(id);
-    QTransform newMatrix = m_image.Matrix();
+    QTransform const newMatrix = m_image.Matrix();
 
     if (not VFuzzyComparePossibleNulls(oldMatrix.m31(), newMatrix.m31()) ||
-            not VFuzzyComparePossibleNulls(oldMatrix.m32(), newMatrix.m32()))
+        not VFuzzyComparePossibleNulls(oldMatrix.m32(), newMatrix.m32()))
     {
         prepareGeometryChange();
         update();
@@ -311,12 +312,10 @@ void VBackgroundImageItem::mousePressEvent(QGraphicsSceneMouseEvent *event)
 
     if (not Image().Hold())
     {
-        if (flags() & QGraphicsItem::ItemIsMovable)
+        if (flags() & QGraphicsItem::ItemIsMovable && event->button() == Qt::LeftButton &&
+            event->type() != QEvent::GraphicsSceneMouseDoubleClick)
         {
-            if (event->button() == Qt::LeftButton && event->type() != QEvent::GraphicsSceneMouseDoubleClick)
-            {
-                SetItemOverrideCursor(this, cursorArrowCloseHand, 1, 1);
-            }
+            SetItemOverrideCursor(this, cursorArrowCloseHand, 1, 1);
         }
 
         if (event->button() == Qt::LeftButton && event->type() != QEvent::GraphicsSceneMouseDoubleClick)
@@ -352,7 +351,7 @@ void VBackgroundImageItem::mouseMoveEvent(QGraphicsSceneMouseEvent *event)
 void VBackgroundImageItem::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
 {
     if (event->button() == Qt::LeftButton && event->type() != QEvent::GraphicsSceneMouseDoubleClick &&
-            (flags() & QGraphicsItem::ItemIsMovable))
+        (flags() & QGraphicsItem::ItemIsMovable))
     {
         m_lastMoveDistance = QPointF();
         SetItemOverrideCursor(this, cursorArrowOpenHand, 1, 1);
@@ -422,16 +421,16 @@ void VBackgroundImageItem::contextMenuEvent(QGraphicsSceneContextMenuEvent *even
     actionVisible->setCheckable(true);
     actionVisible->setChecked(m_image.Visible());
 
- #if defined(Q_OS_MAC)
+#if defined(Q_OS_MAC)
     const QString actionShowTitle = tr("Show in Finder");
 #else
     const QString actionShowTitle = tr("Show in Explorer");
 #endif
-    QAction *actionShow = menu.addAction(QIcon::fromTheme(QStringLiteral("system-search")), actionShowTitle);
+    QAction *actionShow = menu.addAction(FromTheme(VThemeIcon::SystemSearch), actionShowTitle);
     actionShow->setVisible(false);
     actionShow->setEnabled(QFileInfo::exists(m_image.FilePath()));
 
-    QAction *actionSaveAs = menu.addAction(QIcon::fromTheme(QStringLiteral("document-save-as")), tr("Save as …"));
+    QAction *actionSaveAs = menu.addAction(FromTheme(VThemeIcon::DocumentSaveAs), tr("Save as …"));
     actionSaveAs->setVisible(false);
 
     if (not m_image.FilePath().isEmpty())
@@ -446,7 +445,7 @@ void VBackgroundImageItem::contextMenuEvent(QGraphicsSceneContextMenuEvent *even
     QAction *actionReset = menu.addAction(tr("Reset transformation"));
     actionReset->setEnabled(not m_image.Hold());
 
-    QAction *actionRemove = menu.addAction(QIcon::fromTheme(QStringLiteral("edit-delete")), tr("Delete"));
+    QAction *actionRemove = menu.addAction(FromTheme(VThemeIcon::EditDelete), tr("Delete"));
 
     QAction *selectedAction = menu.exec(event->screenPos());
     if (selectedAction == holdOption)
@@ -479,80 +478,65 @@ void VBackgroundImageItem::contextMenuEvent(QGraphicsSceneContextMenuEvent *even
 void VBackgroundImageItem::keyPressEvent(QKeyEvent *event)
 {
     const int move = (event->modifiers() & Qt::ShiftModifier) ? 10 : 1;
-    if (event->key() == Qt::Key_Left)
-    {
-        TranslateImageOn(-move, 0);
-        event->accept();
-        return;
-    }
-
-    if (event->key() == Qt::Key_Right)
-    {
-        TranslateImageOn(move, 0);
-        event->accept();
-        return;
-    }
-
-    if (event->key() == Qt::Key_Up)
-    {
-        TranslateImageOn(0, -move);
-        event->accept();
-        return;
-    }
-
-    if (event->key() == Qt::Key_Down)
-    {
-        TranslateImageOn(0, move);
-        event->accept();
-        return;
-    }
 
     int angle = 15;
-    if(event->modifiers() & Qt::ControlModifier)
+    if (event->modifiers() & Qt::ControlModifier)
     {
         angle = 90;
     }
-    else if(event->modifiers() & Qt::AltModifier)
+    else if (event->modifiers() & Qt::AltModifier)
     {
         angle = 1;
     }
 
-    if (event->key() == Qt::Key_BracketLeft)
+    switch (event->key())
     {
-        RotateImageByAngle(angle);
-        event->accept();
-        return;
-    }
-
-    if (event->key() == Qt::Key_BracketRight)
-    {
-        RotateImageByAngle(-angle);
-        event->accept();
-        return;
-    }
-
-    if (event->key() == Qt::Key_Period || event->key() == Qt::Key_Greater)
-    {
-        if (event->modifiers() & Qt::ControlModifier)
-        {
-            ScaleImageByFactor(2);
-        }
-        else
-        {
-            ScaleImageByAdjustSize(2);
-        }
-    }
-
-    if (event->key() == Qt::Key_Comma || event->key() == Qt::Key_Less)
-    {
-        if (event->modifiers() & Qt::ControlModifier)
-        {
-            ScaleImageByFactor(0.5);
-        }
-        else
-        {
-            ScaleImageByAdjustSize(-2);
-        }
+        case Qt::Key_Left:
+            TranslateImageOn(-move, 0);
+            event->accept();
+            return;
+        case Qt::Key_Right:
+            TranslateImageOn(move, 0);
+            event->accept();
+            return;
+        case Qt::Key_Up:
+            TranslateImageOn(0, -move);
+            event->accept();
+            return;
+        case Qt::Key_Down:
+            TranslateImageOn(0, move);
+            event->accept();
+            return;
+        case Qt::Key_BracketLeft:
+            RotateImageByAngle(angle);
+            event->accept();
+            return;
+        case Qt::Key_BracketRight:
+            RotateImageByAngle(-angle);
+            event->accept();
+            return;
+        case Qt::Key_Period:
+        case Qt::Key_Greater:
+            (event->modifiers() & Qt::AltModifier) ? ScaleImageByFactor(2) : ScaleImageByAdjustSize(2);
+            return;
+        case Qt::Key_Comma:
+        case Qt::Key_Less:
+            (event->modifiers() & Qt::AltModifier) ? ScaleImageByFactor(0.5) : ScaleImageByAdjustSize(-2);
+            return;
+        case Qt::Key_Home:
+            MoveImageZValue(static_cast<int>(ZValueMoveType::Top));
+            return;
+        case Qt::Key_PageUp:
+            MoveImageZValue(static_cast<int>(ZValueMoveType::Up));
+            return;
+        case Qt::Key_PageDown:
+            MoveImageZValue(static_cast<int>(ZValueMoveType::Down));
+            return;
+        case Qt::Key_End:
+            MoveImageZValue(static_cast<int>(ZValueMoveType::Bottom));
+            return;
+        default:
+            break;
     }
 
     QGraphicsObject::keyPressEvent(event);
@@ -572,16 +556,10 @@ void VBackgroundImageItem::keyReleaseEvent(QKeyEvent *event)
                 return;
             }
         }
-        else if (event->key() == Qt::Key_Left ||
-                 event->key() == Qt::Key_Right ||
-                 event->key() == Qt::Key_Up ||
-                 event->key() == Qt::Key_Down ||
-                 event->key() == Qt::Key_BracketLeft ||
-                 event->key() == Qt::Key_BracketRight ||
-                 event->key() == Qt::Key_Period ||
-                 event->key() == Qt::Key_Greater ||
-                 event->key() == Qt::Key_Comma ||
-                 event->key() == Qt::Key_Less)
+        else if (event->key() == Qt::Key_Left || event->key() == Qt::Key_Right || event->key() == Qt::Key_Up ||
+                 event->key() == Qt::Key_Down || event->key() == Qt::Key_BracketLeft ||
+                 event->key() == Qt::Key_BracketRight || event->key() == Qt::Key_Period ||
+                 event->key() == Qt::Key_Greater || event->key() == Qt::Key_Comma || event->key() == Qt::Key_Less)
         {
             if (not event->isAutoRepeat())
             {
@@ -609,12 +587,9 @@ void VBackgroundImageItem::MakeFresh() const
 //---------------------------------------------------------------------------------------------------------------------
 void VBackgroundImageItem::DeleteToolWithConfirm(bool ask)
 {
-    if (ask)
+    if (ask && ConfirmDeletion() == QMessageBox::No)
     {
-        if (ConfirmDeletion() == QMessageBox::No)
-        {
-            return;
-        }
+        return;
     }
 
     emit ActivateControls(QUuid());
@@ -627,7 +602,7 @@ void VBackgroundImageItem::UpdateHoldState()
     m_image = m_doc->GetBackgroundImage(m_image.Id());
     setFlag(QGraphicsItem::ItemIsMovable, not m_image.Hold());
     setFlag(QGraphicsItem::ItemSendsGeometryChanges, not m_image.Hold());
-    setFlag(QGraphicsItem::ItemIsFocusable, not m_image.Hold());// For keyboard input focus
+    setFlag(QGraphicsItem::ItemIsFocusable, not m_image.Hold()); // For keyboard input focus
     emit UpdateControls();
 }
 
@@ -659,7 +634,7 @@ void VBackgroundImageItem::InitImage()
 
     setFlag(QGraphicsItem::ItemIsMovable, not m_image.Hold());
     setFlag(QGraphicsItem::ItemSendsGeometryChanges, not m_image.Hold());
-    setFlag(QGraphicsItem::ItemIsFocusable, not m_image.Hold());// For keyboard input focus
+    setFlag(QGraphicsItem::ItemIsFocusable, not m_image.Hold()); // For keyboard input focus
 
     setVisible(m_image.Visible());
 }
@@ -680,7 +655,7 @@ void VBackgroundImageItem::RotateImageByAngle(qreal angle)
 {
     QTransform imageMatrix = m_image.Matrix();
 
-    QPointF originPos = m_image.BoundingRect().center();
+    QPointF const originPos = m_image.BoundingRect().center();
 
     QTransform m;
     m.translate(originPos.x(), originPos.y());
@@ -699,11 +674,11 @@ void VBackgroundImageItem::RotateImageByAngle(qreal angle)
 //---------------------------------------------------------------------------------------------------------------------
 void VBackgroundImageItem::ScaleImageByAdjustSize(qreal value)
 {
-    QRectF rect = m_image.BoundingRect();
+    QRectF const rect = m_image.BoundingRect();
     QRectF adjusted = rect;
     adjusted.adjust(-value, -value, value, value);
 
-    qreal factor = adjusted.width() / rect.width();
+    qreal const factor = adjusted.width() / rect.width();
     ScaleImageByFactor(factor);
 }
 
@@ -711,7 +686,7 @@ void VBackgroundImageItem::ScaleImageByAdjustSize(qreal value)
 void VBackgroundImageItem::ScaleImageByFactor(qreal factor)
 {
     QTransform imageMatrix = m_image.Matrix();
-    QPointF originPos = m_image.BoundingRect().center();
+    QPointF const originPos = m_image.BoundingRect().center();
 
     QTransform m;
     m.translate(originPos.x(), originPos.y());
@@ -727,6 +702,13 @@ void VBackgroundImageItem::ScaleImageByFactor(qreal factor)
     m_allowChangeMerge = true;
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void VBackgroundImageItem::MoveImageZValue(int move)
+{
+    auto zMove = static_cast<ZValueMoveType>(move);
+    VAbstractApplication::VApp()->getUndoStack()->push(new ZValueMoveBackgroundImage(m_image.Id(), zMove, m_doc));
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 void VBackgroundImageItem::UpdateSceneRect()
 {
