@@ -28,47 +28,41 @@
 
 #include "vtoolflippingbyaxis.h"
 
-#include <climits>
-#include <qiterator.h>
 #include <QColor>
 #include <QDomNode>
 #include <QDomNodeList>
 #include <QMapIterator>
 #include <QPoint>
 #include <QSharedPointer>
-#include <QStaticStringData>
-#include <QStringData>
-#include <QStringDataPtr>
 #include <QUndoStack>
+#include <climits>
 #include <new>
+#include <qiterator.h>
 
-#include "../../../../dialogs/tools/dialogtool.h"
 #include "../../../../dialogs/tools/dialogflippingbyaxis.h"
+#include "../../../../dialogs/tools/dialogtool.h"
 #include "../../../../visualization/line/operation/vistoolflippingbyaxis.h"
 #include "../../../../visualization/visualization.h"
-#include "../vgeometry/vpointf.h"
-#include "../vpatterndb/vtranslatevars.h"
-#include "../vmisc/vabstractapplication.h"
-#include "../vmisc/vcommonsettings.h"
-#if QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
-#include "../vmisc/diagnostic.h"
-#endif // QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
-#include "../vpatterndb/vcontainer.h"
-#include "../vpatterndb/vformula.h"
-#include "../ifc/ifcdef.h"
-#include "../ifc/exception/vexception.h"
-#include "../vwidgets/vabstractsimple.h"
-#include "../vwidgets/vmaingraphicsscene.h"
 #include "../../../vabstracttool.h"
 #include "../../../vdatatool.h"
 #include "../../vdrawtool.h"
+#include "../ifc/exception/vexception.h"
+#include "../ifc/ifcdef.h"
+#include "../vgeometry/vpointf.h"
+#include "../vmisc/vabstractapplication.h"
+#include "../vmisc/vcommonsettings.h"
+#include "../vpatterndb/vcontainer.h"
+#include "../vpatterndb/vformula.h"
+#include "../vpatterndb/vtranslatevars.h"
+#include "../vwidgets/vabstractsimple.h"
+#include "../vwidgets/vmaingraphicsscene.h"
 
 template <class T> class QSharedPointer;
 
 const QString VToolFlippingByAxis::ToolType = QStringLiteral("flippingByAxis");
 
 //---------------------------------------------------------------------------------------------------------------------
-void VToolFlippingByAxis::setDialog()
+void VToolFlippingByAxis::SetDialog()
 {
     SCASSERT(not m_dialog.isNull())
     const QPointer<DialogFlippingByAxis> dialogTool = qobject_cast<DialogFlippingByAxis *>(m_dialog);
@@ -83,8 +77,8 @@ void VToolFlippingByAxis::setDialog()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VToolFlippingByAxis *VToolFlippingByAxis::Create(const QPointer<DialogTool> &dialog, VMainGraphicsScene *scene,
-                                                 VAbstractPattern *doc, VContainer *data)
+auto VToolFlippingByAxis::Create(const QPointer<DialogTool> &dialog, VMainGraphicsScene *scene, VAbstractPattern *doc,
+                                 VContainer *data) -> VToolFlippingByAxis *
 {
     SCASSERT(not dialog.isNull())
     const QPointer<DialogFlippingByAxis> dialogTool = qobject_cast<DialogFlippingByAxis *>(dialog);
@@ -105,7 +99,7 @@ VToolFlippingByAxis *VToolFlippingByAxis::Create(const QPointer<DialogTool> &dia
     initData.typeCreation = Source::FromGui;
     initData.notes = dialogTool->GetNotes();
 
-    VToolFlippingByAxis* operation = Create(initData);
+    VToolFlippingByAxis *operation = Create(initData);
     if (operation != nullptr)
     {
         operation->m_dialog = dialog;
@@ -114,10 +108,10 @@ VToolFlippingByAxis *VToolFlippingByAxis::Create(const QPointer<DialogTool> &dia
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VToolFlippingByAxis *VToolFlippingByAxis::Create(VToolFlippingByAxisInitData initData)
+auto VToolFlippingByAxis::Create(VToolFlippingByAxisInitData initData) -> VToolFlippingByAxis *
 {
     const auto originPoint = *initData.data->GeometricObject<VPointF>(initData.originPointId);
-    const QPointF fPoint = static_cast<QPointF>(originPoint);
+    const auto fPoint = static_cast<QPointF>(originPoint);
 
     QPointF sPoint;
     if (initData.axisType == AxisType::VerticalAxis)
@@ -139,7 +133,7 @@ VToolFlippingByAxis *VToolFlippingByAxis::Create(VToolFlippingByAxisInitData ini
         }
 
         VAbstractTool::AddRecord(initData.id, Tool::FlippingByAxis, initData.doc);
-        VToolFlippingByAxis *tool = new VToolFlippingByAxis(initData);
+        auto *tool = new VToolFlippingByAxis(initData);
         initData.scene->addItem(tool);
         InitOperationToolConnections(initData.scene, tool);
         VAbstractPattern::AddTool(initData.id, tool);
@@ -161,7 +155,7 @@ VToolFlippingByAxis *VToolFlippingByAxis::Create(VToolFlippingByAxisInitData ini
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-AxisType VToolFlippingByAxis::GetAxisType() const
+auto VToolFlippingByAxis::GetAxisType() const -> AxisType
 {
     return m_axisType;
 }
@@ -176,7 +170,7 @@ void VToolFlippingByAxis::SetAxisType(AxisType value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VToolFlippingByAxis::OriginPointName() const
+auto VToolFlippingByAxis::OriginPointName() const -> QString
 {
     return VAbstractTool::data.GetGObject(m_originPointId)->name();
 }
@@ -194,10 +188,10 @@ void VToolFlippingByAxis::ShowContextMenu(QGraphicsSceneContextMenuEvent *event,
     {
         ContextMenu<DialogFlippingByAxis>(event, id);
     }
-    catch(const VExceptionToolWasDeleted &e)
+    catch (const VExceptionToolWasDeleted &e)
     {
         Q_UNUSED(e)
-        return;//Leave this method immediately!!!
+        return; // Leave this method immediately!!!
     }
 }
 
@@ -232,7 +226,7 @@ void VToolFlippingByAxis::SaveDialog(QDomElement &domElement, QList<quint32> &ol
     doc->SetAttribute(domElement, AttrAxisType, QString().setNum(static_cast<int>(dialogTool->GetAxisType())));
     doc->SetAttribute(domElement, AttrSuffix, dialogTool->GetSuffix());
     doc->SetAttributeOrRemoveIf<QString>(domElement, AttrNotes, dialogTool->GetNotes(),
-                                         [](const QString &notes) noexcept {return notes.isEmpty();});
+                                         [](const QString &notes) noexcept { return notes.isEmpty(); });
 
     source = dialogTool->GetSourceObjects();
     SaveSourceDestination(domElement);
@@ -261,19 +255,19 @@ void VToolFlippingByAxis::SaveOptions(QDomElement &tag, QSharedPointer<VGObject>
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VToolFlippingByAxis::MakeToolTip() const
+auto VToolFlippingByAxis::MakeToolTip() const -> QString
 {
     return QStringLiteral("<tr> <td><b>%1:</b> %2</td> </tr>"
                           "%3")
-            .arg(tr("Origin point"), OriginPointName()) // 1, 2
-            .arg(VisibilityGroupToolTip());             // 3
+        .arg(tr("Origin point"), OriginPointName()) // 1, 2
+        .arg(VisibilityGroupToolTip());             // 3
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 VToolFlippingByAxis::VToolFlippingByAxis(const VToolFlippingByAxisInitData &initData, QGraphicsItem *parent)
-    : VAbstractFlipping(initData, parent),
-      m_originPointId(initData.originPointId),
-      m_axisType(initData.axisType)
+  : VAbstractFlipping(initData, parent),
+    m_originPointId(initData.originPointId),
+    m_axisType(initData.axisType)
 {
     InitOperatedObjects();
     ToolCreation(initData.typeCreation);
