@@ -28,47 +28,41 @@
 
 #include "vtoolflippingbyline.h"
 
-#include <climits>
-#include <qiterator.h>
 #include <QColor>
 #include <QDomNode>
 #include <QDomNodeList>
 #include <QMapIterator>
 #include <QPoint>
 #include <QSharedPointer>
-#include <QStaticStringData>
-#include <QStringData>
-#include <QStringDataPtr>
 #include <QUndoStack>
+#include <climits>
 #include <new>
+#include <qiterator.h>
 
-#include "../../../../dialogs/tools/dialogtool.h"
 #include "../../../../dialogs/tools/dialogflippingbyline.h"
+#include "../../../../dialogs/tools/dialogtool.h"
 #include "../../../../visualization/line/operation/vistoolflippingbyline.h"
 #include "../../../../visualization/visualization.h"
-#include "../vgeometry/vpointf.h"
-#include "../vpatterndb/vtranslatevars.h"
-#include "../vmisc/vabstractapplication.h"
-#include "../vmisc/vcommonsettings.h"
-#if QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
-#include "../vmisc/diagnostic.h"
-#endif // QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
-#include "../vpatterndb/vcontainer.h"
-#include "../vpatterndb/vformula.h"
-#include "../ifc/ifcdef.h"
-#include "../ifc/exception/vexception.h"
-#include "../vwidgets/vabstractsimple.h"
-#include "../vwidgets/vmaingraphicsscene.h"
 #include "../../../vabstracttool.h"
 #include "../../../vdatatool.h"
 #include "../../vdrawtool.h"
+#include "../ifc/exception/vexception.h"
+#include "../ifc/ifcdef.h"
+#include "../vgeometry/vpointf.h"
+#include "../vmisc/vabstractapplication.h"
+#include "../vmisc/vcommonsettings.h"
+#include "../vpatterndb/vcontainer.h"
+#include "../vpatterndb/vformula.h"
+#include "../vpatterndb/vtranslatevars.h"
+#include "../vwidgets/vabstractsimple.h"
+#include "../vwidgets/vmaingraphicsscene.h"
 
 template <class T> class QSharedPointer;
 
 const QString VToolFlippingByLine::ToolType = QStringLiteral("flippingByLine");
 
 //---------------------------------------------------------------------------------------------------------------------
-void VToolFlippingByLine::setDialog()
+void VToolFlippingByLine::SetDialog()
 {
     SCASSERT(not m_dialog.isNull())
     const QPointer<DialogFlippingByLine> dialogTool = qobject_cast<DialogFlippingByLine *>(m_dialog);
@@ -83,8 +77,8 @@ void VToolFlippingByLine::setDialog()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VToolFlippingByLine *VToolFlippingByLine::Create(const QPointer<DialogTool> &dialog, VMainGraphicsScene *scene,
-                                                 VAbstractPattern *doc, VContainer *data)
+auto VToolFlippingByLine::Create(const QPointer<DialogTool> &dialog, VMainGraphicsScene *scene, VAbstractPattern *doc,
+                                 VContainer *data) -> VToolFlippingByLine *
 {
     SCASSERT(not dialog.isNull())
     const QPointer<DialogFlippingByLine> dialogTool = qobject_cast<DialogFlippingByLine *>(dialog);
@@ -105,7 +99,7 @@ VToolFlippingByLine *VToolFlippingByLine::Create(const QPointer<DialogTool> &dia
     initData.typeCreation = Source::FromGui;
     initData.notes = dialogTool->GetNotes();
 
-    VToolFlippingByLine* operation = Create(initData);
+    VToolFlippingByLine *operation = Create(initData);
     if (operation != nullptr)
     {
         operation->m_dialog = dialog;
@@ -114,13 +108,13 @@ VToolFlippingByLine *VToolFlippingByLine::Create(const QPointer<DialogTool> &dia
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VToolFlippingByLine *VToolFlippingByLine::Create(VToolFlippingByLineInitData initData)
+auto VToolFlippingByLine::Create(VToolFlippingByLineInitData initData) -> VToolFlippingByLine *
 {
     const auto firstPoint = *initData.data->GeometricObject<VPointF>(initData.firstLinePointId);
-    const QPointF fPoint = static_cast<QPointF>(firstPoint);
+    const auto fPoint = static_cast<QPointF>(firstPoint);
 
     const auto secondPoint = *initData.data->GeometricObject<VPointF>(initData.secondLinePointId);
-    const QPointF sPoint = static_cast<QPointF>(secondPoint);
+    const auto sPoint = static_cast<QPointF>(secondPoint);
 
     CreateDestination(initData, fPoint, sPoint);
 
@@ -132,7 +126,7 @@ VToolFlippingByLine *VToolFlippingByLine::Create(VToolFlippingByLineInitData ini
         }
 
         VAbstractTool::AddRecord(initData.id, Tool::FlippingByLine, initData.doc);
-        VToolFlippingByLine *tool = new VToolFlippingByLine(initData);
+        auto *tool = new VToolFlippingByLine(initData);
         initData.scene->addItem(tool);
         InitOperationToolConnections(initData.scene, tool);
         VAbstractPattern::AddTool(initData.id, tool);
@@ -155,13 +149,13 @@ VToolFlippingByLine *VToolFlippingByLine::Create(VToolFlippingByLineInitData ini
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VToolFlippingByLine::FirstLinePointName() const
+auto VToolFlippingByLine::FirstLinePointName() const -> QString
 {
     return VAbstractTool::data.GetGObject(m_firstLinePointId)->name();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VToolFlippingByLine::SecondLinePointName() const
+auto VToolFlippingByLine::SecondLinePointName() const -> QString
 {
     return VAbstractTool::data.GetGObject(m_secondLinePointId)->name();
 }
@@ -179,10 +173,10 @@ void VToolFlippingByLine::ShowContextMenu(QGraphicsSceneContextMenuEvent *event,
     {
         ContextMenu<DialogFlippingByLine>(event, id);
     }
-    catch(const VExceptionToolWasDeleted &e)
+    catch (const VExceptionToolWasDeleted &e)
     {
         Q_UNUSED(e)
-        return;//Leave this method immediately!!!
+        return; // Leave this method immediately!!!
     }
 }
 
@@ -219,7 +213,7 @@ void VToolFlippingByLine::SaveDialog(QDomElement &domElement, QList<quint32> &ol
     doc->SetAttribute(domElement, AttrP2Line, QString().setNum(dialogTool->GetSecondLinePointId()));
     doc->SetAttribute(domElement, AttrSuffix, dialogTool->GetSuffix());
     doc->SetAttributeOrRemoveIf<QString>(domElement, AttrNotes, dialogTool->GetNotes(),
-                                         [](const QString &notes) noexcept {return notes.isEmpty();});
+                                         [](const QString &notes) noexcept { return notes.isEmpty(); });
 
     source = dialogTool->GetSourceObjects();
     SaveSourceDestination(domElement);
@@ -248,21 +242,20 @@ void VToolFlippingByLine::SaveOptions(QDomElement &tag, QSharedPointer<VGObject>
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VToolFlippingByLine::MakeToolTip() const
+auto VToolFlippingByLine::MakeToolTip() const -> QString
 {
     return QStringLiteral("<tr> <td><b>%1:</b> %2</td> </tr>"
                           "<tr> <td><b>%3:</b> %4</td> </tr>"
                           "%5")
-            .arg(tr("First line point"), FirstLinePointName(),
-             tr("Second line point"), SecondLinePointName()) // 1, 2, 3, 4
-            .arg(VisibilityGroupToolTip()); // 5
+        .arg(tr("First line point"), FirstLinePointName(), tr("Second line point"), SecondLinePointName()) // 1, 2, 3, 4
+        .arg(VisibilityGroupToolTip());                                                                    // 5
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 VToolFlippingByLine::VToolFlippingByLine(const VToolFlippingByLineInitData &initData, QGraphicsItem *parent)
-    : VAbstractFlipping(initData, parent),
-      m_firstLinePointId(initData.firstLinePointId),
-      m_secondLinePointId(initData.secondLinePointId)
+  : VAbstractFlipping(initData, parent),
+    m_firstLinePointId(initData.firstLinePointId),
+    m_secondLinePointId(initData.secondLinePointId)
 {
     InitOperatedObjects();
     ToolCreation(initData.typeCreation);
