@@ -29,19 +29,18 @@
 #ifndef VABSTRACTOPERATION_H
 #define VABSTRACTOPERATION_H
 
-#include <QtGlobal>
-#include <qcompilerdetection.h>
+#include <QGraphicsLineItem>
 #include <QMap>
 #include <QMetaObject>
 #include <QObject>
 #include <QString>
 #include <QVector>
-#include <QGraphicsLineItem>
+#include <QtGlobal>
 
+#include "../../toolsdef.h"
 #include "../vdrawtool.h"
 #include "../vwidgets/vsimplecurve.h"
 #include "../vwidgets/vsimplepoint.h"
-#include "../../toolsdef.h"
 
 struct DestinationItem
 {
@@ -53,9 +52,7 @@ struct DestinationItem
 
 struct VAbstractOperationInitData : VDrawToolInitData
 {
-    VAbstractOperationInitData()
-        : VDrawToolInitData()
-    {}
+    using VDrawToolInitData::VDrawToolInitData;
 
     QString suffix{};
     QVector<SourceItem> source{};
@@ -74,71 +71,74 @@ class VAbstractOperation : public VDrawTool, public QGraphicsLineItem
     // Fix warning "Class implements the interface QGraphicsItem but does not list it
     // in Q_INTERFACES. qobject_cast to QGraphicsItem will not work!"
     Q_INTERFACES(QGraphicsItem)
+
 public:
-    virtual ~VAbstractOperation() = default;
+    ~VAbstractOperation() override = default;
 
     static const QString TagItem;
     static const QString TagSource;
     static const QString TagDestination;
 
-    virtual QString getTagName() const override;
+    auto getTagName() const -> QString override;
 
-    QString Suffix() const;
-    void    SetSuffix(const QString &suffix);
+    auto Suffix() const -> QString;
+    void SetSuffix(const QString &suffix);
 
-    virtual void SetNotes(const QString &notes) override;
+    void SetNotes(const QString &notes) override;
 
-    QVector<SourceItem> SourceItems() const;
+    auto SourceItems() const -> QVector<SourceItem>;
 
-    virtual void GroupVisibility(quint32 object, bool visible) override;
-    virtual void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget) override;
-    virtual void ChangeLabelPosition(quint32 id, const QPointF &pos) override;
+    void GroupVisibility(quint32 object, bool visible) override;
+    void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget) override;
+    void ChangeLabelPosition(quint32 id, const QPointF &pos) override;
 
-    virtual bool IsLabelVisible(quint32 id) const override;
-    virtual void SetLabelVisible(quint32 id, bool visible) override;
+    auto IsLabelVisible(quint32 id) const -> bool override;
+    void SetLabelVisible(quint32 id, bool visible) override;
 
     static void ExtractData(const QDomElement &domElement, VAbstractOperationInitData &initData);
-    static QVector<SourceItem> ExtractSourceData(const QDomElement &domElement);
-    static QVector<DestinationItem> ExtractDestinationData(const QDomElement &domElement);
+    static auto ExtractSourceData(const QDomElement &domElement) -> QVector<SourceItem>;
+    static auto ExtractDestinationData(const QDomElement &domElement) -> QVector<DestinationItem>;
+
+    static auto OperationColorsList() -> QMap<QString, QString>;
 
-    static QMap<QString, QString> OperationColorsList();
 public slots:
-    virtual void FullUpdateFromFile() override;
+    void FullUpdateFromFile() override;
 
-    virtual void AllowHover(bool enabled) override;
-    virtual void AllowSelecting(bool enabled) override;
-    virtual void EnableToolMove(bool move) override;
+    void AllowHover(bool enabled) override;
+    void AllowSelecting(bool enabled) override;
+    void EnableToolMove(bool move) override;
 
-    void         AllowPointHover(bool enabled);
-    void         AllowPointSelecting(bool enabled);
+    void AllowPointHover(bool enabled);
+    void AllowPointSelecting(bool enabled);
 
-    void         AllowPointLabelHover(bool enabled);
-    void         AllowPointLabelSelecting(bool enabled);
+    void AllowPointLabelHover(bool enabled);
+    void AllowPointLabelSelecting(bool enabled);
 
-    void         AllowSplineHover(bool enabled);
-    void         AllowSplineSelecting(bool enabled);
+    void AllowSplineHover(bool enabled);
+    void AllowSplineSelecting(bool enabled);
 
-    void         AllowSplinePathHover(bool enabled);
-    void         AllowSplinePathSelecting(bool enabled);
+    void AllowSplinePathHover(bool enabled);
+    void AllowSplinePathSelecting(bool enabled);
 
-    void         AllowArcHover(bool enabled);
-    void         AllowArcSelecting(bool enabled);
+    void AllowArcHover(bool enabled);
+    void AllowArcSelecting(bool enabled);
 
-    void         AllowElArcHover(bool enabled);
-    void         AllowElArcSelecting(bool enabled);
+    void AllowElArcHover(bool enabled);
+    void AllowElArcSelecting(bool enabled);
+
+    void ToolSelectionType(const SelectionType &type) override;
+    void Disable(bool disable, const QString &namePP) override;
+    void ObjectSelected(bool selected, quint32 objId);
+    void DeleteFromLabel();
+    void LabelChangePosition(const QPointF &pos, quint32 labelId);
 
-    virtual void ToolSelectionType(const SelectionType &type) override;
-    virtual void Disable(bool disable, const QString &namePP) override;
-    void         ObjectSelected(bool selected, quint32 objId);
-    void         DeleteFromLabel();
-    void         LabelChangePosition(const QPointF &pos, quint32 labelId);
 protected:
     QString suffix;
 
     QVector<SourceItem> source;
     QVector<DestinationItem> destination;
 
-    QMap<quint32, VAbstractSimple *> operatedObjects;
+    QMap<quint32, VAbstractSimple *> operatedObjects{};
 
     bool hasLinkedGroup{false};
     QString groupName{};
@@ -146,54 +146,50 @@ protected:
 
     explicit VAbstractOperation(const VAbstractOperationInitData &initData, QGraphicsItem *parent = nullptr);
 
-    virtual void AddToFile() override;
-    virtual void ChangeLabelVisibility(quint32 id, bool visible) override;
-    virtual void ApplyToolOptions(const QList<quint32> &oldDependencies, const QList<quint32> &newDependencies,
-                                  const QDomElement &oldDomElement, const QDomElement &newDomElement) override;
-    virtual void PerformDelete() override;
-    virtual void ReadToolAttributes(const QDomElement &domElement) override;
-    virtual void SaveOptions(QDomElement &tag, QSharedPointer<VGObject> &obj) override;
+    void AddToFile() override;
+    void ChangeLabelVisibility(quint32 id, bool visible) override;
+    void ApplyToolOptions(const QList<quint32> &oldDependencies, const QList<quint32> &newDependencies,
+                          const QDomElement &oldDomElement, const QDomElement &newDomElement) override;
+    void PerformDelete() override;
+    void ReadToolAttributes(const QDomElement &domElement) override;
+    void SaveOptions(QDomElement &tag, QSharedPointer<VGObject> &obj) override;
 
-    virtual void UpdateNamePosition(quint32 id, const QPointF &pos) override;
+    void UpdateNamePosition(quint32 id, const QPointF &pos) override;
     void SaveSourceDestination(QDomElement &tag);
 
-    template <typename T>
-    void ShowToolVisualization(bool show);
+    template <typename T> void ShowToolVisualization(bool show);
 
-    template <typename T>
-    void SetDialogVisibilityGroupData(QPointer<T> dialogTool);
+    template <typename T> void SetDialogVisibilityGroupData(QPointer<T> dialogTool);
 
-    template <typename T>
-    void SaveVisibilityGroupData(QPointer<T> dialogTool);
+    template <typename T> void SaveVisibilityGroupData(QPointer<T> dialogTool);
 
     void InitCurve(quint32 id, VContainer *data, GOType curveType, SceneObject sceneType);
 
-    template <typename T>
-    static void InitOperationToolConnections(VMainGraphicsScene *scene, T *tool);
+    template <typename T> static void InitOperationToolConnections(VMainGraphicsScene *scene, T *tool);
 
     void InitOperatedObjects();
 
-    QString ComplexPointToolTip(quint32 itemId) const;
-    QString ComplexCurveToolTip(quint32 itemId) const;
-    QString VisibilityGroupToolTip() const;
+    auto ComplexPointToolTip(quint32 itemId) const -> QString;
+    auto ComplexCurveToolTip(quint32 itemId) const -> QString;
+    auto VisibilityGroupToolTip() const -> QString;
+
+    static void CreateVisibilityGroup(const VAbstractOperationInitData &initData);
 
-    static void CreateVisibilityGroup(const VAbstractOperationInitData & initData);
 private:
     Q_DISABLE_COPY_MOVE(VAbstractOperation) // NOLINT
 
     void AllowCurveHover(bool enabled, GOType type);
     void AllowCurveSelecting(bool enabled, GOType type);
 
-    bool NeedUpdateVisibilityGroup() const;
+    auto NeedUpdateVisibilityGroup() const -> bool;
 };
 
 //---------------------------------------------------------------------------------------------------------------------
-template<typename T>
-void VAbstractOperation::SetDialogVisibilityGroupData(QPointer<T> dialogTool)
+template <typename T> void VAbstractOperation::SetDialogVisibilityGroupData(QPointer<T> dialogTool)
 {
     SCASSERT(not dialogTool.isNull())
 
-    vidtype group = doc->GroupLinkedToTool(m_id);
+    vidtype const group = doc->GroupLinkedToTool(m_id);
     dialogTool->SetGroupCategories(doc->GetGroupCategories());
     if (group != null_id)
     {
@@ -208,8 +204,7 @@ void VAbstractOperation::SetDialogVisibilityGroupData(QPointer<T> dialogTool)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-template<typename T>
-void VAbstractOperation::SaveVisibilityGroupData(QPointer<T> dialogTool)
+template <typename T> void VAbstractOperation::SaveVisibilityGroupData(QPointer<T> dialogTool)
 {
     SCASSERT(not dialogTool.isNull())
 
@@ -220,8 +215,7 @@ void VAbstractOperation::SaveVisibilityGroupData(QPointer<T> dialogTool)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-template <typename T>
-void VAbstractOperation::ShowToolVisualization(bool show)
+template <typename T> void VAbstractOperation::ShowToolVisualization(bool show)
 {
     if (show)
     {
@@ -245,8 +239,7 @@ void VAbstractOperation::ShowToolVisualization(bool show)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-template <typename T>
-void VAbstractOperation::InitOperationToolConnections(VMainGraphicsScene *scene, T *tool)
+template <typename T> void VAbstractOperation::InitOperationToolConnections(VMainGraphicsScene *scene, T *tool)
 {
     SCASSERT(scene != nullptr)
     SCASSERT(tool != nullptr)
