@@ -28,49 +28,41 @@
 
 #include "vtoolmove.h"
 
-#include <climits>
-#include <qiterator.h>
 #include <QColor>
 #include <QDomNode>
 #include <QDomNodeList>
 #include <QMapIterator>
 #include <QPoint>
 #include <QSharedPointer>
-#include <QStaticStringData>
-#include <QStringData>
-#include <QStringDataPtr>
 #include <QUndoStack>
+#include <climits>
 #include <new>
+#include <qiterator.h>
 
-#include "../../../dialogs/tools/dialogtool.h"
 #include "../../../dialogs/tools/dialogmove.h"
+#include "../../../dialogs/tools/dialogtool.h"
 #include "../../../visualization/line/operation/vistoolmove.h"
 #include "../../../visualization/visualization.h"
+#include "../../vabstracttool.h"
+#include "../../vdatatool.h"
+#include "../ifc/exception/vexception.h"
+#include "../ifc/ifcdef.h"
+#include "../vdrawtool.h"
 #include "../vgeometry/vabstractcurve.h"
 #include "../vgeometry/varc.h"
-#include "../vgeometry/vellipticalarc.h"
 #include "../vgeometry/vcubicbezier.h"
 #include "../vgeometry/vcubicbezierpath.h"
+#include "../vgeometry/vellipticalarc.h"
 #include "../vgeometry/vgobject.h"
 #include "../vgeometry/vpointf.h"
 #include "../vgeometry/vspline.h"
 #include "../vgeometry/vsplinepath.h"
-#include "../vpatterndb/vtranslatevars.h"
 #include "../vmisc/vabstractapplication.h"
 #include "../vmisc/vcommonsettings.h"
-#if QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
-#include "../vmisc/diagnostic.h"
-#endif // QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
-#include "../vmisc/compatibility.h"
 #include "../vpatterndb/vcontainer.h"
 #include "../vpatterndb/vformula.h"
-#include "../ifc/ifcdef.h"
-#include "../ifc/exception/vexception.h"
-#include "../vwidgets/vabstractsimple.h"
+#include "../vpatterndb/vtranslatevars.h"
 #include "../vwidgets/vmaingraphicsscene.h"
-#include "../../vabstracttool.h"
-#include "../../vdatatool.h"
-#include "../vdrawtool.h"
 
 template <class T> class QSharedPointer;
 
@@ -78,20 +70,19 @@ const QString VToolMove::ToolType = QStringLiteral("moving");
 
 namespace
 {
-QT_WARNING_PUSH
-QT_WARNING_DISABLE_GCC("-Wswitch-default")
-QPointF GetOriginPoint(const QVector<SourceItem> &objects, const VContainer *data, qreal calcLength, qreal calcAngle)
+auto GetOriginPoint(const QVector<SourceItem> &objects, const VContainer *data, qreal calcLength, qreal calcAngle)
+    -> QPointF
 {
     QPolygonF originObjects;
 
-    for (auto object : objects)
+    for (const auto &object : objects)
     {
         const QSharedPointer<VGObject> obj = data->GetGObject(object.id);
 
         // This check helps to find missed objects in the switch
         Q_STATIC_ASSERT_X(static_cast<int>(GOType::Unknown) == 8, "Not all objects were handled.");
 
-        switch(static_cast<GOType>(obj->getType()))
+        switch (static_cast<GOType>(obj->getType()))
         {
             case GOType::Point:
                 originObjects.append(data->GeometricObject<VPointF>(object.id)->toQPointF());
@@ -102,25 +93,26 @@ QPointF GetOriginPoint(const QVector<SourceItem> &objects, const VContainer *dat
             case GOType::SplinePath:
             case GOType::CubicBezier:
             case GOType::CubicBezierPath:
-                AppendTo(originObjects, data->GeometricObject<VAbstractCurve>(object.id)->GetPoints());
+                originObjects.append(data->GeometricObject<VAbstractCurve>(object.id)->GetPoints());
                 break;
             case GOType::Unknown:
             case GOType::PlaceLabel:
                 Q_UNREACHABLE();
                 break;
+            default:
+                break;
         }
     }
 
-    QPointF rotationOrigin = originObjects.boundingRect().center();
-    QLineF move(rotationOrigin, QPointF(rotationOrigin.x()+calcLength, rotationOrigin.y()));
+    QPointF const rotationOrigin = originObjects.boundingRect().center();
+    QLineF move(rotationOrigin, QPointF(rotationOrigin.x() + calcLength, rotationOrigin.y()));
     move.setAngle(calcAngle);
     return move.p2();
 }
-QT_WARNING_POP
-}
+} // namespace
 
 //---------------------------------------------------------------------------------------------------------------------
-void VToolMove::setDialog()
+void VToolMove::SetDialog()
 {
     SCASSERT(not m_dialog.isNull())
     const QPointer<DialogMove> dialogTool = qobject_cast<DialogMove *>(m_dialog);
@@ -137,8 +129,8 @@ void VToolMove::setDialog()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VToolMove *VToolMove::Create(const QPointer<DialogTool> &dialog, VMainGraphicsScene *scene, VAbstractPattern *doc,
-                             VContainer *data)
+auto VToolMove::Create(const QPointer<DialogTool> &dialog, VMainGraphicsScene *scene, VAbstractPattern *doc,
+                       VContainer *data) -> VToolMove *
 {
     SCASSERT(not dialog.isNull())
     const QPointer<DialogMove> dialogTool = qobject_cast<DialogMove *>(dialog);
@@ -161,7 +153,7 @@ VToolMove *VToolMove::Create(const QPointer<DialogTool> &dialog, VMainGraphicsSc
     initData.typeCreation = Source::FromGui;
     initData.notes = dialogTool->GetNotes();
 
-    VToolMove* operation = Create(initData);
+    VToolMove *operation = Create(initData);
     if (operation != nullptr)
     {
         operation->m_dialog = dialog;
@@ -170,7 +162,7 @@ VToolMove *VToolMove::Create(const QPointer<DialogTool> &dialog, VMainGraphicsSc
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VToolMove *VToolMove::Create(VToolMoveInitData &initData)
+auto VToolMove::Create(VToolMoveInitData &initData) -> VToolMove *
 {
     qreal calcAngle = 0;
     qreal calcRotationAngle = 0;
@@ -178,8 +170,8 @@ VToolMove *VToolMove::Create(VToolMoveInitData &initData)
 
     calcAngle = CheckFormula(initData.id, initData.formulaAngle, initData.data);
     calcRotationAngle = CheckFormula(initData.id, initData.formulaRotationAngle, initData.data);
-    calcLength = VAbstractValApplication::VApp()->toPixel(CheckFormula(initData.id, initData.formulaLength,
-                                                                       initData.data));
+    calcLength =
+        VAbstractValApplication::VApp()->toPixel(CheckFormula(initData.id, initData.formulaLength, initData.data));
 
     QPointF rotationOrigin;
     QSharedPointer<VPointF> originPoint;
@@ -196,20 +188,22 @@ VToolMove *VToolMove::Create(VToolMoveInitData &initData)
 
     if (initData.typeCreation == Source::FromGui)
     {
-        initData.destination.clear();// Try to avoid mistake, value must be empty
+        initData.destination.clear(); // Try to avoid mistake, value must be empty
 
-        initData.id = initData.data->getNextId();//Just reserve id for tool
+        initData.id = initData.data->getNextId(); // Just reserve id for tool
 
-        for (auto object : qAsConst(initData.source))
+        for (const auto &object : qAsConst(initData.source))
         {
             const QSharedPointer<VGObject> obj = initData.data->GetGObject(object.id);
 
             // This check helps to find missed objects in the switch
             Q_STATIC_ASSERT_X(static_cast<int>(GOType::Unknown) == 8, "Not all objects were handled.");
 
-QT_WARNING_PUSH
-QT_WARNING_DISABLE_GCC("-Wswitch-default")
-            switch(static_cast<GOType>(obj->getType()))
+            QT_WARNING_PUSH
+            QT_WARNING_DISABLE_GCC("-Wswitch-default")
+            QT_WARNING_DISABLE_CLANG("-Wswitch-default")
+
+            switch (static_cast<GOType>(obj->getType()))
             {
                 case GOType::Point:
                     initData.destination.append(CreatePoint(initData.id, object, calcAngle, calcLength,
@@ -232,10 +226,9 @@ QT_WARNING_DISABLE_GCC("-Wswitch-default")
                                                                      initData.data));
                     break;
                 case GOType::SplinePath:
-                    initData.destination.append(CreateCurveWithSegments<VSplinePath>(initData.id, object, calcAngle,
-                                                                                     calcLength, calcRotationAngle,
-                                                                                     rotationOrigin, initData.suffix,
-                                                                                     initData.data));
+                    initData.destination.append(CreateCurveWithSegments<VSplinePath>(
+                        initData.id, object, calcAngle, calcLength, calcRotationAngle, rotationOrigin, initData.suffix,
+                        initData.data));
                     break;
                 case GOType::CubicBezier:
                     initData.destination.append(CreateCurve<VCubicBezier>(initData.id, object, calcAngle, calcLength,
@@ -243,19 +236,17 @@ QT_WARNING_DISABLE_GCC("-Wswitch-default")
                                                                           initData.suffix, initData.data));
                     break;
                 case GOType::CubicBezierPath:
-                    initData.destination.append(CreateCurveWithSegments<VCubicBezierPath>(initData.id, object,
-                                                                                          calcAngle, calcLength,
-                                                                                          calcRotationAngle,
-                                                                                          rotationOrigin,
-                                                                                          initData.suffix,
-                                                                                          initData.data));
+                    initData.destination.append(CreateCurveWithSegments<VCubicBezierPath>(
+                        initData.id, object, calcAngle, calcLength, calcRotationAngle, rotationOrigin, initData.suffix,
+                        initData.data));
                     break;
                 case GOType::Unknown:
                 case GOType::PlaceLabel:
                     Q_UNREACHABLE();
                     break;
             }
-QT_WARNING_POP
+
+            QT_WARNING_POP
         }
     }
     else
@@ -268,9 +259,11 @@ QT_WARNING_POP
             // This check helps to find missed objects in the switch
             Q_STATIC_ASSERT_X(static_cast<int>(GOType::Unknown) == 8, "Not all objects were handled.");
 
-QT_WARNING_PUSH
-QT_WARNING_DISABLE_GCC("-Wswitch-default")
-            switch(static_cast<GOType>(obj->getType()))
+            QT_WARNING_PUSH
+            QT_WARNING_DISABLE_GCC("-Wswitch-default")
+            QT_WARNING_DISABLE_CLANG("-Wswitch-default")
+
+            switch (static_cast<GOType>(obj->getType()))
             {
                 case GOType::Point:
                     UpdatePoint(initData.id, object, calcAngle, calcLength, calcRotationAngle, rotationOrigin,
@@ -286,31 +279,31 @@ QT_WARNING_DISABLE_GCC("-Wswitch-default")
                                               initData.destination.at(i).id);
                     break;
                 case GOType::Spline:
-                    UpdateCurve<VSpline>(initData.id, object, calcAngle, calcLength, calcRotationAngle,
-                                         rotationOrigin, initData.suffix, initData.data, initData.destination.at(i).id);
+                    UpdateCurve<VSpline>(initData.id, object, calcAngle, calcLength, calcRotationAngle, rotationOrigin,
+                                         initData.suffix, initData.data, initData.destination.at(i).id);
                     break;
                 case GOType::SplinePath:
-                    UpdateCurveWithSegments<VSplinePath>(initData.id, object, calcAngle, calcLength,
-                                                         calcRotationAngle, rotationOrigin,initData.suffix,
-                                                         initData.data, initData.destination.at(i).id);
+                    UpdateCurveWithSegments<VSplinePath>(initData.id, object, calcAngle, calcLength, calcRotationAngle,
+                                                         rotationOrigin, initData.suffix, initData.data,
+                                                         initData.destination.at(i).id);
                     break;
                 case GOType::CubicBezier:
                     UpdateCurve<VCubicBezier>(initData.id, object, calcAngle, calcLength, calcRotationAngle,
-                                              rotationOrigin,initData.suffix, initData.data,
+                                              rotationOrigin, initData.suffix, initData.data,
                                               initData.destination.at(i).id);
                     break;
                 case GOType::CubicBezierPath:
                     UpdateCurveWithSegments<VCubicBezierPath>(initData.id, object, calcAngle, calcLength,
-                                                              calcRotationAngle, rotationOrigin,
-                                                              initData.suffix, initData.data,
-                                                              initData.destination.at(i).id);
+                                                              calcRotationAngle, rotationOrigin, initData.suffix,
+                                                              initData.data, initData.destination.at(i).id);
                     break;
                 case GOType::Unknown:
                 case GOType::PlaceLabel:
                     Q_UNREACHABLE();
                     break;
             }
-QT_WARNING_POP
+
+            QT_WARNING_POP
         }
         if (initData.parse != Document::FullParse)
         {
@@ -326,7 +319,7 @@ QT_WARNING_POP
         }
 
         VAbstractTool::AddRecord(initData.id, Tool::Move, initData.doc);
-        VToolMove *tool = new VToolMove(initData);
+        auto *tool = new VToolMove(initData);
         initData.scene->addItem(tool);
         InitOperationToolConnections(initData.scene, tool);
         VAbstractPattern::AddTool(initData.id, tool);
@@ -336,7 +329,7 @@ QT_WARNING_POP
             initData.doc->IncrementReferens(originPoint->getIdTool());
         }
 
-        for (auto object : qAsConst(initData.source))
+        for (const auto &object : qAsConst(initData.source))
         {
             initData.doc->IncrementReferens(initData.data->GetGObject(object.id)->getIdTool());
         }
@@ -353,10 +346,9 @@ QT_WARNING_POP
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VFormula VToolMove::GetFormulaAngle() const
+auto VToolMove::GetFormulaAngle() const -> VFormula
 {
     VFormula fAngle(formulaAngle, getData());
-    fAngle.setCheckZero(false);
     fAngle.setToolId(m_id);
     fAngle.setPostfix(degreeSymbol);
     fAngle.Eval();
@@ -366,7 +358,7 @@ VFormula VToolMove::GetFormulaAngle() const
 //---------------------------------------------------------------------------------------------------------------------
 void VToolMove::SetFormulaAngle(const VFormula &value)
 {
-    if (value.error() == false)
+    if (!value.error())
     {
         formulaAngle = value.GetFormula(FormulaType::FromUser);
 
@@ -376,10 +368,9 @@ void VToolMove::SetFormulaAngle(const VFormula &value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VFormula VToolMove::GetFormulaRotationAngle() const
+auto VToolMove::GetFormulaRotationAngle() const -> VFormula
 {
     VFormula fAngle(formulaRotationAngle, getData());
-    fAngle.setCheckZero(false);
     fAngle.setToolId(m_id);
     fAngle.setPostfix(degreeSymbol);
     fAngle.Eval();
@@ -389,7 +380,7 @@ VFormula VToolMove::GetFormulaRotationAngle() const
 //---------------------------------------------------------------------------------------------------------------------
 void VToolMove::SetFormulaRotationAngle(const VFormula &value)
 {
-    if (value.error() == false)
+    if (!value.error())
     {
         formulaRotationAngle = value.GetFormula(FormulaType::FromUser);
 
@@ -399,10 +390,9 @@ void VToolMove::SetFormulaRotationAngle(const VFormula &value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VFormula VToolMove::GetFormulaLength() const
+auto VToolMove::GetFormulaLength() const -> VFormula
 {
     VFormula fLength(formulaLength, getData());
-    fLength.setCheckZero(true);
     fLength.setToolId(m_id);
     fLength.setPostfix(UnitsToStr(VAbstractValApplication::VApp()->patternUnits()));
     fLength.Eval();
@@ -422,7 +412,7 @@ void VToolMove::SetFormulaLength(const VFormula &value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VToolMove::OriginPointName() const
+auto VToolMove::OriginPointName() const -> QString
 {
     try
     {
@@ -447,10 +437,10 @@ void VToolMove::ShowContextMenu(QGraphicsSceneContextMenuEvent *event, quint32 i
     {
         ContextMenu<DialogMove>(event, id);
     }
-    catch(const VExceptionToolWasDeleted &e)
+    catch (const VExceptionToolWasDeleted &e)
     {
         Q_UNUSED(e)
-        return;//Leave this method immediately!!!
+        return; // Leave this method immediately!!!
     }
 }
 
@@ -491,7 +481,7 @@ void VToolMove::SaveDialog(QDomElement &domElement, QList<quint32> &oldDependenc
     doc->SetAttribute(domElement, AttrCenter, QString().setNum(dialogTool->GetRotationOrigPointId()));
     doc->SetAttribute(domElement, AttrRotationAngle, dialogTool->GetRotationAngle());
     doc->SetAttributeOrRemoveIf<QString>(domElement, AttrNotes, dialogTool->GetNotes(),
-                                         [](const QString &notes) noexcept {return notes.isEmpty();});
+                                         [](const QString &notes) noexcept { return notes.isEmpty(); });
 
     source = dialogTool->GetSourceObjects();
     SaveSourceDestination(domElement);
@@ -505,10 +495,10 @@ void VToolMove::ReadToolAttributes(const QDomElement &domElement)
 {
     VAbstractOperation::ReadToolAttributes(domElement);
 
-    origPointId = doc->GetParametrUInt(domElement, AttrCenter, NULL_ID_STR);
-    formulaAngle = doc->GetParametrString(domElement, AttrAngle, QChar('0'));
-    formulaRotationAngle = doc->GetParametrString(domElement, AttrRotationAngle, QChar('0'));
-    formulaLength = doc->GetParametrString(domElement, AttrLength, QChar('0'));
+    origPointId = VDomDocument::GetParametrUInt(domElement, AttrCenter, NULL_ID_STR);
+    formulaAngle = VDomDocument::GetParametrString(domElement, AttrAngle, QChar('0'));
+    formulaRotationAngle = VDomDocument::GetParametrString(domElement, AttrRotationAngle, QChar('0'));
+    formulaLength = VDomDocument::GetParametrString(domElement, AttrLength, QChar('0'));
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -524,41 +514,40 @@ void VToolMove::SaveOptions(QDomElement &tag, QSharedPointer<VGObject> &obj)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VToolMove::MakeToolTip() const
+auto VToolMove::MakeToolTip() const -> QString
 {
     return QStringLiteral("<tr> <td><b>%1:</b> %2°</td> </tr>"
                           "<tr> <td><b>%3:</b> %4 %5</td> </tr>"
                           "<tr> <td><b>%6:</b> %7°</td> </tr>"
                           "<tr> <td><b>%8:</b> %9</td> </tr>"
                           "%10")
-            .arg(tr("Angle"))                                // 1
-            .arg(GetFormulaAngle().getDoubleValue())         // 2
-            .arg(tr("Length"))                               // 3
-            .arg(GetFormulaLength().getDoubleValue())        // 4
-            .arg(UnitsToStr(VAbstractValApplication::VApp()->patternUnits(), true),     // 5
-                 tr("Rotation angle"))                       // 6
-            .arg(GetFormulaRotationAngle().getDoubleValue()) // 7
-            .arg(tr("Rotation origin point"),                // 8
-                 OriginPointName())                          // 9
-            .arg(VisibilityGroupToolTip());                  // 10
+        .arg(tr("Angle"))                                                       // 1
+        .arg(GetFormulaAngle().getDoubleValue())                                // 2
+        .arg(tr("Length"))                                                      // 3
+        .arg(GetFormulaLength().getDoubleValue())                               // 4
+        .arg(UnitsToStr(VAbstractValApplication::VApp()->patternUnits(), true), // 5
+             tr("Rotation angle"))                                              // 6
+        .arg(GetFormulaRotationAngle().getDoubleValue())                        // 7
+        .arg(tr("Rotation origin point"),                                       // 8
+             OriginPointName(),                                                 // 9
+             VisibilityGroupToolTip());                                         // 10
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 VToolMove::VToolMove(const VToolMoveInitData &initData, QGraphicsItem *parent)
-    : VAbstractOperation(initData, parent),
-      formulaAngle(initData.formulaAngle),
-      formulaRotationAngle(initData.formulaRotationAngle),
-      formulaLength(initData.formulaLength),
-      origPointId(initData.rotationOrigin)
+  : VAbstractOperation(initData, parent),
+    formulaAngle(initData.formulaAngle),
+    formulaRotationAngle(initData.formulaRotationAngle),
+    formulaLength(initData.formulaLength),
+    origPointId(initData.rotationOrigin)
 {
     InitOperatedObjects();
     ToolCreation(initData.typeCreation);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-DestinationItem VToolMove::CreatePoint(quint32 idTool, const SourceItem &sItem, qreal angle,
-                                       qreal length, qreal rotationAngle, const QPointF &rotationOrigin,
-                                       const QString &suffix, VContainer *data)
+auto VToolMove::CreatePoint(quint32 idTool, const SourceItem &sItem, qreal angle, qreal length, qreal rotationAngle,
+                            const QPointF &rotationOrigin, const QString &suffix, VContainer *data) -> DestinationItem
 {
     const QSharedPointer<VPointF> point = data->GeometricObject<VPointF>(sItem.id);
     VPointF moved = point->Move(length, angle, suffix).Rotate(rotationOrigin, rotationAngle);
@@ -579,12 +568,11 @@ DestinationItem VToolMove::CreatePoint(quint32 idTool, const SourceItem &sItem,
 
 //---------------------------------------------------------------------------------------------------------------------
 template <class Item>
-DestinationItem VToolMove::CreateArc(quint32 idTool, const SourceItem &sItem, qreal angle, qreal length,
-                                     qreal rotationAngle, const QPointF &rotationOrigin, const QString &suffix,
-                                     VContainer *data)
+auto VToolMove::CreateArc(quint32 idTool, const SourceItem &sItem, qreal angle, qreal length, qreal rotationAngle,
+                          const QPointF &rotationOrigin, const QString &suffix, VContainer *data) -> DestinationItem
 {
-    const DestinationItem item = CreateItem<Item>(idTool, sItem, angle, length, rotationAngle, rotationOrigin, suffix,
-                                                  data);
+    const DestinationItem item =
+        CreateItem<Item>(idTool, sItem, angle, length, rotationAngle, rotationOrigin, suffix, data);
     data->AddArc(data->GeometricObject<Item>(item.id), item.id);
     return item;
 }
@@ -620,9 +608,8 @@ void VToolMove::UpdateArc(quint32 idTool, const SourceItem &sItem, qreal angle,
 
 //---------------------------------------------------------------------------------------------------------------------
 template <class Item>
-DestinationItem VToolMove::CreateItem(quint32 idTool, const SourceItem &sItem, qreal angle, qreal length,
-                                      qreal rotationAngle, const QPointF &rotationOrigin, const QString &suffix,
-                                      VContainer *data)
+auto VToolMove::CreateItem(quint32 idTool, const SourceItem &sItem, qreal angle, qreal length, qreal rotationAngle,
+                           const QPointF &rotationOrigin, const QString &suffix, VContainer *data) -> DestinationItem
 {
     const QSharedPointer<Item> i = data->GeometricObject<Item>(sItem.id);
     Item moved = i->Move(length, angle, suffix).Rotate(rotationOrigin, rotationAngle);
@@ -650,25 +637,23 @@ DestinationItem VToolMove::CreateItem(quint32 idTool, const SourceItem &sItem, q
 
 //---------------------------------------------------------------------------------------------------------------------
 template <class Item>
-DestinationItem VToolMove::CreateCurve(quint32 idTool, const SourceItem &sItem, qreal angle, qreal length,
-                                       qreal rotationAngle, const QPointF &rotationOrigin, const QString &suffix,
-                                       VContainer *data)
+auto VToolMove::CreateCurve(quint32 idTool, const SourceItem &sItem, qreal angle, qreal length, qreal rotationAngle,
+                            const QPointF &rotationOrigin, const QString &suffix, VContainer *data) -> DestinationItem
 {
-    const DestinationItem item = CreateItem<Item>(idTool, sItem, angle, length, rotationAngle, rotationOrigin, suffix,
-                                                  data);
+    const DestinationItem item =
+        CreateItem<Item>(idTool, sItem, angle, length, rotationAngle, rotationOrigin, suffix, data);
     data->AddSpline(data->GeometricObject<Item>(item.id), item.id);
     return item;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 template <class Item>
-DestinationItem VToolMove::CreateCurveWithSegments(quint32 idTool, const SourceItem &sItem, qreal angle,
-                                                   qreal length, qreal rotationAngle,
-                                                   const QPointF &rotationOrigin, const QString &suffix,
-                                                   VContainer *data)
+auto VToolMove::CreateCurveWithSegments(quint32 idTool, const SourceItem &sItem, qreal angle, qreal length,
+                                        qreal rotationAngle, const QPointF &rotationOrigin, const QString &suffix,
+                                        VContainer *data) -> DestinationItem
 {
-    const DestinationItem item = CreateItem<Item>(idTool, sItem, angle, length, rotationAngle, rotationOrigin, suffix,
-                                                  data);
+    const DestinationItem item =
+        CreateItem<Item>(idTool, sItem, angle, length, rotationAngle, rotationOrigin, suffix, data);
     data->AddCurveWithSegments(data->GeometricObject<Item>(item.id), item.id);
     return item;
 }
