@@ -28,48 +28,39 @@
 
 #include "vtoolrotation.h"
 
-#include <climits>
-#include <qiterator.h>
 #include <QColor>
 #include <QDomNode>
 #include <QDomNodeList>
 #include <QMapIterator>
 #include <QPoint>
 #include <QSharedPointer>
-#include <QStaticStringData>
-#include <QStringData>
-#include <QStringDataPtr>
 #include <QUndoStack>
+#include <climits>
 #include <new>
 
-#include "../../../dialogs/tools/dialogtool.h"
 #include "../../../dialogs/tools/dialogrotation.h"
+#include "../../../dialogs/tools/dialogtool.h"
 #include "../../../visualization/line/operation/vistoolrotation.h"
 #include "../../../visualization/visualization.h"
-#include "../vgeometry/vabstractcurve.h"
+#include "../../vabstracttool.h"
+#include "../../vdatatool.h"
+#include "../ifc/exception/vexception.h"
+#include "../ifc/ifcdef.h"
+#include "../vdrawtool.h"
 #include "../vgeometry/varc.h"
-#include "../vgeometry/vellipticalarc.h"
 #include "../vgeometry/vcubicbezier.h"
 #include "../vgeometry/vcubicbezierpath.h"
+#include "../vgeometry/vellipticalarc.h"
 #include "../vgeometry/vgobject.h"
 #include "../vgeometry/vpointf.h"
 #include "../vgeometry/vspline.h"
 #include "../vgeometry/vsplinepath.h"
-#include "../vpatterndb/vtranslatevars.h"
 #include "../vmisc/vabstractapplication.h"
 #include "../vmisc/vcommonsettings.h"
-#if QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
-#include "../vmisc/diagnostic.h"
-#endif // QT_VERSION < QT_VERSION_CHECK(5, 5, 0)
 #include "../vpatterndb/vcontainer.h"
 #include "../vpatterndb/vformula.h"
-#include "../ifc/ifcdef.h"
-#include "../ifc/exception/vexception.h"
-#include "../vwidgets/vabstractsimple.h"
+#include "../vpatterndb/vtranslatevars.h"
 #include "../vwidgets/vmaingraphicsscene.h"
-#include "../../vabstracttool.h"
-#include "../../vdatatool.h"
-#include "../vdrawtool.h"
 
 class QDomElement;
 class QGraphicsSceneContextMenuEvent;
@@ -82,16 +73,16 @@ const QString VToolRotation::ToolType = QStringLiteral("rotation");
 
 //---------------------------------------------------------------------------------------------------------------------
 VToolRotation::VToolRotation(const VToolRotationInitData &initData, QGraphicsItem *parent)
-    : VAbstractOperation(initData, parent),
-      origPointId(initData.origin),
-      formulaAngle(initData.angle)
+  : VAbstractOperation(initData, parent),
+    origPointId(initData.origin),
+    formulaAngle(initData.angle)
 {
     InitOperatedObjects();
     ToolCreation(initData.typeCreation);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VToolRotation::setDialog()
+void VToolRotation::SetDialog()
 {
     SCASSERT(not m_dialog.isNull())
     const QPointer<DialogRotation> dialogTool = qobject_cast<DialogRotation *>(m_dialog);
@@ -106,8 +97,8 @@ void VToolRotation::setDialog()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VToolRotation *VToolRotation::Create(const QPointer<DialogTool> &dialog, VMainGraphicsScene *scene,
-                                     VAbstractPattern *doc, VContainer *data)
+auto VToolRotation::Create(const QPointer<DialogTool> &dialog, VMainGraphicsScene *scene, VAbstractPattern *doc,
+                           VContainer *data) -> VToolRotation *
 {
     SCASSERT(not dialog.isNull())
     const QPointer<DialogRotation> dialogTool = qobject_cast<DialogRotation *>(dialog);
@@ -128,7 +119,7 @@ VToolRotation *VToolRotation::Create(const QPointer<DialogTool> &dialog, VMainGr
     initData.typeCreation = Source::FromGui;
     initData.notes = dialogTool->GetNotes();
 
-    VToolRotation* operation = Create(initData);
+    VToolRotation *operation = Create(initData);
     if (operation != nullptr)
     {
         operation->m_dialog = dialog;
@@ -137,68 +128,69 @@ VToolRotation *VToolRotation::Create(const QPointer<DialogTool> &dialog, VMainGr
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VToolRotation *VToolRotation::Create(VToolRotationInitData &initData)
+auto VToolRotation::Create(VToolRotationInitData &initData) -> VToolRotation *
 {
     qreal calcAngle = 0;
 
     calcAngle = CheckFormula(initData.id, initData.angle, initData.data);
 
     const auto originPoint = *initData.data->GeometricObject<VPointF>(initData.origin);
-    const QPointF oPoint = static_cast<QPointF>(originPoint);
+    const auto oPoint = static_cast<QPointF>(originPoint);
 
     if (initData.typeCreation == Source::FromGui)
     {
-        initData.destination.clear();// Try to avoid mistake, value must be empty
+        initData.destination.clear(); // Try to avoid mistake, value must be empty
 
-        initData.id = initData.data->getNextId();//Just reserve id for tool
+        initData.id = initData.data->getNextId(); // Just reserve id for tool
 
-        for (auto object : qAsConst(initData.source))
+        for (const auto &object : qAsConst(initData.source))
         {
             const QSharedPointer<VGObject> obj = initData.data->GetGObject(object.id);
 
             // This check helps to find missed objects in the switch
             Q_STATIC_ASSERT_X(static_cast<int>(GOType::Unknown) == 8, "Not all objects were handled.");
 
-QT_WARNING_PUSH
-QT_WARNING_DISABLE_GCC("-Wswitch-default")
-            switch(static_cast<GOType>(obj->getType()))
+            QT_WARNING_PUSH
+            QT_WARNING_DISABLE_GCC("-Wswitch-default")
+            QT_WARNING_DISABLE_CLANG("-Wswitch-default")
+
+            switch (static_cast<GOType>(obj->getType()))
             {
                 case GOType::Point:
-                    initData.destination.append(CreatePoint(initData.id, object, oPoint, calcAngle, initData.suffix,
-                                                            initData.data));
+                    initData.destination.append(
+                        CreatePoint(initData.id, object, oPoint, calcAngle, initData.suffix, initData.data));
                     break;
                 case GOType::Arc:
-                    initData.destination.append(CreateArc<VArc>(initData.id, object, oPoint, calcAngle,
-                                                                initData.suffix, initData.data));
+                    initData.destination.append(
+                        CreateArc<VArc>(initData.id, object, oPoint, calcAngle, initData.suffix, initData.data));
                     break;
                 case GOType::EllipticalArc:
                     initData.destination.append(CreateArc<VEllipticalArc>(initData.id, object, oPoint, calcAngle,
                                                                           initData.suffix, initData.data));
                     break;
                 case GOType::Spline:
-                    initData.destination.append(CreateCurve<VSpline>(initData.id, object, oPoint, calcAngle,
-                                                                     initData.suffix, initData.data));
+                    initData.destination.append(
+                        CreateCurve<VSpline>(initData.id, object, oPoint, calcAngle, initData.suffix, initData.data));
                     break;
                 case GOType::SplinePath:
-                    initData.destination.append(CreateCurveWithSegments<VSplinePath>(initData.id, object, oPoint,
-                                                                                     calcAngle, initData.suffix,
-                                                                                     initData.data));
+                    initData.destination.append(CreateCurveWithSegments<VSplinePath>(
+                        initData.id, object, oPoint, calcAngle, initData.suffix, initData.data));
                     break;
                 case GOType::CubicBezier:
                     initData.destination.append(CreateCurve<VCubicBezier>(initData.id, object, oPoint, calcAngle,
                                                                           initData.suffix, initData.data));
                     break;
                 case GOType::CubicBezierPath:
-                    initData.destination.append(CreateCurveWithSegments<VCubicBezierPath>(initData.id, object, oPoint,
-                                                                                          calcAngle, initData.suffix,
-                                                                                          initData.data));
+                    initData.destination.append(CreateCurveWithSegments<VCubicBezierPath>(
+                        initData.id, object, oPoint, calcAngle, initData.suffix, initData.data));
                     break;
                 case GOType::Unknown:
                 case GOType::PlaceLabel:
                     Q_UNREACHABLE();
                     break;
             }
-QT_WARNING_POP
+
+            QT_WARNING_POP
         }
     }
     else
@@ -211,9 +203,11 @@ QT_WARNING_POP
             // This check helps to find missed objects in the switch
             Q_STATIC_ASSERT_X(static_cast<int>(GOType::Unknown) == 8, "Not all objects were handled.");
 
-QT_WARNING_PUSH
-QT_WARNING_DISABLE_GCC("-Wswitch-default")
-            switch(static_cast<GOType>(obj->getType()))
+            QT_WARNING_PUSH
+            QT_WARNING_DISABLE_GCC("-Wswitch-default")
+            QT_WARNING_DISABLE_CLANG("-Wswitch-default")
+
+            switch (static_cast<GOType>(obj->getType()))
             {
                 case GOType::Point:
                 {
@@ -250,7 +244,8 @@ QT_WARNING_DISABLE_GCC("-Wswitch-default")
                     Q_UNREACHABLE();
                     break;
             }
-QT_WARNING_POP
+
+            QT_WARNING_POP
         }
         if (initData.parse != Document::FullParse)
         {
@@ -266,12 +261,12 @@ QT_WARNING_POP
         }
 
         VAbstractTool::AddRecord(initData.id, Tool::Rotation, initData.doc);
-        VToolRotation *tool = new VToolRotation(initData);
+        auto *tool = new VToolRotation(initData);
         initData.scene->addItem(tool);
         InitOperationToolConnections(initData.scene, tool);
         VAbstractPattern::AddTool(initData.id, tool);
         initData.doc->IncrementReferens(originPoint.getIdTool());
-        for (auto object : qAsConst(initData.source))
+        for (const auto &object : qAsConst(initData.source))
         {
             initData.doc->IncrementReferens(initData.data->GetGObject(object.id)->getIdTool());
         }
@@ -288,16 +283,15 @@ QT_WARNING_POP
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VToolRotation::OriginPointName() const
+auto VToolRotation::OriginPointName() const -> QString
 {
     return VAbstractTool::data.GetGObject(origPointId)->name();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VFormula VToolRotation::GetFormulaAngle() const
+auto VToolRotation::GetFormulaAngle() const -> VFormula
 {
     VFormula fAngle(formulaAngle, getData());
-    fAngle.setCheckZero(false);
     fAngle.setToolId(m_id);
     fAngle.setPostfix(degreeSymbol);
     fAngle.Eval();
@@ -307,7 +301,7 @@ VFormula VToolRotation::GetFormulaAngle() const
 //---------------------------------------------------------------------------------------------------------------------
 void VToolRotation::SetFormulaAngle(const VFormula &value)
 {
-    if (value.error() == false)
+    if (!value.error())
     {
         formulaAngle = value.GetFormula(FormulaType::FromUser);
 
@@ -329,10 +323,10 @@ void VToolRotation::ShowContextMenu(QGraphicsSceneContextMenuEvent *event, quint
     {
         ContextMenu<DialogRotation>(event, id);
     }
-    catch(const VExceptionToolWasDeleted &e)
+    catch (const VExceptionToolWasDeleted &e)
     {
         Q_UNUSED(e)
-        return;//Leave this method immediately!!!
+        return; // Leave this method immediately!!!
     }
 }
 
@@ -346,8 +340,8 @@ void VToolRotation::SetVisualization()
 
         visual->SetObjects(SourceToObjects(source));
         visual->SetOriginPointId(origPointId);
-        visual->SetAngle(VAbstractApplication::VApp()->TrVars()
-                         ->FormulaToUser(formulaAngle, VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
+        visual->SetAngle(VAbstractApplication::VApp()->TrVars()->FormulaToUser(
+            formulaAngle, VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
         visual->SetMode(Mode::Show);
         visual->RefreshGeometry();
     }
@@ -368,7 +362,7 @@ void VToolRotation::SaveDialog(QDomElement &domElement, QList<quint32> &oldDepen
     doc->SetAttribute(domElement, AttrAngle, dialogTool->GetAngle());
     doc->SetAttribute(domElement, AttrSuffix, dialogTool->GetSuffix());
     doc->SetAttributeOrRemoveIf<QString>(domElement, AttrNotes, dialogTool->GetNotes(),
-                                         [](const QString &notes) noexcept {return notes.isEmpty();});
+                                         [](const QString &notes) noexcept { return notes.isEmpty(); });
 
     source = dialogTool->GetSourceObjects();
     SaveSourceDestination(domElement);
@@ -397,19 +391,19 @@ void VToolRotation::SaveOptions(QDomElement &tag, QSharedPointer<VGObject> &obj)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VToolRotation::MakeToolTip() const
+auto VToolRotation::MakeToolTip() const -> QString
 {
     return QStringLiteral("<tr> <td><b>%1:</b> %2</td> </tr>"
                           "<tr> <td><b>%3:</b> %4°</td> </tr>"
                           "%5")
-            .arg(tr("Origin point"), OriginPointName(), tr("Rotation angle")) // 1, 2, 3
-            .arg(GetFormulaAngle().getDoubleValue())                          // 4
-            .arg(VisibilityGroupToolTip());                                   // 5
+        .arg(tr("Origin point"), OriginPointName(), tr("Rotation angle")) // 1, 2, 3
+        .arg(GetFormulaAngle().getDoubleValue())                          // 4
+        .arg(VisibilityGroupToolTip());                                   // 5
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-DestinationItem VToolRotation::CreatePoint(quint32 idTool, const SourceItem &sItem, const QPointF &origin, qreal angle,
-                                          const QString &suffix, VContainer *data)
+auto VToolRotation::CreatePoint(quint32 idTool, const SourceItem &sItem, const QPointF &origin, qreal angle,
+                                const QString &suffix, VContainer *data) -> DestinationItem
 {
     const QSharedPointer<VPointF> point = data->GeometricObject<VPointF>(sItem.id);
     VPointF rotated = point->Rotate(origin, angle, suffix);
@@ -430,8 +424,8 @@ DestinationItem VToolRotation::CreatePoint(quint32 idTool, const SourceItem &sIt
 
 //---------------------------------------------------------------------------------------------------------------------
 template <class Item>
-DestinationItem VToolRotation::CreateItem(quint32 idTool, const SourceItem &sItem, const QPointF &origin, qreal angle,
-                                           const QString &suffix, VContainer *data)
+auto VToolRotation::CreateItem(quint32 idTool, const SourceItem &sItem, const QPointF &origin, qreal angle,
+                               const QString &suffix, VContainer *data) -> DestinationItem
 {
     const QSharedPointer<Item> i = data->GeometricObject<Item>(sItem.id);
     Item rotated = i->Rotate(origin, angle, suffix);
@@ -459,8 +453,8 @@ DestinationItem VToolRotation::CreateItem(quint32 idTool, const SourceItem &sIte
 
 //---------------------------------------------------------------------------------------------------------------------
 template <class Item>
-DestinationItem VToolRotation::CreateArc(quint32 idTool, const SourceItem &sItem, const QPointF &origin, qreal angle,
-                                          const QString &suffix, VContainer *data)
+auto VToolRotation::CreateArc(quint32 idTool, const SourceItem &sItem, const QPointF &origin, qreal angle,
+                              const QString &suffix, VContainer *data) -> DestinationItem
 {
     const DestinationItem item = CreateItem<Item>(idTool, sItem, origin, angle, suffix, data);
     data->AddArc(data->GeometricObject<Item>(item.id), item.id);
@@ -469,8 +463,8 @@ DestinationItem VToolRotation::CreateArc(quint32 idTool, const SourceItem &sItem
 
 //---------------------------------------------------------------------------------------------------------------------
 template <class Item>
-DestinationItem VToolRotation::CreateCurve(quint32 idTool, const SourceItem &sItem, const QPointF &origin, qreal angle,
-                                           const QString &suffix, VContainer *data)
+auto VToolRotation::CreateCurve(quint32 idTool, const SourceItem &sItem, const QPointF &origin, qreal angle,
+                                const QString &suffix, VContainer *data) -> DestinationItem
 {
     const DestinationItem item = CreateItem<Item>(idTool, sItem, origin, angle, suffix, data);
     data->AddSpline(data->GeometricObject<Item>(item.id), item.id);
@@ -479,8 +473,8 @@ DestinationItem VToolRotation::CreateCurve(quint32 idTool, const SourceItem &sIt
 
 //---------------------------------------------------------------------------------------------------------------------
 template <class Item>
-DestinationItem VToolRotation::CreateCurveWithSegments(quint32 idTool, const SourceItem &sItem, const QPointF &origin,
-                                                       qreal angle, const QString &suffix, VContainer *data)
+auto VToolRotation::CreateCurveWithSegments(quint32 idTool, const SourceItem &sItem, const QPointF &origin, qreal angle,
+                                            const QString &suffix, VContainer *data) -> DestinationItem
 {
     const DestinationItem item = CreateItem<Item>(idTool, sItem, origin, angle, suffix, data);
     data->AddCurveWithSegments(data->GeometricObject<Item>(item.id), item.id);
