@@ -37,57 +37,56 @@
 #include <QLineF>
 #include <QPen>
 #include <QSharedPointer>
-#include <Qt>
-#include <new>
 
+#include "../../../visualization/line/visline.h"
+#include "../../vabstracttool.h"
 #include "../ifc/exception/vexception.h"
 #include "../ifc/xml/vabstractpattern.h"
-#include "../qmuparser/qmutokenparser.h"
 #include "../qmuparser/qmudef.h"
+#include "../qmuparser/qmutokenparser.h"
+#include "../vdrawtool.h"
+#include "../vgeometry/vabstractarc.h"
 #include "../vgeometry/vgobject.h"
 #include "../vgeometry/vpointf.h"
 #include "../vgeometry/vspline.h"
-#include "../vgeometry/vabstractarc.h"
+#include "../vmisc/theme/vscenestylesheet.h"
 #include "../vpatterndb/vcontainer.h"
-#include "../vwidgets/vcontrolpointspline.h"
 #include "../vwidgets/global.h"
-#include "../../../visualization/line/visline.h"
-#include "../../vabstracttool.h"
-#include "../vdrawtool.h"
+
+#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
+#include "../vmisc/compatibility.h"
+#endif
+
+using namespace Qt::Literals::StringLiterals;
 
 //---------------------------------------------------------------------------------------------------------------------
 VAbstractSpline::VAbstractSpline(VAbstractPattern *doc, VContainer *data, quint32 id, const QString &notes,
                                  QGraphicsItem *parent)
-    :VDrawTool(doc, data, id, notes),
-      QGraphicsPathItem(parent),
-      controlPoints(),
-      sceneType(SceneObject::Unknown),
-      m_isHovered(false),
-      detailsMode(VAbstractApplication::VApp()->Settings()->IsShowCurveDetails()),
-      m_acceptHoverEvents(true)
+  : VDrawTool(doc, data, id, notes),
+    QGraphicsPathItem(parent),
+    m_detailsMode(VAbstractApplication::VApp()->Settings()->IsShowCurveDetails())
 {
     InitDefShape();
     setAcceptHoverEvents(m_acceptHoverEvents);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QPainterPath VAbstractSpline::shape() const
+auto VAbstractSpline::shape() const -> QPainterPath
 {
     const QSharedPointer<VAbstractCurve> curve = VAbstractTool::data.GeometricObject<VAbstractCurve>(m_id);
     const QVector<QPointF> points = curve->GetPoints();
 
     QPainterPath path;
-    for (qint32 i = 0; i < points.count()-1; ++i)
+    for (qint32 i = 0; i < points.count() - 1; ++i)
     {
         path.moveTo(points.at(i));
-        path.lineTo(points.at(i+1));
+        path.lineTo(points.at(i + 1));
     }
 
-    if (m_isHovered || detailsMode)
+    if (m_isHovered || m_detailsMode)
     {
-        path.addPath(VAbstractCurve::ShowDirection(curve->DirectionArrows(),
-                                                   ScaleWidth(VAbstractCurve::LengthCurveDirectionArrow(),
-                                                              SceneScale(scene()))));
+        path.addPath(VAbstractCurve::ShowDirection(
+            curve->DirectionArrows(), ScaleWidth(VAbstractCurve::LengthCurveDirectionArrow(), SceneScale(scene()))));
     }
     path.setFillRule(Qt::WindingFill);
     return ItemShapeFromPath(path, pen());
@@ -101,11 +100,13 @@ void VAbstractSpline::paint(QPainter *painter, const QStyleOptionGraphicsItem *o
                                    SceneScale(scene()));
 
     const QSharedPointer<VAbstractCurve> curve = VAbstractTool::data.GeometricObject<VAbstractCurve>(m_id);
-    setPen(QPen(CorrectColor(this, curve->GetColor()), width, LineStyleToPenStyle(curve->GetPenStyle()), Qt::RoundCap));
+    QColor const penColor =
+        VSceneStylesheet::CorrectToolColor(this, VSceneStylesheet::CorrectToolColorForDarkTheme(curve->GetColor()));
+    setPen(QPen(penColor, width, LineStyleToPenStyle(curve->GetPenStyle()), Qt::RoundCap));
 
     auto PaintSpline = [this, curve](QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget)
     {
-        if (m_isHovered || detailsMode)
+        if (m_isHovered || m_detailsMode)
         {
             painter->save();
 
@@ -115,9 +116,9 @@ void VAbstractSpline::paint(QPainter *painter, const QStyleOptionGraphicsItem *o
             painter->setPen(arrowPen);
             painter->setBrush(brush());
 
-            painter->drawPath(VAbstractCurve::ShowDirection(curve->DirectionArrows(),
-                                                            ScaleWidth(VAbstractCurve::LengthCurveDirectionArrow(),
-                                                                       SceneScale(scene()))));
+            painter->drawPath(VAbstractCurve::ShowDirection(
+                curve->DirectionArrows(),
+                ScaleWidth(VAbstractCurve::LengthCurveDirectionArrow(), SceneScale(scene()))));
 
             painter->restore();
         }
@@ -129,11 +130,18 @@ void VAbstractSpline::paint(QPainter *painter, const QStyleOptionGraphicsItem *o
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VAbstractSpline::getTagName() const
+auto VAbstractSpline::getTagName() const -> QString
 {
     return VAbstractPattern::TagSpline;
 }
 
+//---------------------------------------------------------------------------------------------------------------------
+void VAbstractSpline::ShowHandles(bool show)
+{
+    Q_UNUSED(show);
+    update(); // Show direction
+}
+
 //---------------------------------------------------------------------------------------------------------------------
 /**
  * @brief FullUpdateFromFile update tool data form file.
@@ -153,46 +161,36 @@ void VAbstractSpline::Disable(bool disable, const QString &namePP)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VAbstractSpline::DetailsMode(bool mode)
+void VAbstractSpline::SetDetailsMode(bool mode)
 {
-    detailsMode = mode;
+    m_detailsMode = mode;
     RefreshGeometry();
-    ShowHandles(detailsMode);
+    ShowHandles(m_detailsMode);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void VAbstractSpline::AllowHover(bool enabled)
 {
     // Manually handle hover events. Need for setting cursor for not selectable paths.
-    m_acceptHoverEvents = enabled;
-
-    for (auto point : qAsConst(controlPoints))
-    {
-        point->setAcceptHoverEvents(enabled);
-    }
+    SetAcceptHoverEvents(enabled);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 void VAbstractSpline::AllowSelecting(bool enabled)
 {
     setFlag(QGraphicsItem::ItemIsSelectable, enabled);
-
-    for (auto point : qAsConst(controlPoints))
-    {
-        point->setFlag(QGraphicsItem::ItemIsSelectable, enabled);
-    }
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VAbstractSpline::MakeToolTip() const
+auto VAbstractSpline::MakeToolTip() const -> QString
 {
     const QSharedPointer<VAbstractCurve> curve = VAbstractTool::data.GeometricObject<VAbstractCurve>(m_id);
 
-    const QString toolTip = QString("<table>"
-                                    "<tr> <td><b>%4:</b> %5</td> </tr>"
-                                    "<tr> <td><b>%1:</b> %2 %3</td> </tr>"
-                                    "</table>")
-            .arg(tr("Length"))
+    const QString toolTip =
+        u"<table>"
+        u"<tr> <td><b>%4:</b> %5</td> </tr>"
+        u"<tr> <td><b>%1:</b> %2 %3</td> </tr>"
+        u"</table>"_s.arg(tr("Length"))
             .arg(VAbstractValApplication::VApp()->fromPixel(curve->GetLength()))
             .arg(UnitsToStr(VAbstractValApplication::VApp()->patternUnits(), true), tr("Label"), curve->ObjectName());
     return toolTip;
@@ -249,7 +247,7 @@ void VAbstractSpline::hoverLeaveEvent(QGraphicsSceneHoverEvent *event)
  * @param value value.
  * @return value.
  */
-QVariant VAbstractSpline::itemChange(QGraphicsItem::GraphicsItemChange change, const QVariant &value)
+auto VAbstractSpline::itemChange(QGraphicsItem::GraphicsItemChange change, const QVariant &value) -> QVariant
 {
     if (change == QGraphicsItem::ItemSelectedHasChanged)
     {
@@ -273,16 +271,16 @@ void VAbstractSpline::keyReleaseEvent(QKeyEvent *event)
             {
                 DeleteToolWithConfirm();
             }
-            catch(const VExceptionToolWasDeleted &e)
+            catch (const VExceptionToolWasDeleted &e)
             {
                 Q_UNUSED(e)
-                return;//Leave this method immediately!!!
+                return; // Leave this method immediately!!!
             }
             break;
         default:
             break;
     }
-    QGraphicsPathItem::keyReleaseEvent ( event );
+    QGraphicsPathItem::keyReleaseEvent(event);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -292,12 +290,12 @@ void VAbstractSpline::mousePressEvent(QGraphicsSceneMouseEvent *event)
     QGraphicsPathItem::mousePressEvent(event);
 
     // Somehow clicking on notselectable object do not clean previous selections.
-    if (not (flags() & ItemIsSelectable) && scene())
+    if (not(flags() & ItemIsSelectable) && scene())
     {
         scene()->clearSelection();
     }
 
-    event->accept();// Special for not selectable item first need to call standard mousePressEvent then accept event
+    event->accept(); // Special for not selectable item first need to call standard mousePressEvent then accept event
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -324,7 +322,7 @@ void VAbstractSpline::SaveOptions(QDomElement &tag, QSharedPointer<VGObject> &ob
     doc->SetAttribute(tag, AttrPenStyle, curve->GetPenStyle());
     doc->SetAttribute(tag, AttrAScale, curve->GetApproximationScale());
     doc->SetAttributeOrRemoveIf<QString>(tag, AttrAlias, curve->GetAliasSuffix(),
-                                         [](const QString &suffix) noexcept {return suffix.isEmpty();});
+                                         [](const QString &suffix) noexcept { return suffix.isEmpty(); });
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -340,8 +338,8 @@ void VAbstractSpline::contextMenuEvent(QGraphicsSceneContextMenuEvent *event)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VSpline VAbstractSpline::CorrectedSpline(const VSpline &spline, const SplinePointPosition &position,
-                                         const QPointF &pos) const
+auto VAbstractSpline::CorrectedSpline(const VSpline &spline, const SplinePointPosition &position, const QPointF &pos)
+    -> VSpline
 {
     VSpline spl;
     if (position == SplinePointPosition::FirstPoint)
@@ -399,27 +397,13 @@ VSpline VAbstractSpline::CorrectedSpline(const VSpline &spline, const SplinePoin
             newLength2 = spline.GetC2Length();
             newLength2F = spline.GetC2LengthFormula();
         }
-        spl = VSpline(spline.GetP1(), spline.GetP4(), spline.GetStartAngle(), spline.GetStartAngleFormula(),
-                      newAngle2, newAngle2F, spline.GetC1Length(), spline.GetC1LengthFormula(),
-                      newLength2, newLength2F);
+        spl = VSpline(spline.GetP1(), spline.GetP4(), spline.GetStartAngle(), spline.GetStartAngleFormula(), newAngle2,
+                      newAngle2F, spline.GetC1Length(), spline.GetC1LengthFormula(), newLength2, newLength2F);
     }
 
     return spl;
 }
 
-//---------------------------------------------------------------------------------------------------------------------
-void VAbstractSpline::CurveSelected(bool selected)
-{
-    setSelected(selected);
-
-    for (auto point : qAsConst(controlPoints))
-    {
-        point->blockSignals(true);
-        point->setSelected(selected);
-        point->blockSignals(false);
-    }
-}
-
 //---------------------------------------------------------------------------------------------------------------------
 void VAbstractSpline::InitDefShape()
 {
@@ -428,17 +412,7 @@ void VAbstractSpline::InitDefShape()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VAbstractSpline::ShowHandles(bool show)
-{
-    for (auto point : qAsConst(controlPoints))
-    {
-        point->setVisible(show);
-    }
-    update();// Show direction
-}
-
-//---------------------------------------------------------------------------------------------------------------------
-QString VAbstractSpline::GetLineColor() const
+auto VAbstractSpline::GetLineColor() const -> QString
 {
     const QSharedPointer<VAbstractCurve> curve = VAbstractTool::data.GeometricObject<VAbstractCurve>(m_id);
     return curve->GetColor();
@@ -447,14 +421,14 @@ QString VAbstractSpline::GetLineColor() const
 //---------------------------------------------------------------------------------------------------------------------
 void VAbstractSpline::SetLineColor(const QString &value)
 {
-    QSharedPointer<VAbstractCurve> curve = VAbstractTool::data.GeometricObject<VAbstractCurve>(m_id);
+    QSharedPointer<VAbstractCurve> const curve = VAbstractTool::data.GeometricObject<VAbstractCurve>(m_id);
     curve->SetColor(value);
     QSharedPointer<VGObject> obj = qSharedPointerCast<VGObject>(curve);
     SaveOption(obj);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VAbstractSpline::GetPenStyle() const
+auto VAbstractSpline::GetPenStyle() const -> QString
 {
     const QSharedPointer<VAbstractCurve> curve = VAbstractTool::data.GeometricObject<VAbstractCurve>(m_id);
     return curve->GetPenStyle();
@@ -463,32 +437,32 @@ QString VAbstractSpline::GetPenStyle() const
 //---------------------------------------------------------------------------------------------------------------------
 void VAbstractSpline::SetPenStyle(const QString &value)
 {
-    QSharedPointer<VAbstractCurve> curve = VAbstractTool::data.GeometricObject<VAbstractCurve>(m_id);
+    QSharedPointer<VAbstractCurve> const curve = VAbstractTool::data.GeometricObject<VAbstractCurve>(m_id);
     curve->SetPenStyle(value);
     QSharedPointer<VGObject> obj = qSharedPointerCast<VGObject>(curve);
     SaveOption(obj);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VAbstractSpline::name() const
+auto VAbstractSpline::name() const -> QString
 {
     return ObjectName<VAbstractCurve>(m_id);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-qreal VAbstractSpline::GetApproximationScale() const
+auto VAbstractSpline::GetApproximationScale() const -> qreal
 {
     return VAbstractTool::data.GeometricObject<VAbstractCurve>(m_id)->GetApproximationScale();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-quint32 VAbstractSpline::GetDuplicate() const
+auto VAbstractSpline::GetDuplicate() const -> quint32
 {
     return VAbstractTool::data.GeometricObject<VAbstractCurve>(m_id)->GetDuplicate();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VAbstractSpline::GetAliasSuffix() const
+auto VAbstractSpline::GetAliasSuffix() const -> QString
 {
     return ObjectAliasSuffix<VAbstractCurve>(m_id);
 }
@@ -496,15 +470,14 @@ QString VAbstractSpline::GetAliasSuffix() const
 //---------------------------------------------------------------------------------------------------------------------
 void VAbstractSpline::SetAliasSuffix(QString alias)
 {
-    QSharedPointer<VAbstractCurve> curve = VAbstractTool::data.GeometricObject<VAbstractCurve>(m_id);
+    QSharedPointer<VAbstractCurve> const curve = VAbstractTool::data.GeometricObject<VAbstractCurve>(m_id);
 
     const QString oldAliasSuffix = curve->GetAliasSuffix();
-    alias = alias.simplified().replace(QChar(QChar::Space), QChar('_'));
+    alias = alias.simplified().replace(QChar(QChar::Space), '_'_L1);
     curve->SetAliasSuffix(alias);
 
-    QRegularExpression rx(NameRegExp());
-
-    if (alias.isEmpty() || (rx.match(curve->GetAlias()).hasMatch() && VAbstractTool::data.IsUnique(curve->GetAlias())))
+    if (QRegularExpression const rx(NameRegExp());
+        alias.isEmpty() || (rx.match(curve->GetAlias()).hasMatch() && VAbstractTool::data.IsUnique(curve->GetAlias())))
     {
         QSharedPointer<VGObject> obj = qSharedPointerCast<VGObject>(curve);
         SaveOption(obj);
@@ -526,13 +499,14 @@ void VAbstractSpline::GroupVisibility(quint32 object, bool visible)
 //---------------------------------------------------------------------------------------------------------------------
 VToolAbstractArc::VToolAbstractArc(VAbstractPattern *doc, VContainer *data, quint32 id, const QString &notes,
                                    QGraphicsItem *parent)
-    : VAbstractSpline(doc, data, id, notes, parent)
-{}
+  : VAbstractSpline(doc, data, id, notes, parent)
+{
+}
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VToolAbstractArc::CenterPointName() const
+auto VToolAbstractArc::CenterPointName() const -> QString
 {
-    QSharedPointer<VAbstractArc> arc = VAbstractTool::data.GeometricObject<VAbstractArc>(m_id);
+    QSharedPointer<VAbstractArc> const arc = VAbstractTool::data.GeometricObject<VAbstractArc>(m_id);
     SCASSERT(arc.isNull() == false)
 
     return VAbstractTool::data.GetGObject(arc->GetCenter().id())->name();
