@@ -30,19 +30,17 @@
 
 #include <QPen>
 #include <QSharedPointer>
-#include <QStaticStringData>
-#include <QStringData>
-#include <QStringDataPtr>
-#include <Qt>
 #include <new>
 
-#include "../../../dialogs/tools/dialogtool.h"
 #include "../../../dialogs/tools/dialogellipticalarc.h"
+#include "../../../dialogs/tools/dialogtool.h"
 #include "../../../visualization/path/vistoolellipticalarc.h"
 #include "../../../visualization/visualization.h"
+#include "../../vabstracttool.h"
 #include "../ifc/exception/vexception.h"
-#include "../ifc/xml/vdomdocument.h"
 #include "../ifc/ifcdef.h"
+#include "../ifc/xml/vdomdocument.h"
+#include "../vdrawtool.h"
 #include "../vgeometry/vellipticalarc.h"
 #include "../vgeometry/vgobject.h"
 #include "../vgeometry/vpointf.h"
@@ -52,10 +50,14 @@
 #include "../vpatterndb/vformula.h"
 #include "../vpatterndb/vtranslatevars.h"
 #include "../vwidgets/vmaingraphicsscene.h"
-#include "../../vabstracttool.h"
-#include "../vdrawtool.h"
 #include "vabstractspline.h"
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
+#include "../vmisc/compatibility.h"
+#endif
+
+using namespace Qt::Literals::StringLiterals;
+
 const QString VToolEllipticalArc::ToolType = QStringLiteral("simple");
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -65,11 +67,11 @@ const QString VToolEllipticalArc::ToolType = QStringLiteral("simple");
  * @param parent parent object
  */
 VToolEllipticalArc::VToolEllipticalArc(const VToolEllipticalArcInitData &initData, QGraphicsItem *parent)
-    :VToolAbstractArc(initData.doc, initData.data, initData.id, initData.notes, parent)
+  : VToolAbstractArc(initData.doc, initData.data, initData.id, initData.notes, parent)
 {
-    sceneType = SceneObject::ElArc;
+    SetSceneType(SceneObject::ElArc);
 
-    this->setFlag(QGraphicsItem::ItemIsFocusable, true);// For keyboard input focus
+    this->setFlag(QGraphicsItem::ItemIsFocusable, true); // For keyboard input focus
 
     ToolCreation(initData.typeCreation);
 }
@@ -78,7 +80,7 @@ VToolEllipticalArc::VToolEllipticalArc(const VToolEllipticalArcInitData &initDat
 /**
  * @brief setDialog set dialog when user want change tool option.
  */
-void VToolEllipticalArc::setDialog()
+void VToolEllipticalArc::SetDialog()
 {
     SCASSERT(not m_dialog.isNull())
     const QPointer<DialogEllipticalArc> dialogTool = qobject_cast<DialogEllipticalArc *>(m_dialog);
@@ -104,8 +106,8 @@ void VToolEllipticalArc::setDialog()
  * @param doc dom document container
  * @param data container with variables
  */
-VToolEllipticalArc* VToolEllipticalArc::Create(const QPointer<DialogTool> &dialog, VMainGraphicsScene *scene,
-                                               VAbstractPattern *doc, VContainer *data)
+auto VToolEllipticalArc::Create(const QPointer<DialogTool> &dialog, VMainGraphicsScene *scene, VAbstractPattern *doc,
+                                VContainer *data) -> VToolEllipticalArc *
 {
     SCASSERT(not dialog.isNull())
     const QPointer<DialogEllipticalArc> dialogTool = qobject_cast<DialogEllipticalArc *>(dialog);
@@ -128,9 +130,9 @@ VToolEllipticalArc* VToolEllipticalArc::Create(const QPointer<DialogTool> &dialo
     initData.approximationScale = dialogTool->GetApproximationScale();
     initData.notes = dialogTool->GetNotes();
     initData.aliasSuffix = dialogTool->GetAliasSuffix();
-    //initData.approximationScale = dialogTool->GetApproximationScale(); // For future use
+    // initData.approximationScale = dialogTool->GetApproximationScale(); // For future use
 
-    VToolEllipticalArc* point = Create(initData);
+    VToolEllipticalArc *point = Create(initData);
     if (point != nullptr)
     {
         point->m_dialog = dialog;
@@ -138,13 +140,12 @@ VToolEllipticalArc* VToolEllipticalArc::Create(const QPointer<DialogTool> &dialo
     return point;
 }
 
-
 //---------------------------------------------------------------------------------------------------------------------
 /**
  * @brief Create help create tool form GUI.
  * @param initData init data.
  */
-VToolEllipticalArc* VToolEllipticalArc::Create(VToolEllipticalArcInitData &initData)
+auto VToolEllipticalArc::Create(VToolEllipticalArcInitData &initData) -> VToolEllipticalArc *
 {
     qreal calcRadius1 = 0, calcRadius2 = 0, calcF1 = 0, calcF2 = 0, calcRotationAngle = 0;
 
@@ -156,9 +157,8 @@ VToolEllipticalArc* VToolEllipticalArc::Create(VToolEllipticalArcInitData &initD
     calcRotationAngle = CheckFormula(initData.id, initData.rotationAngle, initData.data);
 
     const VPointF c = *initData.data->GeometricObject<VPointF>(initData.center);
-    VEllipticalArc *elArc = new VEllipticalArc(c, calcRadius1, calcRadius2, initData.radius1, initData.radius2, calcF1,
-                                               initData.f1, calcF2, initData.f2, calcRotationAngle,
-                                               initData.rotationAngle);
+    auto *elArc = new VEllipticalArc(c, calcRadius1, calcRadius2, initData.radius1, initData.radius2, calcF1,
+                                     initData.f1, calcF2, initData.f2, calcRotationAngle, initData.rotationAngle);
     elArc->SetColor(initData.color);
     elArc->SetPenStyle(initData.penStyle);
     elArc->SetApproximationScale(initData.approximationScale);
@@ -182,7 +182,7 @@ VToolEllipticalArc* VToolEllipticalArc::Create(VToolEllipticalArcInitData &initD
     if (initData.parse == Document::FullParse)
     {
         VAbstractTool::AddRecord(initData.id, Tool::EllipticalArc, initData.doc);
-        VToolEllipticalArc *toolEllipticalArc = new VToolEllipticalArc(initData);
+        auto *toolEllipticalArc = new VToolEllipticalArc(initData);
         initData.scene->addItem(toolEllipticalArc);
         InitElArcToolConnections(initData.scene, toolEllipticalArc);
         VAbstractPattern::AddTool(initData.id, toolEllipticalArc);
@@ -193,19 +193,18 @@ VToolEllipticalArc* VToolEllipticalArc::Create(VToolEllipticalArcInitData &initD
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VToolEllipticalArc::getTagName() const
+auto VToolEllipticalArc::getTagName() const -> QString
 {
     return VAbstractPattern::TagElArc;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VFormula VToolEllipticalArc::GetFormulaRadius1() const
+auto VToolEllipticalArc::GetFormulaRadius1() const -> VFormula
 {
-    QSharedPointer<VEllipticalArc> elArc = VAbstractTool::data.GeometricObject<VEllipticalArc>(m_id);
+    QSharedPointer<VEllipticalArc> const elArc = VAbstractTool::data.GeometricObject<VEllipticalArc>(m_id);
     SCASSERT(elArc.isNull() == false)
 
     VFormula radius1(elArc->GetFormulaRadius1(), getData());
-    radius1.setCheckZero(true);
     radius1.setToolId(m_id);
     radius1.setPostfix(UnitsToStr(VAbstractValApplication::VApp()->patternUnits()));
     radius1.Eval();
@@ -215,26 +214,22 @@ VFormula VToolEllipticalArc::GetFormulaRadius1() const
 //---------------------------------------------------------------------------------------------------------------------
 void VToolEllipticalArc::SetFormulaRadius1(const VFormula &value)
 {
-    if (value.error() == false)
+    if (!value.error())
     {
-        if (value.getDoubleValue() > 0)// Formula don't check this, but radius1 can't be 0 or negative
-        {
-            QSharedPointer<VGObject> obj = VAbstractTool::data.GetGObject(m_id);
-            QSharedPointer<VEllipticalArc> elArc = qSharedPointerDynamicCast<VEllipticalArc>(obj);
-            elArc->SetFormulaRadius1(value.GetFormula(FormulaType::FromUser), value.getDoubleValue());
-            SaveOption(obj);
-        }
+        QSharedPointer<VGObject> obj = VAbstractTool::data.GetGObject(m_id);
+        QSharedPointer<VEllipticalArc> const elArc = qSharedPointerDynamicCast<VEllipticalArc>(obj);
+        elArc->SetFormulaRadius1(value.GetFormula(FormulaType::FromUser), value.getDoubleValue());
+        SaveOption(obj);
     }
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VFormula VToolEllipticalArc::GetFormulaRadius2() const
+auto VToolEllipticalArc::GetFormulaRadius2() const -> VFormula
 {
-    QSharedPointer<VEllipticalArc> elArc = VAbstractTool::data.GeometricObject<VEllipticalArc>(m_id);
+    QSharedPointer<VEllipticalArc> const elArc = VAbstractTool::data.GeometricObject<VEllipticalArc>(m_id);
     SCASSERT(elArc.isNull() == false)
 
     VFormula radius2(elArc->GetFormulaRadius2(), getData());
-    radius2.setCheckZero(true);
     radius2.setToolId(m_id);
     radius2.setPostfix(UnitsToStr(VAbstractValApplication::VApp()->patternUnits()));
     radius2.Eval();
@@ -244,26 +239,22 @@ VFormula VToolEllipticalArc::GetFormulaRadius2() const
 //---------------------------------------------------------------------------------------------------------------------
 void VToolEllipticalArc::SetFormulaRadius2(const VFormula &value)
 {
-    if (value.error() == false)
+    if (!value.error())
     {
-        if (value.getDoubleValue() > 0)// Formula don't check this, but radius2 can't be 0 or negative
-        {
-            QSharedPointer<VGObject> obj = VAbstractTool::data.GetGObject(m_id);
-            QSharedPointer<VEllipticalArc> elArc = qSharedPointerDynamicCast<VEllipticalArc>(obj);
-            elArc->SetFormulaRadius2(value.GetFormula(FormulaType::FromUser), value.getDoubleValue());
-            SaveOption(obj);
-        }
+        QSharedPointer<VGObject> obj = VAbstractTool::data.GetGObject(m_id);
+        QSharedPointer<VEllipticalArc> const elArc = qSharedPointerDynamicCast<VEllipticalArc>(obj);
+        elArc->SetFormulaRadius2(value.GetFormula(FormulaType::FromUser), value.getDoubleValue());
+        SaveOption(obj);
     }
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VFormula VToolEllipticalArc::GetFormulaF1() const
+auto VToolEllipticalArc::GetFormulaF1() const -> VFormula
 {
-    QSharedPointer<VEllipticalArc> elArc = VAbstractTool::data.GeometricObject<VEllipticalArc>(m_id);
+    QSharedPointer<VEllipticalArc> const elArc = VAbstractTool::data.GeometricObject<VEllipticalArc>(m_id);
     SCASSERT(elArc.isNull() == false)
 
     VFormula f1(elArc->GetFormulaF1(), getData());
-    f1.setCheckZero(false);
     f1.setToolId(m_id);
     f1.setPostfix(degreeSymbol);
     f1.Eval();
@@ -273,23 +264,22 @@ VFormula VToolEllipticalArc::GetFormulaF1() const
 //---------------------------------------------------------------------------------------------------------------------
 void VToolEllipticalArc::SetFormulaF1(const VFormula &value)
 {
-    if (value.error() == false)
+    if (!value.error())
     {
         QSharedPointer<VGObject> obj = VAbstractTool::data.GetGObject(m_id);
-        QSharedPointer<VEllipticalArc> elArc = qSharedPointerDynamicCast<VEllipticalArc>(obj);
+        QSharedPointer<VEllipticalArc> const elArc = qSharedPointerDynamicCast<VEllipticalArc>(obj);
         elArc->SetFormulaF1(value.GetFormula(FormulaType::FromUser), value.getDoubleValue());
         SaveOption(obj);
     }
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VFormula VToolEllipticalArc::GetFormulaF2() const
+auto VToolEllipticalArc::GetFormulaF2() const -> VFormula
 {
-    QSharedPointer<VEllipticalArc> elArc = VAbstractTool::data.GeometricObject<VEllipticalArc>(m_id);
+    QSharedPointer<VEllipticalArc> const elArc = VAbstractTool::data.GeometricObject<VEllipticalArc>(m_id);
     SCASSERT(elArc.isNull() == false)
 
     VFormula f2(elArc->GetFormulaF2(), getData());
-    f2.setCheckZero(false);
     f2.setToolId(m_id);
     f2.setPostfix(degreeSymbol);
     f2.Eval();
@@ -299,23 +289,22 @@ VFormula VToolEllipticalArc::GetFormulaF2() const
 //---------------------------------------------------------------------------------------------------------------------
 void VToolEllipticalArc::SetFormulaF2(const VFormula &value)
 {
-    if (value.error() == false)
+    if (!value.error())
     {
         QSharedPointer<VGObject> obj = VAbstractTool::data.GetGObject(m_id);
-        QSharedPointer<VEllipticalArc> elArc = qSharedPointerDynamicCast<VEllipticalArc>(obj);
+        QSharedPointer<VEllipticalArc> const elArc = qSharedPointerDynamicCast<VEllipticalArc>(obj);
         elArc->SetFormulaF2(value.GetFormula(FormulaType::FromUser), value.getDoubleValue());
         SaveOption(obj);
     }
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VFormula VToolEllipticalArc::GetFormulaRotationAngle() const
+auto VToolEllipticalArc::GetFormulaRotationAngle() const -> VFormula
 {
-    QSharedPointer<VEllipticalArc> elArc = VAbstractTool::data.GeometricObject<VEllipticalArc>(m_id);
+    QSharedPointer<VEllipticalArc> const elArc = VAbstractTool::data.GeometricObject<VEllipticalArc>(m_id);
     SCASSERT(elArc.isNull() == false)
 
     VFormula rotationAngle(elArc->GetFormulaRotationAngle(), getData());
-    rotationAngle.setCheckZero(false);
     rotationAngle.setToolId(m_id);
     rotationAngle.setPostfix(degreeSymbol);
     rotationAngle.Eval();
@@ -325,19 +314,19 @@ VFormula VToolEllipticalArc::GetFormulaRotationAngle() const
 //---------------------------------------------------------------------------------------------------------------------
 void VToolEllipticalArc::SetFormulaRotationAngle(const VFormula &value)
 {
-    if (value.error() == false)
+    if (!value.error())
     {
         QSharedPointer<VGObject> obj = VAbstractTool::data.GetGObject(m_id);
-        QSharedPointer<VEllipticalArc> elArc = qSharedPointerDynamicCast<VEllipticalArc>(obj);
+        QSharedPointer<VEllipticalArc> const elArc = qSharedPointerDynamicCast<VEllipticalArc>(obj);
         elArc->SetFormulaRotationAngle(value.GetFormula(FormulaType::FromUser), value.getDoubleValue());
         SaveOption(obj);
     }
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-qreal VToolEllipticalArc::GetApproximationScale() const
+auto VToolEllipticalArc::GetApproximationScale() const -> qreal
 {
-    QSharedPointer<VEllipticalArc> arc = VAbstractTool::data.GeometricObject<VEllipticalArc>(m_id);
+    QSharedPointer<VEllipticalArc> const arc = VAbstractTool::data.GeometricObject<VEllipticalArc>(m_id);
     SCASSERT(arc.isNull() == false)
 
     return arc->GetApproximationScale();
@@ -347,7 +336,7 @@ qreal VToolEllipticalArc::GetApproximationScale() const
 void VToolEllipticalArc::SetApproximationScale(qreal value)
 {
     QSharedPointer<VGObject> obj = VAbstractTool::data.GetGObject(m_id);
-    QSharedPointer<VEllipticalArc> arc = qSharedPointerDynamicCast<VEllipticalArc>(obj);
+    QSharedPointer<VEllipticalArc> const arc = qSharedPointerDynamicCast<VEllipticalArc>(obj);
     arc->SetApproximationScale(value);
     SaveOption(obj);
 }
@@ -366,10 +355,10 @@ void VToolEllipticalArc::ShowContextMenu(QGraphicsSceneContextMenuEvent *event,
     {
         ContextMenu<DialogEllipticalArc>(event);
     }
-    catch(const VExceptionToolWasDeleted &e)
+    catch (const VExceptionToolWasDeleted &e)
     {
         Q_UNUSED(e)
-        return;//Leave this method immediately!!!
+        return; // Leave this method immediately!!!
     }
 }
 
@@ -409,9 +398,9 @@ void VToolEllipticalArc::SaveDialog(QDomElement &domElement, QList<quint32> &old
     doc->SetAttribute(domElement, AttrPenStyle, dialogTool->GetPenStyle());
     doc->SetAttribute(domElement, AttrAScale, dialogTool->GetApproximationScale());
     doc->SetAttributeOrRemoveIf<QString>(domElement, AttrAlias, dialogTool->GetAliasSuffix(),
-                                         [](const QString &suffix) noexcept {return suffix.isEmpty();});
+                                         [](const QString &suffix) noexcept { return suffix.isEmpty(); });
     doc->SetAttributeOrRemoveIf<QString>(domElement, AttrNotes, dialogTool->GetNotes(),
-                                         [](const QString &notes) noexcept {return notes.isEmpty();});
+                                         [](const QString &notes) noexcept { return notes.isEmpty(); });
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -419,7 +408,7 @@ void VToolEllipticalArc::SaveOptions(QDomElement &tag, QSharedPointer<VGObject>
 {
     VAbstractSpline::SaveOptions(tag, obj);
 
-    QSharedPointer<VEllipticalArc> elArc = qSharedPointerDynamicCast<VEllipticalArc>(obj);
+    QSharedPointer<VEllipticalArc> const elArc = qSharedPointerDynamicCast<VEllipticalArc>(obj);
     SCASSERT(elArc.isNull() == false)
 
     doc->SetAttribute(tag, AttrType, ToolType);
@@ -457,33 +446,33 @@ void VToolEllipticalArc::SetVisualization()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VToolEllipticalArc::MakeToolTip() const
+auto VToolEllipticalArc::MakeToolTip() const -> QString
 {
     const QSharedPointer<VEllipticalArc> elArc = VAbstractTool::data.GeometricObject<VEllipticalArc>(m_id);
 
-    const QString toolTip = QString("<table>"
-                                    "<tr> <td><b>%12:</b> %13</td> </tr>"
-                                    "<tr> <td><b>%1:</b> %2 %3</td> </tr>"
-                                    "<tr> <td><b>%4:</b> %5 %3</td> </tr>"
-                                    "<tr> <td><b>%6:</b> %7 %3</td> </tr>"
-                                    "<tr> <td><b>%8:</b> %9°</td> </tr>"
-                                    "<tr> <td><b>%10:</b> %11°</td> </tr>"
-                                    "<tr> <td><b>%14:</b> %15°</td> </tr>"
-                                    "</table>")
-            .arg(tr("Length"))                          // 1
-            .arg(VAbstractValApplication::VApp()->fromPixel(elArc->GetLength()))   // 2
-            .arg(UnitsToStr(VAbstractValApplication::VApp()->patternUnits(), true), // 3
-                 tr("Radius") + QLatin1Char('1'))       // 4
-            .arg(VAbstractValApplication::VApp()->fromPixel(elArc->GetRadius1()))  // 5
-            .arg(tr("Radius") + QLatin1Char('2'))       // 6
-            .arg(VAbstractValApplication::VApp()->fromPixel(elArc->GetRadius2()))  // 7
-            .arg(tr("Start angle"))                     // 8
-            .arg(elArc->GetStartAngle())                // 9
-            .arg(tr("End angle"))                       // 10
-            .arg(elArc->GetEndAngle())                  // 11
-            .arg(tr("Label"),                           // 12
-                 elArc->ObjectName(),                   // 13
-                 tr("Rotation"))                        // 14
-            .arg(elArc->GetRotationAngle());            // 15
+    const QString toolTip = u"<table>"
+                            u"<tr> <td><b>%12:</b> %13</td> </tr>"
+                            u"<tr> <td><b>%1:</b> %2 %3</td> </tr>"
+                            u"<tr> <td><b>%4:</b> %5 %3</td> </tr>"
+                            u"<tr> <td><b>%6:</b> %7 %3</td> </tr>"
+                            u"<tr> <td><b>%8:</b> %9°</td> </tr>"
+                            u"<tr> <td><b>%10:</b> %11°</td> </tr>"
+                            u"<tr> <td><b>%14:</b> %15°</td> </tr>"
+                            u"</table>"_s
+                                .arg(tr("Length"))                                                      // 1
+                                .arg(VAbstractValApplication::VApp()->fromPixel(elArc->GetLength()))    // 2
+                                .arg(UnitsToStr(VAbstractValApplication::VApp()->patternUnits(), true), // 3
+                                     tr("Radius") + '1'_L1)                                             // 4
+                                .arg(VAbstractValApplication::VApp()->fromPixel(elArc->GetRadius1()))   // 5
+                                .arg(tr("Radius") + '2'_L1)                                             // 6
+                                .arg(VAbstractValApplication::VApp()->fromPixel(elArc->GetRadius2()))   // 7
+                                .arg(tr("Start angle"))                                                 // 8
+                                .arg(elArc->GetStartAngle())                                            // 9
+                                .arg(tr("End angle"))                                                   // 10
+                                .arg(elArc->GetEndAngle())                                              // 11
+                                .arg(tr("Label"),                                                       // 12
+                                     elArc->ObjectName(),                                               // 13
+                                     tr("Rotation"))                                                    // 14
+                                .arg(elArc->GetRotationAngle());                                        // 15
     return toolTip;
 }
