@@ -31,20 +31,19 @@
 #include <QLineF>
 #include <QMessageLogger>
 #include <QSharedPointer>
-#include <QStaticStringData>
-#include <QStringData>
-#include <QStringDataPtr>
 #include <QtDebug>
 #include <new>
 
 #include "../../../../dialogs/tools/dialogpointofcontact.h"
 #include "../../../../dialogs/tools/dialogtool.h"
-#include "../../../../visualization/visualization.h"
 #include "../../../../visualization/line/vistoolpointofcontact.h"
+#include "../../../../visualization/visualization.h"
+#include "../../../vabstracttool.h"
+#include "../../vdrawtool.h"
 #include "../ifc/exception/vexception.h"
 #include "../ifc/exception/vexceptionobjecterror.h"
-#include "../ifc/xml/vdomdocument.h"
 #include "../ifc/ifcdef.h"
+#include "../ifc/xml/vdomdocument.h"
 #include "../vgeometry/vgobject.h"
 #include "../vgeometry/vpointf.h"
 #include "../vmisc/vabstractapplication.h"
@@ -53,10 +52,14 @@
 #include "../vpatterndb/vformula.h"
 #include "../vpatterndb/vtranslatevars.h"
 #include "../vwidgets/vmaingraphicsscene.h"
-#include "../../../vabstracttool.h"
-#include "../../vdrawtool.h"
 #include "vtoolsinglepoint.h"
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
+#include "../vmisc/compatibility.h"
+#endif
+
+using namespace Qt::Literals::StringLiterals;
+
 template <class T> class QSharedPointer;
 
 const QString VToolPointOfContact::ToolType = QStringLiteral("pointOfContact");
@@ -68,11 +71,11 @@ const QString VToolPointOfContact::ToolType = QStringLiteral("pointOfContact");
  * @param parent parent object.
  */
 VToolPointOfContact::VToolPointOfContact(const VToolPointOfContactInitData &initData, QGraphicsItem *parent)
-    : VToolSinglePoint(initData.doc, initData.data, initData.id, initData.notes, parent),
-      arcRadius(initData.radius),
-      center(initData.center),
-      firstPointId(initData.firstPointId),
-      secondPointId(initData.secondPointId)
+  : VToolSinglePoint(initData.doc, initData.data, initData.id, initData.notes, parent),
+    arcRadius(initData.radius),
+    center(initData.center),
+    firstPointId(initData.firstPointId),
+    secondPointId(initData.secondPointId)
 {
     ToolCreation(initData.typeCreation);
 }
@@ -81,7 +84,7 @@ VToolPointOfContact::VToolPointOfContact(const VToolPointOfContactInitData &init
 /**
  * @brief setDialog set dialog when user want change tool option.
  */
-void VToolPointOfContact::setDialog()
+void VToolPointOfContact::SetDialog()
 {
     SCASSERT(not m_dialog.isNull())
     const QPointer<DialogPointOfContact> dialogTool = qobject_cast<DialogPointOfContact *>(m_dialog);
@@ -105,13 +108,13 @@ void VToolPointOfContact::setDialog()
  * @param intersectionPoint point of intersection.
  * @return true if intersection exists.
  */
-bool VToolPointOfContact::FindPoint(qreal radius, const QPointF &center, const QPointF &firstPoint,
-                                    const QPointF &secondPoint, QPointF *intersectionPoint)
+auto VToolPointOfContact::FindPoint(qreal radius, const QPointF &center, const QPointF &firstPoint,
+                                    const QPointF &secondPoint, QPointF *intersectionPoint) -> bool
 {
     SCASSERT(intersectionPoint != nullptr)
 
     QPointF p1, p2;
-    qint32 res = VGObject::LineIntersectCircle(center, radius, QLineF(firstPoint, secondPoint), p1, p2);
+    qint32 const res = VGObject::LineIntersectCircle(center, qAbs(radius), QLineF(firstPoint, secondPoint), p1, p2);
     switch (res)
     {
         case 0:
@@ -121,10 +124,9 @@ bool VToolPointOfContact::FindPoint(qreal radius, const QPointF &center, const Q
             return true;
         case 2:
         {
-            const bool flagP1 = VGObject::IsPointOnLineSegment (p1, firstPoint, secondPoint);
-            const bool flagP2 = VGObject::IsPointOnLineSegment (p2, firstPoint, secondPoint);
-            if ((flagP1 == true && flagP2 == true) ||
-                (flagP1 == false && flagP2 == false)/*In case we have something wrong*/)
+            const bool flagP1 = VGObject::IsPointOnLineSegment(p1, firstPoint, secondPoint);
+            const bool flagP2 = VGObject::IsPointOnLineSegment(p2, firstPoint, secondPoint);
+            if ((flagP1 && flagP2) || (!flagP1 && !flagP2) /*In case we have something wrong*/)
             {
                 // We don't have options for choosing correct point. Use closest to segment first point.
                 if (QLineF(firstPoint, p1).length() <= QLineF(firstPoint, p2).length())
@@ -132,25 +134,20 @@ bool VToolPointOfContact::FindPoint(qreal radius, const QPointF &center, const Q
                     *intersectionPoint = p1;
                     return true;
                 }
-                else
-                {
-                    *intersectionPoint = p2;
-                    return true;
-                }
+
+                *intersectionPoint = p2;
+                return true;
             }
-            else
-            { // In this case we have one real and one theoretical intersection.
-                if (flagP1)
-                {
-                    *intersectionPoint = p1;
-                    return true;
-                }
-                else
-                {
-                    *intersectionPoint = p2;
-                    return true;
-                }
+
+            // In this case we have one real and one theoretical intersection.
+            if (flagP1)
+            {
+                *intersectionPoint = p1;
+                return true;
             }
+
+            *intersectionPoint = p2;
+            return true;
         }
         default:
             qDebug() << "Unxpected value" << res;
@@ -167,8 +164,8 @@ bool VToolPointOfContact::FindPoint(qreal radius, const QPointF &center, const Q
  * @param doc dom document container.
  * @param data container with variables.
  */
-VToolPointOfContact* VToolPointOfContact::Create(const QPointer<DialogTool> &dialog, VMainGraphicsScene *scene,
-                                                 VAbstractPattern *doc, VContainer *data)
+auto VToolPointOfContact::Create(const QPointer<DialogTool> &dialog, VMainGraphicsScene *scene, VAbstractPattern *doc,
+                                 VContainer *data) -> VToolPointOfContact *
 {
     SCASSERT(not dialog.isNull())
     const QPointer<DialogPointOfContact> dialogTool = qobject_cast<DialogPointOfContact *>(dialog);
@@ -200,7 +197,7 @@ VToolPointOfContact* VToolPointOfContact::Create(const QPointer<DialogTool> &dia
  * @brief Create help create tool.
  * @param initData init data.
  */
-VToolPointOfContact* VToolPointOfContact::Create(VToolPointOfContactInitData &initData)
+auto VToolPointOfContact::Create(VToolPointOfContactInitData &initData) -> VToolPointOfContact *
 {
     const QSharedPointer<VPointF> centerP = initData.data->GeometricObject<VPointF>(initData.center);
     const QSharedPointer<VPointF> firstP = initData.data->GeometricObject<VPointF>(initData.firstPointId);
@@ -209,21 +206,23 @@ VToolPointOfContact* VToolPointOfContact::Create(VToolPointOfContactInitData &in
     const qreal result = CheckFormula(initData.id, initData.radius, initData.data);
 
     QPointF fPoint;
-    const bool success = VToolPointOfContact::FindPoint(VAbstractValApplication::VApp()->toPixel(result),
-                                                        static_cast<QPointF>(*centerP),
-                                                        static_cast<QPointF>(*firstP), static_cast<QPointF>(*secondP),
-                                                        &fPoint);
+    const bool success =
+        VToolPointOfContact::FindPoint(VAbstractValApplication::VApp()->toPixel(result), static_cast<QPointF>(*centerP),
+                                       static_cast<QPointF>(*firstP), static_cast<QPointF>(*secondP), &fPoint);
 
     if (not success)
     {
         const QString errorMsg = tr("Error calculating point '%1'. Circle with center '%2' and radius '%3' doesn't "
                                     "have intersection with line (%4;%5)")
-                .arg(initData.name, centerP->name()).arg(result).arg(firstP->name(), secondP->name());
-        VAbstractApplication::VApp()->IsPedantic() ? throw VExceptionObjectError(errorMsg) :
-                                              qWarning() << VAbstractValApplication::warningMessageSignature + errorMsg;
+                                     .arg(initData.name, centerP->name())
+                                     .arg(result)
+                                     .arg(firstP->name(), secondP->name());
+        VAbstractApplication::VApp()->IsPedantic()
+            ? throw VExceptionObjectError(errorMsg)
+            : qWarning() << VAbstractValApplication::warningMessageSignature + errorMsg;
     }
 
-    VPointF *p = new VPointF(fPoint, initData.name, initData.mx, initData.my);
+    auto *p = new VPointF(fPoint, initData.name, initData.mx, initData.my);
     p->SetShowLabel(initData.showLabel);
 
     if (initData.typeCreation == Source::FromGui)
@@ -248,7 +247,7 @@ VToolPointOfContact* VToolPointOfContact::Create(VToolPointOfContactInitData &in
     if (initData.parse == Document::FullParse)
     {
         VAbstractTool::AddRecord(initData.id, Tool::PointOfContact, initData.doc);
-        VToolPointOfContact *point = new VToolPointOfContact(initData);
+        auto *point = new VToolPointOfContact(initData);
         initData.scene->addItem(point);
         InitToolConnections(initData.scene, point);
         VAbstractPattern::AddTool(initData.id, point);
@@ -261,19 +260,19 @@ VToolPointOfContact* VToolPointOfContact::Create(VToolPointOfContactInitData &in
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VToolPointOfContact::ArcCenterPointName() const
+auto VToolPointOfContact::ArcCenterPointName() const -> QString
 {
     return VAbstractTool::data.GetGObject(center)->name();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VToolPointOfContact::FirstPointName() const
+auto VToolPointOfContact::FirstPointName() const -> QString
 {
     return VAbstractTool::data.GetGObject(firstPointId)->name();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VToolPointOfContact::SecondPointName() const
+auto VToolPointOfContact::SecondPointName() const -> QString
 {
     return VAbstractTool::data.GetGObject(secondPointId)->name();
 }
@@ -317,7 +316,7 @@ void VToolPointOfContact::SaveDialog(QDomElement &domElement, QList<quint32> &ol
     doc->SetAttribute(domElement, AttrFirstPoint, QString().setNum(dialogTool->GetFirstPoint()));
     doc->SetAttribute(domElement, AttrSecondPoint, QString().setNum(dialogTool->GetSecondPoint()));
     doc->SetAttributeOrRemoveIf<QString>(domElement, AttrNotes, dialogTool->GetNotes(),
-                                         [](const QString &notes) noexcept {return notes.isEmpty();});
+                                         [](const QString &notes) noexcept { return notes.isEmpty(); });
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -354,15 +353,15 @@ void VToolPointOfContact::SetVisualization()
         visual->SetLineP1Id(firstPointId);
         visual->SetLineP2Id(secondPointId);
         visual->SetRadiusId(center);
-        visual->SetRadius(VAbstractApplication::VApp()->TrVars()
-                          ->FormulaToUser(arcRadius, VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
+        visual->SetRadius(VAbstractApplication::VApp()->TrVars()->FormulaToUser(
+            arcRadius, VAbstractApplication::VApp()->Settings()->GetOsSeparator()));
         visual->SetMode(Mode::Show);
         visual->RefreshGeometry();
     }
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VToolPointOfContact::MakeToolTip() const
+auto VToolPointOfContact::MakeToolTip() const -> QString
 {
     const QSharedPointer<VPointF> p1 = VAbstractTool::data.GeometricObject<VPointF>(firstPointId);
     const QSharedPointer<VPointF> p2 = VAbstractTool::data.GeometricObject<VPointF>(secondPointId);
@@ -373,23 +372,22 @@ QString VToolPointOfContact::MakeToolTip() const
     const QLineF p2ToCur(static_cast<QPointF>(*p2), static_cast<QPointF>(*current));
     const QLineF centerToCur(static_cast<QPointF>(*centerP), static_cast<QPointF>(*current));
 
-    const QString toolTip = QString("<table>"
-                                    "<tr> <td><b>%10:</b> %11</td> </tr>"
-                                    "<tr> <td><b>%1:</b> %2 %3</td> </tr>"
-                                    "<tr> <td><b>%4:</b> %5 %3</td> </tr>"
-                                    "<tr> <td><b>%6:</b> %7 %3</td> </tr>"
-                                    "<tr> <td><b>%8:</b> %9°</td> </tr>"
-                                    "</table>")
-            .arg(QStringLiteral("%1->%2").arg(p1->name(), current->name()))
-            .arg(VAbstractValApplication::VApp()->fromPixel(p1ToCur.length()))
-            .arg(UnitsToStr(VAbstractValApplication::VApp()->patternUnits(), true),
-                 QStringLiteral("%1->%2").arg(p2->name(), current->name()))
-            .arg(VAbstractValApplication::VApp()->fromPixel(p2ToCur.length()))
-            .arg(QStringLiteral("%1 %2->%3").arg(tr("Length"), centerP->name(), current->name()))
-            .arg(VAbstractValApplication::VApp()->fromPixel(centerToCur.length()))
-            .arg(QStringLiteral("%1 %2->%3").arg(tr("Angle"), centerP->name(), current->name()))
-            .arg(centerToCur.angle())
-            .arg(tr("Label"), current->name());
+    const QString toolTip = u"<table>"
+                            u"<tr> <td><b>%10:</b> %11</td> </tr>"
+                            u"<tr> <td><b>%1:</b> %2 %3</td> </tr>"
+                            u"<tr> <td><b>%4:</b> %5 %3</td> </tr>"
+                            u"<tr> <td><b>%6:</b> %7 %3</td> </tr>"
+                            u"<tr> <td><b>%8:</b> %9°</td> </tr>"
+                            u"</table>"_s.arg(u"%1->%2"_s.arg(p1->name(), current->name()))
+                                .arg(VAbstractValApplication::VApp()->fromPixel(p1ToCur.length()))
+                                .arg(UnitsToStr(VAbstractValApplication::VApp()->patternUnits(), true),
+                                     u"%1->%2"_s.arg(p2->name(), current->name()))
+                                .arg(VAbstractValApplication::VApp()->fromPixel(p2ToCur.length()))
+                                .arg(u"%1 %2->%3"_s.arg(tr("Length"), centerP->name(), current->name()))
+                                .arg(VAbstractValApplication::VApp()->fromPixel(centerToCur.length()))
+                                .arg(u"%1 %2->%3"_s.arg(tr("Angle"), centerP->name(), current->name()))
+                                .arg(centerToCur.angle())
+                                .arg(tr("Label"), current->name());
     return toolTip;
 }
 
@@ -406,18 +404,17 @@ void VToolPointOfContact::ShowContextMenu(QGraphicsSceneContextMenuEvent *event,
     {
         ContextMenu<DialogPointOfContact>(event, id);
     }
-    catch(const VExceptionToolWasDeleted &e)
+    catch (const VExceptionToolWasDeleted &e)
     {
         Q_UNUSED(e)
-        return;//Leave this method immediately!!!
+        return; // Leave this method immediately!!!
     }
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-VFormula VToolPointOfContact::getArcRadius() const
+auto VToolPointOfContact::getArcRadius() const -> VFormula
 {
     VFormula radius(arcRadius, this->getData());
-    radius.setCheckZero(true);
     radius.setToolId(m_id);
     radius.setPostfix(UnitsToStr(VAbstractValApplication::VApp()->patternUnits()));
     radius.Eval();
