@@ -40,30 +40,29 @@
 #include <QRectF>
 #include <QSharedPointer>
 #include <QUndoStack>
-#include <Qt>
 #include <new>
 
 #include "../../../../undocommands/label/movelabel.h"
 #include "../../../../undocommands/label/showlabel.h"
+#include "../../../vabstracttool.h"
+#include "../../vdrawtool.h"
 #include "../ifc/exception/vexception.h"
 #include "../ifc/ifcdef.h"
 #include "../ifc/xml/vabstractpattern.h"
+#include "../vabstractpoint.h"
+#include "../vgeometry/vabstractcubicbezier.h"
+#include "../vgeometry/vabstractcubicbezierpath.h"
+#include "../vgeometry/varc.h"
+#include "../vgeometry/vellipticalarc.h"
 #include "../vgeometry/vgobject.h"
 #include "../vgeometry/vpointf.h"
-#include "../vgeometry/vabstractcubicbezierpath.h"
-#include "../vgeometry/vabstractcubicbezier.h"
 #include "../vgeometry/vspline.h"
 #include "../vgeometry/vsplinepath.h"
-#include "../vgeometry/vellipticalarc.h"
-#include "../vgeometry/varc.h"
 #include "../vmisc/vabstractapplication.h"
 #include "../vpatterndb/vcontainer.h"
-#include "../vwidgets/vgraphicssimpletextitem.h"
-#include "../vwidgets/scalesceneitems.h"
 #include "../vwidgets/global.h"
-#include "../../../vabstracttool.h"
-#include "../../vdrawtool.h"
-#include "../vabstractpoint.h"
+#include "../vwidgets/scalesceneitems.h"
+#include "../vwidgets/vgraphicssimpletextitem.h"
 #include "toolcut/vtoolcutsplinepath.h"
 
 QT_WARNING_PUSH
@@ -84,8 +83,8 @@ QT_WARNING_POP
  */
 VToolSinglePoint::VToolSinglePoint(VAbstractPattern *doc, VContainer *data, quint32 id, const QString &notes,
                                    QGraphicsItem *parent)
-    : VAbstractPoint(doc, data, id, notes),
-      VScenePoint(parent)
+  : VAbstractPoint(doc, data, id, notes),
+    VScenePoint(VColorRole::PatternColor, parent)
 {
     connect(m_namePoint, &VGraphicsSimpleTextItem::ShowContextMenu, this, &VToolSinglePoint::contextMenuEvent);
     connect(m_namePoint, &VGraphicsSimpleTextItem::DeleteTool, this, &VToolSinglePoint::DeleteFromLabel);
@@ -96,7 +95,7 @@ VToolSinglePoint::VToolSinglePoint(VAbstractPattern *doc, VContainer *data, quin
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VToolSinglePoint::name() const
+auto VToolSinglePoint::name() const -> QString
 {
     return ObjectName<VPointF>(m_id);
 }
@@ -122,17 +121,15 @@ void VToolSinglePoint::GroupVisibility(quint32 object, bool visible)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VToolSinglePoint::IsLabelVisible(quint32 id) const
+auto VToolSinglePoint::IsLabelVisible(quint32 id) const -> bool
 {
     if (m_id == id)
     {
         const QSharedPointer<VPointF> point = VAbstractTool::data.GeometricObject<VPointF>(id);
         return point->IsShowLabel();
     }
-    else
-    {
-        return false;
-    }
+
+    return false;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -179,14 +176,15 @@ void VToolSinglePoint::mousePressEvent(QGraphicsSceneMouseEvent *event)
     VScenePoint::mousePressEvent(event);
 
     // Somehow clicking on notselectable object do not clean previous selections.
-    if (not (flags() & ItemIsSelectable) && scene())
+    if (not(flags() & ItemIsSelectable) && scene())
     {
         scene()->clearSelection();
     }
 
     if (selectionType == SelectionType::ByMouseRelease)
     {
-        event->accept();// Special for not selectable item first need to call standard mousePressEvent then accept event
+        event
+            ->accept(); // Special for not selectable item first need to call standard mousePressEvent then accept event
     }
     else
     {
@@ -244,12 +242,9 @@ void VToolSinglePoint::FullUpdateFromFile()
  */
 void VToolSinglePoint::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
 {
-    if (selectionType == SelectionType::ByMouseRelease)
+    if (selectionType == SelectionType::ByMouseRelease && IsSelectedByReleaseEvent(this, event))
     {
-        if (IsSelectedByReleaseEvent(this, event))
-        {
-            PointChoosed();
-        }
+        PointChoosed();
     }
     VScenePoint::mouseReleaseEvent(event);
 }
@@ -268,7 +263,7 @@ void VToolSinglePoint::hoverEnterEvent(QGraphicsSceneHoverEvent *event)
  * @param value value.
  * @return value.
  */
-QVariant VToolSinglePoint::itemChange(QGraphicsItem::GraphicsItemChange change, const QVariant &value)
+auto VToolSinglePoint::itemChange(QGraphicsItem::GraphicsItemChange change, const QVariant &value) -> QVariant
 {
     if (change == QGraphicsItem::ItemSelectedHasChanged)
     {
@@ -299,16 +294,16 @@ void VToolSinglePoint::keyReleaseEvent(QKeyEvent *event)
             {
                 DeleteToolWithConfirm();
             }
-            catch(const VExceptionToolWasDeleted &e)
+            catch (const VExceptionToolWasDeleted &e)
             {
                 Q_UNUSED(e)
-                return;//Leave this method immediately!!!
+                return; // Leave this method immediately!!!
             }
             break;
         default:
             break;
     }
-    VScenePoint::keyReleaseEvent ( event );
+    VScenePoint::keyReleaseEvent(event);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -322,7 +317,7 @@ void VToolSinglePoint::SaveOptions(QDomElement &tag, QSharedPointer<VGObject> &o
 {
     VDrawTool::SaveOptions(tag, obj);
 
-    QSharedPointer<VPointF> point = qSharedPointerDynamicCast<VPointF>(obj);
+    QSharedPointer<VPointF> const point = qSharedPointerDynamicCast<VPointF>(obj);
     SCASSERT(point.isNull() == false)
 
     doc->SetAttribute(tag, AttrName, point->name());
@@ -345,7 +340,7 @@ void VToolSinglePoint::ChangeLabelPosition(quint32 id, const QPointF &pos)
 {
     if (id == m_id)
     {
-        QSharedPointer<VPointF> point = VAbstractTool::data.GeometricObject<VPointF>(id);
+        QSharedPointer<VPointF> const point = VAbstractTool::data.GeometricObject<VPointF>(id);
         point->setMx(pos.x());
         point->setMy(pos.y());
         m_namePoint->SetRealPos(pos);
@@ -392,13 +387,16 @@ void VToolSinglePoint::ToolSelectionType(const SelectionType &type)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QT_WARNING_PUSH
-QT_WARNING_DISABLE_GCC("-Wswitch-default")
+
 auto VToolSinglePoint::InitSegments(GOType curveType, qreal segLength, const VPointF *p, quint32 curveId,
-                                    VContainer *data, const QString &alias1,
-                                    const QString &alias2) -> QPair<QString, QString>
+                                    VContainer *data, const QString &alias1, const QString &alias2)
+    -> QPair<QString, QString>
 {
-    switch(curveType)
+    QT_WARNING_PUSH
+    QT_WARNING_DISABLE_GCC("-Wswitch-default")
+    QT_WARNING_DISABLE_CLANG("-Wswitch-default")
+
+    switch (curveType)
     {
         case GOType::EllipticalArc:
             return InitArc<VEllipticalArc>(data, segLength, p, curveId, alias1, alias2);
@@ -421,8 +419,8 @@ auto VToolSinglePoint::InitSegments(GOType curveType, qreal segLength, const VPo
                 spl->CutSpline(0, spl1p2, spl1p3, spl2p2, spl2p3, p->name());
             }
 
-            VSpline *spl1 = new VSpline(spl->GetP1(), spl1p2, spl1p3, *p);
-            VSpline *spl2 = new VSpline(*p, spl2p2, spl2p3, spl->GetP4());
+            auto *spl1 = new VSpline(spl->GetP1(), spl1p2, spl1p3, *p);
+            auto *spl2 = new VSpline(*p, spl2p2, spl2p3, spl->GetP4());
 
             if (not VFuzzyComparePossibleNulls(segLength, -1))
             {
@@ -520,7 +518,7 @@ auto VToolSinglePoint::InitSegments(GOType curveType, qreal segLength, const VPo
             break;
     }
 
+    QT_WARNING_POP
+
     return {};
 }
-
-QT_WARNING_POP
