@@ -34,18 +34,16 @@
 #include <QScopedPointer>
 #include <QSharedPointer>
 #include <QUndoStack>
-#include <Qt>
 #include <QtDebug>
 
-#include "../ifc/ifcdef.h"
-#include "../ifc/xml/vdomdocument.h"
-#include "../ifc/xml/vabstractpattern.h"
-#include "../ifc/exception/vexceptionwrongid.h"
 #include "../../undocommands/addtocalc.h"
 #include "../../undocommands/savetooloptions.h"
-#include "../qmuparser/qmuparsererror.h"
-#include "../vpatterndb/vcontainer.h"
+#include "../ifc/exception/vexceptionwrongid.h"
+#include "../ifc/ifcdef.h"
+#include "../ifc/xml/vabstractpattern.h"
+#include "../ifc/xml/vdomdocument.h"
 #include "../vabstracttool.h"
+#include "../vpatterndb/vcontainer.h"
 
 template <class T> class QSharedPointer;
 
@@ -57,10 +55,10 @@ template <class T> class QSharedPointer;
  * @param id object id in container.
  */
 VDrawTool::VDrawTool(VAbstractPattern *doc, VContainer *data, quint32 id, const QString &notes, QObject *parent)
-    : VInteractiveTool(doc, data, id, parent),
-      nameActivDraw(doc->GetNameActivPP()),
-      m_lineType(TypeLineLine),
-      m_notes(notes)
+  : VInteractiveTool(doc, data, id, parent),
+    nameActivDraw(doc->GetNameActivPP()),
+    m_lineType(TypeLineLine),
+    m_notes(notes)
 {
     connect(this->doc, &VAbstractPattern::ChangedActivPP, this, &VDrawTool::ChangedActivDraw);
     connect(this->doc, &VAbstractPattern::ChangedNameDraw, this, &VDrawTool::ChangedNameDraw);
@@ -108,7 +106,7 @@ void VDrawTool::SaveDialogChange(const QString &undoText)
 {
     Q_UNUSED(undoText)
     qCDebug(vTool, "Saving tool options after using dialog");
-    QDomElement oldDomElement = doc->elementById(m_id, getTagName());
+    QDomElement const oldDomElement = doc->elementById(m_id, getTagName());
     if (oldDomElement.isElement())
     {
         QDomElement newDomElement = oldDomElement.cloneNode().toElement();
@@ -125,12 +123,12 @@ void VDrawTool::SaveDialogChange(const QString &undoText)
 
 //---------------------------------------------------------------------------------------------------------------------
 void VDrawTool::ApplyToolOptions(const QList<quint32> &oldDependencies, const QList<quint32> &newDependencies,
-                                const QDomElement &oldDomElement, const QDomElement &newDomElement)
+                                 const QDomElement &oldDomElement, const QDomElement &newDomElement)
 {
     if (newDependencies != oldDependencies || not VDomDocument::Compare(newDomElement, oldDomElement))
     {
-        SaveToolOptions *saveOptions = new SaveToolOptions(oldDomElement, newDomElement, oldDependencies,
-                                                           newDependencies, doc, m_id);
+        auto *saveOptions =
+            new SaveToolOptions(oldDomElement, newDomElement, oldDependencies, newDependencies, doc, m_id);
         connect(saveOptions, &SaveToolOptions::NeedLiteParsing, doc, &VAbstractPattern::LiteParseTree);
         VAbstractApplication::VApp()->getUndoStack()->push(saveOptions);
     }
@@ -152,15 +150,15 @@ void VDrawTool::AddToFile()
 void VDrawTool::SaveOption(QSharedPointer<VGObject> &obj)
 {
     qCDebug(vTool, "Saving tool options");
-    QDomElement oldDomElement = doc->elementById(m_id, getTagName());
+    QDomElement const oldDomElement = doc->elementById(m_id, getTagName());
     if (oldDomElement.isElement())
     {
         QDomElement newDomElement = oldDomElement.cloneNode().toElement();
 
         SaveOptions(newDomElement, obj);
 
-        SaveToolOptions *saveOptions = new SaveToolOptions(oldDomElement, newDomElement, QList<quint32>(),
-                                                           QList<quint32>(), doc, m_id);
+        auto *saveOptions =
+            new SaveToolOptions(oldDomElement, newDomElement, QList<quint32>(), QList<quint32>(), doc, m_id);
         connect(saveOptions, &SaveToolOptions::NeedLiteParsing, doc, &VAbstractPattern::LiteParseTree);
         VAbstractApplication::VApp()->getUndoStack()->push(saveOptions);
     }
@@ -177,11 +175,11 @@ void VDrawTool::SaveOptions(QDomElement &tag, QSharedPointer<VGObject> &obj)
 
     doc->SetAttribute(tag, VDomDocument::AttrId, m_id);
     doc->SetAttributeOrRemoveIf<QString>(tag, AttrNotes, m_notes,
-                                         [](const QString &notes) noexcept {return notes.isEmpty();});
+                                         [](const QString &notes) noexcept { return notes.isEmpty(); });
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VDrawTool::MakeToolTip() const
+auto VDrawTool::MakeToolTip() const -> QString
 {
     return QString();
 }
@@ -194,16 +192,14 @@ void VDrawTool::UpdateNamePosition(quint32 id, const QPointF &pos)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VDrawTool::CorrectDisable(bool disable, const QString &namePP) const
+auto VDrawTool::CorrectDisable(bool disable, const QString &namePP) const -> bool
 {
     if (disable)
     {
         return disable;
     }
-    else
-    {
-        return !(nameActivDraw == namePP);
-    }
+
+    return !(nameActivDraw == namePP);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -223,7 +219,7 @@ void VDrawTool::ReadAttributes()
 //---------------------------------------------------------------------------------------------------------------------
 void VDrawTool::ReadToolAttributes(const QDomElement &domElement)
 {
-    m_notes = doc->GetParametrEmptyString(domElement, AttrNotes);
+    m_notes = VDomDocument::GetParametrEmptyString(domElement, AttrNotes);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -234,7 +230,7 @@ void VDrawTool::EnableToolMove(bool move)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VDrawTool::DetailsMode(bool mode)
+void VDrawTool::SetDetailsMode(bool mode)
 {
     Q_UNUSED(mode)
     // Do nothing.
@@ -260,7 +256,7 @@ void VDrawTool::AddToCalculation(const QDomElement &domElement)
         throw VExceptionWrongId(tr("This id (%1) is not unique.").arg(m_id), duplicate);
     }
 
-    AddToCalc *addToCal = new AddToCalc(domElement, doc);
+    auto *addToCal = new AddToCalc(domElement, doc);
     connect(addToCal, &AddToCalc::NeedFullParsing, doc, &VAbstractPattern::NeedFullParsing);
     VAbstractApplication::VApp()->getUndoStack()->push(addToCal);
 }
@@ -276,7 +272,7 @@ void VDrawTool::AddDependence(QList<quint32> &list, quint32 objectId) const
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VDrawTool::getLineType() const
+auto VDrawTool::getLineType() const -> QString
 {
     return m_lineType;
 }
@@ -291,14 +287,14 @@ void VDrawTool::SetLineType(const QString &value)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool VDrawTool::IsLabelVisible(quint32 id) const
+auto VDrawTool::IsLabelVisible(quint32 id) const -> bool
 {
     Q_UNUSED(id)
     return false;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VDrawTool::GetNotes() const
+auto VDrawTool::GetNotes() const -> QString
 {
     return m_notes;
 }
