@@ -34,24 +34,30 @@
 #include <QPen>
 #include <QPointF>
 #include <QSharedPointer>
-#include <Qt>
 #include <QtDebug>
 #include <new>
 
 #include "../../dialogs/tools/dialogline.h"
 #include "../../dialogs/tools/dialogtool.h"
-#include "../../visualization/visualization.h"
 #include "../../visualization/line/vistoolline.h"
+#include "../../visualization/visualization.h"
 #include "../ifc/exception/vexception.h"
 #include "../ifc/ifcdef.h"
+#include "../vabstracttool.h"
 #include "../vgeometry/vgobject.h"
 #include "../vgeometry/vpointf.h"
+#include "../vmisc/theme/vscenestylesheet.h"
 #include "../vpatterndb/vcontainer.h"
-#include "../vwidgets/vmaingraphicsscene.h"
 #include "../vwidgets/global.h"
-#include "../vabstracttool.h"
+#include "../vwidgets/vmaingraphicsscene.h"
 #include "vdrawtool.h"
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
+#include "../vmisc/compatibility.h"
+#endif
+
+using namespace Qt::Literals::StringLiterals;
+
 template <class T> class QSharedPointer;
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -61,18 +67,18 @@ template <class T> class QSharedPointer;
  * @param parent parent object.
  */
 VToolLine::VToolLine(const VToolLineInitData &initData, QGraphicsItem *parent)
-    :VDrawTool(initData.doc, initData.data, initData.id, initData.notes),
-      VScaledLine(parent),
-      firstPoint(initData.firstPoint),
-      secondPoint(initData.secondPoint),
-      lineColor(initData.lineColor),
-      m_acceptHoverEvents(true)
+  : VDrawTool(initData.doc, initData.data, initData.id, initData.notes),
+    VScaledLine(VColorRole::CustomColor, parent),
+    firstPoint(initData.firstPoint),
+    secondPoint(initData.secondPoint),
+    lineColor(initData.lineColor),
+    m_acceptHoverEvents(true)
 {
     SetBoldLine(false);
     this->m_lineType = initData.typeLine;
-    //Line
+    // Line
     RefreshGeometry();
-    this->setFlag(QGraphicsItem::ItemIsFocusable, true);// For keyboard input focus
+    this->setFlag(QGraphicsItem::ItemIsFocusable, true); // For keyboard input focus
     this->setAcceptHoverEvents(m_acceptHoverEvents);
 
     ToolCreation(initData.typeCreation);
@@ -82,7 +88,7 @@ VToolLine::VToolLine(const VToolLineInitData &initData, QGraphicsItem *parent)
 /**
  * @brief setDialog set dialog when user want change tool option.
  */
-void VToolLine::setDialog()
+void VToolLine::SetDialog()
 {
     SCASSERT(not m_dialog.isNull())
     const QPointer<DialogLine> dialogTool = qobject_cast<DialogLine *>(m_dialog);
@@ -102,8 +108,8 @@ void VToolLine::setDialog()
  * @param doc dom document container.
  * @param data container with variables.
  */
-VToolLine *VToolLine::Create(const QPointer<DialogTool> &dialog, VMainGraphicsScene *scene, VAbstractPattern *doc,
-                             VContainer *data)
+auto VToolLine::Create(const QPointer<DialogTool> &dialog, VMainGraphicsScene *scene, VAbstractPattern *doc,
+                       VContainer *data) -> VToolLine *
 {
     SCASSERT(not dialog.isNull())
     const QPointer<DialogLine> dialogTool = qobject_cast<DialogLine *>(dialog);
@@ -134,7 +140,7 @@ VToolLine *VToolLine::Create(const QPointer<DialogTool> &dialog, VMainGraphicsSc
  * @brief Create help create tool.
  * @param initData init data.
  */
-VToolLine * VToolLine::Create(VToolLineInitData initData)
+auto VToolLine::Create(VToolLineInitData initData) -> VToolLine *
 {
     SCASSERT(initData.scene != nullptr)
     SCASSERT(initData.doc != nullptr)
@@ -157,7 +163,7 @@ VToolLine * VToolLine::Create(VToolLineInitData initData)
     if (initData.parse == Document::FullParse)
     {
         VAbstractTool::AddRecord(initData.id, Tool::Line, initData.doc);
-        VToolLine *line = new VToolLine(initData);
+        auto *line = new VToolLine(initData);
         initData.scene->addItem(line);
         InitDrawToolConnections(initData.scene, line);
         connect(initData.scene, &VMainGraphicsScene::EnableLineItemSelection, line, &VToolLine::AllowSelecting);
@@ -175,7 +181,7 @@ VToolLine * VToolLine::Create(VToolLineInitData initData)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VToolLine::getTagName() const
+auto VToolLine::getTagName() const -> QString
 {
     return VDomDocument::TagLine;
 }
@@ -185,7 +191,7 @@ void VToolLine::paint(QPainter *painter, const QStyleOptionGraphicsItem *option,
 {
     // Don't set pen width. Parent should take care of it.
     QPen lPen = pen();
-    lPen.setColor(CorrectColor(this, lineColor));
+    lPen.setColor(VSceneStylesheet::CorrectToolColor(this, VSceneStylesheet::CorrectToolColorForDarkTheme(lineColor)));
     lPen.setStyle(LineStyleToPenStyle(m_lineType));
     setPen(lPen);
 
@@ -193,13 +199,13 @@ void VToolLine::paint(QPainter *painter, const QStyleOptionGraphicsItem *option,
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VToolLine::FirstPointName() const
+auto VToolLine::FirstPointName() const -> QString
 {
     return VAbstractTool::data.GetGObject(firstPoint)->name();
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VToolLine::SecondPointName() const
+auto VToolLine::SecondPointName() const -> QString
 {
     return VAbstractTool::data.GetGObject(secondPoint)->name();
 }
@@ -254,10 +260,10 @@ void VToolLine::ShowContextMenu(QGraphicsSceneContextMenuEvent *event, quint32 i
     {
         ContextMenu<DialogLine>(event);
     }
-    catch(const VExceptionToolWasDeleted &e)
+    catch (const VExceptionToolWasDeleted &e)
     {
         Q_UNUSED(e)
-        return;//Leave this method immediately!!!
+        return; // Leave this method immediately!!!
     }
 }
 
@@ -278,7 +284,7 @@ void VToolLine::contextMenuEvent(QGraphicsSceneContextMenuEvent *event)
 void VToolLine::AddToFile()
 {
     QDomElement domElement = doc->createElement(getTagName());
-    QSharedPointer<VGObject> obj = QSharedPointer<VGObject> ();
+    auto obj = QSharedPointer<VGObject>();
     SaveOptions(domElement, obj);
     AddToCalculation(domElement);
 }
@@ -336,7 +342,7 @@ void VToolLine::RemoveReferens()
  * @param value value.
  * @return value.
  */
-QVariant VToolLine::itemChange(QGraphicsItem::GraphicsItemChange change, const QVariant &value)
+auto VToolLine::itemChange(QGraphicsItem::GraphicsItemChange change, const QVariant &value) -> QVariant
 {
     if (change == QGraphicsItem::ItemSelectedHasChanged)
     {
@@ -360,24 +366,23 @@ void VToolLine::keyReleaseEvent(QKeyEvent *event)
             {
                 DeleteToolWithConfirm();
             }
-            catch(const VExceptionToolWasDeleted &e)
+            catch (const VExceptionToolWasDeleted &e)
             {
                 Q_UNUSED(e)
-                return;//Leave this method immediately!!!
+                return; // Leave this method immediately!!!
             }
             break;
         default:
             break;
     }
-    QGraphicsItem::keyReleaseEvent ( event );
+    QGraphicsItem::keyReleaseEvent(event);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 /**
  * @brief SaveDialog save options into file after change in dialog.
  */
-void VToolLine::SaveDialog(QDomElement &domElement, QList<quint32> &oldDependencies,
-                           QList<quint32> &newDependencies)
+void VToolLine::SaveDialog(QDomElement &domElement, QList<quint32> &oldDependencies, QList<quint32> &newDependencies)
 {
     SCASSERT(not m_dialog.isNull())
     const QPointer<DialogLine> dialogTool = qobject_cast<DialogLine *>(m_dialog);
@@ -393,7 +398,7 @@ void VToolLine::SaveDialog(QDomElement &domElement, QList<quint32> &oldDependenc
     doc->SetAttribute(domElement, AttrTypeLine, dialogTool->GetTypeLine());
     doc->SetAttribute(domElement, AttrLineColor, dialogTool->GetLineColor());
     doc->SetAttributeOrRemoveIf<QString>(domElement, AttrNotes, dialogTool->GetNotes(),
-                                         [](const QString &notes) noexcept {return notes.isEmpty();});
+                                         [](const QString &notes) noexcept { return notes.isEmpty(); });
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -435,21 +440,20 @@ void VToolLine::SetVisualization()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VToolLine::MakeToolTip() const
+auto VToolLine::MakeToolTip() const -> QString
 {
     const QSharedPointer<VPointF> first = VAbstractTool::data.GeometricObject<VPointF>(firstPoint);
     const QSharedPointer<VPointF> second = VAbstractTool::data.GeometricObject<VPointF>(secondPoint);
 
     const QLineF line(static_cast<QPointF>(*first), static_cast<QPointF>(*second));
 
-    const QString toolTip = QString("<table>"
-                                    "<tr> <td><b>%1:</b> %2 %3</td> </tr>"
-                                    "<tr> <td><b>%4:</b> %5°</td> </tr>"
-                                    "</table>")
-            .arg(tr("Length"))
-            .arg(VAbstractValApplication::VApp()->fromPixel(line.length()))
-            .arg(UnitsToStr(VAbstractValApplication::VApp()->patternUnits(), true), tr("Angle"))
-            .arg(line.angle());
+    const QString toolTip = u"<table>"
+                            u"<tr> <td><b>%1:</b> %2 %3</td> </tr>"
+                            u"<tr> <td><b>%4:</b> %5°</td> </tr>"
+                            u"</table>"_s.arg(tr("Length"))
+                                .arg(VAbstractValApplication::VApp()->fromPixel(line.length()))
+                                .arg(UnitsToStr(VAbstractValApplication::VApp()->patternUnits(), true), tr("Angle"))
+                                .arg(line.angle());
     return toolTip;
 }
 
@@ -465,7 +469,7 @@ void VToolLine::ShowVisualization(bool show)
         }
         else
         {
-            if (VisToolLine *visual = qobject_cast<VisToolLine *>(vis))
+            if (auto *visual = qobject_cast<VisToolLine *>(vis))
             {
                 visual->show();
             }
@@ -483,12 +487,12 @@ void VToolLine::SetLineType(const QString &value)
 {
     m_lineType = value;
 
-    QSharedPointer<VGObject> obj;//We don't have object for line in data container. Just will send an empty object.
+    QSharedPointer<VGObject> obj; // We don't have object for line in data container. Just will send an empty object.
     SaveOption(obj);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VToolLine::GetLineColor() const
+auto VToolLine::GetLineColor() const -> QString
 {
     return lineColor;
 }
@@ -498,7 +502,7 @@ void VToolLine::SetLineColor(const QString &value)
 {
     lineColor = value;
 
-    QSharedPointer<VGObject> obj;//We don't have object for line in data container. Just will send an empty object.
+    QSharedPointer<VGObject> obj; // We don't have object for line in data container. Just will send an empty object.
     SaveOption(obj);
 }
 
@@ -507,7 +511,7 @@ void VToolLine::SetNotes(const QString &notes)
 {
     m_notes = notes;
 
-    QSharedPointer<VGObject> obj;//We don't have object for line in data container. Just will send an empty object.
+    QSharedPointer<VGObject> obj; // We don't have object for line in data container. Just will send an empty object.
     SaveOption(obj);
 }
 
