@@ -40,28 +40,25 @@
 #include <QPoint>
 #include <QRectF>
 #include <QSharedPointer>
-#include <QStaticStringData>
-#include <QStringData>
-#include <QStringDataPtr>
-#include <Qt>
-#include <new>
 
 #include "../../../vgeometry/vpointf.h"
 #include "../../../vwidgets/vgraphicssimpletextitem.h"
-#include "../ifc/xml/vdomdocument.h"
+#include "../../undocommands/label/movelabel.h"
+#include "../../undocommands/label/showlabel.h"
 #include "../ifc/ifcdef.h"
+#include "../ifc/xml/vdomdocument.h"
+#include "../vabstracttool.h"
+#include "../vdatatool.h"
+#include "../vmisc/theme/themeDef.h"
 #include "../vmisc/vabstractapplication.h"
 #include "../vpatterndb/vcontainer.h"
 #include "../vpatterndb/vpiecenode.h"
+#include "../vtoolseamallowance.h"
+#include "../vwidgets/global.h"
+#include "../vwidgets/scalesceneitems.h"
 #include "../vwidgets/vmaingraphicsscene.h"
 #include "../vwidgets/vmaingraphicsview.h"
-#include "../vwidgets/global.h"
-#include "../vabstracttool.h"
-#include "../vdatatool.h"
 #include "vabstractnode.h"
-#include "../../undocommands/label/movelabel.h"
-#include "../../undocommands/label/showlabel.h"
-#include "../vtoolseamallowance.h"
 
 const QString VNodePoint::ToolType = QStringLiteral("modeling");
 
@@ -71,7 +68,7 @@ enum class ContextMenuOption : int
 {
     NoSelection,
     ShowLabel,
-    Passmark,
+    NonePassmark,
     Exclude,
     ByLength,
     ByPointsIntersection,
@@ -91,18 +88,22 @@ enum class ContextMenuOption : int
     TwoLines,
     ThreeLines,
     TMark,
-    VMark,
-    VMark2,
+    ExternalVMark,
+    InternalVMark,
     UMark,
     BoxMark,
+    CheckMark,
     Option,
     InLayout,
     ForbidFlipping,
     ForceFlipping,
+    ShowFullPiece,
+    ResetLabelTemplate,
     Remove,
+    TurnPoint,
     LAST_ONE_DO_NOT_USE
 };
-}
+} // namespace
 
 //---------------------------------------------------------------------------------------------------------------------
 /**
@@ -111,18 +112,18 @@ enum class ContextMenuOption : int
  * @param parent parent object.
  */
 VNodePoint::VNodePoint(const VAbstractNodeInitData &initData, QObject *qoParent, QGraphicsItem *parent)
-    : VAbstractNode(initData.doc, initData.data, initData.id, initData.idObject, initData.drawName, initData.idTool,
-                    qoParent),
-      VScenePoint(parent)
+  : VAbstractNode(initData.doc, initData.data, initData.id, initData.idObject, initData.drawName, initData.idTool,
+                  qoParent),
+    VScenePoint(VColorRole::PiecePointColor, parent)
 {
+    m_namePoint->SetTextColor(VColorRole::PieceNodeLabelColor);
+    m_namePoint->SetTextHoverColor(VColorRole::PieceNodeLabelHoverColor);
     m_namePoint->SetShowParentTooltip(false);
     connect(m_namePoint, &VGraphicsSimpleTextItem::PointChoosed, this, &VNodePoint::PointChoosed);
     connect(m_namePoint, &VGraphicsSimpleTextItem::NameChangePosition, this, &VNodePoint::NameChangePosition);
-    connect(m_namePoint, &VGraphicsSimpleTextItem::ShowContextMenu,
-            this, [this](QGraphicsSceneContextMenuEvent *event)
-    {
-        contextMenuEvent(event);
-    });
+    connect(m_namePoint, &VGraphicsSimpleTextItem::ShowContextMenu, this,
+            [this](QGraphicsSceneContextMenuEvent *event) { contextMenuEvent(event); });
+    m_lineName->SetColorRole(VColorRole::PieceNodeLabelLineColor);
     RefreshPointGeometry(*VAbstractTool::data.GeometricObject<VPointF>(initData.id));
     ToolCreation(initData.typeCreation);
     setCursor(Qt::ArrowCursor);
@@ -138,9 +139,9 @@ void VNodePoint::Create(const VAbstractNodeInitData &initData)
     if (initData.parse == Document::FullParse)
     {
         VAbstractTool::AddRecord(initData.id, Tool::NodePoint, initData.doc);
-        //TODO Need create garbage collector and remove all nodes, what we don't use.
-        //Better check garbage before each saving file. Check only modeling tags.
-        VNodePoint *point = new VNodePoint(initData);
+        // TODO Need create garbage collector and remove all nodes, what we don't use.
+        // Better check garbage before each saving file. Check only modeling tags.
+        auto *point = new VNodePoint(initData);
 
         connect(initData.scene, &VMainGraphicsScene::EnableToolMove, point, &VNodePoint::EnableToolMove);
         connect(initData.scene, &VMainGraphicsScene::EnablePointItemHover, point, &VNodePoint::AllowHover);
@@ -150,16 +151,16 @@ void VNodePoint::Create(const VAbstractNodeInitData &initData)
         VAbstractPattern::AddTool(initData.id, point);
         if (initData.idTool != NULL_ID)
         {
-            //Some nodes we don't show on scene. Tool that create this nodes must free memory.
+            // Some nodes we don't show on scene. Tool that create this nodes must free memory.
             VDataTool *tool = VAbstractPattern::getTool(initData.idTool);
             SCASSERT(tool != nullptr)
-            point->setParent(tool);// Adopted by a tool
+            point->setParent(tool); // Adopted by a tool
         }
         else
         {
             // Try to prevent memory leak
-            initData.scene->addItem(point);// First adopted by scene
-            point->hide();// If no one will use node, it will stay hidden
+            initData.scene->addItem(point); // First adopted by scene
+            point->hide();                  // If no one will use node, it will stay hidden
             point->SetParentType(ParentType::Scene);
         }
     }
@@ -170,7 +171,7 @@ void VNodePoint::Create(const VAbstractNodeInitData &initData)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QString VNodePoint::getTagName() const
+auto VNodePoint::getTagName() const -> QString
 {
     return VAbstractPattern::TagPoint;
 }
@@ -180,7 +181,7 @@ void VNodePoint::ChangeLabelPosition(quint32 id, const QPointF &pos)
 {
     if (id == m_id)
     {
-        QSharedPointer<VPointF> point = VAbstractTool::data.GeometricObject<VPointF>(id);
+        QSharedPointer<VPointF> const point = VAbstractTool::data.GeometricObject<VPointF>(id);
         point->setMx(pos.x());
         point->setMy(pos.y());
         m_namePoint->SetRealPos(pos);
@@ -259,12 +260,12 @@ void VNodePoint::mousePressEvent(QGraphicsSceneMouseEvent *event)
     VScenePoint::mousePressEvent(event);
 
     // Somehow clicking on notselectable object do not clean previous selections.
-    if (not (flags() & ItemIsSelectable) && scene())
+    if (not(flags() & ItemIsSelectable) && scene())
     {
         scene()->clearSelection();
     }
 
-    event->accept();// Special for not selectable item first need to call standard mousePressEvent then accept event
+    event->accept(); // Special for not selectable item first need to call standard mousePressEvent then accept event
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -307,50 +308,70 @@ void VNodePoint::HideNode()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QHash<int, QAction *> VNodePoint::InitContextMenu(QMenu *menu, vidtype pieceId, quint32 referens)
+auto VNodePoint::InitContextMenu(QMenu *menu, vidtype pieceId, quint32 referens) -> QHash<int, QAction *>
 {
     SCASSERT(menu != nullptr)
 
     QHash<int, QAction *> contextMenu;
 
-    QAction *actionShowLabel = menu->addAction(tr("Show label"));
+    QAction *actionShowLabel = menu->addAction(QCoreApplication::translate("VNodePoint", "Show label"));
     actionShowLabel->setCheckable(true);
     actionShowLabel->setChecked(VAbstractTool::data.GeometricObject<VPointF>(m_id)->IsShowLabel());
     contextMenu.insert(static_cast<int>(ContextMenuOption::ShowLabel), actionShowLabel);
 
     InitPassmarkMenu(menu, pieceId, contextMenu);
 
-    contextMenu.insert(static_cast<int>(ContextMenuOption::Exclude), menu->addAction(tr("Exclude")));
+    contextMenu.insert(static_cast<int>(ContextMenuOption::Exclude),
+                       menu->addAction(QCoreApplication::translate("VNodePoint", "Exclude")));
 
     InitAngleTypeMenu(menu, pieceId, contextMenu);
     InitPassmarkAngleTypeMenu(menu, pieceId, contextMenu);
-    InitPassmarkLineTypeMenu(menu, pieceId, contextMenu);
 
-    QAction *separatorAct = new QAction(this);
+    auto *separatorAct = new QAction(this);
     separatorAct->setSeparator(true);
     menu->addAction(separatorAct);
 
-    contextMenu.insert(static_cast<int>(ContextMenuOption::Option),
-                       menu->addAction(QIcon::fromTheme(QStringLiteral("preferences-other")), tr("Options")));
+    contextMenu.insert(
+        static_cast<int>(ContextMenuOption::Option),
+        menu->addAction(FromTheme(VThemeIcon::PreferencesOther), QCoreApplication::translate("VNodePoint", "Options")));
 
     const VPiece detail = VAbstractTool::data.GetPiece(pieceId);
 
-    QAction *inLayoutOption = menu->addAction(tr("In layout"));
+    QAction *inLayoutOption = menu->addAction(QCoreApplication::translate("VNodePoint", "In layout"));
     inLayoutOption->setCheckable(true);
     inLayoutOption->setChecked(detail.IsInLayout());
     contextMenu.insert(static_cast<int>(ContextMenuOption::InLayout), inLayoutOption);
 
-    QAction *forbidFlippingOption = menu->addAction(tr("Forbid flipping"));
+    QAction *forbidFlippingOption = menu->addAction(QCoreApplication::translate("VNodePoint", "Forbid flipping"));
     forbidFlippingOption->setCheckable(true);
     forbidFlippingOption->setChecked(detail.IsForbidFlipping());
     contextMenu.insert(static_cast<int>(ContextMenuOption::ForbidFlipping), forbidFlippingOption);
 
-    QAction *forceFlippingOption = menu->addAction(tr("Force flipping"));
+    QAction *forceFlippingOption = menu->addAction(QCoreApplication::translate("VNodePoint", "Force flipping"));
     forceFlippingOption->setCheckable(true);
     forceFlippingOption->setChecked(detail.IsForceFlipping());
     contextMenu.insert(static_cast<int>(ContextMenuOption::ForceFlipping), forceFlippingOption);
 
-    QAction *actionRemove = menu->addAction(QIcon::fromTheme(QStringLiteral("edit-delete")), tr("Delete"));
+    QAction *showFullPieceOption = menu->addAction(QCoreApplication::translate("VNodePoint", "Show full piece"));
+    showFullPieceOption->setCheckable(true);
+    {
+        const QLineF mirrorLine = detail.SeamAllowanceMirrorLine(&(VAbstractTool::data));
+        showFullPieceOption->setEnabled(not mirrorLine.isNull());
+        showFullPieceOption->setChecked(true);
+        if (not mirrorLine.isNull())
+        {
+            showFullPieceOption->setChecked(detail.IsShowFullPiece());
+        }
+    }
+    contextMenu.insert(static_cast<int>(ContextMenuOption::ShowFullPiece), showFullPieceOption);
+
+    QAction *reseteLabelTemplateOption =
+        menu->addAction(QCoreApplication::translate("VNodePoint", "Reset piece label template"));
+    reseteLabelTemplateOption->setEnabled(not doc->GetDefaultPieceLabelPath().isEmpty());
+    contextMenu.insert(static_cast<int>(ContextMenuOption::ResetLabelTemplate), reseteLabelTemplateOption);
+
+    QAction *actionRemove =
+        menu->addAction(FromTheme(VThemeIcon::EditDelete), QCoreApplication::translate("VNodePoint", "Delete"));
     referens > 1 ? actionRemove->setEnabled(false) : actionRemove->setEnabled(true);
     contextMenu.insert(static_cast<int>(ContextMenuOption::Remove), actionRemove);
 
@@ -363,15 +384,55 @@ void VNodePoint::InitPassmarkMenu(QMenu *menu, vidtype pieceId, QHash<int, QActi
     SCASSERT(menu != nullptr)
 
     const VPiece detail = VAbstractTool::data.GetPiece(pieceId);
-    const int nodeIndex = detail.GetPath().indexOfNode(m_id);
-    if (nodeIndex != -1)
+    const VPiecePath &path = detail.GetPath();
+    const int nodeIndex = path.indexOfNode(m_id);
+    if (nodeIndex == -1)
     {
-        QAction *actionPassmark = menu->addAction(tr("Passmark"));
-        actionPassmark->setCheckable(true);
-        actionPassmark->setChecked(detail.GetPath().at(nodeIndex).IsPassmark());
-
-        contextMenu.insert(static_cast<int>(ContextMenuOption::Passmark), actionPassmark);
+        return;
     }
+
+    const VPieceNode &node = path.at(nodeIndex);
+
+    QMenu *passmarkSubmenu = menu->addMenu(tr("Passmark"));
+
+    QAction *actionNonePassmark = passmarkSubmenu->addAction(tr("None"));
+    actionNonePassmark->setCheckable(true);
+    actionNonePassmark->setChecked(!node.IsPassmark());
+    contextMenu.insert(static_cast<int>(ContextMenuOption::NonePassmark), actionNonePassmark);
+
+    Q_STATIC_ASSERT_X(static_cast<int>(PassmarkLineType::LAST_ONE_DO_NOT_USE) == 9, "Not all types were handled.");
+
+    auto InitPassmarkLineTypeAction = [passmarkSubmenu, node](const QString &name, PassmarkLineType lineType)
+    {
+        QAction *action = passmarkSubmenu->addAction(name);
+        action->setCheckable(true);
+        action->setChecked(node.IsPassmark() && lineType == node.GetPassmarkLineType());
+        return action;
+    };
+
+    contextMenu.insert(static_cast<int>(ContextMenuOption::OneLine),
+                       InitPassmarkLineTypeAction(tr("One line"), PassmarkLineType::OneLine));
+    contextMenu.insert(static_cast<int>(ContextMenuOption::TwoLines),
+                       InitPassmarkLineTypeAction(tr("Two lines"), PassmarkLineType::TwoLines));
+    contextMenu.insert(static_cast<int>(ContextMenuOption::ThreeLines),
+                       InitPassmarkLineTypeAction(tr("Three lines"), PassmarkLineType::ThreeLines));
+    contextMenu.insert(static_cast<int>(ContextMenuOption::TMark),
+                       InitPassmarkLineTypeAction(tr("T mark"), PassmarkLineType::TMark));
+    contextMenu.insert(static_cast<int>(ContextMenuOption::ExternalVMark),
+                       InitPassmarkLineTypeAction(tr("External V mark"), PassmarkLineType::ExternalVMark));
+    contextMenu.insert(static_cast<int>(ContextMenuOption::InternalVMark),
+                       InitPassmarkLineTypeAction(tr("Internal V mark"), PassmarkLineType::InternalVMark));
+    contextMenu.insert(static_cast<int>(ContextMenuOption::UMark),
+                       InitPassmarkLineTypeAction(tr("U mark"), PassmarkLineType::UMark));
+    contextMenu.insert(static_cast<int>(ContextMenuOption::BoxMark),
+                       InitPassmarkLineTypeAction(tr("Box mark"), PassmarkLineType::BoxMark));
+    contextMenu.insert(static_cast<int>(ContextMenuOption::CheckMark),
+                       InitPassmarkLineTypeAction(tr("Check mark"), PassmarkLineType::CheckMark));
+
+    QAction *actionTurnPoint = menu->addAction(tr("Turn point"));
+    actionTurnPoint->setCheckable(true);
+    actionTurnPoint->setChecked(node.IsTurnPoint());
+    contextMenu.insert(static_cast<int>(ContextMenuOption::TurnPoint), actionTurnPoint);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -381,11 +442,11 @@ void VNodePoint::InitAngleTypeMenu(QMenu *menu, vidtype pieceId, QHash<int, QAct
     PieceNodeAngle curType = PieceNodeAngle::ByLength;
 
     const VPiece detail = VAbstractTool::data.GetPiece(pieceId);
-    const int nodeIndex = detail.GetPath().indexOfNode(m_id);
+    const VPiecePath &path = detail.GetPath();
+    const int nodeIndex = path.indexOfNode(m_id);
     if (nodeIndex != -1)
     {
-        const VPieceNode &node = detail.GetPath().at(nodeIndex);
-        curType = node.GetAngleType();
+        curType = path.at(nodeIndex).GetAngleType();
 
         angleTypeMenu->setEnabled(detail.IsSeamAllowance() && not detail.IsSeamAllowanceBuiltIn());
     }
@@ -420,28 +481,24 @@ void VNodePoint::InitAngleTypeMenu(QMenu *menu, vidtype pieceId, QHash<int, QAct
 //---------------------------------------------------------------------------------------------------------------------
 void VNodePoint::InitPassmarkAngleTypeMenu(QMenu *menu, vidtype pieceId, QHash<int, QAction *> &contextMenu)
 {
-    QMenu *passmarkAngleMenu = menu->addMenu(tr("Passmark angle"));
-    PassmarkAngleType passmarkAngleCurType = PassmarkAngleType::Straightforward;
-
     const VPiece detail = VAbstractTool::data.GetPiece(pieceId);
-    const int nodeIndex = detail.GetPath().indexOfNode(m_id);
-    if (nodeIndex != -1)
+    const VPiecePath &path = detail.GetPath();
+    const int nodeIndex = path.indexOfNode(m_id);
+    if (nodeIndex == -1)
     {
-        const VPieceNode &node = detail.GetPath().at(nodeIndex);
-        passmarkAngleMenu->setEnabled(node.IsPassmark());
-        passmarkAngleCurType = node.GetPassmarkAngleType();
-    }
-    else
-    {
-        passmarkAngleMenu->setVisible(false);
+        return;
     }
 
-    auto InitPassmarkAngleAction = [passmarkAngleMenu, passmarkAngleCurType](const QString &name,
-            PassmarkAngleType checkType)
+    const VPieceNode &node = path.at(nodeIndex);
+
+    QMenu *passmarkAngleMenu = menu->addMenu(tr("Passmark angle"));
+
+    auto InitPassmarkAngleAction = [passmarkAngleMenu, node](const QString &name, PassmarkAngleType checkType)
     {
         QAction *action = passmarkAngleMenu->addAction(name);
         action->setCheckable(true);
-        action->setChecked(passmarkAngleCurType == checkType);
+        action->setChecked(node.IsPassmark() && node.GetPassmarkAngleType() == checkType);
+        action->setEnabled(node.IsPassmark());
         return action;
     };
 
@@ -452,68 +509,20 @@ void VNodePoint::InitPassmarkAngleTypeMenu(QMenu *menu, vidtype pieceId, QHash<i
                        InitPassmarkAngleAction(tr("Bisector"), PassmarkAngleType::Bisector));
     contextMenu.insert(static_cast<int>(ContextMenuOption::Intersection),
                        InitPassmarkAngleAction(tr("Intersection"), PassmarkAngleType::Intersection));
-    contextMenu.insert(static_cast<int>(ContextMenuOption::IntersectionOnlyLeft),
-                       InitPassmarkAngleAction(tr("Intersection (only left)"),
-                                               PassmarkAngleType::IntersectionOnlyLeft));
-    contextMenu.insert(static_cast<int>(ContextMenuOption::IntersectionOnlyRight),
-                       InitPassmarkAngleAction(tr("Intersection (only right)"),
-                                               PassmarkAngleType::IntersectionOnlyRight));
+    contextMenu.insert(
+        static_cast<int>(ContextMenuOption::IntersectionOnlyLeft),
+        InitPassmarkAngleAction(tr("Intersection (only left)"), PassmarkAngleType::IntersectionOnlyLeft));
+    contextMenu.insert(
+        static_cast<int>(ContextMenuOption::IntersectionOnlyRight),
+        InitPassmarkAngleAction(tr("Intersection (only right)"), PassmarkAngleType::IntersectionOnlyRight));
     contextMenu.insert(static_cast<int>(ContextMenuOption::Intersection2),
                        InitPassmarkAngleAction(tr("Intersection 2"), PassmarkAngleType::Intersection2));
-    contextMenu.insert(static_cast<int>(ContextMenuOption::Intersection2OnlyLeft),
-                       InitPassmarkAngleAction(tr("Intersection 2 (only left)"),
-                                               PassmarkAngleType::Intersection2OnlyLeft));
-    contextMenu.insert(static_cast<int>(ContextMenuOption::Intersection2OnlyRight),
-                       InitPassmarkAngleAction(tr("Intersection 2 (only right)"),
-                                               PassmarkAngleType::Intersection2OnlyRight));
-}
-
-//---------------------------------------------------------------------------------------------------------------------
-void VNodePoint::InitPassmarkLineTypeMenu(QMenu *menu, vidtype pieceId, QHash<int, QAction *> &contextMenu)
-{
-    QMenu *passmarkLineTypeMenu = menu->addMenu(tr("Passmark mark"));
-    PassmarkLineType passmarkLineCurType = PassmarkLineType::OneLine;
-
-    const VPiece detail = VAbstractTool::data.GetPiece(pieceId);
-    const int nodeIndex = detail.GetPath().indexOfNode(m_id);
-    if (nodeIndex != -1)
-    {
-        const VPieceNode &node = detail.GetPath().at(nodeIndex);
-        passmarkLineTypeMenu->setEnabled(node.IsPassmark());
-        passmarkLineCurType = node.GetPassmarkLineType();
-    }
-    else
-    {
-        passmarkLineTypeMenu->setVisible(false);
-    }
-
-    auto InitPassmarkLineTypeAction = [passmarkLineTypeMenu, passmarkLineCurType](const QString &name,
-            PassmarkLineType checkType)
-    {
-        QAction *action = passmarkLineTypeMenu->addAction(name);
-        action->setCheckable(true);
-        action->setChecked(passmarkLineCurType == checkType);
-        return action;
-    };
-
-    Q_STATIC_ASSERT_X(static_cast<int>(PassmarkLineType::LAST_ONE_DO_NOT_USE) == 8, "Not all types were handled.");
-    contextMenu.insert(static_cast<int>(ContextMenuOption::OneLine),
-                       InitPassmarkLineTypeAction(tr("One line"), PassmarkLineType::OneLine));
-    contextMenu.insert(static_cast<int>(ContextMenuOption::TwoLines),
-                       InitPassmarkLineTypeAction(tr("Two lines"), PassmarkLineType::TwoLines));
-    contextMenu.insert(static_cast<int>(ContextMenuOption::ThreeLines),
-                       InitPassmarkLineTypeAction(tr("Three lines"), PassmarkLineType::ThreeLines));
-    contextMenu.insert(static_cast<int>(ContextMenuOption::TMark),
-                       InitPassmarkLineTypeAction(tr("T mark"), PassmarkLineType::TMark));
-    contextMenu.insert(static_cast<int>(ContextMenuOption::VMark),
-                       InitPassmarkLineTypeAction(tr("V mark"), PassmarkLineType::VMark));
-    contextMenu.insert(static_cast<int>(ContextMenuOption::VMark2),
-                       InitPassmarkLineTypeAction(tr("V mark 2"), PassmarkLineType::VMark2));
-    contextMenu.insert(static_cast<int>(ContextMenuOption::UMark),
-                       InitPassmarkLineTypeAction(tr("U mark"), PassmarkLineType::UMark));
-    contextMenu.insert(static_cast<int>(ContextMenuOption::BoxMark),
-                       InitPassmarkLineTypeAction(tr("Box mark"), PassmarkLineType::BoxMark));
-
+    contextMenu.insert(
+        static_cast<int>(ContextMenuOption::Intersection2OnlyLeft),
+        InitPassmarkAngleAction(tr("Intersection 2 (only left)"), PassmarkAngleType::Intersection2OnlyLeft));
+    contextMenu.insert(
+        static_cast<int>(ContextMenuOption::Intersection2OnlyRight),
+        InitPassmarkAngleAction(tr("Intersection 2 (only right)"), PassmarkAngleType::Intersection2OnlyRight));
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -524,168 +533,186 @@ void VNodePoint::contextMenuEvent(QGraphicsSceneContextMenuEvent *event)
         return;
     }
 
-    if (VToolSeamAllowance *piece = qgraphicsitem_cast<VToolSeamAllowance *>(parentItem()))
+    auto *piece = qgraphicsitem_cast<VToolSeamAllowance *>(parentItem());
+    if (piece == nullptr)
     {
-        QMenu menu;
-        QHash<int, QAction *> contextMenu = InitContextMenu(&menu, piece->getId(), piece->referens());
-
-        PieceNodeAngle angleCurType = PieceNodeAngle::ByLength;
-        PassmarkAngleType passmarkAngleCurType = PassmarkAngleType::Straightforward;
-        PassmarkLineType passmarkLineCurType = PassmarkLineType::OneLine;
-        bool isPassmark = false;
-
-        const VPiece detail = VAbstractTool::data.GetPiece(piece->getId());
-        const int nodeIndex = detail.GetPath().indexOfNode(m_id);
-        if (nodeIndex != -1)
-        {
-            const VPieceNode &node = detail.GetPath().at(nodeIndex);
-            angleCurType = node.GetAngleType();
-            passmarkAngleCurType = node.GetPassmarkAngleType();
-            passmarkLineCurType = node.GetPassmarkLineType();
-            isPassmark = node.IsPassmark();
-        }
-
-        auto SelectSeamAllowanceAngle = [angleCurType, this](PieceNodeAngle type)
-        {
-            if (angleCurType != type)
-            {
-                emit ToggleSeamAllowanceAngleType(m_id, type);
-            }
-        };
-
-        auto SelectPassmarkAngle = [passmarkAngleCurType, this](PassmarkAngleType type)
-        {
-            if (passmarkAngleCurType != type)
-            {
-                emit TogglePassmarkAngleType(m_id, type);
-            }
-        };
-
-        auto SelectPassmarkLine = [passmarkLineCurType, this](PassmarkLineType type)
-        {
-            if (passmarkLineCurType != type)
-            {
-                emit TogglePassmarkLineType(m_id, type);
-            }
-        };
-
-        QAction *selectedAction = menu.exec(event->screenPos());
-        ContextMenuOption selectedOption = static_cast<ContextMenuOption>(
-                    contextMenu.key(selectedAction, static_cast<int>(ContextMenuOption::NoSelection)));
-
-        Q_STATIC_ASSERT_X(static_cast<int>(ContextMenuOption::LAST_ONE_DO_NOT_USE) == 31,
-                          "Not all options were handled.");
-
-QT_WARNING_PUSH
-QT_WARNING_DISABLE_GCC("-Wswitch-default")
-        switch(selectedOption)
-        {
-            case ContextMenuOption::LAST_ONE_DO_NOT_USE:
-                Q_UNREACHABLE();
-            case ContextMenuOption::NoSelection:
-                return;
-            case ContextMenuOption::Option:
-                emit ShowOptions();
-                break;
-            case ContextMenuOption::InLayout:
-                emit ToggleInLayout(selectedAction->isChecked());
-                break;
-            case ContextMenuOption::ForbidFlipping:
-                emit ToggleForbidFlipping(selectedAction->isChecked());
-                break;
-            case ContextMenuOption::ForceFlipping:
-                emit ToggleForceFlipping(selectedAction->isChecked());
-                break;
-            case ContextMenuOption::Remove:
-                try
-                {
-                    emit Delete();
-                }
-                catch(const VExceptionToolWasDeleted &e)
-                {
-                    Q_UNUSED(e);
-                    return;//Leave this method immediately!!!
-                }
-                return;//Leave this method immediately after call!!!
-            case ContextMenuOption::ShowLabel:
-                VAbstractApplication::VApp()->getUndoStack()->push(
-                            new ShowLabel(doc, m_id, selectedAction->isChecked()));
-                break;
-            case ContextMenuOption::Exclude:
-                emit ToggleExcludeState(m_id);
-                break;
-            case ContextMenuOption::ByLength:
-                SelectSeamAllowanceAngle(PieceNodeAngle::ByLength);
-                break;
-            case ContextMenuOption::ByPointsIntersection:
-                SelectSeamAllowanceAngle(PieceNodeAngle::ByPointsIntersection);
-                break;
-            case ContextMenuOption::ByFirstEdgeSymmetry:
-                SelectSeamAllowanceAngle(PieceNodeAngle::ByFirstEdgeSymmetry);
-                break;
-            case ContextMenuOption::BySecondEdgeSymmetry:
-                SelectSeamAllowanceAngle(PieceNodeAngle::BySecondEdgeSymmetry);
-                break;
-            case ContextMenuOption::ByFirstEdgeRightAngle:
-                SelectSeamAllowanceAngle(PieceNodeAngle::ByFirstEdgeRightAngle);
-                break;
-            case ContextMenuOption::BySecondEdgeRightAngle:
-                SelectSeamAllowanceAngle(PieceNodeAngle::BySecondEdgeRightAngle);
-                break;
-            case ContextMenuOption::Passmark:
-                emit TogglePassmark(m_id, not isPassmark);
-                break;
-            case ContextMenuOption::Straightforward:
-                SelectPassmarkAngle(PassmarkAngleType::Straightforward);
-                break;
-            case ContextMenuOption::Bisector:
-                SelectPassmarkAngle(PassmarkAngleType::Bisector);
-                break;
-            case ContextMenuOption::Intersection:
-                SelectPassmarkAngle(PassmarkAngleType::Intersection);
-                break;
-            case ContextMenuOption::IntersectionOnlyLeft:
-                SelectPassmarkAngle(PassmarkAngleType::IntersectionOnlyLeft);
-                break;
-            case ContextMenuOption::IntersectionOnlyRight:
-                SelectPassmarkAngle(PassmarkAngleType::IntersectionOnlyRight);
-                break;
-            case ContextMenuOption::Intersection2:
-                SelectPassmarkAngle(PassmarkAngleType::Intersection2);
-                break;
-            case ContextMenuOption::Intersection2OnlyLeft:
-                SelectPassmarkAngle(PassmarkAngleType::Intersection2OnlyLeft);
-                break;
-            case ContextMenuOption::Intersection2OnlyRight:
-                SelectPassmarkAngle(PassmarkAngleType::Intersection2OnlyRight);
-                break;
-            case ContextMenuOption::OneLine:
-                SelectPassmarkLine(PassmarkLineType::OneLine);
-                break;
-            case ContextMenuOption::TwoLines:
-                SelectPassmarkLine(PassmarkLineType::TwoLines);
-                break;
-            case ContextMenuOption::ThreeLines:
-                SelectPassmarkLine(PassmarkLineType::ThreeLines);
-                break;
-            case ContextMenuOption::TMark:
-                SelectPassmarkLine(PassmarkLineType::TMark);
-                break;
-            case ContextMenuOption::VMark:
-                SelectPassmarkLine(PassmarkLineType::VMark);
-                break;
-            case ContextMenuOption::VMark2:
-                SelectPassmarkLine(PassmarkLineType::VMark2);
-                break;
-            case ContextMenuOption::UMark:
-                SelectPassmarkLine(PassmarkLineType::UMark);
-                break;
-            case ContextMenuOption::BoxMark:
-                SelectPassmarkLine(PassmarkLineType::BoxMark);
-                break;
-        };
-QT_WARNING_POP
+        return;
     }
+
+    QMenu menu;
+    QHash<int, QAction *> const contextMenu = InitContextMenu(&menu, piece->getId(), piece->referens());
+
+    PieceNodeAngle angleCurType = PieceNodeAngle::ByLength;
+    PassmarkAngleType passmarkAngleCurType = PassmarkAngleType::Straightforward;
+    PassmarkLineType passmarkLineCurType = PassmarkLineType::OneLine;
+
+    const VPiece detail = VAbstractTool::data.GetPiece(piece->getId());
+    const VPiecePath &path = detail.GetPath();
+    const int nodeIndex = path.indexOfNode(m_id);
+    if (nodeIndex != -1)
+    {
+        const VPieceNode &node = path.at(nodeIndex);
+        angleCurType = node.GetAngleType();
+        passmarkAngleCurType = node.GetPassmarkAngleType();
+        passmarkLineCurType = node.GetPassmarkLineType();
+    }
+
+    auto SelectSeamAllowanceAngle = [angleCurType, this](PieceNodeAngle type)
+    {
+        if (angleCurType != type)
+        {
+            emit ToggleSeamAllowanceAngleType(m_id, type);
+        }
+    };
+
+    auto SelectPassmarkAngle = [passmarkAngleCurType, this](PassmarkAngleType type)
+    {
+        if (passmarkAngleCurType != type)
+        {
+            emit TogglePassmarkAngleType(m_id, type);
+        }
+    };
+
+    auto SelectPassmarkLine = [passmarkLineCurType, this](PassmarkLineType type)
+    {
+        emit TogglePassmark(m_id, true);
+
+        if (passmarkLineCurType != type)
+        {
+            emit TogglePassmarkLineType(m_id, type);
+        }
+    };
+
+    QAction *selectedAction = menu.exec(event->screenPos());
+    auto const selectedOption = static_cast<ContextMenuOption>(
+        contextMenu.key(selectedAction, static_cast<int>(ContextMenuOption::NoSelection)));
+
+    Q_STATIC_ASSERT_X(static_cast<int>(ContextMenuOption::LAST_ONE_DO_NOT_USE) == 35, "Not all options were handled.");
+
+    QT_WARNING_PUSH
+    QT_WARNING_DISABLE_GCC("-Wswitch-default")
+    QT_WARNING_DISABLE_CLANG("-Wswitch-default")
+
+    switch (selectedOption)
+    {
+        case ContextMenuOption::LAST_ONE_DO_NOT_USE:
+            Q_UNREACHABLE();
+            break;
+        case ContextMenuOption::NoSelection:
+            return;
+        case ContextMenuOption::Option:
+            emit ShowOptions();
+            break;
+        case ContextMenuOption::InLayout:
+            emit ToggleInLayout(selectedAction->isChecked());
+            break;
+        case ContextMenuOption::ForbidFlipping:
+            emit ToggleForbidFlipping(selectedAction->isChecked());
+            break;
+        case ContextMenuOption::ForceFlipping:
+            emit ToggleForceFlipping(selectedAction->isChecked());
+            break;
+        case ContextMenuOption::ShowFullPiece:
+            emit ToggleShowFullPiece(selectedAction->isChecked());
+            break;
+        case ContextMenuOption::ResetLabelTemplate:
+            emit ResetPieceLabelTemplate();
+            break;
+        case ContextMenuOption::Remove:
+            try
+            {
+                emit Delete();
+            }
+            catch (const VExceptionToolWasDeleted &e)
+            {
+                Q_UNUSED(e);
+                return; // Leave this method immediately!!!
+            }
+            return; // Leave this method immediately after call!!!
+        case ContextMenuOption::ShowLabel:
+            VAbstractApplication::VApp()->getUndoStack()->push(new ShowLabel(doc, m_id, selectedAction->isChecked()));
+            break;
+        case ContextMenuOption::Exclude:
+            emit ToggleExcludeState(m_id);
+            break;
+        case ContextMenuOption::TurnPoint:
+            emit ToggleTurnPointState(m_id);
+            break;
+        case ContextMenuOption::ByLength:
+            SelectSeamAllowanceAngle(PieceNodeAngle::ByLength);
+            break;
+        case ContextMenuOption::ByPointsIntersection:
+            SelectSeamAllowanceAngle(PieceNodeAngle::ByPointsIntersection);
+            break;
+        case ContextMenuOption::ByFirstEdgeSymmetry:
+            SelectSeamAllowanceAngle(PieceNodeAngle::ByFirstEdgeSymmetry);
+            break;
+        case ContextMenuOption::BySecondEdgeSymmetry:
+            SelectSeamAllowanceAngle(PieceNodeAngle::BySecondEdgeSymmetry);
+            break;
+        case ContextMenuOption::ByFirstEdgeRightAngle:
+            SelectSeamAllowanceAngle(PieceNodeAngle::ByFirstEdgeRightAngle);
+            break;
+        case ContextMenuOption::BySecondEdgeRightAngle:
+            SelectSeamAllowanceAngle(PieceNodeAngle::BySecondEdgeRightAngle);
+            break;
+        case ContextMenuOption::NonePassmark:
+            emit TogglePassmark(m_id, false);
+            break;
+        case ContextMenuOption::Straightforward:
+            SelectPassmarkAngle(PassmarkAngleType::Straightforward);
+            break;
+        case ContextMenuOption::Bisector:
+            SelectPassmarkAngle(PassmarkAngleType::Bisector);
+            break;
+        case ContextMenuOption::Intersection:
+            SelectPassmarkAngle(PassmarkAngleType::Intersection);
+            break;
+        case ContextMenuOption::IntersectionOnlyLeft:
+            SelectPassmarkAngle(PassmarkAngleType::IntersectionOnlyLeft);
+            break;
+        case ContextMenuOption::IntersectionOnlyRight:
+            SelectPassmarkAngle(PassmarkAngleType::IntersectionOnlyRight);
+            break;
+        case ContextMenuOption::Intersection2:
+            SelectPassmarkAngle(PassmarkAngleType::Intersection2);
+            break;
+        case ContextMenuOption::Intersection2OnlyLeft:
+            SelectPassmarkAngle(PassmarkAngleType::Intersection2OnlyLeft);
+            break;
+        case ContextMenuOption::Intersection2OnlyRight:
+            SelectPassmarkAngle(PassmarkAngleType::Intersection2OnlyRight);
+            break;
+        case ContextMenuOption::OneLine:
+            SelectPassmarkLine(PassmarkLineType::OneLine);
+            break;
+        case ContextMenuOption::TwoLines:
+            SelectPassmarkLine(PassmarkLineType::TwoLines);
+            break;
+        case ContextMenuOption::ThreeLines:
+            SelectPassmarkLine(PassmarkLineType::ThreeLines);
+            break;
+        case ContextMenuOption::TMark:
+            SelectPassmarkLine(PassmarkLineType::TMark);
+            break;
+        case ContextMenuOption::ExternalVMark:
+            SelectPassmarkLine(PassmarkLineType::ExternalVMark);
+            break;
+        case ContextMenuOption::InternalVMark:
+            SelectPassmarkLine(PassmarkLineType::InternalVMark);
+            break;
+        case ContextMenuOption::UMark:
+            SelectPassmarkLine(PassmarkLineType::UMark);
+            break;
+        case ContextMenuOption::BoxMark:
+            SelectPassmarkLine(PassmarkLineType::BoxMark);
+            break;
+        case ContextMenuOption::CheckMark:
+            SelectPassmarkLine(PassmarkLineType::CheckMark);
+            break;
+    };
+
+    QT_WARNING_POP
 }
 
 //---------------------------------------------------------------------------------------------------------------------
