@@ -34,33 +34,33 @@
 #include "../ifc/ifcdef.h"
 #include "../ifc/xml/vabstractpattern.h"
 #include "../ifc/xml/vdomdocument.h"
-#include "../vmisc/def.h"
 #include "../tools/vdatatool.h"
-#include "vundocommand.h"
+#include "../vmisc/def.h"
 #include "../vpatterndb/vpiecenode.h"
 #include "../vpatterndb/vpiecepath.h"
 #include "../vwidgets/vmaingraphicsview.h"
+#include "vundocommand.h"
 
 //---------------------------------------------------------------------------------------------------------------------
 DeletePiece::DeletePiece(VAbstractPattern *doc, quint32 id, const VContainer &data, VMainGraphicsScene *scene,
                          QUndoCommand *parent)
-    : VUndoCommand(QDomElement(), doc, parent),
-      m_parentNode(),
-      m_siblingId(NULL_ID),
-      m_detail(data.GetPiece(id)),
-      m_data(data),
-      m_scene(scene),
-      m_tool(),
-      m_record(VAbstractTool::GetRecord(id, Tool::Piece, doc))
+  : VUndoCommand(QDomElement(), doc, parent),
+    m_parentNode(),
+    m_siblingId(NULL_ID),
+    m_detail(data.GetPiece(id)),
+    m_data(data),
+    m_scene(scene),
+    m_tool(),
+    m_record(VAbstractTool::GetRecord(id, Tool::Piece, doc))
 {
     setText(tr("delete tool"));
     nodeId = id;
-    QDomElement domElement = doc->elementById(id, VAbstractPattern::TagDetail);
+    QDomElement const domElement = doc->elementById(id, VAbstractPattern::TagDetail);
     if (domElement.isElement())
     {
         xml = domElement.cloneNode().toElement();
         m_parentNode = domElement.parentNode();
-        QDomNode previousDetail = domElement.previousSibling();
+        QDomNode const previousDetail = domElement.previousSibling();
         if (previousDetail.isNull())
         {
             m_siblingId = NULL_ID;
@@ -112,16 +112,17 @@ void DeletePiece::redo()
 {
     qCDebug(vUndo, "Redo.");
 
-    QDomElement domElement = doc->elementById(nodeId, VAbstractPattern::TagDetail);
+    QDomElement const domElement = doc->elementById(nodeId, VAbstractPattern::TagDetail);
     if (domElement.isElement())
     {
         m_parentNode.removeChild(domElement);
 
-        m_tool = qobject_cast<VToolSeamAllowance*>(VAbstractPattern::getTool(nodeId));
+        m_tool = qobject_cast<VToolSeamAllowance *>(VAbstractPattern::getTool(nodeId));
         SCASSERT(not m_tool.isNull());
         m_tool->DisconnectOutsideSignals();
         m_tool->EnableToolMove(true);
         m_tool->hide();
+        m_tool->CancelLabelRendering();
 
         m_scene->removeItem(m_tool);
 
