@@ -33,12 +33,10 @@
 #include <QTransform>
 #include <QUuid>
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 13, 0)
-#include "../vmisc/defglobal.h"
-#endif // QT_VERSION < QT_VERSION_CHECK(5, 13, 0)
-
 class ResetBackgroundImage : public VUndoCommand
 {
+    Q_OBJECT // NOLINT
+
 public:
     ResetBackgroundImage(QUuid id, VAbstractPattern *doc, QUndoCommand *parent = nullptr);
     ~ResetBackgroundImage() override = default;
