@@ -30,11 +30,7 @@
 
 #include "../vundocommand.h"
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 13, 0)
-#include "../vmisc/defglobal.h"
-#endif // QT_VERSION < QT_VERSION_CHECK(5, 13, 0)
-
-enum class ZValueMove
+enum class ZValueMoveType
 {
     Top,
     Up,
@@ -44,16 +40,19 @@ enum class ZValueMove
 
 class ZValueMoveBackgroundImage : public VUndoCommand
 {
+    Q_OBJECT // NOLINT
+
 public:
-    ZValueMoveBackgroundImage(QUuid id, ZValueMove move, VAbstractPattern *doc, QUndoCommand *parent = nullptr);
-    ~ZValueMoveBackgroundImage() override =default;
+    ZValueMoveBackgroundImage(QUuid id, ZValueMoveType move, VAbstractPattern *doc, QUndoCommand *parent = nullptr);
+    ~ZValueMoveBackgroundImage() override = default;
     void undo() override;
     void redo() override;
+
 private:
     // cppcheck-suppress unknownMacro
     Q_DISABLE_COPY_MOVE(ZValueMoveBackgroundImage) // NOLINT
     QUuid m_id;
-    ZValueMove m_move;
+    ZValueMoveType m_move;
     QHash<QUuid, qreal> m_oldValues{};
 };
 
