@@ -29,7 +29,6 @@
 #ifndef MOVEABSTRACTLABEL_H
 #define MOVEABSTRACTLABEL_H
 
-#include <qcompilerdetection.h>
 #include <QMetaObject>
 #include <QObject>
 #include <QString>
@@ -42,32 +41,35 @@ class QGraphicsScene;
 class MoveAbstractLabel : public VUndoCommand
 {
     Q_OBJECT // NOLINT
+
 public:
     MoveAbstractLabel(VAbstractPattern *doc, quint32 pointId, const QPointF &pos, QUndoCommand *parent = nullptr);
-    virtual ~MoveAbstractLabel()=default;
+    ~MoveAbstractLabel() = default;
 
-    virtual void undo() override;
-    virtual void redo() override;
+    void undo() override;
+    void redo() override;
+
+    auto GetPointId() const -> quint32;
+    auto GetNewPos() const -> QPointF;
 
-    quint32 GetPointId() const;
-    QPointF GetNewPos() const;
 protected:
     QPointF m_oldPos;
     QPointF m_newPos;
 
-    virtual void Do(const QPointF &pos)=0;
+    virtual void Do(const QPointF &pos) = 0;
+
 private:
     Q_DISABLE_COPY_MOVE(MoveAbstractLabel) // NOLINT
 };
 
 //---------------------------------------------------------------------------------------------------------------------
-inline quint32 MoveAbstractLabel::GetPointId() const
+inline auto MoveAbstractLabel::GetPointId() const -> quint32
 {
     return nodeId;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-inline QPointF MoveAbstractLabel::GetNewPos() const
+inline auto MoveAbstractLabel::GetNewPos() const -> QPointF
 {
     return m_newPos;
 }
