@@ -29,7 +29,6 @@
 #ifndef MOVEDETAIL_H
 #define MOVEDETAIL_H
 
-#include <qcompilerdetection.h>
 #include <QMetaObject>
 #include <QObject>
 #include <QString>
@@ -42,49 +41,51 @@ class QGraphicsScene;
 class MovePiece : public VUndoCommand
 {
     Q_OBJECT // NOLINT
+
 public:
     MovePiece(VAbstractPattern *doc, const double &x, const double &y, const quint32 &id, QGraphicsScene *scene,
-               QUndoCommand *parent = nullptr);
-    virtual ~MovePiece()=default;
+              QUndoCommand *parent = nullptr);
+    ~MovePiece() = default;
 
-    virtual void undo() override;
-    virtual void redo() override;
+    void undo() override;
+    void redo() override;
     // cppcheck-suppress unusedFunction
-    virtual bool mergeWith(const QUndoCommand *command) override;
-    virtual int  id() const override;
+    auto mergeWith(const QUndoCommand *command) -> bool override;
+    auto id() const -> int override;
 
     void Do(qreal x, qreal y);
 
-    quint32      getDetId() const;
-    double       getNewX() const;
-    double       getNewY() const;
+    auto getDetId() const -> quint32;
+    auto getNewX() const -> double;
+    auto getNewY() const -> double;
+
 private:
     // cppcheck-suppress unknownMacro
     Q_DISABLE_COPY_MOVE(MovePiece) // NOLINT
 
-    double          m_oldX;
-    double          m_oldY;
-    double          m_newX;
-    double          m_newY;
+    double m_oldX;
+    double m_oldY;
+    double m_newX;
+    double m_newY;
     QGraphicsScene *m_scene;
 
     void SaveCoordinates(QDomElement &domElement, double x, double y);
 };
 
 //---------------------------------------------------------------------------------------------------------------------
-inline quint32 MovePiece::getDetId() const
+inline auto MovePiece::getDetId() const -> quint32
 {
     return nodeId;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-inline double MovePiece::getNewX() const
+inline auto MovePiece::getNewX() const -> double
 {
     return m_newX;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-inline double MovePiece::getNewY() const
+inline auto MovePiece::getNewY() const -> double
 {
     return m_newY;
 }
