@@ -34,7 +34,6 @@
 #include "../ifc/xml/vabstractpattern.h"
 #include "../vmisc/vabstractvalapplication.h"
 #include "../vmisc/def.h"
-#include "../vwidgets/vmaingraphicsview.h"
 #include "../vgeometry/vpointf.h"
 #include "../vgeometry/vspline.h"
 #include "vundocommand.h"
@@ -74,7 +73,7 @@ void MoveSpline::redo()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool MoveSpline::mergeWith(const QUndoCommand *command)
+auto MoveSpline::mergeWith(const QUndoCommand *command) -> bool
 {
     const auto *moveCommand = static_cast<const MoveSpline *>(command);
     SCASSERT(moveCommand != nullptr)
@@ -90,7 +89,7 @@ bool MoveSpline::mergeWith(const QUndoCommand *command)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-int MoveSpline::id() const
+auto MoveSpline::id() const -> int
 {
     return static_cast<int>(UndoCommand::MoveSpline);
 }
