@@ -65,9 +65,9 @@ void RenamePP::redo()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool RenamePP::mergeWith(const QUndoCommand *command)
+auto RenamePP::mergeWith(const QUndoCommand *command) -> bool
 {
-    const RenamePP *renameCommand = static_cast<const RenamePP *>(command);
+    const auto *renameCommand = static_cast<const RenamePP *>(command);
     SCASSERT(renameCommand != nullptr)
 
     const QString oldName = renameCommand->getOldPPname();
@@ -81,7 +81,7 @@ bool RenamePP::mergeWith(const QUndoCommand *command)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-int RenamePP::id() const
+auto RenamePP::id() const -> int
 {
     return static_cast<int>(UndoCommand::RenamePP);
 }
