@@ -35,13 +35,15 @@
 #include <QtMath>
 
 #include "../vgeometry/vgobject.h"
+#include "../vmisc/theme/themeDef.h"
 #include "../vpatterndb/vcontainer.h"
 
 //---------------------------------------------------------------------------------------------------------------------
 VisLine::VisLine(const VContainer *data, QGraphicsItem *parent)
-    :Visualization(data), VScaledLine(parent)
+  : Visualization(data),
+    VScaledLine(VColorRole::VisMainColor, parent)
 {
-    this->setZValue(1);// Show on top of a real tool
+    this->setZValue(1); // Show on top of a real tool
     VisLine::InitPen();
 }
 
@@ -51,10 +53,10 @@ auto VisLine::CorrectAngle(const qreal &angle) -> qreal
     qreal ang = angle;
     if (angle > 360)
     {
-        ang = angle - 360.0 * qFloor(angle/360);
+        ang = angle - 360.0 * qFloor(angle / 360);
     }
 
-    switch (qFloor((qAbs(ang)+22.5)/45))
+    switch (qFloor((qAbs(ang) + 22.5) / 45))
     {
         case 1: // <67.5
             return 45;
@@ -70,7 +72,7 @@ auto VisLine::CorrectAngle(const qreal &angle) -> qreal
             return 270;
         case 7: // <337.5
             return 315;
-        case 0: // <22.5
+        case 0:  // <22.5
         default: // <360
             return 0;
     }
@@ -81,18 +83,18 @@ auto VisLine::Ray(const QPointF &firstPoint, const qreal &angle) const -> QPoint
 {
     if (this->scene() == nullptr)
     {
-        QLineF line = QLineF(firstPoint, ScenePos());
+        auto line = QLineF(firstPoint, ScenePos());
         line.setAngle(angle);
-        return line.p2();// We can't find ray because item doesn't have scene. We will return cursor position on scene.
+        return line.p2(); // We can't find ray because item doesn't have scene. We will return cursor position on scene.
     }
 
     QRectF scRect = this->scene()->sceneRect();
 
-    //Limit size of the scene rect. Axis that has same size as scene rect cause scene size growth.
-    QLineF line1 = QLineF(scRect.topLeft(), scRect.bottomRight());
+    // Limit size of the scene rect. Axis that has same size as scene rect cause scene size growth.
+    auto line1 = QLineF(scRect.topLeft(), scRect.bottomRight());
     line1.setLength(2);
 
-    QLineF line2 = QLineF(scRect.bottomRight(), scRect.topLeft());
+    auto line2 = QLineF(scRect.bottomRight(), scRect.topLeft());
     line2.setLength(2);
 
     scRect = QRectF(line1.p2(), line2.p2());
@@ -108,20 +110,20 @@ auto VisLine::Ray(const QPointF &firstPoint, const qreal &angle) const -> QPoint
 //---------------------------------------------------------------------------------------------------------------------
 auto VisLine::Ray(const QPointF &firstPoint) const -> QPointF
 {
-    QLineF line = QLineF(firstPoint, ScenePos());
+    auto const line = QLineF(firstPoint, ScenePos());
     return Ray(firstPoint, line.angle());
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 auto VisLine::Axis(const QPointF &p, const qreal &angle) const -> QLineF
 {
-    return {Ray(p, angle+180), Ray(p, angle)};
+    return {Ray(p, angle + 180), Ray(p, angle)};
 }
 
 //---------------------------------------------------------------------------------------------------------------------
 auto VisLine::Axis(const QPointF &p1, const QPointF &p2) const -> QLineF
 {
-    QLineF line(p1, p2);
+    QLineF const line(p1, p2);
     return Axis(p1, line.angle());
 }
 
@@ -129,9 +131,7 @@ auto VisLine::Axis(const QPointF &p1, const QPointF &p2) const -> QLineF
 void VisLine::InitPen()
 {
     QPen visPen = pen();
-    visPen.setColor(Color(VColor::MainColor));
     visPen.setStyle(LineStyle());
-
     setPen(visPen);
 }
 
@@ -142,13 +142,12 @@ void VisLine::AddOnScene()
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-void VisLine::DrawRay(VScaledLine *lineItem, const QPointF &p, const QPointF &pTangent, const QColor &color,
-                      Qt::PenStyle style)
+void VisLine::DrawRay(VScaledLine *lineItem, const QPointF &p, const QPointF &pTangent, Qt::PenStyle style)
 {
-    SCASSERT (lineItem != nullptr)
+    SCASSERT(lineItem != nullptr)
 
     const qreal angle = QLineF(p, pTangent).angle();
     const QPointF endRay = Ray(p, angle);
     const QLineF tangent = VGObject::BuildLine(p, QLineF(p, endRay).length(), angle);
-    DrawLine(lineItem, tangent, color, style);
+    DrawLine(lineItem, tangent, style);
 }
