@@ -37,23 +37,23 @@
 #include "../../tools/drawTools/toolpoint/toolsinglepoint/toollinepoint/vtoolbisector.h"
 #include "../vgeometry/vgobject.h"
 #include "../vgeometry/vpointf.h"
-#include "../vpatterndb/vcontainer.h"
 #include "../visualization.h"
-#include "visline.h"
 #include "../vmisc/vmodifierkey.h"
+#include "../vpatterndb/vcontainer.h"
+#include "visline.h"
 
 //---------------------------------------------------------------------------------------------------------------------
 VisToolBisector::VisToolBisector(const VContainer *data, QGraphicsItem *parent)
-    :VisLine(data, parent)
+  : VisLine(data, parent)
 {
-    m_line1P1 = InitPoint(Color(VColor::SupportColor), this);
-    m_line1P2 = InitPoint(Color(VColor::SupportColor), this); //-V656
-    m_line1 = InitItem<VScaledLine>(Color(VColor::SupportColor), this);
+    m_line1P1 = InitPoint(VColorRole::VisSupportColor, this);
+    m_line1P2 = InitPoint(VColorRole::VisSupportColor, this); //-V656
+    m_line1 = InitItem<VScaledLine>(VColorRole::VisSupportColor, this);
 
-    m_line2P2 = InitPoint(Color(VColor::SupportColor), this);
-    m_line2 = InitItem<VScaledLine>(Color(VColor::SupportColor), this);
+    m_line2P2 = InitPoint(VColorRole::VisSupportColor, this);
+    m_line2 = InitItem<VScaledLine>(VColorRole::VisSupportColor, this);
 
-    m_point = InitPoint(Color(VColor::MainColor), this);
+    m_point = InitPoint(VColorRole::VisMainColor, this);
 }
 
 //---------------------------------------------------------------------------------------------------------------------
@@ -68,65 +68,61 @@ void VisToolBisector::RefreshGeometry()
     if (m_point1Id > NULL_ID)
     {
         const QSharedPointer<VPointF> first = GetData()->GeometricObject<VPointF>(m_point1Id);
-        DrawPoint(m_line1P1, static_cast<QPointF>(*first), Color(VColor::SupportColor));
+        DrawPoint(m_line1P1, static_cast<QPointF>(*first));
 
         if (m_point2Id <= NULL_ID)
         {
-            DrawLine(m_line1, QLineF(static_cast<QPointF>(*first), ScenePos()), Color(VColor::SupportColor));
+            DrawLine(m_line1, QLineF(static_cast<QPointF>(*first), ScenePos()));
         }
         else
         {
             const QSharedPointer<VPointF> second = GetData()->GeometricObject<VPointF>(m_point2Id);
-            DrawPoint(m_line1P2, static_cast<QPointF>(*second), Color(VColor::SupportColor));
+            DrawPoint(m_line1P2, static_cast<QPointF>(*second));
 
-            DrawLine(m_line1, QLineF(static_cast<QPointF>(*first), static_cast<QPointF>(*second)),
-                     Color(VColor::SupportColor));
+            DrawLine(m_line1, QLineF(static_cast<QPointF>(*first), static_cast<QPointF>(*second)));
 
             if (m_point3Id <= NULL_ID)
             {
-                DrawLine(m_line2, QLineF(static_cast<QPointF>(*second), ScenePos()), Color(VColor::SupportColor));
+                DrawLine(m_line2, QLineF(static_cast<QPointF>(*second), ScenePos()));
             }
             else
             {
                 const QSharedPointer<VPointF> third = GetData()->GeometricObject<VPointF>(m_point3Id);
-                DrawPoint(m_line2P2, static_cast<QPointF>(*third), Color(VColor::SupportColor));
+                DrawPoint(m_line2P2, static_cast<QPointF>(*third));
 
-                DrawLine(m_line2, QLineF(static_cast<QPointF>(*second), static_cast<QPointF>(*third)),
-                         Color(VColor::SupportColor));
+                DrawLine(m_line2, QLineF(static_cast<QPointF>(*second), static_cast<QPointF>(*third)));
 
                 if (not qFuzzyIsNull(m_length))
                 {
-                    qreal angle = VToolBisector::BisectorAngle(static_cast<QPointF>(*first),
-                                                               static_cast<QPointF>(*second),
-                                                               static_cast<QPointF>(*third));
-                    QLineF mainLine = VGObject::BuildLine(static_cast<QPointF>(*second), m_length, angle);
-                    DrawLine(this, mainLine, Color(VColor::MainColor), LineStyle());
+                    qreal const angle = VToolBisector::BisectorAngle(
+                        static_cast<QPointF>(*first), static_cast<QPointF>(*second), static_cast<QPointF>(*third));
+                    QLineF const mainLine = VGObject::BuildLine(static_cast<QPointF>(*second), m_length, angle);
+                    DrawLine(this, mainLine, LineStyle());
 
-                    DrawPoint(m_point, mainLine.p2(), Color(VColor::MainColor));
+                    DrawPoint(m_point, mainLine.p2());
                 }
                 else if (GetMode() == Mode::Creation)
                 {
-                    QLineF cursorLine (static_cast<QPointF>(*second), ScenePos());
+                    QLineF const cursorLine(static_cast<QPointF>(*second), ScenePos());
                     QLineF baseLine(static_cast<QPointF>(*second), static_cast<QPointF>(*third));
 
-                    qreal angle = VToolBisector::BisectorAngle(static_cast<QPointF>(*first),
-                                                               static_cast<QPointF>(*second),
-                                                               static_cast<QPointF>(*third));
+                    qreal const angle = VToolBisector::BisectorAngle(
+                        static_cast<QPointF>(*first), static_cast<QPointF>(*second), static_cast<QPointF>(*third));
 
                     baseLine.setAngle(angle);
 
                     qreal len = cursorLine.length();
-                    qreal angleTo = baseLine.angleTo(cursorLine);
+                    qreal const angleTo = baseLine.angleTo(cursorLine);
                     if (angleTo > 90 && angleTo < 270)
                     {
                         len *= -1;
                     }
 
-                    QLineF mainLine = VGObject::BuildLine(static_cast<QPointF>(*second), len, angle);
+                    QLineF const mainLine = VGObject::BuildLine(static_cast<QPointF>(*second), len, angle);
 
-                    DrawLine(this, mainLine, Color(VColor::MainColor), LineStyle());
+                    DrawLine(this, mainLine, LineStyle());
 
-                    DrawPoint(m_point, mainLine.p2(), Color(VColor::MainColor));
+                    DrawPoint(m_point, mainLine.p2());
 
                     const QString prefix = UnitsToStr(VAbstractValApplication::VApp()->patternUnits(), true);
                     SetToolTip(tr("Length = %1%2; "
@@ -136,14 +132,12 @@ void VisToolBisector::RefreshGeometry()
                 }
                 else
                 {
-                    qreal angle = VToolBisector::BisectorAngle(static_cast<QPointF>(*first),
-                                                               static_cast<QPointF>(*second),
-                                                               static_cast<QPointF>(*third));
-                    QPointF endRay = Ray(static_cast<QPointF>(*second), angle);
-                    QLineF mainLine = VGObject::BuildLine(static_cast<QPointF>(*second),
-                                                          QLineF(static_cast<QPointF>(*second), endRay).length(),
-                                                          angle);
-                    DrawLine(this, mainLine, Color(VColor::MainColor), LineStyle());
+                    qreal const angle = VToolBisector::BisectorAngle(
+                        static_cast<QPointF>(*first), static_cast<QPointF>(*second), static_cast<QPointF>(*third));
+                    QPointF const endRay = Ray(static_cast<QPointF>(*second), angle);
+                    QLineF const mainLine = VGObject::BuildLine(
+                        static_cast<QPointF>(*second), QLineF(static_cast<QPointF>(*second), endRay).length(), angle);
+                    DrawLine(this, mainLine, LineStyle());
                 }
             }
         }
