@@ -29,7 +29,6 @@
 #include "global.h"
 #include "../vmisc/def.h"
 #include "../vmisc/vabstractapplication.h"
-#include "../vmisc/compatibility.h"
 
 #include <QBitmap>
 #include <QGraphicsItem>
@@ -41,13 +40,13 @@ const qreal minVisibleFontSize = 5;
 
 extern auto qt_regionToPath(const QRegion &region) -> QPainterPath;
 
-inline qreal DefPointRadiusPixel()
+inline auto DefPointRadiusPixel() -> qreal
 {
     return (VAbstractApplication::VApp()->Settings()->GetLineWidth() + 0.8) / 25.4 * PrintDPI;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-qreal SceneScale(QGraphicsScene *scene)
+auto SceneScale(QGraphicsScene *scene) -> qreal
 {
     qreal scale = 1;
 
@@ -56,7 +55,7 @@ qreal SceneScale(QGraphicsScene *scene)
         const QList<QGraphicsView *> views = scene->views();
         if (not views.isEmpty())
         {
-            scale = ConstFirst(views)->transform().m11();
+            scale = views.constFirst()->transform().m11();
         }
     }
 
@@ -64,35 +63,20 @@ qreal SceneScale(QGraphicsScene *scene)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QColor CorrectColor(const QGraphicsItem *item, const QColor &color)
+auto PointRect(qreal radius) -> QRectF
 {
-    SCASSERT(item != nullptr)
-
-    if (item->isEnabled())
-    {
-        return color;
-    }
-    else
-    {
-        return Qt::gray;
-    }
-}
-
-//---------------------------------------------------------------------------------------------------------------------
-QRectF PointRect(qreal radius)
-{
-    QRectF rec = QRectF(0, 0, radius*2, radius*2);
+    auto rec = QRectF(0, 0, radius * 2, radius * 2);
     rec.translate(-rec.center().x(), -rec.center().y());
     return rec;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-qreal ScaledRadius(qreal scale)
+auto ScaledRadius(qreal scale) -> qreal
 {
     qreal scaledRadius = DefPointRadiusPixel();
     if (scale > 1)
     {
-        scaledRadius = qMax(DefPointRadiusPixel()/96, DefPointRadiusPixel()/scale);
+        scaledRadius = qMax(DefPointRadiusPixel() / 96, DefPointRadiusPixel() / scale);
     }
     return scaledRadius;
 }
@@ -106,21 +90,21 @@ void ScaleCircleSize(QGraphicsEllipseItem *item, qreal scale)
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-qreal ScaleWidth(qreal width, qreal scale)
+auto ScaleWidth(qreal width, qreal scale) -> qreal
 {
     if (scale > 1)
     {
-        width = qMax(0.01, width/scale);
+        width = qMax(0.01, width / scale);
     }
     return width;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-QPainterPath ItemShapeFromPath(const QPainterPath &path, const QPen &pen)
+auto ItemShapeFromPath(const QPainterPath &path, const QPen &pen) -> QPainterPath
 {
     // We unfortunately need this hack as QPainterPathStroker will set a width of 1.0
     // if we pass a value of 0.0 to QPainterPathStroker::setWidth()
-    const qreal penWidthZero = qreal(0.00000001);
+    const auto penWidthZero = qreal(0.00000001);
 
     if (path == QPainterPath() || pen == Qt::NoPen)
     {
@@ -148,7 +132,7 @@ auto PixmapToPainterPath(const QPixmap &pixmap) -> QPainterPath
 {
     if (not pixmap.isNull())
     {
-        QBitmap mask = pixmap.mask();
+        QBitmap const mask = pixmap.mask();
         if (not mask.isNull())
         {
             return qt_regionToPath(QRegion(mask));
@@ -160,7 +144,7 @@ auto PixmapToPainterPath(const QPixmap &pixmap) -> QPainterPath
 
 //---------------------------------------------------------------------------------------------------------------------
 void GraphicsItemHighlightSelected(const QRectF &boundingRect, qreal itemPenWidth, QPainter *painter,
-                                    const QStyleOptionGraphicsItem *option)
+                                   const QStyleOptionGraphicsItem *option)
 {
     const QRectF murect = painter->transform().mapRect(QRectF(0, 0, 1, 1));
     if (qFuzzyIsNull(qMax(murect.width(), murect.height())))
@@ -180,9 +164,7 @@ void GraphicsItemHighlightSelected(const QRectF &boundingRect, qreal itemPenWidt
 
     const QColor fgcolor = option->palette.windowText().color();
     const QColor bgcolor( // ensure good contrast against fgcolor
-                          fgcolor.red()   > 127 ? 0 : 255,
-                          fgcolor.green() > 127 ? 0 : 255,
-                          fgcolor.blue()  > 127 ? 0 : 255);
+        fgcolor.red() > 127 ? 0 : 255, fgcolor.green() > 127 ? 0 : 255, fgcolor.blue() > 127 ? 0 : 255);
 
     painter->setPen(QPen(bgcolor, penWidth, Qt::SolidLine));
     painter->setBrush(Qt::NoBrush);
@@ -194,9 +176,9 @@ void GraphicsItemHighlightSelected(const QRectF &boundingRect, qreal itemPenWidt
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-bool IsSelectedByReleaseEvent(QGraphicsItem *item, QGraphicsSceneMouseEvent *event)
+auto IsSelectedByReleaseEvent(QGraphicsItem *item, QGraphicsSceneMouseEvent *event) -> bool
 {
     SCASSERT(item != nullptr)
-    return event->button() == Qt::LeftButton && event->type() != QEvent::GraphicsSceneMouseDoubleClick
-            && item->contains(event->pos());
+    return event->button() == Qt::LeftButton && event->type() != QEvent::GraphicsSceneMouseDoubleClick &&
+           item->contains(event->pos());
 }
