@@ -1,17 +1,17 @@
 /****************************************************************************
-** 
+**
 ** Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies).
 ** All rights reserved.
 ** Contact: Nokia Corporation (qt-info@nokia.com)
-** 
+**
 ** This file is part of a Qt Solutions component.
 **
-** Commercial Usage  
+** Commercial Usage
 ** Licensees holding valid Qt Commercial licenses may use this file in
 ** accordance with the Qt Solutions Commercial License Agreement provided
 ** with the Software or, alternatively, in accordance with the terms
 ** contained in a written agreement between you and Nokia.
-** 
+**
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
 ** General Public License version 2.1 as published by the Free Software
@@ -19,42 +19,40 @@
 ** packaging of this file.  Please review the following information to
 ** ensure the GNU Lesser General Public License version 2.1 requirements
 ** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-** 
+**
 ** In addition, as a special exception, Nokia gives you certain
 ** additional rights. These rights are described in the Nokia Qt LGPL
 ** Exception version 1.1, included in the file LGPL_EXCEPTION.txt in this
 ** package.
-** 
-** GNU General Public License Usage 
+**
+** GNU General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU
 ** General Public License version 3.0 as published by the Free Software
 ** Foundation and appearing in the file LICENSE.GPL included in the
 ** packaging of this file.  Please review the following information to
 ** ensure the GNU General Public License version 3.0 requirements will be
 ** met: http://www.gnu.org/copyleft/gpl.html.
-** 
+**
 ** Please note Third Party Software included with Qt Solutions may impose
 ** additional restrictions and it is the user's responsibility to ensure
 ** that they have met the licensing requirements of the GPL, LGPL, or Qt
 ** Solutions Commercial license and the relevant license of the Third
 ** Party Software they are using.
-** 
+**
 ** If you are unsure which license is appropriate for your use, please
 ** contact Nokia at qt-info@nokia.com.
-** 
+**
 ****************************************************************************/
 
 #ifndef QTCOLORPICKER_H
 #define QTCOLORPICKER_H
-#include <QPushButton>
-#include <QtCore/QString>
+
 #include <QColor>
-
-#include <QLabel>
-#include <QtCore/QEvent>
 #include <QFocusEvent>
-
-#include "../vmisc/defglobal.h"
+#include <QLabel>
+#include <QPushButton>
+#include <QtCore/QEvent>
+#include <QtCore/QString>
 
 class ColorPickerPopup;
 class ColorPickerItem;
@@ -66,25 +64,24 @@ class QtColorPicker : public QPushButton
     Q_PROPERTY(bool colorDialog READ colorDialogEnabled WRITE setColorDialogEnabled)
 
 public:
-    QtColorPicker(QWidget *parent = 0,
-                  int columns = -1, bool enableColorDialog = true);
+    explicit QtColorPicker(QWidget *parent = nullptr, int columns = -1, bool enableColorDialog = true);
 
-    ~QtColorPicker();
+    ~QtColorPicker() override;
 
     void insertColor(const QColor &color, const QString &text = QString(), int index = -1);
 
-    QColor currentColor() const;
+    auto currentColor() const -> QColor;
 
-    QColor color(int index) const;
+    auto color(int index) const -> QColor;
 
     void setColorDialogEnabled(bool enabled);
-    bool colorDialogEnabled() const;
+    auto colorDialogEnabled() const -> bool;
 
     void setStandardColors();
 
     auto CustomColors() const -> QVector<QColor>;
 
-    static QColor getColor(const QPoint &point, bool allowCustomColors = true);
+    static auto getColor(const QPoint &point, bool allowCustomColors = true) -> QColor;
 
 public Q_SLOTS:
     void setCurrentColor(const QColor &color);
@@ -93,7 +90,7 @@ Q_SIGNALS:
     void colorChanged(const QColor &);
 
 protected:
-    void paintEvent(QPaintEvent *e);
+    void paintEvent(QPaintEvent *e) override;
 
 private Q_SLOTS:
     void buttonPressed(bool toggled);
