@@ -30,56 +30,55 @@
 
 #include <QFrame>
 
-#include "../vmisc/defglobal.h"
-
 class VElidedLabel : public QFrame
 {
     Q_OBJECT // NOLINT
     Q_PROPERTY(QString text READ text WRITE setText)
     Q_PROPERTY(bool IsElided READ IsElided)
     Q_PROPERTY(bool showElided READ ShowElided WRITE SetShowElided)
+
 public:
-   explicit VElidedLabel(QWidget *parent = nullptr);
-   explicit VElidedLabel(const QString &text, QWidget *parent = nullptr);
+    explicit VElidedLabel(QWidget *parent = nullptr);
+    explicit VElidedLabel(const QString &text, QWidget *parent = nullptr);
 
-   void           setText(const QString &text);
-   const QString& text() const;
+    void setText(const QString &text);
+    auto text() const -> const QString &;
 
-   bool IsElided() const;
+    auto IsElided() const -> bool;
 
-   bool ShowElided() const;
-   void SetShowElided(bool showElided);
+    auto ShowElided() const -> bool;
+    void SetShowElided(bool showElided);
 
 protected:
-   virtual void paintEvent(QPaintEvent *event) override;
+    virtual void paintEvent(QPaintEvent *event) override;
 
 signals:
-   void ElisionChanged(bool m_elided);
+    void ElisionChanged(bool m_elided);
 
 private:
-   // cppcheck-suppress unknownMacro
-   Q_DISABLE_COPY_MOVE(VElidedLabel) // NOLINT
-   bool    m_elided{false};
-   bool    m_showElided{true};
-   QString m_content{};
+    // cppcheck-suppress unknownMacro
+    Q_DISABLE_COPY_MOVE(VElidedLabel) // NOLINT
+    bool m_elided{false};
+    bool m_showElided{true};
+    QString m_content{};
 
-   bool DrawParagraph(QPainter &painter, const QString& paragraph, int &y, bool &didElide);
+    auto DrawParagraph(QPainter &painter, const QString &paragraph, int &y, bool &didElide) -> bool;
 };
 
 //---------------------------------------------------------------------------------------------------------------------
-inline const QString &VElidedLabel::text() const
+inline auto VElidedLabel::text() const -> const QString &
 {
     return m_content;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-inline bool VElidedLabel::IsElided() const
+inline auto VElidedLabel::IsElided() const -> bool
 {
     return m_elided;
 }
 
 //---------------------------------------------------------------------------------------------------------------------
-inline bool VElidedLabel::ShowElided() const
+inline auto VElidedLabel::ShowElided() const -> bool
 {
     return m_showElided;
 }
