@@ -51,29 +51,43 @@
 #   include <QtXml>
 #endif
 
-//In Windows you can't use same header in all modes.
-#if !defined(Q_OS_WIN)
-#   ifdef QT_WIDGETS_LIB
-#       include <QtWidgets>
-#   endif
+#ifdef QT_TESTLIB_LIB
+#   include <QtTest>
+#endif
 
-#   ifdef QT_SVG_LIB
-#       include <QtSvg/QtSvg>
-#   endif
+#ifdef QT_WINEXTRAS_LIB
+#   include <QtWinExtras>
+#endif
 
-#   ifdef QT_PRINTSUPPORT_LIB
-#       include <QtPrintSupport>
-#   endif
+#ifdef QT_WIDGETS_LIB
+#   include <QtWidgets>
+#endif
 
-    //Build doesn't work, if include this headers on Windows.
-#   ifdef QT_XMLPATTERNS_LIB
-#       include <QtXmlPatterns>
-#   endif
+#ifdef QT_SVG_LIB
+#   include <QtSvg/QtSvg>
+#endif
 
-#   ifdef QT_NETWORK_LIB
-#       include <QtNetwork>
-#   endif
-#endif/*Q_OS_WIN*/
+#ifdef QT_PRINTSUPPORT_LIB
+#   include <QtPrintSupport>
+#endif
+
+#ifdef QT_XMLPATTERNS_LIB
+#   include <QtXmlPatterns>
+#endif
+
+#ifdef QT_NETWORK_LIB
+#   include <QtNetwork>
+#endif
+
+#ifdef QT_CONCURRENT_LIB
+#   include <QtConcurrent>
+#endif
+
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#ifdef QT_OPENGLWIDGETS_LIB
+#   include <QOpenGLWidget>
+#endif
+#endif
 
 #endif /*__cplusplus*/
 
