@@ -36,6 +36,7 @@ class VSAPoint;
 class TST_VAbstractPiece : public AbstractTest
 {
     Q_OBJECT // NOLINT
+
 public:
     explicit TST_VAbstractPiece(QObject *parent = nullptr);
 
@@ -45,6 +46,8 @@ private slots:
     void LayoutAllowanceRemoveLoop_data();
     void LayoutAllowanceRemoveLoop() const;
     void SumTrapezoids() const;
+    void TestAreaCalculation_data();
+    void TestAreaCalculation() const;
     void RawPathRemoveLoop_data() const;
     void RawPathRemoveLoop() const;
     void PathRemoveLoop_data() const;
@@ -63,21 +66,25 @@ private slots:
     void PossibleInfiniteClearLoops() const;
     void IsAllowanceValid_data() const;
     void IsAllowanceValid() const;
+    void TestFullSeamPath_data() const;
+    void TestFullSeamPath() const;
+    void TestFullSeamAllowancePath_data() const;
+    void TestFullSeamAllowancePath() const;
 
 private:
-    QVector<VSAPoint> InputPointsCase3() const;
-    QVector<QPointF>  OutputPointsCase3() const;
+    auto InputPointsCase3() const -> QVector<VSAPoint>;
+    auto OutputPointsCase3() const -> QVector<QPointF>;
 
     void Case3() const;
     void Case4() const;
     void Case5() const;
 
-    QVector<QPointF> InputPointsCase3a() const;
-    QVector<QPointF> InputPointsCase4a() const;
-    QVector<QPointF> InputPointsCase5a() const;
+    auto InputPointsCase3a() const -> QVector<QPointF>;
+    auto InputPointsCase4a() const -> QVector<QPointF>;
+    auto InputPointsCase5a() const -> QVector<QPointF>;
 
-    QVector<VSAPoint> InputLoopByIntersectionTest();
-    QVector<QPointF>  OutputLoopByIntersectionTest();
+    auto InputLoopByIntersectionTest() -> QVector<VSAPoint>;
+    auto OutputLoopByIntersectionTest() -> QVector<QPointF>;
 };
 
 #endif // TST_VABSTRACTPIECE_H
