@@ -30,11 +30,21 @@
 #include "../vmisc/commandoptions.h"
 
 #include <QtTest>
-#include <ciso646>
+
+// Header <ciso646> is removed in C++20.
+#if __cplusplus <= 201703L
+#include <ciso646> // and, not, or
+#endif
+
+#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
+#include "../vmisc/compatibility.h"
+#endif
+
+using namespace Qt::Literals::StringLiterals;
 
 //---------------------------------------------------------------------------------------------------------------------
 TST_VCommandLine::TST_VCommandLine(QObject *parent)
-    :QObject(parent)
+  : QObject(parent)
 {
 }
 
@@ -45,10 +55,10 @@ void TST_VCommandLine::UniqueKeys()
     const QStringList options = AllKeys();
     QSet<QString> unique;
 
-    for (auto &str : options)
+    for (const auto &str : options)
     {
         // cppcheck-suppress unreadVariable
-        const QString message = QString("Options '%1' is not unique!").arg(str);
+        const QString message = u"Options '%1' is not unique!"_s.arg(str);
         QVERIFY2(not unique.contains(str), qUtf8Printable(message));
         unique.insert(str);
     }
