@@ -27,19 +27,25 @@
  *************************************************************************/
 
 #include "tst_vtooluniondetails.h"
-#include "../vpatterndb/vpiecepath.h"
 #include "../vpatterndb/vpiecenode.h"
+#include "../vpatterndb/vpiecepath.h"
 #include "../vtools/tools/vtooluniondetails.h"
 
 #include <QtTest>
 
-typedef QPair<bool, VPieceNode> UnitedPathNode;
+#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
+#include "../vmisc/compatibility.h"
+#endif
+
+using namespace Qt::Literals::StringLiterals;
+
+using UnitedPathNode = QPair<bool, VPieceNode>;
 
 Q_DECLARE_METATYPE(UnitedPathNode)
 
 //---------------------------------------------------------------------------------------------------------------------
 TST_VToolUnionDetails::TST_VToolUnionDetails(QObject *parent)
-    : QObject (parent)
+  : QObject(parent)
 {
 }
 
@@ -52,18 +58,18 @@ void TST_VToolUnionDetails::TestUnitingMainPaths_data()
     QTest::addColumn<quint32>("pRotate");
     QTest::addColumn<QVector<UnitedPathNode>>("result");
 
-    VPieceNode d1p0(1205, Tool::NodePoint);
-    VPieceNode d1p1(1206, Tool::NodePoint);
-    VPieceNode d1p2(1207, Tool::NodeSpline);
-    VPieceNode d1p3(1208, Tool::NodePoint);
-    VPieceNode d1p4(1209, Tool::NodePoint);
-    VPieceNode d1p5(1204, Tool::NodeSpline);
+    VPieceNode const d1p0(1205, Tool::NodePoint);
+    VPieceNode const d1p1(1206, Tool::NodePoint);
+    VPieceNode const d1p2(1207, Tool::NodeSpline);
+    VPieceNode const d1p3(1208, Tool::NodePoint);
+    VPieceNode const d1p4(1209, Tool::NodePoint);
+    VPieceNode const d1p5(1204, Tool::NodeSpline);
 
-    VPieceNode d2p0(1211, Tool::NodePoint);
-    VPieceNode d2p1(1212, Tool::NodePoint);
-    VPieceNode d2p2(1213, Tool::NodeSpline);
-    VPieceNode d2p3(1214, Tool::NodePoint);
-    VPieceNode d2p4(1215, Tool::NodePoint);
+    VPieceNode const d2p0(1211, Tool::NodePoint);
+    VPieceNode const d2p1(1212, Tool::NodePoint);
+    VPieceNode const d2p2(1213, Tool::NodeSpline);
+    VPieceNode const d2p3(1214, Tool::NodePoint);
+    VPieceNode const d2p4(1215, Tool::NodePoint);
 
     QVector<UnitedPathNode> result;
     result.append(qMakePair(true, d1p0));
@@ -92,8 +98,8 @@ void TST_VToolUnionDetails::TestUnitingMainPaths_data()
     d2.Append(d2p3);
     d2.Append(d2p4);
 
-    quint32 indexD2 = 0;
-    quint32 pRotate = 1208;
+    quint32 const indexD2 = 0;
+    quint32 const pRotate = 1208;
 
     // See the file <root>/src/app/share/collection/Issue_#752.val
     QTest::newRow("Case 1") << d1 << d2 << indexD2 << pRotate << result;
@@ -156,19 +162,21 @@ void TST_VToolUnionDetails::TestUnitingMainPaths()
 
     QVERIFY(result.size() == out.size());
 
-    for (int i=0; i < out.size(); ++i)
+    for (int i = 0; i < out.size(); ++i)
     {
         const VPieceNode resP = result.at(i).second;
         const VPieceNode outP = out.at(i).second;
 
         // cppcheck-suppress unreadVariable
-        const QString msg = QString("Index: %1. Got item with id = %2, type = %3; Expected item with id = %4, "
-                                    "type = %5.")
-                .arg(i).arg(outP.GetId()).arg(static_cast<ToolVisHolderType>(outP.GetTypeTool()))
-                .arg(resP.GetId()).arg(static_cast<ToolVisHolderType>(resP.GetTypeTool()));
+        const QString msg = u"Index: %1. Got item with id = %2, type = %3; Expected item with id = %4, "
+                            u"type = %5."_s.arg(i)
+                                .arg(outP.GetId())
+                                .arg(static_cast<ToolVisHolderType>(outP.GetTypeTool()))
+                                .arg(resP.GetId())
+                                .arg(static_cast<ToolVisHolderType>(resP.GetTypeTool()));
 
-        QVERIFY2(out.at(i).first == result.at(i).first
-                 && outP.GetId() == resP.GetId()
-                 && outP.GetTypeTool() == resP.GetTypeTool(), qUtf8Printable(msg));
+        QVERIFY2(out.at(i).first == result.at(i).first && outP.GetId() == resP.GetId() &&
+                     outP.GetTypeTool() == resP.GetTypeTool(),
+                 qUtf8Printable(msg));
     }
 }
