@@ -29,19 +29,19 @@
 #ifndef TST_VTRANSLATEVARS_H
 #define TST_VTRANSLATEVARS_H
 
-#include <QtCore/qglobal.h>
 #include <QLocale>
 #include <QObject>
-
-#include "../vmisc/defglobal.h"
+#include <QtCore/qglobal.h>
 
 class VTranslateVars;
 
 class TST_VTranslateVars : public QObject
 {
     Q_OBJECT // NOLINT
+
 public:
     explicit TST_VTranslateVars(QObject *parent = nullptr);
+    ~TST_VTranslateVars() override;
 private slots:
     void initTestCase();
     void TestFormulaFromUser_data();
@@ -49,11 +49,13 @@ private slots:
     void TestFormulaToUser_data();
     void TestFormulaToUser();
     void cleanupTestCase();
+
 private:
     // cppcheck-suppress unknownMacro
     Q_DISABLE_COPY_MOVE(TST_VTranslateVars) // NOLINT
     VTranslateVars *m_trMs;
     QLocale m_systemLocale;
+    bool m_translateFomula{true};
 
     void PrepareValFromUser(double d, const QLocale &locale);
     void PrepareValToUser(double d, const QLocale &locale);
